#http://bbci.de/competition/iv/
#Dataset 3: ‹hand movement direction in MEG›
#provided by the Brain Machine Interfacing Initiative, Albert-Ludwigs-University Freiburg, the Bernstein Center for Computational Neuroscience Freiburg and the Institute of Medical Psychology and Behavioral Neurobiology, University of Tübingen (Stephan Waldert, Carsten Mehring, HubertPreissl, Christoph Braun)
#
#In short: 2 subjects were recorded moving a joystick with their hand and wrist only in one of four directions (right, up, down, left) of their choice after hearing a prompt, using Magnetoencephalography (MEG). The task is to classify the direction of movement from the MEG data.
#The train/test split given corresponds to the exact split provided in the original competition, with the trails for the two subjects merged, however. Data remains split by subject in the folders Subject1 and Subject2.
#
#From the file 'desc_3.pdf'; a description of the data from the original formatters at the above website
#
#'Title: Directionally modulated MEG activity
#
#Short description:
#The data set contains directionally modulated MEG activity that was recorded while
#subjects performed wrist movements in four different directions.
#
#Detailed Description:
#Brain activity during wrist movements was recorded with MEG at 625 Hz from two
#healthy, right-handed subjects. The subject sat relaxed in an MEG chair, the elbow
#rested on a pillow to prevent upper arm and shoulder movements, and the head was
#stabilized by small pillows. The task was to move a joystick from a center position
#toward one of four targets located radially at 90° intervals (four-class center-out
#paradigm) using exclusively the right hand and wrist. Movement amplitude was 4.5 cm.
#In each trial, the target was self-chosen by the subject. Targets were arranged in the
#form of a rhombus in the horizontal plane with corners pointing left, right, away from
#and toward the subject's body.
#Visual trigger signals were presented on a screen to start a trial or to indicate possible
#time violations. A trial started with the joystick in the center position and the appearance
#of a gray circle. After a variable delay (1-2 s), the disappearance of the circle indicated
#the “go” signal (cued movements). Then, within 0.75 s the subject had to start the
#movement and reach the target. For a trial to be valid, the subject also had to rest at the
#target for at least 1 s. These time constraints allowed for temporal consistency across
#trails and the hold period at the target prevented interference of in- and outward
#movements. A red cross was presented continuously for fixation.
#The trials were cut to contain data from 0.4 s before to 0.6 s after movement onset and
#the signals were band pass filtered (0.5 to 100 Hz) and resampled at 400 Hz, whereas in
#Waldert et al. (JNeurosci 28(4), 2008) we showed that especially the low-frequency
#activity (<8 Hz) contains information about movement direction. The data are composed
#of signals from ten MEG channels which were located above the motor areas. We will
#evaluate the competitor's submissions with respect to the percentage of correct
#classifications (decoding accuracy). Please note that classification using cross-validation
#on the provided training data does not necessarily yield the average decoding accuracy
#reported in our original study because of the reduced number of channels (approx. one
#quarter), inter-subject variability and the reduced number of trials in the training set due
#to separation of data into training and test set. The data are provided as mat-files
#(Matlab), detailed description is provided along with the files. Predicted class labels for
#the test sets must be submitted as a single mat-file containing two variables (vectors):
#PredictedLabelsS1 and PredictedLabelsS2, e.g. PredictedLabelsS1=[3 2 4 1 ...]. The
#name of this mat-file must identify the competitor.'
#
@problemName HandMovementDirection
@timeStamps false
@missing false
@univariate false
@dimensions 10
@equalLength true
@seriesLength 400
@classLabel true right forward left backward
@data
111.129743,176.656478,168.885536,114.513456,110.642422,146.740396,151.982639,88.053454,43.026492,55.154046,73.671971,79.956542,133.738071,163.101268,133.98344,72.83149,-8.74229,65.930605,123.227006,237.671306,268.178352,170.57671,83.954824,-31.376722,-63.232024,-25.34157,108.325346,150.178809,133.416431,97.070493,57.571498,55.856137,52.939478,60.781536,78.51343,165.356449,198.988646,103.206434,-6.677368,-167.973238,-132.599835,-75.596335,0.467245,23.880947,64.402666,69.067589,32.636738,-11.222008,-108.232413,-99.157414,-41.805911,89.381746,111.905008,65.24683,39.268573,10.645312,17.730282,59.833671,176.073405,214.131942,215.41835,189.286691,139.507302,119.853037,98.753132,118.636255,116.62662,40.73424,-21.240307,-77.857967,-35.776936,47.494918,40.106118,70.517601,177.650566,218.314717,293.009572,329.360275,347.525198,318.418023,226.334533,183.424634,198.051669,219.004936,181.905496,24.350399,-61.620466,-201.422403,-235.050194,-213.370362,-147.179933,-95.350902,-15.738612,-48.000411,-191.32284,-208.775099,-113.484408,-65.499706,-70.658909,1.576664,76.759878,117.198602,62.943855,-54.264983,-86.468302,-60.123965,53.795472,94.737421,98.224295,96.238477,151.012696,181.959216,178.058063,93.110501,12.008843,-98.288265,-84.161972,-69.289773,-107.174235,-228.357616,-326.855566,-331.483806,-267.048121,-212.555266,-97.71006,-59.610688,-18.334401,-12.627701,-85.482436,-222.606319,-244.054675,-163.202235,-126.579883,-176.009375,-242.805475,-362.061167,-384.623989,-362.412544,-279.860213,-208.579317,-43.589462,-8.026472,-85.297175,-142.992394,-163.303642,-131.571773,-114.548803,-14.373583,34.910445,-4.448159,-79.266385,-228.770191,-284.076698,-257.53759,-145.700027,-81.174553,24.493885,40.206008,30.410254,26.943815,-36.725981,-192.212841,-236.653989,-156.195246,-88.038423,-90.119986,-149.423672,-261.250666,-269.706723,-197.60404,55.138799,161.680387,227.242377,213.501245,117.918374,13.952342,-184.215728,-130.741169,-54.100324,5.490629,-2.560894,11.862404,33.854625,-9.700097,-136.653,-150.567703,-55.553782,7.185731,53.360662,26.837668,-58.20922,-83.327795,-72.586025,-17.383336,-0.13071,-8.241531,-19.42531,-0.039694,20.490234,-18.960886,-117.860667,-120.8241,-32.567667,26.479739,122.915586,153.193125,177.629499,157.263652,63.773082,49.89906,98.670467,223.843944,253.883963,237.554115,224.445704,183.798947,86.653277,61.823635,144.795006,229.426754,279.071811,207.068957,18.792063,-38.385032,-62.658561,-64.830994,-79.367533,-78.489155,-59.046789,-94.164467,-175.369346,-350.357452,-342.767502,-280.961572,-166.245758,-127.43056,-89.725833,-81.510993,-26.187092,5.606471,-4.077418,-63.983186,-79.733229,-74.819078,-67.944436,-89.710442,-133.199359,-293.708027,-360.831763,-302.181069,-169.903584,-175.124033,-255.770406,-241.66174,-114.91558,-96.138759,-162.014239,-114.050424,-54.1352,43.13332,70.874801,67.41802,46.779603,17.558614,23.118408,43.748655,119.834301,171.779037,247.38287,230.164802,83.843897,13.094073,5.690808,103.897866,123.16217,73.722537,29.745002,-67.721645,-107.7137,-132.243251,-149.049402,-183.347721,-223.882463,-175.767102,-6.665551,43.763957,30.787762,-28.256243,-200.685441,-266.689052,-248.529499,-163.88177,-117.069426,-69.894016,-79.137019,-233.575629,-437.62035,-439.313802,-284.732889,-217.948876,-220.576143,-264.369168,-320.636076,-337.244101,-407.033535,-426.827724,-399.320528,-347.669222,-323.090187,-266.480694,-272.906359,-383.505825,-450.054454,-416.966137,-271.704322,-201.790147,-124.860642,-106.579306,-85.27105,-125.277591,-280.320595,-203.654074,-90.860041,77.239579,114.842862,120.527952,108.675669,53.021453,-57.655543,-106.373263,-142.18074,-120.108942,-28.815502,9.16489,25.133987,2.339798,-41.951661,45.859863,126.956998,229.681046,220.037958,138.603817,110.397605,66.468965,-9.4311,-23.939293,26.451662,53.714682,10.5179,-39.783441,-84.723037,-82.523554,-64.736346,1.730143,43.698844,122.630884,144.284323,86.146507,30.735305,-57.750773,-109.151071,-110.024433,-79.556557,-45.310588,70.938558,108.038861,45.080039,-17.511552,-28.58372,81.3729,111.844459,136.836295,152.31116,181.329532,198.342743,202.055495,164.285223,152.20425,96.758335,53.764206,-8.254868,-14.820968,29.053083,45.311738,10.081321,-9.472532,8.4077,102.021077,153.608834,153.848299,135.029369,182.51072,219.586343,188.445527,154.041104,216.210437,369.31123,372.554174,298.762494,261.693477:80.533307,15.81987,-34.410462,-18.848178,47.128034,130.167802,123.484567,74.33784,56.465642,57.453575,55.000892,81.291638,189.335906,209.622477,111.940518,33.745626,-0.556388,135.727808,193.164677,230.141497,209.746648,99.116464,33.986862,-58.212792,-11.804705,63.407922,162.644755,150.759804,57.599238,21.705687,14.862553,11.378772,-20.902344,-11.864141,18.869853,138.316536,191.542335,156.294975,76.082167,-87.891527,-108.117176,-55.473704,82.289186,117.370708,41.638946,-20.342076,-37.000326,-35.742024,-141.565367,-157.333204,-70.5434,140.571386,205.747384,193.16657,127.689765,-11.86364,-38.431977,25.39309,215.899226,265.542317,222.593812,166.946663,92.15963,87.731538,114.477436,117.793247,92.228247,19.387352,-9.195784,21.259051,75.949776,85.859358,8.567806,19.512382,118.18643,187.433492,324.087713,339.530633,196.36531,98.746057,26.625695,50.093595,65.871411,103.990437,100.828168,32.615588,-16.196427,-151.052503,-228.768046,-201.940089,-112.755145,-105.769245,-173.213155,-215.424808,-254.664515,-237.189199,-135.126253,-45.876491,-21.465424,89.483927,162.416582,161.798665,76.319767,-107.32032,-82.816141,11.239924,186.381736,219.363707,165.135586,105.132082,75.857412,126.640912,212.381326,100.793205,14.222389,-29.790999,-23.527583,-145.270695,-250.315952,-380.914143,-320.060201,-256.94886,-222.141681,-245.906782,-233.085213,-179.107235,-78.698178,-64.839089,-95.920577,-133.270172,-128.653743,-83.338778,-84.1016,-184.248236,-248.493766,-336.214545,-352.934832,-325.006487,-203.455381,-124.246606,-15.218808,-10.696787,-68.039463,-107.108788,-134.955736,-63.684719,-15.527993,73.662182,87.272534,14.752346,-24.554168,-43.240992,-83.725949,-110.086134,-78.356383,-26.791495,40.56507,37.392457,-18.786843,-44.356846,-56.0562,-89.155857,-111.698823,-87.004252,-58.651494,-81.000138,-121.099602,-159.302311,-108.869728,-66.683829,55.89152,115.843912,156.636165,148.086199,47.771723,-51.347969,-168.606438,-77.173802,-25.196188,5.59522,6.993021,4.466318,-12.29634,-92.722373,-136.389138,-110.246335,-28.587759,-5.664323,-6.762778,-29.436869,-100.008011,-117.105149,-64.49374,26.914714,50.424565,78.260435,85.605261,62.44127,46.226919,9.077829,-68.74942,-90.481061,-36.607387,9.704573,41.356546,28.013284,17.176522,22.627223,15.957163,48.882787,109.576407,222.408304,225.018628,137.209511,88.714855,25.105142,-54.668896,-72.518411,62.998387,175.419871,243.232638,177.057745,-29.157152,-119.322304,-174.344982,-113.144708,-106.187019,-142.128455,-147.227153,-139.299437,-162.016683,-247.43551,-229.784697,-183.422737,-110.381088,-84.370324,-44.360266,-45.002653,-102.676516,-124.961458,-43.619626,79.07949,83.160404,31.24311,12.004482,-22.484474,-47.469367,-105.804912,-116.218565,-82.202549,5.997311,23.383667,-43.491478,-85.632561,-63.258943,-30.85792,-22.191031,-17.067055,6.362544,94.86153,137.275997,187.06544,191.677909,167.337568,194.279969,208.220755,211.332618,237.121229,274.808682,235.477765,95.425184,34.955462,-13.328802,109.783902,194.141966,253.841746,220.192775,101.61893,42.080533,-84.118387,-181.540093,-183.282762,-99.607808,-42.274848,18.488085,21.280297,18.829958,5.068758,-75.802933,-143.919939,-128.55832,-31.924366,-11.444338,-40.114007,-48.485419,-112.489209,-303.91734,-363.743518,-292.828991,-216.636785,-169.153246,-204.09015,-292.86232,-327.036495,-366.897194,-358.327473,-333.679233,-277.73353,-270.730091,-283.970643,-296.979925,-376.453185,-458.953093,-453.310632,-359.869897,-308.058622,-288.580509,-315.848594,-341.351339,-337.132545,-321.856228,-222.292122,-163.804184,-138.448968,-151.604022,-142.794915,-128.610409,-124.963905,-107.865464,-96.866267,-69.212096,-32.755182,30.872915,32.875315,-19.991982,-59.271963,-92.282869,-72.091122,-50.357708,52.491223,106.603783,140.978105,126.848103,52.221829,-21.163877,-13.10207,85.682079,115.950182,13.825344,-84.6889,-221.724578,-242.557499,-205.460462,-113.905305,-55.228931,80.401625,106.686779,34.967819,-2.714886,-43.340358,-68.663464,-45.106942,53.233529,109.565987,174.42496,152.812399,50.80487,16.015488,40.628475,156.139184,223.524079,301.980942,289.626256,215.627407,176.860356,93.872841,80.221645,106.151478,161.248157,179.838826,148.36192,96.471475,-9.536356,-62.96392,-121.6618,24.612229,136.213672,255.026194,235.837525,149.658678,137.455113,127.946518,80.377214,90.750175,215.944923,291.371314,341.724226,310.844902,240.356774,219.970208:-152.989498,-78.493896,-44.659136,1.939469,5.499523,-47.400893,-65.521278,-17.588123,43.85049,62.306829,113.787955,140.794652,147.873823,129.283091,51.412405,-7.710665,-58.209609,37.671095,88.932251,144.024669,143.112768,72.06314,11.798023,-89.655998,-39.702641,35.44088,140.84289,139.41622,60.864241,14.86779,-62.443702,-113.153554,-173.887737,-32.73141,90.637848,283.650382,296.562719,205.972109,150.989517,37.780351,24.240305,74.422928,170.606553,191.14651,169.049213,127.67403,1.188599,-85.771937,-254.414944,-215.50846,-100.030232,129.394043,169.615919,132.009666,102.017882,53.989277,55.145149,81.225978,160.757071,198.03012,188.974332,124.944615,-29.532353,-53.092402,40.5024,127.699375,126.532139,85.087196,68.029652,80.123599,104.075002,114.806647,105.828496,131.699826,238.738005,276.944248,262.199621,236.416635,146.330283,61.676592,-37.258576,85.683494,135.448384,47.834144,-24.818665,-44.56569,-46.856157,-190.97358,-253.632431,-194.619605,-78.904048,-71.707551,-147.543379,-192.91057,-222.866248,-218.719379,-198.505843,-165.444081,-129.203312,19.679198,73.194736,-10.328694,-80.520781,-85.470914,-5.686823,10.34745,30.585057,69.438729,124.386875,117.175928,93.783107,78.896769,51.783027,102.81399,134.146618,166.229333,156.249,-4.238097,-128.669618,-261.644802,-165.70984,-116.71394,-159.542356,-190.132264,-113.716723,-40.865822,7.893074,-23.228076,-76.972765,-64.016348,-34.090659,28.326501,16.171048,-113.206582,-194.885024,-288.43351,-259.883601,-236.434219,-194.709419,-147.244167,-24.056572,-2.512644,-72.810497,-122.566967,-105.952559,12.585165,45.107446,59.658831,50.692011,15.580568,-0.324233,-44.82948,-94.307647,-88.636396,-6.211758,32.712416,33.862159,17.956423,8.582631,-17.207061,-146.197999,-234.287672,-213.525134,-54.192633,21.123667,28.877714,-25.06189,-141.033742,-124.420745,-55.2134,90.297601,125.104095,140.881538,150.276637,110.78682,39.509525,-49.004677,48.781199,97.065964,113.676718,106.742236,78.624783,34.263407,-88.84693,-78.839592,-20.175355,40.802741,3.16675,-97.718018,-108.524765,-112.042166,-132.7688,-128.692958,-6.816258,52.629154,78.86358,53.555957,18.841757,26.32094,15.55683,-64.099874,-77.567984,-28.210255,-11.856761,-23.16549,-29.311294,-60.711361,-80.470468,-25.487652,85.60713,104.052042,103.200154,106.01366,71.792041,16.473442,-78.47823,-75.099611,-52.180585,66.606812,138.247469,107.639779,1.107759,-205.900202,-258.446195,-249.362888,-178.283852,-146.082617,-105.172972,-103.296751,-153.175902,-216.320022,-322.784117,-224.32522,-140.974327,-55.037606,-54.885171,-72.549259,-64.472171,-31.403749,-25.107975,3.104632,62.525332,85.755601,103.120245,90.422372,50.893098,32.059806,-34.904224,-75.044945,-62.273127,-14.487431,12.260431,36.247041,24.185325,-24.531362,-55.679409,-84.887239,-47.412629,-7.302674,107.849972,136.517881,106.088445,103.271523,140.257321,141.328706,141.742581,166.334458,177.275688,181.604403,179.986055,102.003675,16.316567,-34.502442,162.451443,239.104871,235.063855,184.24518,71.751681,38.110036,-21.072404,-148.865047,-195.779599,-106.252914,7.14513,112.940532,69.343326,-43.561236,-74.754825,-116.945109,-113.379761,-81.16322,28.696778,78.590883,111.57089,90.672882,-20.016348,-146.604269,-170.575514,-138.618356,-112.571594,-106.934427,-136.133719,-230.457184,-284.829882,-354.392199,-333.356826,-309.613273,-258.945347,-248.494825,-298.961052,-334.973223,-367.335421,-346.307909,-310.390079,-232.839228,-219.100894,-257.768405,-283.721005,-317.517955,-340.113465,-333.570778,-174.111363,-87.932053,-78.098375,-141.408202,-214.264636,-209.745504,-182.770699,-98.349971,-57.571985,-39.584615,-21.401401,42.616562,48.662365,3.1741,-21.884559,-30.96949,-3.676169,27.941849,121.297788,137.410254,80.615129,50.125253,9.185082,-21.208465,-35.847869,-55.229465,-42.623908,-26.299086,-44.400693,-126.947811,-187.689955,-246.10206,-108.520735,-14.632961,66.504211,37.042829,-45.625922,-57.843588,-45.338087,2.650459,30.307568,77.598609,112.29738,199.225749,226.96137,208.635242,175.621244,141.384244,181.71879,213.660643,277.803394,288.979022,225.751003,175.476398,89.321972,58.478934,91.346563,196.864942,216.331237,149.435183,92.742736,8.804932,-15.018419,1.328541,102.599149,163.37182,252.622872,246.289481,130.713635,84.577769,128.725234,237.463198,260.561998,294.799986,335.021691,374.143317,347.211523,270.745687,234.688034:158.920473,113.786088,85.615855,52.200679,31.030882,-32.753159,-51.666374,-64.098022,-88.183899,-97.345383,-49.154554,18.098376,140.752735,157.215485,140.607371,119.630728,80.418923,124.262497,166.03684,217.17754,194.989546,40.862593,-52.954553,-202.247925,-198.585807,-124.182537,12.222003,18.200576,-85.688939,-130.1001,-73.042178,-14.198741,22.224539,-17.239928,-30.096208,12.498187,58.36381,72.083733,8.174867,-159.612239,-136.456656,-52.006768,112.272112,167.241961,204.168758,181.569739,106.914876,64.201915,-33.725863,-37.01035,7.646416,128.219577,163.656418,100.500722,30.397438,-57.254751,-10.532235,47.194572,126.241665,149.074911,186.436959,179.330316,135.929386,123.843557,121.566105,100.50521,67.56055,-32.007978,-77.793729,-75.509358,-31.688589,-0.757314,-17.501194,15.383215,150.257339,230.877126,355.197661,370.842141,322.415418,279.212956,197.821148,154.249599,149.104924,137.349716,103.885641,-15.116307,-84.499838,-238.444018,-286.250236,-238.276049,-114.07639,-74.44913,-72.102518,-97.16653,-121.517168,-131.260311,-192.527616,-240.656454,-237.415847,-119.379941,-24.788806,-0.381899,-101.062252,-267.289909,-153.311637,-56.721746,38.49518,47.962854,75.766973,98.779177,130.523624,132.685279,145.21637,177.197848,165.325638,104.929881,64.154253,-90.363089,-178.59502,-296.929453,-299.962525,-251.922084,-153.102308,-128.240297,-95.623298,-62.057773,2.578028,-15.108437,-123.8073,-165.126676,-140.880553,-30.650671,-0.637775,-111.644607,-209.300213,-309.902742,-246.801671,-207.808167,-175.816755,-130.309912,34.004633,86.683287,41.589481,-34.895438,-138.030736,-74.54526,-0.211754,137.469154,143.870023,17.67715,-46.512401,-111.044065,-160.660406,-171.897218,-104.509606,-23.404203,88.941372,71.819172,-22.363782,-60.264833,-134.646287,-198.284664,-201.629898,-121.846924,-63.164314,-14.999198,-32.832036,-112.679989,-125.271121,-64.157017,88.215191,132.261542,183.385296,206.580697,183.904546,111.837268,-39.445349,17.77665,91.810314,166.748528,169.030191,172.176386,165.535365,61.633436,-39.277872,-20.852903,92.717246,129.609617,77.858987,4.841477,-102.39317,-100.757186,1.785783,150.558994,196.292447,154.023805,89.810317,35.503265,37.694391,-49.034887,-153.968007,-138.299636,-27.607918,18.963674,64.286565,59.521756,10.078714,-12.346012,23.567567,177.273885,248.615966,279.95016,241.669401,127.114496,65.060501,-77.805401,-165.478239,-130.558187,45.899358,118.368231,115.056209,44.461325,-120.099266,-196.016649,-289.050267,-213.215862,-177.849103,-205.497225,-208.358002,-167.583216,-193.702277,-350.104997,-340.918711,-258.049479,-144.458756,-128.188663,-69.446185,-18.766346,3.800522,-55.117398,-161.191663,-90.481319,-29.443448,58.72249,75.402154,53.171388,20.79113,-55.368014,-39.757,-10.016021,-36.529468,-75.700885,-84.377549,-64.894555,-78.272892,-115.608093,-170.483689,-153.023997,-138.830353,-81.408401,-32.472111,73.757774,106.764797,61.742496,-4.990486,2.200481,48.076861,88.423399,175.300953,171.758139,44.123885,-32.670887,-68.275912,17.885411,38.964927,36.570819,26.175639,-60.179212,-129.390094,-241.42542,-312.120183,-329.586173,-253.958441,-157.079796,-7.414775,-4.763333,-95.395836,-151.376953,-215.548791,-205.218568,-175.317283,-98.703464,-80.273058,-75.392461,-79.691118,-173.448431,-286.04901,-267.327141,-163.368917,-143.811549,-169.892405,-171.297815,-168.547543,-222.044477,-379.994425,-394.129711,-351.39674,-257.738604,-245.768106,-293.566591,-325.290912,-378.624963,-350.696161,-306.975339,-233.555331,-210.189212,-150.844178,-109.356843,-77.945675,-119.08434,-193.609501,-99.482338,-40.904389,13.506492,15.659412,-11.935551,-30.861202,-48.524117,-31.167558,-39.339139,-92.489847,-86.304068,-8.515912,10.579448,-18.572821,-34.643673,0.370768,68.288616,71.258189,64.535808,75.023715,63.933861,27.299244,-70.304196,-97.096567,-86.398769,-86.298237,-90.107619,-110.268956,-148.481439,-242.804058,-266.932846,-254.262053,-167.398666,-95.54753,43.611019,63.706304,-3.23708,-48.099956,-100.547764,-89.531916,-59.364749,7.76945,32.129559,68.874414,74.50335,34.973075,-4.669452,-0.772742,189.28501,269.314557,292.750975,276.664945,251.537824,214.147196,63.823485,14.780256,72.536054,176.185216,156.986397,41.884672,23.723416,100.206855,116.406199,52.240096,33.346818,69.1611,220.756559,292.847499,304.7426,262.649255,180.267233,133.34834,142.327994,248.269126,333.531444,443.841941,404.918429,208.788154,131.305234:-65.494423,17.060809,23.610819,37.490314,34.152889,-88.454729,-168.921483,-237.71915,-242.94089,-227.693272,-69.43222,47.597376,147.331998,118.621372,44.418244,26.751604,38.035022,75.487308,87.679057,111.909773,108.064579,14.78537,-62.369106,-180.319336,-128.350163,-50.424873,101.87851,137.63143,67.180944,-10.77728,-122.441333,-134.303382,-81.984552,1.34564,55.603923,175.179238,184.747253,50.641367,-46.81704,-181.439742,-160.480894,-85.834766,132.169652,227.465321,288.807032,265.710349,154.587247,54.467265,-119.086816,-28.873099,81.255766,226.852884,214.72065,49.910444,-37.97787,-106.575035,-67.954571,-3.936576,184.494124,249.269219,241.481763,191.672435,78.232629,43.401666,60.940667,103.008734,110.928985,88.644572,42.33477,-76.075843,-113.940709,-114.865951,14.200478,105.905972,243.935435,283.734725,296.363525,280.945458,256.001289,216.792318,100.806255,144.08296,208.112516,230.675804,170.851168,-11.000075,-121.814912,-322.993053,-250.90991,-138.523459,-21.087537,-22.925012,-51.262735,-70.252814,-135.821337,-185.644584,-257.073918,-202.858252,-146.483792,-31.468033,13.251339,1.34378,-77.594041,-234.701893,-115.033638,-17.202415,52.183275,66.964834,130.171891,155.287195,165.561433,145.840116,102.812418,173.721889,228.933878,271.62777,244.037345,87.540456,-20.323626,-196.049431,-228.744957,-195.604852,-89.794909,-53.027096,-42.397569,-39.0476,-60.66764,-122.227542,-201.616155,-65.017921,10.262642,84.371845,86.280158,-30.755854,-140.985804,-292.379928,-247.79065,-198.217492,-109.657289,-52.608562,47.810654,53.146471,0.670558,-34.942154,-65.765292,46.730703,130.652117,209.821986,173.331582,17.801381,-52.458604,-122.965571,-86.333833,-53.266974,18.358854,76.386638,146.228414,108.977263,-53.224053,-128.791371,-213.573195,-176.599719,-117.475194,-18.805862,-16.03169,-78.082011,-123.820362,-226.964956,-179.325562,-82.676249,100.894072,155.884793,204.278908,207.698366,170.071965,112.19518,-22.649641,3.378559,67.234068,163.867649,172.004864,151.757951,144.823552,73.933691,-42.285718,-49.120273,48.746809,105.378954,91.307082,10.664656,-139.213943,-161.283288,-135.940279,-50.735968,-3.075835,36.605725,23.590342,-22.656941,-45.713149,-106.414612,-148.058123,-143.69189,-60.74484,2.357291,72.241254,71.74643,28.24342,-13.353715,-54.41932,42.450623,108.54621,198.011614,206.246644,133.853716,50.032775,-164.104104,-264.537171,-232.688189,-44.163479,38.773995,8.240376,-85.828247,-293.929862,-361.941146,-338.4889,-203.400476,-174.710456,-182.900675,-172.127388,-148.525332,-179.188444,-296.888151,-306.953488,-254.58406,-133.037602,-81.259179,-7.426631,9.542811,6.242837,-20.864823,-42.710484,55.787804,107.783267,150.262959,127.67605,50.956567,31.924277,-1.942535,-38.203018,-18.894392,64.841641,94.775149,133.849943,127.337716,-20.936704,-128.462329,-196.206111,-35.351698,56.111517,139.923689,137.02257,134.901947,143.947636,135.724244,131.488356,145.069393,165.466827,178.953332,199.124828,173.61438,57.174651,21.578481,65.638878,133.044339,154.753221,193.630873,183.271844,41.110917,-50.269058,-140.818806,-189.546863,-201.513353,-63.795913,43.275625,98.820018,51.970919,-57.53833,-102.666883,-111.191889,22.717169,92.212537,149.252746,131.760414,69.600601,47.363,-47.570936,-180.277716,-183.078113,-42.296488,29.265284,13.096014,-46.281798,-149.762278,-218.504053,-373.375224,-305.015681,-182.470311,3.767263,0.638206,-131.932096,-204.105403,-294.617866,-247.439226,-186.577742,-110.008203,-101.585827,-97.616538,-109.12364,-213.468048,-283.619821,-308.809037,-166.684597,-90.740657,5.683182,23.38957,-21.150236,-76.734306,-159.200005,-104.609189,-62.671351,12.648639,66.252798,105.294869,56.823837,-39.142363,-41.359489,-14.671784,-2.747585,37.016035,149.793852,133.264264,-33.917926,-86.109495,-109.343237,-100.469238,-68.727888,-29.002318,-46.567179,-106.067091,-126.296655,-143.996269,-159.654862,-219.43062,-211.936504,-145.113865,31.419119,58.29421,-58.317444,-124.039211,-129.78997,-65.638845,-42.572964,25.833197,72.071088,94.055848,61.07417,0.790392,1.118205,83.92983,207.018076,254.21072,325.424889,326.900737,208.828015,120.902445,-25.999135,-54.050859,5.742584,177.338056,214.563122,139.824755,83.700875,38.364385,12.31113,-56.115484,24.958942,117.672406,271.784944,289.330318,251.453496,237.724361,209.101132,179.366095,196.848583,300.545444,353.693088,373.491032,337.068763,212.271236,143.39951:30.317042,113.198682,124.166723,106.351386,93.361359,87.187124,99.54631,66.336426,-38.94995,-62.284146,-4.772995,66.923893,190.385542,205.599296,154.074859,108.355043,60.182208,78.356684,60.826227,42.134062,73.161648,57.67447,-21.466685,-163.464234,-102.543313,-28.414751,48.311686,51.434652,56.979987,68.112877,97.590866,93.048208,32.562714,34.43401,75.304659,167.470862,165.303241,-6.429603,-123.911102,-244.344333,-152.059822,-57.290078,95.363255,131.513835,145.49742,126.151455,56.202358,6.985765,-123.887946,-140.023523,-54.555579,140.792556,166.426937,68.799205,-2.390779,-100.796393,-62.562825,23.661794,207.66983,261.507301,303.054516,291.966493,195.338771,125.89872,42.239317,97.467483,131.584146,75.611749,-6.496676,-77.89546,-26.798006,58.763176,3.081654,7.622733,124.111055,191.248261,333.960305,393.873272,407.968603,356.260145,232.221996,160.645794,135.71035,140.976258,139.487708,-2.118799,-118.706195,-267.790256,-206.037932,-136.892489,-52.029429,-39.485814,-47.417648,-85.73193,-191.539757,-209.15615,-197.497561,-233.171126,-222.465918,-58.886985,33.986186,45.094535,-21.670386,-122.620267,-132.795405,-118.325861,-38.557212,18.428529,98.176796,102.299168,69.354614,49.833135,20.477438,4.222025,-10.3279,-29.964556,-40.27125,-82.258503,-93.962954,-140.51695,-254.297873,-272.982198,-172.705256,-80.905307,65.281872,103.621852,138.729143,97.814402,-107.818559,-189.460166,-147.966762,-40.25314,-23.927706,-112.398709,-203.188479,-350.025091,-331.265418,-295.70816,-246.109351,-190.215049,27.220909,107.826599,50.837414,-49.130307,-186.717669,-122.92786,-59.706002,2.795014,-1.892904,-45.479829,-83.76072,-189.91199,-259.037212,-249.516283,-154.34362,-87.039244,21.761905,34.726346,-13.645027,-45.546209,-87.059625,-116.977105,-127.568891,-67.925922,-14.547251,-58.697656,-168.082849,-350.091676,-284.910352,-178.866663,38.631113,121.026427,222.136759,236.961942,178.413508,101.48377,-35.15132,26.210939,108.91966,236.236991,255.052701,201.862591,149.237194,84.492248,144.77856,206.86364,310.478602,317.303256,195.16308,99.820543,-5.687116,3.437711,59.183352,93.703035,95.072838,141.228482,208.56852,271.270666,218.399803,34.436985,-64.533029,-45.265454,46.359532,77.487904,129.058898,168.342294,236.718393,231.694517,171.286556,172.156303,212.381918,370.919907,428.999427,348.125686,251.204349,87.063062,-8.831387,3.801073,174.069933,272.779151,309.8615,234.022371,55.849457,9.987366,-0.508064,20.500215,0.206669,-78.58214,-94.180587,-116.217857,-166.061435,-343.621573,-444.187267,-404.36818,-259.858033,-215.739751,-121.613739,-26.378085,170.05934,174.679547,-5.205782,-98.079892,-55.53591,104.992804,150.383444,74.376261,14.864795,-10.511876,-23.839476,-34.811085,-26.590641,-20.998663,-4.718756,10.853901,-14.049212,-75.740267,-218.567813,-220.699565,-160.248495,-25.762018,11.228202,28.024927,24.885989,-34.764129,-166.675889,-191.709492,-74.28935,23.994247,135.829994,135.961363,68.364249,13.951522,-26.290021,38.357796,54.41531,65.589986,69.637658,-11.610151,-90.885708,-192.033704,-214.345761,-228.342403,-219.451488,-165.533561,-16.006534,30.594672,30.086387,-13.107949,-109.805809,-107.806423,-92.016502,-63.080419,-32.771892,-26.321939,-97.895193,-293.133388,-338.323271,-294.136027,-163.0707,-112.458558,-88.427197,-106.287235,-165.396468,-218.224981,-342.834254,-326.400645,-250.89253,-83.888757,-45.842822,-97.720205,-160.434573,-298.823779,-357.094183,-316.704581,-156.605783,-93.122604,-71.731449,-90.357572,-78.055194,-54.532279,-57.753864,-78.643081,-62.060042,24.465543,56.27446,63.169097,66.848719,81.078445,41.620191,-18.511021,-158.162415,-166.931338,-42.222919,2.426577,-45.449005,-90.403791,-98.052916,6.161335,52.062555,69.23148,50.964491,1.635428,-16.252356,-37.913767,-73.098142,-92.038589,-108.068651,-84.659833,-38.298126,-70.041639,-189.799101,-224.84681,-225.762191,-144.153947,-66.561552,99.78839,125.429654,-8.226323,-101.080298,-174.121658,-188.026787,-211.294939,-210.762982,-155.415831,-36.747364,-31.700126,-97.023167,-114.622067,-48.576285,66.592404,99.347386,169.268302,200.303576,154.007572,110.153253,101.658909,137.280761,136.752572,82.228433,43.673482,-25.219935,-26.150781,107.39296,176.191178,147.20092,81.580809,82.345772,101.830198,115.938155,120.55264,98.32445,61.09742,72.237888,82.696759,181.657369,270.738256,354.23817,312.324689,156.896238,85.411937:30.660383,131.260607,161.329612,178.598176,164.951193,48.008854,-33.228852,-176.51457,-225.303908,-176.50826,13.32574,105.584524,220.553329,232.445574,151.987656,78.53923,32.310489,178.981395,232.228393,243.041387,226.448886,119.425718,30.7362,-128.169273,-157.808397,-97.897166,73.832832,128.903822,137.284827,108.556308,50.208069,25.542933,-17.845054,8.652478,71.524018,243.612629,273.028655,106.589328,-38.612408,-260.150271,-224.717043,-113.993491,156.740323,262.444568,328.380385,296.086637,155.600677,47.265811,-147.374623,-90.129841,13.826917,170.669466,173.374704,49.705834,-36.22112,-151.090788,-70.696096,29.871389,226.745089,288.217354,266.744603,204.596433,132.338571,117.366539,53.072321,49.265722,89.809828,122.014647,64.361397,-86.408957,-106.872269,-107.539749,-142.197665,-110.367574,92.951604,216.255134,346.900644,330.252467,217.259577,150.960859,52.009132,78.553951,123.739845,184.474231,170.586267,36.038375,-65.713452,-234.381173,-200.69106,-130.330376,11.686656,60.573299,48.419471,3.413404,-99.874944,-166.858332,-290.794513,-273.389448,-219.725481,-74.367867,-12.628943,-30.477063,-105.517161,-250.52123,-252.716111,-192.762143,-8.138873,85.385391,173.456373,144.622064,7.73632,-56.498502,-84.605939,27.120512,87.949485,150.235302,133.398277,-32.879149,-156.245223,-360.057908,-376.352031,-312.686954,-162.653096,-105.748062,-51.6403,-58.979756,-120.616289,-153.116893,-190.860826,-166.543925,-119.865709,32.1613,85.711542,-37.895112,-193.447981,-405.059164,-321.636225,-230.330308,-60.728465,20.249946,141.82502,153.320284,74.756505,9.601084,-72.820654,-16.272633,42.588162,130.405008,138.584729,97.613296,59.66413,-54.332519,-125.944523,-96.033732,69.01487,159.137102,200.23831,142.429934,10.108444,-38.994471,-130.309692,-176.80292,-148.706646,14.621595,82.586442,3.544451,-123.106281,-342.255403,-285.462043,-154.086294,122.52844,227.223048,389.002977,434.939131,361.777819,239.390275,13.257652,33.399216,114.461175,283.934967,327.210537,272.45514,203.906848,104.772478,79.867888,100.674977,226.214816,294.334998,274.12538,183.587072,36.062403,20.293127,38.064759,92.38174,149.737849,266.069973,284.268284,214.147617,129.902221,-96.604775,-155.631187,-77.150703,107.903191,162.064958,218.906702,229.30238,225.474097,209.383416,188.24938,289.205744,365.789019,474.746478,467.339464,251.577204,83.174969,-171.604607,-137.444837,-25.905671,182.962543,226.586207,182.730822,110.421261,-60.753869,-134.899091,-222.908779,-153.732952,-79.990205,4.883875,6.417431,-52.600053,-128.029046,-352.705666,-425.28298,-332.238357,-54.107593,41.680957,108.382833,109.924591,94.834136,76.991064,71.633058,125.645737,155.521876,222.949732,236.872676,210.056836,194.194459,108.883058,-13.129529,7.077798,198.10746,273.655325,275.599078,222.402071,53.053182,-44.355194,-134.260882,-20.469419,63.52742,195.758405,221.154791,160.72944,97.831256,-11.373188,-22.637353,11.649283,144.76617,238.775876,318.650069,245.197293,21.998755,-37.765182,-11.14617,74.05794,94.463922,109.911955,102.374468,1.325781,-84.714555,-242.582955,-283.842691,-245.883202,-93.481531,-3.097937,97.54454,75.881002,-38.879181,-89.76889,-93.380258,8.768617,34.277363,37.783026,42.944622,3.901198,-70.542934,-243.174247,-245.772963,-188.720427,-84.151352,-57.15625,-51.875052,-58.874222,-112.024823,-190.229059,-339.098908,-244.268516,-134.117322,9.704617,-0.402927,-128.42309,-214.223211,-374.887086,-367.812405,-286.768339,-108.627554,-60.382531,-76.224041,-135.380832,-273.739822,-310.762692,-275.364566,-148.324278,-84.269269,34.543227,59.907514,-5.777909,-61.30384,-158.479851,-214.062397,-205.414313,-115.221777,-52.376155,-23.330666,-91.12837,-259.597421,-297.102007,-258.204266,-139.726222,-66.561397,56.716318,59.811457,-75.267493,-176.89553,-343.340407,-353.674732,-311.473774,-222.02947,-187.286002,-161.090216,-188.871651,-308.160969,-369.98639,-439.95969,-360.447811,-245.771594,1.266803,26.753536,-142.526233,-225.550491,-268.947547,-267.175599,-247.00489,-110.41561,-4.928377,113.527209,68.988704,-111.885527,-154.771561,-85.295363,55.232496,124.917282,257.52834,281.521903,182.452027,83.969954,-82.441021,-49.263087,18.543613,101.019545,100.114158,52.301989,47.47935,126.301963,142.678592,42.010475,-20.056734,0.197645,70.407064,85.485846,62.462835,61.129566,66.871782,55.510181,100.090304,264.183533,309.373066,242.999108,165.343,10.286707,-59.741196:83.532751,114.076543,121.155051,123.678198,131.90346,155.937898,173.400274,216.547488,210.004775,207.833487,220.132505,209.371609,153.466146,134.547265,170.99556,192.753034,118.699276,-17.910888,-47.684577,44.176446,132.919623,174.033591,111.103949,9.072825,63.931739,108.728901,119.730552,102.044362,115.848503,153.183164,234.115184,230.70138,97.924356,-35.933964,-62.370138,-38.223192,-3.183411,3.931027,-39.706482,-137.512724,-172.628245,-147.679606,-27.849754,37.666844,113.336688,108.071681,37.22589,-15.761809,-157.826592,-232.656722,-204.17367,-82.730621,-38.064573,-48.239525,-81.176399,-119.432693,-53.388944,19.984743,102.530827,92.773698,83.75069,96.380452,91.494352,62.954433,-6.164216,-69.661976,-91.154287,-119.362504,-139.977669,-144.149426,-105.021405,-18.095231,-26.142986,-40.248374,-28.111871,-9.783167,62.496759,127.156544,242.75244,238.065088,129.215992,98.919395,106.689012,91.994285,76.891261,31.206158,0.93041,-57.617615,-56.469291,-12.97305,87.809414,100.489464,62.50296,50.065916,45.121808,35.71893,14.057947,-26.171193,-53.646505,-6.549843,80.207354,184.543823,148.960472,17.428612,-43.194688,-53.617746,-105.011235,-119.748178,-45.956729,-15.083585,-100.41326,-162.633143,-127.042859,15.45871,19.005951,-70.661256,-84.207273,-30.780275,-30.916723,-150.468966,-168.890315,-95.525922,24.499565,44.008937,95.126939,148.153766,195.701631,123.897196,-103.217276,-161.834633,-135.796704,-73.824955,-44.878327,0.516976,-4.625762,-100.33361,-243.104983,-298.894159,-327.813785,-279.461284,-66.424753,31.650483,19.165123,-75.628531,-185.279015,-83.170659,-40.550746,-22.606144,-8.770116,-11.063482,-52.785357,-144.378932,-156.81718,-130.71452,-44.097026,-6.140581,10.236234,0.764782,15.526262,25.426206,-40.999115,-125.379502,-113.308197,-39.134971,-29.080095,-120.598649,-205.59429,-338.089047,-280.647305,-188.44916,19.732208,102.3995,178.670482,197.767799,216.751089,172.661168,26.946274,40.663831,94.495815,182.08274,196.070047,82.017645,-13.021445,-40.104738,138.048752,228.096348,373.877404,427.316544,404.813072,320.846427,170.187069,137.289584,96.737359,116.329559,144.892931,175.203097,183.107675,179.360501,152.445254,64.117619,11.291058,20.370055,50.724601,57.554594,107.631434,163.664909,284.777125,290.634891,138.74467,52.106015,98.187461,244.251295,281.78822,257.230114,227.697907,156.234611,100.187475,122.469432,225.919938,264.872017,276.431563,253.98472,201.823009,177.011302,98.519225,35.765643,28.934491,11.35733,-5.012343,-28.136885,-53.729362,-179.594627,-252.303299,-216.826262,-78.888842,-18.74972,24.773901,30.416841,95.243803,115.006004,30.390062,-30.532433,15.340938,178.894258,209.957034,118.496681,70.643829,43.583654,17.781683,17.840372,59.012972,70.38473,21.431485,-24.247707,-106.216023,-153.656747,-253.677413,-234.73978,-185.236567,-107.556947,-88.500428,-61.692442,-66.179955,-165.827725,-232.936076,-196.196117,-63.939613,-6.422448,74.730548,104.26412,103.126138,54.028883,-18.962709,46.631325,60.611304,14.910753,1.043862,18.803728,43.72441,105.383162,84.659276,43.632644,54.956932,143.942865,337.373517,370.275041,306.538559,231.202843,80.347469,91.933605,136.196281,187.564427,181.661393,86.167649,4.545451,-173.203686,-204.777686,-117.841426,104.755078,155.969576,123.361627,74.992247,-9.798522,-28.324509,-20.710685,-10.64952,-15.639571,5.619698,26.815808,-2.734136,-67.325435,-233.866735,-305.836957,-278.451884,-120.282132,-15.537355,87.588281,61.335004,0.055757,2.015124,20.885881,21.510982,20.676404,65.056882,112.247789,164.877306,133.20984,-21.646239,-131.546786,-139.259888,-143.80517,-151.276766,-126.187735,-107.282122,-82.467902,-65.165552,-0.342923,124.197885,167.079756,124.798671,76.725452,56.591565,81.078999,57.134112,-64.667999,-87.426908,-63.434072,-57.894283,-75.996848,-80.80693,-68.377685,-75.046314,-116.301701,-80.117987,-32.439941,54.553916,70.164895,21.259603,-22.797073,-110.248865,-201.140098,-238.321926,-244.029938,-199.547352,-117.461966,-113.979178,-113.961422,-104.922204,-77.209737,-33.200253,-47.971616,-121.02781,-113.046208,-24.680744,0.167877,14.066769,50.292301,64.488586,53.613486,46.624099,83.10541,118.530031,199.33605,227.792798,164.656071,-2.228246,-34.717372,39.87497,85.557482,117.952577,107.536448,34.686153,18.921924,50.460107,112.109036,148.901458,238.880164,234.478234,76.891884,-19.490725:74.642068,66.748549,79.208919,143.085044,172.074857,211.459277,236.757359,242.472201,167.026821,152.273949,198.011319,227.505445,221.78752,179.059789,93.917343,87.220482,72.276223,-22.302742,-34.344587,117.977269,225.433645,247.07215,156.643323,18.34187,40.627659,56.785729,47.352673,46.781823,74.329777,88.352573,131.620179,147.576819,96.85877,69.440922,98.005546,163.143302,164.994612,50.627824,-44.835745,-177.927649,-133.88071,-75.674312,-10.160784,0.819543,35.4248,46.444194,2.626789,-61.951844,-198.963487,-166.116932,-102.599431,-21.324649,-24.479072,-77.600637,-100.639544,-125.096808,-68.86176,4.390032,103.263404,92.601015,53.641031,76.541692,172.76281,180.735754,79.905852,-24.515819,-48.934842,-84.660286,-114.947152,-144.958767,-114.912322,-69.132294,-117.263934,-114.782767,-33.388617,30.331812,202.709325,278.801248,332.807738,317.457389,243.637282,179.727016,168.448784,182.499292,189.818502,163.505348,127.218657,-2.892025,-87.708177,-59.541816,31.979572,39.713422,6.582161,-7.250081,6.068738,44.272568,129.411259,119.672473,83.704319,90.315135,150.414945,200.640841,148.510972,6.797927,-23.014841,8.721595,73.084936,91.064521,115.271712,115.668802,140.341268,164.097419,100.700407,-59.210465,-97.210045,-41.313945,16.388544,39.171312,-6.876236,-110.665377,-147.41354,-132.83603,-67.190388,-34.306544,-2.304095,-0.959091,-0.361177,-21.193808,-148.878662,-298.010272,-333.829873,-214.848632,-104.419923,-93.874967,-206.146386,-380.298051,-320.684518,-292.237121,-357.323306,-369.608111,-257.856627,-213.903341,-266.022381,-306.015295,-264.983935,-163.859894,-154.067242,-163.338576,-151.82769,-144.151413,-170.27548,-267.972875,-316.738028,-279.451434,-147.879806,-93.321148,-6.089389,21.717706,-19.925027,-91.572976,-232.090436,-248.031759,-222.527855,-162.785634,-145.009066,-189.16715,-248.933629,-358.919469,-334.905988,-257.94516,-32.667074,76.850457,208.405273,223.035137,143.079776,55.498678,-73.455625,-24.797862,17.489166,80.683863,101.767794,70.159948,30.39759,-13.277567,10.893462,55.462502,177.332246,210.724136,166.326058,109.134986,15.78542,-5.124943,-27.155502,-41.470647,-47.164831,-11.296292,44.589996,123.200788,113.705768,60.941051,17.528047,16.576536,102.302183,173.035999,253.808326,254.943794,276.470183,296.952063,260.37931,174.127197,167.216874,247.543511,300.098779,318.998907,288.985872,201.496553,132.552675,133.537085,188.942047,220.174166,230.774448,203.807167,154.701558,142.370763,78.625818,-7.264397,-26.636206,-18.255864,1.763333,17.944382,-12.583054,-156.153132,-297.468337,-302.161365,-167.071696,-80.197844,39.705383,63.386394,29.195435,-19.360615,-96.252652,-79.155856,-47.661321,28.257834,50.725476,11.85845,-47.847952,-200.151094,-269.68943,-231.802191,-121.257984,-106.786169,-146.65852,-169.256627,-170.509198,-179.734276,-280.836326,-263.047815,-174.193811,-8.758561,23.62974,5.811515,-20.864401,-67.416961,-66.469164,-42.129628,36.23282,90.317358,184.072821,188.498468,97.753014,38.457443,1.485944,52.196863,65.065213,39.673877,7.42621,-79.781049,-101.198798,-44.252194,-7.889172,-46.762273,-138.346543,-105.898319,108.278011,184.179345,130.402977,40.669646,-65.500694,-20.50766,-3.773085,-6.723465,-9.820552,-40.686932,-86.930222,-252.527512,-356.225966,-316.199418,-145.991967,-92.324473,-99.592652,-117.891492,-106.329881,-107.321078,-174.794224,-193.684807,-166.11172,-115.440698,-106.58381,-131.270222,-187.421054,-346.78548,-341.091404,-256.234985,-70.786023,-10.472625,46.592336,62.938692,78.448135,33.091169,-143.878483,-137.518041,-76.189734,56.715838,140.462654,273.226173,276.924956,156.94164,-0.077616,-46.751557,-75.224782,-62.840844,-16.400233,-8.074196,-4.361054,11.677426,42.001684,91.258625,135.693054,173.976043,167.091046,192.210543,218.054105,165.101957,-20.408595,-59.391235,35.739578,93.406476,91.341405,52.3549,-16.283166,-52.6529,-85.272296,34.127637,117.491234,200.36372,189.545536,121.453872,81.317006,-34.03246,-168.527901,-189.962021,-168.296897,-140.397778,-16.088397,42.672767,30.548861,-16.572511,-51.900939,-37.5276,-55.654652,-46.354348,17.129614,139.21302,152.008405,130.882079,114.767537,92.59029,16.50781,-6.168231,31.201004,66.403641,94.913967,90.503807,79.563937,65.420597,50.098045,40.79641,48.559223,32.236352,15.764882,56.740921,181.393685,196.445157,106.359161,97.087469,215.528619,257.871091,194.468242,108.542721:-34.829832,37.293815,74.700771,96.918634,92.857019,63.772149,51.390373,19.713363,-9.411667,23.907568,134.851309,143.44552,72.503414,76.615313,206.216101,237.461384,117.896821,-24.992301,-32.446932,63.356108,111.029613,97.001937,51.037389,-34.008221,-18.630172,35.761507,98.107091,72.251152,67.578792,133.930203,236.541319,195.242526,17.457933,-3.507722,40.246764,67.264658,31.592287,-38.961237,-53.900421,-109.85186,-161.728072,-117.143902,69.814853,127.669176,108.120316,71.405264,27.41365,0.604311,-97.28929,-65.257076,10.610202,96.270892,66.080906,-41.216072,-47.858248,-5.068295,-38.903492,-20.718776,163.107424,248.411805,251.284933,196.203688,130.329079,125.129707,77.219779,-13.068145,-49.533444,-38.905373,0.612332,6.615193,-29.175464,-63.533873,-37.74025,0.634571,94.992029,132.148079,205.73229,239.484059,262.009854,231.496445,118.28396,85.35689,87.257096,67.365448,56.820769,17.701902,-27.557369,-96.059136,20.268147,99.425599,96.406268,47.161385,10.955528,8.811852,-34.752044,-70.050335,-95.574374,-87.599648,-115.835612,-127.993257,-86.602436,-42.225476,-56.027053,-98.488496,-110.866778,-98.396287,-32.59139,13.60055,57.008729,42.33819,-13.020903,-52.246827,-122.75368,-87.807893,-51.65654,-28.313603,-33.61155,-52.353199,-81.114642,-168.412226,-203.962798,-168.337228,0.857683,72.783119,104.397656,94.062566,90.362426,85.640281,10.128982,-77.774592,-63.378875,47.429173,73.699271,28.397119,4.236585,-64.544356,-150.459296,-128.260193,9.774515,73.228319,129.476725,112.44891,42.226806,20.196231,5.521296,9.5314,13.139338,58.985622,97.836356,106.635701,62.293455,-70.552875,-119.41114,-75.95318,42.578338,68.966784,18.562949,-31.663019,-38.736664,-8.20364,-13.930837,-38.727508,-25.285071,69.396839,118.139281,-0.320093,-163.100547,-386.116021,-285.965069,-149.011935,137.506606,234.887001,331.133882,345.730777,261.636936,149.463577,-33.688348,42.409877,110.326773,157.825511,153.245335,122.27853,103.356951,63.498058,16.948207,37.940462,191.74483,264.717562,256.998366,193.776336,132.083657,147.770512,137.915505,81.411983,72.376284,129.528904,190.137736,221.370239,152.505306,-52.656713,-111.788706,-39.60889,146.945708,178.58648,161.390786,163.033614,211.78489,214.326674,104.985161,41.155188,72.614154,179.467443,204.782841,149.645232,94.170686,-27.224947,-49.543044,17.99725,179.031222,214.665974,177.318779,131.514239,54.372623,11.369393,-128.278679,-211.467799,-189.564082,-94.379362,-64.951833,-118.228061,-187.217615,-311.52672,-374.296694,-356.925115,-219.823435,-129.4141,6.008584,44.249923,141.600927,180.389148,77.344986,-54.696407,-1.631329,222.749558,275.555957,186.390991,102.805044,-12.596272,-26.771479,1.172006,83.776897,122.72501,127.599756,67.048901,-112.674335,-195.137731,-275.893334,-171.060252,-105.994111,-101.590781,-136.421427,-128.766597,-81.303735,-57.123605,-145.854088,-169.818419,-160.402909,-124.193446,-35.152065,-27.107059,-33.30971,-9.488373,39.567188,18.957795,-5.564027,-49.699282,-72.500953,-126.848553,-145.692901,-151.6955,-164.818194,-183.48509,-146.96018,-74.969327,79.875268,125.74614,119.823677,69.734181,-36.553238,-3.213701,37.856842,81.467306,82.585914,-18.830227,-118.229177,-267.690011,-216.207184,-149.242942,-82.799808,-69.68792,-6.094058,19.575929,-11.698579,-62.261723,-125.119484,-44.276375,1.771461,36.488868,30.979656,-11.195203,-40.229511,-134.971191,-245.907717,-252.60926,-151.302961,-69.609994,73.52108,92.240802,44.518102,11.394824,-51.590355,-92.13783,-84.306307,16.649124,65.686344,47.936993,5.512486,-46.28026,-107.918775,-164.098826,-207.436353,-170.037008,-141.670449,-190.546163,-254.834656,-216.075659,-78.313672,-23.906442,-33.968528,-21.226053,2.380135,-30.289295,-75.912301,-108.74506,-77.042649,-85.984244,-174.1922,-196.466278,-132.85862,-102.618368,-146.460543,-201.392286,-289.505138,-235.284452,-147.610632,42.736086,67.358254,-71.376922,-146.920497,-178.43995,-156.51153,-158.083931,-133.160603,-68.223755,36.406811,-4.056158,-114.104703,-96.918061,12.432534,88.48188,108.294862,129.910813,130.074315,73.195074,18.337269,-85.628109,-84.563168,-39.775011,42.01603,58.621973,53.168559,46.362948,88.77326,115.216891,80.217909,37.822531,37.564121,55.445922,85.532305,171.554002,200.471802,157.005571,92.117786,112.46596,145.900981,139.39113,158.490012,154.694632,45.963114,-25.873812:right
-64.057189,-37.377601,-66.00475,-154.798895,-155.869091,-38.385626,26.675689,92.013493,61.711734,9.709656,-80.892502,-79.843022,19.569436,63.861405,53.262188,50.520428,110.387649,114.857971,84.488422,16.085079,7.72399,73.764129,114.418594,123.575923,82.0376,81.484335,81.196323,56.089267,24.375591,26.578453,-18.352367,-55.534885,-54.245435,25.873613,32.99625,-106.583931,-194.736139,-215.475362,-166.506946,-83.952592,-84.782504,-118.904166,-200.704201,-223.634588,-222.064288,-198.295085,-94.923022,-24.648928,53.058372,13.93294,-4.582619,-27.085114,-50.799041,-84.283512,-74.992539,-6.885027,80.298435,90.131263,33.410844,-17.257162,-115.856219,-128.475975,-66.068204,-19.387393,58.302182,59.54293,12.579309,-114.455945,-151.865051,-114.706968,-46.136762,94.760924,59.916709,-43.981753,-253.696166,-294.782426,-274.499325,-255.007402,-194.291527,-137.908881,-67.544411,-99.067753,-111.913217,-102.762233,-55.305113,136.527405,213.366743,282.61673,252.073291,169.584552,-2.635756,-44.562108,-34.862875,18.508927,142.957703,163.809935,87.321008,-73.872029,-145.673385,-261.011971,-286.788421,-216.219407,-152.889578,-69.282111,-72.800819,-83.638982,-33.872297,-9.36189,-64.747355,-101.705061,-84.881511,-45.408525,1.827569,6.60046,10.7379,-17.68527,-25.557582,18.668668,41.987604,125.55457,251.871925,254.946496,159.935114,115.711589,56.798225,42.303119,81.237886,147.096962,300.533055,354.289573,338.59975,239.506143,191.745247,223.628086,282.160256,330.075443,289.093916,291.295949,322.395948,310.227821,254.403995,248.433805,271.639555,252.690294,109.318829,-41.934607,-87.951645,-130.920544,-101.503989,62.512886,130.33381,143.577458,87.689991,59.146032,-21.02529,-55.946402,-6.552429,72.670735,201.043263,236.497751,235.781309,125.375977,77.310797,-13.707339,-68.35909,-132.496252,-136.063509,-139.69192,-179.568983,-215.978833,-317.298541,-365.786339,-392.983986,-375.602247,-319.911094,-269.989113,-177.466625,-271.093663,-348.286168,-367.936989,-302.99849,-134.040412,-75.045045,-36.537299,-71.53837,-88.406986,-26.273477,35.258546,88.320776,69.743509,23.56582,33.642054,91.767378,42.311376,-9.104826,-52.701945,-47.172484,19.466519,105.657952,322.78872,335.750218,239.062257,0.779811,-89.384088,-135.907935,-100.305724,-13.137381,28.429784,80.943033,69.416273,59.018847,-1.717614,-51.359222,-95.614872,-70.203881,38.715088,95.907153,73.316831,11.218042,4.302923,27.876444,36.175197,24.309351,31.496281,93.323688,47.718062,-32.411658,-185.305527,-211.230592,-104.465826,-16.075293,58.974231,-24.489228,-84.124199,-159.464296,-185.153226,-249.904279,-258.807795,-180.920243,-117.581067,-47.442464,-86.488742,-140.424447,-330.428503,-425.726084,-500.778574,-482.430017,-386.116032,-332.479918,-318.272147,-216.056873,-164.504497,-118.607467,-94.234921,-104.007265,-158.042473,-231.87771,-147.309038,-83.963821,-53.85988,-86.220193,-107.609482,-60.267932,90.056296,79.901562,-14.519008,-186.590695,-228.334405,-253.396774,-210.664412,-38.176267,16.939626,-8.29996,-12.421076,36.330281,60.580176,-0.968577,-125.982276,-133.142365,-42.041341,45.947579,54.809,19.854495,5.830579,32.744002,61.172105,157.458489,228.712227,301.52762,183.58641,74.501468,-140.308848,-199.092581,-204.780621,-190.54357,-134.264154,35.930281,114.294359,89.501596,16.132551,-43.593423,-26.9569,-24.847152,-30.549897,-5.965068,-45.453889,-96.083813,-182.727397,-202.44982,-165.184263,-116.873748,-20.36479,48.765042,57.508416,-1.042655,-57.718448,-114.057998,-72.486217,75.711527,127.109408,128.544566,36.453577,-1.857921,-48.9551,-50.773834,0.315114,22.085735,35.353569,14.740344,-9.882422,-47.977862,-78.592606,-159.396816,-165.107051,-109.237143,-77.97916,31.486545,184.946819,186.148184,-6.426746,-112.074081,-167.149994,-140.390723,-76.312742,-28.590452,-55.969366,-220.987042,-290.720195,-270.450865,-212.481009,-157.783722,-177.240893,-270.43425,-353.574898,-356.44233,-292.488549,-238.171621,-62.204447,45.615535,187.273513,152.682892,94.921132,-21.685598,-81.817033,-203.205031,-243.840478,-272.514543,-258.48296,-172.334858,-58.93246,-7.708994,50.967159,55.807386,44.070208,55.954315,155.79239,176.026733,122.073378,23.808436,6.808819,-15.103626,-26.933619,-9.398721,17.952697,15.545312,-65.867897,-83.463901,-101.895732,-119.423764,-121.569175,-91.841536,33.916925,171.097132,200.062872,174.030427,135.823037,63.519538,62.769831,185.704819,274.690282:59.202975,137.644764,71.193838,-101.147131,-96.138855,68.593147,145.244119,142.669577,-12.072073,-66.867179,-121.272584,-152.599475,-156.853223,-107.828774,12.416585,54.299824,51.399842,-60.624849,-97.799247,-86.807775,-63.331541,3.002329,43.001215,91.387323,68.106364,26.577032,-63.443173,-87.380387,-70.453628,-36.34701,-15.890376,-59.955146,-166.468886,-136.331178,-110.792827,-150.07424,-172.951411,-139.640897,-93.040936,23.973426,65.085006,44.539242,-6.50638,-47.095911,-128.347422,-108.613335,19.633343,69.672209,131.941876,172.627197,144.721345,-28.121553,-94.070188,-36.661567,30.244068,92.679237,85.300291,61.654969,5.243854,-9.640442,-32.801648,-48.225246,-30.828836,3.521658,44.957526,0.46693,-45.700171,-138.778932,-143.765108,-33.520044,36.886382,99.441382,18.96051,-45.185121,-108.942002,-117.417276,-161.568297,-186.608801,-157.919773,-110.068705,-61.787447,-98.760511,-147.80672,-223.568065,-176.844208,76.807071,183.081731,229.82827,131.703339,56.483199,-49.348857,-77.062626,-110.228576,-80.69812,116.042957,224.167329,236.41022,5.592364,-108.351943,-228.016893,-208.551304,-69.963135,-12.256278,37.760643,-5.946628,-43.874979,-73.132601,-84.409722,-140.566463,-173.882522,-177.400546,-119.797432,15.29969,-21.46709,-90.404753,-160.716681,-116.395059,-5.700358,-14.633954,-70.390683,-6.76435,42.92054,104.289615,96.538011,11.542693,-9.840254,81.296972,157.287887,210.957887,173.767673,178.944459,222.05049,235.39668,253.182779,265.44348,269.513755,234.654325,225.683521,220.279911,195.29999,139.072069,141.821275,173.986535,166.488238,34.42169,-124.646639,-149.374914,-164.241801,-169.001977,-112.121507,-52.387468,39.444692,57.687103,58.112837,-1.010929,-45.108103,-7.33772,77.782297,212.889622,215.714651,146.543257,118.948332,104.226218,-10.114393,-69.021691,-51.008177,4.726472,45.405585,-38.651234,-82.842223,-174.768716,-234.736035,-296.860096,-260.111455,-117.122684,-64.020818,-67.241986,-231.674666,-317.596129,-335.723752,-271.257736,-111.755284,-49.58969,19.436935,-32.011875,-57.378434,-8.884447,7.506928,-9.87254,19.085049,150.993933,203.308245,221.064436,141.974197,92.645066,29.614347,26.858014,80.139311,120.481654,171.677724,134.748574,82.616333,-57.115778,-121.272891,-168.695403,-144.359896,-37.778763,13.706671,26.527434,-26.730001,-49.638115,-120.562433,-164.234705,-227.504654,-221.123877,-86.333913,41.838201,43.136631,-29.700874,-73.747911,-148.908069,-164.719035,-76.400415,24.984873,146.336742,-31.151955,-175.601197,-387.889103,-415.66013,-306.864849,-209.753267,-66.784165,-102.099122,-153.193118,-264.098892,-335.432903,-401.262459,-349.011667,-203.336995,-181.363044,-249.429587,-332.27957,-344.922039,-368.460304,-386.394848,-391.832508,-384.501461,-343.310968,-282.523876,-254.605783,-190.838855,-171.282493,-116.098658,-72.657869,-84.052226,-134.777545,-189.895702,-163.024495,-150.10657,-157.602381,-168.72345,-168.754515,-125.874766,27.674942,4.638431,-68.100506,-151.584975,-180.762082,-251.171957,-238.839013,-95.725084,-36.179015,-58.118437,-58.408598,-5.268609,1.261963,-60.51722,-149.229111,-152.520254,-110.734379,-108.440549,-131.774713,-153.266443,-132.242752,-13.32959,64.047365,211.259191,270.475278,274.69139,136.339204,56.439602,-60.165181,-75.110618,-45.826186,-32.395321,-24.880209,11.297786,52.362853,77.471531,21.262651,-96.896343,-81.153678,75.843398,144.9869,152.160275,25.73599,-59.138207,-192.949349,-195.293528,-56.758682,23.8453,98.61767,128.507396,131.524371,91.52537,64.493391,40.413137,39.949973,71.439326,112.296207,131.844912,60.189061,55.191872,58.296683,34.049971,9.214513,29.340476,62.031201,10.512401,-29.278372,-128.713969,-202.838833,-302.128874,-276.66368,-133.542975,-53.060142,91.988999,125.272724,71.540675,-126.472858,-200.518519,-190.704644,-149.230397,-101.94738,-106.152548,-123.505294,-202.953869,-262.697676,-229.133274,-88.955133,147.127905,137.197943,8.005638,-15.903025,-18.510777,-89.962979,-106.062274,41.733476,169.578268,359.683069,316.87768,226.000757,58.289872,7.466102,8.886129,48.359333,85.671041,83.278981,105.895098,123.442273,113.135109,88.609731,100.349841,208.845107,289.285413,390.26558,323.92378,260.79477,153.693827,110.951772,83.158207,115.142526,214.451467,232.267562,114.507736,-78.750641,-118.542636,-82.913626,-54.64991,-16.739457,22.266698,142.052267,144.315013,91.912272,1.026701,-11.766388,59.866966,140.257242,313.206599,363.12287:149.622888,69.848468,16.108532,-42.320556,-24.317332,90.44267,150.570636,185.574603,89.429655,31.580318,-44.222169,-64.22163,-62.318047,-48.326203,1.14779,47.082824,123.527798,103.744931,73.918066,-10.503059,-52.006715,-39.449212,1.847345,-12.982139,-125.59648,-137.763959,-88.636266,-78.847195,-108.512029,-116.633416,-69.649821,-46.202017,-112.764265,-223.709362,-246.50969,-229.726108,-186.253962,-52.594061,25.510692,169.296513,132.495983,44.75458,-35.432578,-3.777767,51.450012,62.16456,127.743266,177.263279,201.896714,100.131071,24.830032,-100.874324,-113.452614,-46.870272,3.893374,87.609159,113.816758,108.25807,23.405214,-44.824697,-97.688745,-75.636463,-23.111618,-11.431325,-35.405671,-73.718366,-103.639072,-166.111597,-161.139392,-99.70765,-68.530824,-42.38527,-126.234051,-179.48068,-227.552204,-237.11865,-248.093412,-241.200615,-180.322784,-126.256051,-70.718066,-152.488807,-199.765421,-178.593956,-100.098516,73.01639,113.313584,91.706983,-44.464113,-132.42077,-216.458622,-184.267486,-35.459949,29.317986,111.594627,141.513582,134.398205,-29.295797,-153.56066,-336.090658,-335.114736,-177.040506,-93.804348,-58.096917,-184.279041,-251.894535,-286.28707,-262.002781,-220.254835,-202.816576,-129.475151,-94.621015,-77.395418,-74.228099,-83.0089,-106.96231,-81.605394,-7.229744,-14.00789,-61.943244,-41.516079,-26.214532,-36.332383,-43.528704,-28.876236,-28.673365,-20.774708,20.211802,96.390759,42.891183,-6.088083,-49.007761,-16.28081,116.372178,162.629877,146.267486,91.721394,77.361639,28.262285,-7.742126,-40.648494,-27.256073,30.113341,43.010833,-41.356906,-127.680667,-113.740274,-77.829722,-71.599504,-3.770426,63.767397,156.13316,71.583603,-28.830842,-198.669334,-182.760957,29.302878,132.676877,257.555433,297.596447,277.221455,104.400104,31.534493,-33.619114,-37.54913,36.974471,95.930114,134.8475,24.787347,-50.712242,-191.323336,-242.476292,-227.706396,-159.611314,-23.320288,3.753964,-59.433242,-249.446615,-330.979703,-296.932131,-196.722188,-54.287289,-39.260039,-25.692912,-4.263677,13.977312,63.51671,59.685531,35.101122,71.265453,215.891921,266.085194,271.331602,185.682643,123.965378,34.865832,29.218311,78.499902,112.665395,139.069932,89.123851,65.4889,-10.390431,-78.595416,-104.133111,-23.485319,136.867379,140.983416,-1.09791,-130.920059,-146.3853,-189.827732,-236.622069,-247.245401,-170.494078,14.263584,32.04875,18.344579,-26.695186,-109.308434,-300.24443,-302.450256,-88.077265,34.734026,105.860154,-71.531111,-198.465088,-388.849595,-408.055422,-295.992208,-220.695687,-143.823744,-198.432208,-267.545097,-395.002816,-424.997935,-380.410417,-312.757582,-201.377558,-201.101792,-306.334119,-388.990526,-389.205752,-415.123092,-452.986844,-431.60166,-346.158098,-184.656177,-214.770721,-256.667821,-246.230976,-201.244813,-119.50216,-98.02438,-44.691429,-3.918938,0.461499,-94.995639,-127.391661,-132.910283,-112.617115,-90.830207,-86.67113,-23.459119,-24.649955,-78.17614,-164.147604,-159.769662,-77.359706,-50.283343,-52.745936,-31.174007,52.068526,42.273892,-1.53064,-95.186725,-115.454887,-106.930559,-97.466903,-62.584533,-51.903717,-68.986746,-106.341124,-112.157361,-57.248452,13.923761,204.517988,281.1513,293.2253,162.495001,87.204681,-43.341073,-78.695975,-71.347527,-38.496613,47.058778,70.077351,46.319505,-52.710894,-101.672838,-89.950926,-26.255387,118.641286,167.78265,164.577194,12.876046,-68.660508,-130.913865,-103.435694,13.843515,60.463887,96.42528,151.231295,199.925258,252.558649,219.259286,114.698274,105.450889,204.393501,261.152404,230.087656,92.52301,58.333492,61.773957,78.725414,100.439595,78.881985,-31.461402,-79.783439,-69.268631,-124.742488,-197.277525,-250.423166,-180.320124,24.588696,76.999651,53.541562,-34.594365,-87.791855,-222.480573,-278.011783,-267.145248,-204.739627,-78.167468,-39.112921,-62.096439,-231.556721,-334.794843,-294.590624,-121.390042,236.334644,319.733183,290.163025,122.559387,39.897,-1.218927,57.57841,230.114999,299.278429,388.387539,350.249975,280.723741,133.940526,89.399735,126.814564,185.651998,246.811084,250.617453,318.278628,381.641052,328.583093,179.514383,185.680544,347.058039,422.103631,466.835567,385.612968,310.600991,151.708776,92.394652,37.351524,46.748579,120.135257,150.875328,138.41251,69.199242,25.659897,-41.768506,-24.381823,106.099029,174.876423,251.906346,175.764032,103.665604,22.335555,36.260092,126.913823,166.892677,284.458488,373.297497:19.848987,32.02073,-8.10616,-90.511037,-96.2636,4.681752,90.644111,208.636039,166.220628,125.929132,81.089642,69.517341,93.219744,134.148899,244.635539,313.76251,387.169269,250.190102,168.663826,122.90347,145.413449,204.667336,207.826286,111.799188,17.500451,14.91351,20.705976,-8.717543,-68.222541,-59.744728,-34.249118,-49.661648,-113.107178,-127.785449,-112.830822,-111.250911,-112.525909,-47.472336,12.192668,153.215709,189.684775,126.732433,-3.499105,-37.809556,-67.895147,-32.157303,112.964736,167.849844,204.153942,156.971348,116.772078,12.182106,-40.580891,-59.455126,-21.782929,83.212109,132.5318,112.354982,-5.495662,-72.548062,-88.254538,-41.929367,-9.26474,-28.499433,-40.767431,-58.278119,-92.610778,-167.865024,-183.626151,-153.667997,-113.42692,-29.286693,-66.287531,-138.000096,-296.457133,-350.111843,-362.840456,-332.097484,-249.448089,-203.52362,-116.955789,-71.17791,-61.369298,-44.41786,-19.378773,87.158608,146.949433,207.795179,133.042659,38.845979,-146.068593,-188.90139,-151.09804,-73.890027,104.870228,143.126517,55.727716,-143.189566,-222.263663,-316.653322,-339.170885,-310.837943,-261.966992,-134.664536,-109.714392,-164.896503,-292.343279,-318.492881,-269.026331,-212.818288,-121.917218,-94.657533,-53.379432,-62.09307,-79.771279,-89.782082,-61.368206,2.877374,-7.808099,-44.081272,-11.987372,-7.812986,-50.590006,-86.428677,-160.981795,-179.813931,-128.98384,-52.483578,105.301081,139.886987,111.639926,4.733401,-25.548993,40.058331,112.39685,240.275647,259.407701,234.058359,158.837737,120.472973,78.444575,87.117315,128.824367,116.528842,-24.393488,-147.882091,-158.435038,-136.987267,-104.777715,30.993308,103.548265,153.229282,54.665355,-15.333608,-106.028342,-107.894923,-15.421107,69.778143,244.576704,308.516873,335.453303,179.953422,85.437943,-26.808902,-47.422737,-49.645109,-60.02378,-131.524705,-193.421891,-218.564353,-316.519246,-380.366722,-420.043363,-387.129316,-300.056373,-270.268953,-262.54837,-327.704415,-370.267469,-365.185638,-292.642841,-99.800987,-24.48093,40.139215,10.72403,-4.401019,22.132128,28.151763,-4.756393,18.49256,149.549907,183.165663,123.720922,37.535159,24.196849,14.235561,4.598388,55.450211,134.34402,289.074961,244.423698,165.192963,19.766745,-31.942024,-57.039672,-29.551118,56.08845,93.86662,81.485566,-12.213898,-45.895107,-140.339932,-201.134638,-236.974996,-193.457251,-61.855204,-25.154375,-39.833238,-86.123369,-129.212291,-213.394665,-202.97893,-55.083403,18.89113,21.857111,-104.868696,-174.300206,-300.400831,-335.26859,-262.76987,-155.918917,57.300418,45.043211,-39.832887,-233.690346,-319.164111,-369.999206,-304.600194,-148.949191,-138.396757,-214.800315,-294.574811,-346.846893,-484.798174,-524.670789,-475.678785,-415.697549,-295.606161,-273.682229,-314.818086,-341.981514,-295.932832,-160.722817,-104.712945,-75.350328,-91.380631,-125.935374,-197.503192,-230.499305,-219.991544,-196.584814,-167.042003,-139.497299,-28.052748,-51.674904,-133.15788,-201.689537,-174.459229,-138.290864,-144.563277,-139.838126,-99.910808,22.68718,104.040203,110.356214,45.796664,-6.184342,-86.698988,-92.775039,-20.008417,27.589464,20.528844,-17.825983,-51.261033,-54.476507,9.148146,212.491944,311.610473,357.005851,169.79317,60.360377,-113.420771,-156.430415,-112.665127,-51.899502,63.970947,149.413265,175.889579,121.481673,30.742993,-120.487686,-107.145383,63.06497,135.346602,129.818691,14.458289,-38.55381,-114.448484,-124.943759,-89.271218,-65.014279,-16.200189,47.249596,75.972097,97.783592,82.018738,40.128304,44.667046,126.382079,179.859211,188.208871,64.889017,16.844038,-16.326383,-13.140782,9.418109,19.231226,30.167039,36.708329,30.318718,-57.378519,-138.381225,-270.221442,-281.481898,-164.646984,-64.851448,51.640092,21.253955,-4.653624,-91.818246,-150.74329,-216.057339,-214.362975,-179.522736,-131.754635,-124.506338,-189.058574,-249.338508,-274.354199,-191.672089,39.465759,98.014869,21.491156,-123.668412,-142.241068,-119.767703,-99.080533,28.410525,126.470195,246.387452,165.202223,90.838611,-26.865879,-86.50847,-203.124073,-225.310412,-163.346462,-88.167859,71.195332,107.141076,85.577949,78.762902,115.112782,215.062321,243.992007,257.63339,209.750859,166.794363,78.388056,38.441406,8.544459,26.668874,84.634389,93.994013,19.200264,-58.32627,-41.643221,32.391409,61.25938,109.093142,129.528495,198.031461,268.111298,262.460873,194.256775,165.749723,202.21754,274.818668,450.750611,508.303098:154.986077,73.887696,15.351281,-23.115441,-10.980506,43.622961,105.986715,258.859042,229.423774,149.709556,32.708389,37.843768,169.038297,242.909107,315.70836,327.707879,304.864275,170.850534,93.783106,20.993052,37.186008,109.453641,125.576404,114.039619,54.003372,1.095678,-88.759592,-106.157508,-67.619959,-18.088278,37.590797,-1.357583,-176.165808,-253.079866,-242.625488,-199.788216,-145.421078,12.66705,86.728797,226.823965,224.617539,141.860657,-34.896541,-83.809981,-47.566941,54.590106,277.180603,304.372603,189.053322,56.245146,10.157452,-67.859289,-90.459832,-91.011023,-67.489575,33.918806,81.037377,45.23581,-84.197893,-126.719792,-49.740978,29.069172,54.568074,11.927582,-67.889553,-159.84932,-219.72812,-360.155103,-394.455518,-277.338626,-147.783159,25.147722,-135.783091,-268.239693,-439.741384,-460.556042,-345.417454,-228.596101,-52.786379,-40.152315,-123.209389,-197.644075,-186.246499,-103.213675,-65.619941,-14.573903,15.696399,77.751066,5.083132,-78.375656,-219.33837,-244.718322,-164.861611,-78.311463,73.819276,100.056921,15.256354,-169.908777,-268.183815,-406.220182,-403.802504,-290.04541,-237.586474,-202.689129,-263.378283,-322.9843,-424.012341,-435.759098,-314.205116,-194.318921,0.00692,32.153911,-18.176871,-100.818876,-121.706358,-105.228449,-46.26353,73.702789,68.595359,7.649004,-25.999679,-62.209402,-154.76679,-178.851108,-189.432564,-196.607137,-148.104876,-71.925888,33.035212,-37.004056,-87.868237,-123.562491,-90.386053,23.441003,85.925114,202.022517,165.154461,92.668267,-53.810162,-101.790399,-93.925997,-52.280664,41.6137,70.592625,-16.606386,-193.10825,-219.443013,-153.517607,-89.678741,67.975587,133.289154,166.533587,50.46288,-55.010371,-260.239408,-280.407741,-90.27491,37.181808,187.69477,218.857039,181.900454,-3.537884,-100.777103,-195.269596,-172.182486,-25.09663,32.508127,-13.38254,-181.329631,-246.473859,-329.976546,-370.289305,-395.67673,-347.647241,-154.906194,-75.52554,-119.209033,-325.536486,-394.586053,-377.629462,-300.935731,-107.455671,-21.901198,62.795391,28.420066,11.56356,-25.248561,-63.666401,-83.699487,-32.858281,99.991335,121.310671,37.934878,-95.575081,-152.705935,-209.855417,-174.6715,10.135282,95.131464,141.78192,48.189959,-11.088099,-117.315153,-165.507245,-123.631627,-15.149528,169.458362,178.737985,52.049308,-104.367088,-151.793227,-235.267182,-280.111928,-260.890063,-171.273182,-10.66762,-43.780221,-84.809666,-169.163703,-218.051582,-237.315551,-183.411927,-25.160702,35.130239,39.261454,-117.892357,-211.696743,-320.286502,-311.775426,-177.08625,-86.693596,7.601075,-101.643466,-185.022834,-290.3764,-331.606493,-379.446247,-349.956317,-260.819763,-264.937783,-370.934674,-437.424303,-446.764564,-491.749285,-504.956309,-423.884328,-340.233135,-185.163393,-202.699304,-267.952246,-307.312873,-241.664513,-58.653293,-10.362438,-18.987802,-41.379745,-82.455969,-145.005513,-209.240314,-332.989411,-334.682634,-248.580125,-194.205569,-80.283672,-96.865557,-154.139573,-211.415418,-187.838512,-77.31365,-37.236262,-52.109687,-52.51227,50.692425,111.778241,70.483567,-49.444757,-64.667933,-28.654374,5.640501,111.65008,118.712811,74.93842,-4.853707,-33.4157,-16.392127,48.769283,234.44104,311.123454,282.716226,29.818265,-82.159482,-145.550122,-102.149908,16.93542,59.504008,164.378636,238.750412,202.23917,15.035317,-71.246053,-96.99915,-37.742875,122.076671,179.275143,187.496095,72.162089,-7.561516,-95.65734,-59.330249,98.678514,159.37406,200.326963,219.136289,240.996367,234.177424,195.13241,165.224014,202.251892,332.316835,384.011517,316.838203,87.178439,7.224776,-23.202309,-8.466253,5.99491,2.414358,-1.528168,23.34622,15.949403,-126.944212,-221.313278,-281.962371,-249.044182,-125.101989,-60.645361,-2.057863,-88.045161,-181.964345,-322.365369,-323.99485,-248.13483,-189.91228,-45.624109,-9.441042,-64.220209,-210.951031,-248.966114,-155.259024,-20.676474,238.551638,284.308558,190.166942,41.157932,14.192784,29.691221,51.443318,126.647722,196.134131,341.123546,310.5671,238.789891,88.762252,33.767091,27.713291,75.643088,177.034545,187.872963,155.325116,192.329104,198.708032,147.643954,161.646412,297.770913,333.937759,267.37529,178.613536,152.92184,73.54527,23.908744,10.427791,50.518386,132.002887,143.112261,105.045244,111.654064,109.641032,-2.189227,-29.318315,125.322629,229.058396,277.850573,173.476193,129.593604,77.922821,92.762297,283.038418,391.782338,449.406315,417.579282:-96.396393,-191.960074,-231.439678,-141.693563,-57.03376,18.648626,8.848916,6.641416,46.318872,46.626884,27.114529,45.17229,137.837937,171.290154,178.648875,187.503275,242.494756,265.203287,265.62578,216.374857,172.591048,166.185996,196.738094,195.530634,91.871142,55.287569,100.183448,139.907155,128.915063,101.228101,62.165814,41.979767,12.983365,3.650219,-21.228526,-150.711633,-215.948505,-208.391063,-146.004075,-25.632554,-3.256404,-28.702499,-106.491899,-155.47826,-206.896668,-168.909661,-18.552335,48.428697,100.9075,71.227374,63.084773,45.436842,29.222613,47.85215,76.654061,114.925082,109.90747,68.357046,-40.569207,-66.4404,-29.514862,13.564524,58.129652,64.230631,91.842918,60.281598,5.057874,-119.714358,-150.744278,-99.042559,-30.393519,90.097877,37.719064,-60.739636,-273.816261,-354.274575,-430.02592,-389.714119,-194.821052,-123.64035,-116.111631,-124.105009,-88.954332,-17.410489,3.194723,99.064839,184.930013,321.537213,258.520099,161.014796,-36.930017,-91.143291,-60.782756,-11.23759,20.60967,16.917681,27.851065,-106.383667,-225.402245,-419.890844,-459.41499,-391.632462,-330.037973,-258.197145,-227.749682,-219.641827,-209.860219,-221.46202,-284.207369,-295.371134,-208.021449,-128.531688,-12.305512,17.024868,25.275266,8.97002,-7.623673,10.834795,43.185822,113.367808,112.299107,53.628505,-114.948393,-181.740389,-232.494664,-214.295217,-133.189481,-72.098098,71.703209,117.982801,100.8138,23.058698,-11.807821,4.630041,39.21333,107.30135,215.348697,260.738624,256.592627,219.534652,167.258034,173.979756,219.097876,216.108604,100.036977,-30.811629,-58.838919,-68.499485,-33.731961,164.641879,264.391899,270.246827,148.103816,129.38088,151.29223,151.067301,144.284824,177.69569,300.068679,342.048554,301.760596,112.177079,26.217972,-67.444376,-97.776755,-134.078177,-136.620265,-174.495911,-276.432018,-313.193854,-317.979158,-297.794253,-232.573593,-190.52901,-103.896645,-66.574057,-52.090982,-145.560868,-207.448803,-242.068287,-175.895848,12.665006,64.261752,110.812565,131.718747,121.330317,103.636674,98.317667,93.225889,109.894086,166.481631,177.915048,106.215832,-27.019589,-58.535899,-58.135726,-43.821517,54.034923,153.595768,386.228136,423.331605,317.736698,24.807385,-70.238111,-80.159418,-35.232237,36.714444,63.771415,81.676246,19.057195,-10.973041,-78.547222,-102.585109,-52.205601,-8.738383,33.929582,68.604496,80.107455,-8.31269,-98.206502,-156.112503,-105.666429,-13.993891,-4.008687,-13.368347,-46.365588,-78.541747,-160.919904,-181.147424,-83.225984,12.557735,170.938162,165.148365,84.769663,-82.489066,-145.257409,-240.112838,-232.08363,-92.663753,-27.627797,-50.295936,-194.117581,-260.033695,-369.961355,-398.990192,-399.730527,-394.050092,-358.194346,-261.959938,-225.176609,-198.025168,-197.202455,-194.590551,-158.194793,-47.841388,-29.94015,-74.976393,-103.814706,-92.249353,-72.513256,-79.795622,-60.888019,-0.810653,148.52745,147.735851,106.133554,33.968458,-6.291559,-93.108286,-107.885377,-58.111738,-11.466731,60.990253,62.496293,61.106646,57.697367,22.328964,-49.668592,-11.800403,163.065291,189.387445,147.976689,101.10394,110.219909,175.790291,214.885064,275.723757,321.548281,361.936899,105.344727,-61.276154,-243.691631,-265.603126,-250.021323,-219.809541,-74.712179,133.883691,190.730202,106.57691,-3.816643,-138.289576,-132.563055,-61.578128,-4.231135,71.318871,-70.403415,-172.544771,-245.393433,-209.858115,-150.609559,-154.193559,-96.977246,58.491412,87.043406,-28.91466,-126.765192,-226.713854,-191.271287,10.880521,118.101867,190.469806,92.983667,45.524254,-19.759128,-42.415347,-17.43263,22.06893,99.923539,96.354863,45.420223,-96.707249,-151.167147,-154.504631,-130.091702,-125.14584,-108.95699,21.055202,91.959291,57.627731,-69.54108,-116.096952,-155.444102,-159.068347,-127.095996,-136.660245,-194.205692,-331.199185,-369.624951,-360.705486,-322.563317,-224.331716,-195.3651,-227.016272,-271.59571,-262.635054,-220.578927,-191.689144,-76.608135,1.889325,97.870843,16.327167,-61.105644,-202.325898,-280.498881,-399.592354,-393.598215,-327.457628,-315.740002,-268.888638,-141.69291,-85.074278,8.693214,41.356528,43.531016,17.295134,1.297887,80.131038,105.15105,103.402093,104.30473,134.959082,148.764698,97.405648,47.985093,1.441132,5.735495,32.826818,82.444808,62.098448,-9.059584,1.297838,135.986856,245.440541,248.721597,215.286516,192.042178,187.909647,239.642784,354.278408,363.130565:119.156245,-28.070362,-108.402318,-134.489288,-84.663198,54.863263,121.160397,224.04314,216.100737,156.078023,31.1492,17.171838,129.843694,221.522806,347.79236,374.040132,354.347042,233.077625,153.340007,35.651968,54.484173,218.187046,267.711192,235.637712,138.944516,78.106839,-40.317215,-81.19541,-82.192592,-47.498046,12.742334,17.212442,-30.709844,-123.37857,-174.147426,-223.136922,-186.419021,-12.092524,87.571311,236.614149,202.293827,110.047798,-89.213282,-146.964943,-83.295699,31.998523,256.440448,317.8784,307.76007,155.160954,77.08459,10.828502,28.820356,125.62863,183.031194,283.239159,242.864549,156.130961,-59.091367,-134.848573,-110.158224,-39.432773,54.620886,73.563508,73.74058,-50.364557,-141.710881,-295.126253,-306.217539,-128.354936,1.499985,141.102701,30.505632,-95.454459,-339.825805,-412.732905,-391.632103,-291.272717,-66.659433,-24.662013,-77.020193,-124.02987,-111.368031,-64.104398,-40.041327,57.824703,144.130367,306.969347,232.342737,91.283933,-192.238939,-243.707147,-138.96746,-37.389705,146.353061,192.463469,106.531327,-140.591877,-269.920482,-467.148387,-489.836061,-403.30719,-357.760964,-314.612882,-311.116224,-334.217825,-406.046383,-414.503674,-304.152857,-214.165743,-67.232895,-17.722457,12.09998,-86.978967,-168.829247,-287.178186,-266.632796,-73.655463,30.41713,138.613344,74.804786,-14.021779,-209.362564,-276.214981,-307.535931,-285.162014,-182.798308,-98.321716,38.195742,17.489577,-25.268686,-133.937568,-162.112922,-49.295052,54.288347,187.564456,169.97707,121.453582,14.374124,-24.490593,-42.264459,-6.606333,127.991895,169.202398,48.642609,-184.31565,-224.058265,-170.274266,-116.340065,48.372101,138.969582,234.832233,139.839715,37.3485,-119.165313,-124.714327,-3.899202,84.87636,252.369029,306.759761,250.680291,-21.713205,-153.49315,-268.349627,-257.757647,-199.013048,-170.348923,-131.987403,-258.794145,-367.534082,-506.73991,-535.684611,-499.97215,-408.724074,-166.296841,-84.473844,-95.359179,-292.107267,-389.231752,-435.140807,-365.74451,-155.970884,-73.948239,37.600709,79.645274,50.263711,-49.89014,-71.422458,-42.441237,-10.671461,83.440725,125.587942,93.546623,-68.584599,-146.560837,-232.56439,-206.196329,26.997531,186.906351,393.977391,279.996577,156.028508,-24.659326,-82.797989,-115.816428,-47.832659,151.621266,185.000539,74.355238,-38.379448,-84.20319,-275.355074,-353.033167,-245.254553,-103.070769,70.315636,-7.899051,-85.534365,-238.336025,-290.152281,-277.693067,-212.111219,-50.582376,-6.782446,-45.836346,-155.175618,-205.601674,-295.27497,-305.391497,-147.058758,0.564626,196.788856,74.847949,-43.607798,-228.980665,-289.176492,-323.224521,-282.994202,-123.199218,-50.960262,-84.490312,-299.66652,-378.746868,-450.229933,-455.158211,-385.789873,-332.066439,-238.386547,-239.588052,-285.699274,-310.566645,-268.493589,-192.03467,-163.998008,-62.576221,-13.908714,-2.550888,-76.005042,-134.85095,-239.953338,-251.584397,-167.055656,-80.309242,81.193194,22.341767,-61.4445,-121.554751,-106.664222,-115.771703,-116.285659,-4.976216,70.65529,111.055657,70.819885,46.464734,-41.981534,-71.785524,-42.32933,15.774412,172.843191,145.904566,53.418899,-96.857838,-108.815386,-1.562873,80.485049,239.654301,316.919338,346.653359,96.049348,-67.448537,-259.429545,-233.894254,-59.363433,-5.977442,61.809072,143.844871,132.586261,-0.468857,-78.924678,-147.021151,-100.527298,113.894683,205.437103,207.08771,45.30993,-32.662505,-151.143314,-174.82074,-72.306207,34.380496,179.293801,187.28162,184.535022,116.925162,40.519844,-42.881107,-2.324062,169.377201,239.900374,208.523318,-3.554844,-76.7998,-92.52794,-66.080728,-21.578761,-8.220285,55.939694,117.819296,92.649024,-74.882715,-169.536045,-226.228229,-180.654198,-51.981924,3.235409,53.456758,-48.575356,-131.501246,-189.346106,-153.058304,-82.341502,-58.354728,5.274176,0.590492,-45.218906,-174.526845,-224.389292,-169.790524,-57.395353,151.90007,177.222376,52.529207,-102.774433,-121.897316,-78.537307,-27.930081,150.646376,256.456632,373.630146,208.379093,56.267991,-188.59371,-274.736064,-327.049132,-245.162734,-0.913154,55.884336,14.194128,-47.07988,-57.164181,-48.409022,-21.054113,95.492253,159.894255,208.227411,116.559517,52.21994,-54.531677,-78.788057,24.894514,126.383069,204.966814,169.203088,77.901152,-15.806381,-66.072625,-108.369542,-57.565205,144.18792,203.348238,197.710021,185.245613,172.259708,111.50799,87.062051,139.817441,231.026678,446.828715,505.113485:-2.702182,-189.686335,-292.020392,-356.064748,-319.340249,-215.558479,-195.157276,-245.424947,-283.569229,-256.884342,-168.451402,-139.455605,-125.782286,-145.113932,-168.19136,-125.075061,-14.149077,-3.913174,0.738845,-14.907553,-50.677069,-46.405569,6.342896,55.180662,-58.850494,-110.678504,-82.275432,-47.78328,-37.084376,-38.050314,-49.395629,-59.84932,-36.662608,-20.840161,-44.781615,-113.718737,-122.484063,-94.428584,-95.366809,-143.071067,-193.027189,-202.426758,-203.284308,-214.927429,-184.857627,-112.782639,10.615378,32.286458,27.87735,-33.092445,-27.993144,69.185899,98.213483,78.54027,68.050269,119.363457,178.992495,160.662269,93.914007,77.401981,84.40004,113.146596,170.952642,166.90343,125.10188,91.938234,63.451852,-8.383309,-20.651509,17.160309,52.203822,143.541004,150.784152,78.088869,-113.001236,-158.705949,-129.469654,-108.539582,-140.494212,-148.433632,-51.284377,12.753441,-36.296731,-194.125155,-205.469346,-21.381298,98.433158,228.586962,201.035504,151.053139,57.910782,43.287617,87.18464,117.77946,130.296634,114.131398,34.878333,-88.77199,-132.752173,-242.468794,-336.190295,-455.586214,-440.711804,-339.002092,-211.328443,-144.196039,-31.237691,10.679556,65.740592,65.82056,-18.816471,-64.099725,-19.915529,128.546248,161.785465,73.054605,4.556071,-15.618743,24.783485,104.008437,123.174626,92.007158,-26.529566,-89.645338,-224.467655,-265.789168,-194.410248,-113.901299,-19.829549,-34.905224,-58.739972,-149.844294,-209.499403,-237.202232,-173.283067,16.264643,84.205766,82.792275,156.74955,211.793387,205.151646,159.937162,141.240934,171.022836,193.975148,166.863474,169.225129,181.564898,171.989085,169.009513,224.291203,435.262246,515.824713,474.142112,363.100968,317.547395,265.8728,288.916748,365.76743,348.692552,198.14402,86.003757,59.652981,-22.414668,-72.809858,-123.628235,-131.890876,-171.263488,-212.090764,-216.681552,-180.271216,-134.759148,0.13377,57.33955,67.682379,54.267112,96.987081,140.016018,120.115942,47.095968,56.495181,194.308807,246.879644,243.503972,276.485132,320.18485,341.622681,316.95781,275.141351,246.785231,161.148653,150.688096,188.50672,107.767512,26.088668,-80.401723,-62.757784,133.698217,267.149928,450.918912,368.807031,225.29759,-27.420805,-86.632713,-140.612827,-129.998183,15.417166,100.272329,113.411289,49.846582,62.347843,52.223235,22.237712,80.439749,151.688819,220.391568,174.518388,125.345596,52.066102,44.131222,69.064818,98.866945,129.42544,110.992018,59.824052,-1.424182,-30.563108,25.233101,99.392083,163.492995,143.434879,146.930668,190.715929,163.918891,80.273431,46.412863,-41.991831,-65.36005,29.246081,112.459685,127.827691,-66.261689,-151.574885,-234.516773,-246.521589,-254.742355,-250.722857,-191.663627,-185.773677,-230.857972,-262.856038,-226.588468,-160.166354,-144.510668,-136.204583,-152.790841,-228.776511,-293.041338,-278.147231,-159.812438,-100.251907,-36.863048,0.705798,178.376288,213.991792,93.626252,-150.375651,-180.075621,-112.908321,-68.464863,-32.579693,-29.916793,10.707933,101.169052,155.591672,142.747977,54.668475,-82.051218,-67.927285,38.649899,68.808368,64.41543,93.23748,114.040822,126.3245,133.01367,163.761372,166.695044,96.559461,-40.911219,-113.040844,-256.162673,-318.163862,-368.866424,-343.605713,-202.636253,-44.34129,-5.735139,-23.578378,-70.744254,-179.275309,-203.328379,-166.522925,-131.973989,-130.610454,-205.452558,-231.782018,-255.83038,-256.771579,-210.025621,-160.066061,-29.578399,108.847809,153.678551,107.87035,22.144053,-96.355915,-63.921699,116.110599,190.705564,202.242603,133.146705,127.256582,117.484333,89.243325,38.096222,28.96496,50.359253,53.793805,17.107304,-20.70291,-0.88638,18.937819,2.364441,-2.141194,24.320303,47.918838,45.04862,55.852356,9.498251,-47.885083,-89.210476,-66.639013,-45.924142,-77.399408,-88.072103,-84.70122,-104.296682,-215.45999,-268.060867,-290.460419,-265.823536,-250.286686,-282.452344,-255.80125,-189.402627,-191.990761,-134.490283,-55.347562,2.330187,-122.325348,-167.40578,-202.865273,-239.012585,-300.759819,-293.163389,-284.151323,-286.191909,-200.416376,-23.843016,41.808095,63.30354,55.826539,87.028391,94.692369,46.562042,26.264957,54.539903,158.15091,204.791794,256.054934,277.534537,277.943308,252.869056,231.665044,201.647378,174.640669,133.243975,103.526885,-9.095034,-63.343174,0.337137,229.808674,277.452803,171.530431,83.923843,51.402448,119.571301,223.064323,218.579251:27.509451,-1.731172,-75.844646,-211.055018,-213.409178,-132.604316,-115.424348,-121.090198,-131.172718,-146.796155,-108.128672,-43.94201,45.353813,33.48692,-27.081005,-16.441746,60.946334,90.717832,104.126337,93.056818,75.690257,149.637865,213.385396,222.633096,106.540601,60.50502,74.844174,120.508522,185.717063,171.608523,46.351092,-16.197641,-15.143291,89.625221,112.59973,19.32918,-57.298984,-151.170512,-162.384731,-131.058298,-121.371619,-140.032197,-153.694249,-159.400017,-184.02913,-163.989401,-49.047778,14.044913,92.964816,99.119668,104.399511,104.311717,84.737008,94.960197,148.755044,267.000846,266.711003,220.406151,96.833929,29.053905,-58.13675,-52.922594,19.154389,74.59382,169.37878,148.121557,110.557676,29.636719,-5.744888,-22.218874,13.101063,96.937922,12.433508,-73.923405,-148.6374,-131.066056,-113.992803,-139.003626,-210.343977,-216.573447,-141.104827,-91.461064,-119.352855,-211.415158,-205.556331,-19.381765,103.321193,272.091759,285.285866,214.022217,37.887187,2.394545,32.905473,52.551735,28.558801,0.280423,-26.516177,-95.825479,-167.543349,-327.682525,-390.451782,-395.119284,-324.129703,-164.038168,-145.990169,-136.483958,-12.719131,25.488109,-21.486455,-34.966246,6.859162,42.294381,141.636667,208.658884,189.277457,52.720422,-3.847903,6.732676,55.402922,176.221984,210.57854,178.288424,103.746509,63.332513,-40.814092,-64.603229,-9.452107,40.245888,128.677065,205.69713,233.972848,175.075436,101.578216,51.582543,88.836022,151.354274,118.634494,131.982331,236.027446,243.387868,163.830517,158.425218,218.174013,211.681788,78.884049,-36.217797,-30.624644,21.616023,35.30987,70.820199,100.343399,185.021656,245.606831,248.767604,185.228966,119.509045,30.325092,37.181013,87.974983,114.002569,155.207238,154.930459,127.275261,-21.544075,-104.393926,-184.399018,-206.925935,-279.461954,-301.508108,-274.783055,-221.115605,-222.889032,-214.745753,-187.993789,-171.200585,-172.800869,-110.617216,-66.804277,-89.305706,-186.599758,-231.575258,-204.413437,-129.262347,22.438205,52.173687,34.831598,43.600662,78.313186,130.44359,105.623976,-28.691306,-67.725283,-49.564297,-18.696415,-2.98654,-33.719356,-76.699824,-58.128081,39.380212,317.799937,377.332262,258.743618,-73.478014,-186.802661,-243.400783,-206.849605,-70.448877,4.19152,121.138512,135.181563,99.635332,-36.392032,-90.332555,-73.74993,-28.049252,43.950818,45.78683,45.200141,86.792,102.93648,70.198911,20.630402,-94.180277,-112.714846,-50.084497,-16.805959,-42.695997,-107.076715,-100.793472,-7.257739,41.426771,95.411116,38.185602,-30.839912,-122.208241,-131.310525,-166.905481,-189.720534,-140.22985,-72.265814,-30.040592,-178.356328,-257.513292,-376.515097,-418.840921,-440.974581,-429.527455,-362.67217,-256.371025,-234.908826,-249.590531,-250.03246,-202.496194,-166.03409,-146.503461,-155.234576,-116.807483,-75.499351,-72.729085,-63.356722,-75.807192,-111.732415,-67.454608,138.142369,175.934124,93.354234,-32.320121,-33.930891,-57.50139,-91.42531,-75.948361,-15.064966,100.126968,140.37566,166.481115,190.358972,144.298383,19.984839,-5.734262,33.251817,135.08211,176.057491,217.476872,218.209672,213.522848,212.543582,194.054035,189.907602,176.229742,73.028074,-2.190302,-160.031875,-234.468138,-306.306337,-298.138244,-244.098141,-129.263902,-62.671971,19.528083,23.556448,-18.304126,-46.373003,-59.905123,-31.624892,0.684109,-74.593546,-121.174128,-171.58708,-159.618832,-110.501209,-110.012466,-81.873241,84.337112,167.301743,154.546526,55.558181,-51.225327,30.158696,291.864879,359.232346,293.50907,154.94564,132.021091,109.567437,93.178018,94.538437,98.627206,109.379131,130.799516,129.953376,111.518578,80.091148,-23.592749,-55.167111,-40.179846,-4.433872,137.161295,280.922569,268.269617,42.464618,-74.317854,-108.525408,-64.660331,-38.706051,-84.257481,-86.258642,-49.95879,-48.883568,-112.935842,-156.014634,-220.004979,-242.029801,-294.734172,-337.17464,-335.037677,-287.106693,-233.831319,-78.637241,-30.673934,-29.707044,23.347422,78.520265,82.469233,-2.550695,-221.561624,-289.009616,-338.622193,-341.296632,-285.884043,-136.340318,-57.636235,-0.172821,-20.186174,-21.954115,28.18636,135.728099,130.036814,111.425627,130.038052,163.819938,226.528641,221.114171,102.452526,43.347821,56.145902,130.577939,131.401463,42.482237,-14.080231,-43.057668,-29.800633,24.721173,159.109166,201.317484,166.640482,106.817375,-17.793377,-34.221366,34.935512,75.909349:6.719297,-109.294313,-164.990183,-176.120185,-144.277827,-44.757981,-22.744351,-81.763042,-130.487999,-129.288256,-75.040167,-27.828063,20.456756,12.475443,2.01938,15.005144,35.722485,-2.399615,-18.029935,-25.097985,-15.045403,67.410421,118.764268,114.958077,-42.4037,-76.382083,-3.834802,27.319042,0.336812,-41.990464,-101.642887,-93.566659,-51.2049,-104.797644,-162.032297,-226.663284,-207.76025,-99.886803,-54.92895,-33.131919,-84.862622,-121.071047,-128.377515,-98.07232,4.32787,81.761415,230.94605,261.700564,191.656381,118.540594,145.041576,171.884166,139.291376,122.084977,147.22499,188.102538,176.719876,131.716912,49.217383,44.791386,45.432337,44.529717,103.677481,150.159526,147.590685,54.033329,43.038216,23.321281,-10.11096,-7.972225,31.202721,104.794391,70.533307,-5.007041,-208.663289,-315.185553,-391.207385,-306.124801,-65.451765,-12.934259,-77.069955,-148.258089,-125.842144,-54.250929,-32.415159,33.32127,77.652719,109.72054,83.443741,57.11558,-57.363114,-123.680725,-154.7916,-103.818002,7.024207,16.289047,-47.356782,-164.794671,-235.038074,-366.736766,-393.43343,-349.292688,-330.290461,-335.927888,-348.792147,-357.979503,-301.511253,-232.785828,-133.208459,-135.836807,-188.759798,-169.96532,-5.688555,72.68169,22.913657,-86.721498,-72.14508,28.201869,53.225653,33.009658,-27.779211,-67.94747,-163.907937,-212.260296,-253.645361,-245.299477,-244.403336,-238.629801,-168.539298,-157.794251,-185.336498,-230.356251,-226.890061,-164.095626,-126.060977,-26.461186,88.714444,123.239678,126.362681,81.246687,-21.157331,-0.101878,186.980602,259.064443,211.513567,50.801498,3.277353,13.856662,63.415957,213.614321,284.241241,318.51663,234.741279,201.937445,165.337537,138.531848,95.201229,112.478203,215.103913,259.561284,249.093096,70.632608,-36.756352,-181.113999,-215.414999,-226.716767,-223.239166,-253.024917,-314.794664,-341.316613,-375.166682,-383.080162,-315.608795,-219.01588,-15.156241,37.798463,65.626442,26.843599,-22.087297,-112.036586,-108.796074,12.050253,89.075182,194.370885,230.379469,238.095921,207.058435,157.439535,95.190574,116.472144,175.09298,167.342278,61.824218,-91.820043,-132.976968,-102.256618,-55.857816,84.646781,187.010128,327.557061,227.479932,147.999503,40.982249,-7.087452,-65.860966,-48.052015,51.558244,103.420566,159.512718,69.122005,-39.584766,-263.592537,-288.271048,-64.473159,103.697837,257.216219,78.867434,-28.538929,-96.573572,-84.635732,-29.92564,24.398836,127.505697,140.907109,95.841324,9.514139,-32.351535,-62.426093,-36.532578,62.890173,108.509506,151.57872,111.754581,64.926058,-19.137753,-57.876971,-125.051779,-113.774626,-32.45284,-8.347602,3.440393,-79.946432,-166.181763,-323.150625,-335.809388,-227.173957,-180.768861,-176.627682,-201.352554,-226.3296,-227.810306,-173.90422,-51.104984,-25.51404,-44.604466,-72.943509,-133.522064,-203.189545,-229.238954,-228.782287,-208.353762,-120.961954,-59.386644,50.84805,47.65201,13.536467,-20.551747,-43.78174,-129.505213,-128.898676,0.658301,65.332205,125.698415,180.872145,190.238698,103.731807,51.302055,40.150585,72.299816,120.015962,0.765996,-87.591823,-72.025903,15.74221,113.050793,116.709575,139.556937,160.254597,121.726131,-45.039777,-126.962588,-237.124826,-242.168521,-138.488249,-86.692092,-18.580867,69.135831,72.818301,25.945703,17.575436,-20.134308,-63.369707,-93.733602,-43.645873,82.343623,-12.390988,-134.80724,-304.48875,-295.6627,-173.165442,-111.663445,19.33677,134.173905,152.919739,68.965451,-33.06189,-154.690544,-93.099326,114.986946,146.430609,49.244259,-41.608751,-61.600065,-119.753389,-144.993521,-132.644429,-101.159683,-7.243254,86.883519,100.251585,-23.087247,-138.397848,-243.851563,-198.32969,-72.196434,-44.122897,-41.873521,-27.325553,3.461078,39.439668,8.535024,-86.669749,-116.444268,-159.044848,-206.972808,-213.934695,-197.663879,-207.62231,-239.797607,-224.390593,-145.500505,-107.359166,-106.52577,-211.874931,-247.005658,-223.978157,-168.735797,35.315135,144.71495,218.464168,71.363778,-37.663154,-228.403734,-287.458778,-328.255672,-314.726858,-214.789016,-145.77592,-48.188013,-54.115119,-78.695758,-107.340194,-80.149892,38.607964,66.570188,17.983591,-35.883154,-28.901008,38.673001,63.911415,82.429508,104.014754,189.489274,226.222178,219.148777,106.290719,65.341915,46.782551,42.307952,60.035564,76.825348,77.532448,110.23937,167.732817,260.691866,235.94449,119.297546,113.77235,222.663966,283.475236:right
-103.094571,-61.318526,-13.630784,136.466868,223.613657,352.183339,356.892184,236.554565,132.11576,86.638478,-52.847287,-116.95687,-145.942192,-100.972645,-0.556353,1.201308,-51.733802,-101.29538,-118.836771,-74.226218,-10.527959,112.905453,123.250141,-35.980831,-232.529859,-244.003555,-132.131374,-64.476096,43.055632,92.396114,172.645645,182.901821,138.935839,12.394598,-62.070944,-73.182381,-3.232816,81.128352,44.179251,-33.934392,41.115669,43.914177,-112.348633,-199.964461,-277.852433,-281.577069,-254.420094,-227.996522,-202.648082,-271.783577,-295.067227,-219.886613,-170.809756,-163.642628,-179.943588,-211.771908,-267.608004,-289.480771,-277.198863,-245.299439,-196.99551,-194.614636,-177.628479,-153.792109,-113.963596,-81.504426,-53.520498,5.848287,3.300265,-81.437487,-123.339271,-166.652515,-227.898295,-271.25909,-314.822637,-305.932539,-343.096403,-386.993898,-370.765663,-317.824174,-271.366579,-303.982225,-298.493928,-231.958334,-199.063821,-134.861403,-93.769053,-59.599522,-139.850929,-196.170342,-247.284011,-229.887345,-160.48183,-131.261693,-143.647549,-185.96369,-255.603835,-311.698542,-345.118706,-366.308375,-353.645325,-305.057353,-264.533847,-153.789736,-108.334456,-154.360121,-284.548361,-290.52432,-164.439217,-77.541724,33.110022,26.693748,-98.276308,-271.372451,-306.553952,-166.611998,-60.743583,31.916443,44.117772,69.570856,37.39228,-2.341096,-73.285641,-87.293067,-63.031143,-39.497239,-38.717289,-59.450628,-70.19018,-19.158405,16.882418,117.548482,171.689448,225.376477,207.833011,74.664372,-64.492711,-97.51973,-122.397445,-117.641718,-45.42,9.719631,89.889786,108.149363,126.897257,108.794002,110.920185,170.489558,175.332453,80.99291,31.439945,-5.982893,-19.869356,-25.307829,-25.616633,-20.619676,-15.063684,-15.914679,8.313231,58.426249,198.155111,194.833996,149.982591,92.033895,66.925605,9.72088,-12.467644,-54.567532,-117.86877,-157.842379,-146.923108,-75.396613,37.588704,48.266118,64.645202,72.706058,15.860226,-97.098441,-117.26311,-56.005945,-14.191205,19.827627,20.497634,4.733101,-44.35332,-75.072033,-61.429039,3.466135,161.936065,218.467563,241.761061,192.283826,5.07722,-147.509332,-148.950034,-23.740895,29.019352,22.356767,-2.163103,-39.325425,-101.500313,-118.273391,-30.802758,59.649605,217.092697,250.869873,179.634581,85.915887,-63.240583,-52.995686,-12.847812,94.19074,128.438115,93.77995,48.865527,-20.847493,-35.813514,-20.463588,17.274672,17.899788,15.03029,34.24488,62.52715,50.777709,78.161273,186.181051,201.910501,146.051114,126.686658,195.703158,238.218495,141.723128,-81.435674,-117.026908,-4.966697,60.995704,46.439017,-3.688861,-37.45146,-31.998562,-53.241872,-108.671892,-141.053219,-172.40421,-161.234832,-91.343472,-50.15815,-41.200383,-173.432562,-256.379153,-307.841126,-257.04391,-113.004257,-48.561661,34.940182,26.033397,-76.36635,-190.82732,-221.15522,-189.253368,-151.9564,-98.901853,-75.429391,-39.023546,-67.80173,-107.194322,-159.245798,-164.759877,-199.462957,-218.114142,-212.00123,-205.908642,-196.21236,-227.57456,-253.063828,-193.626021,-117.035661,-42.217711,-77.782074,-198.915582,-233.94538,-245.80942,-293.879542,-279.916167,-165.55446,-128.293783,-156.065044,-189.207749,-251.612389,-349.906632,-381.921924,-323.512444,-264.261538,-198.064018,-214.500439,-310.55436,-302.057196,-256.885709,-187.162147,-153.624954,-60.918332,-25.425255,-45.284374,-79.39249,-67.550535,1.853366,28.410227,101.1644,140.65128,237.466595,307.41246,371.018132,221.037697,119.897505,36.57242,77.944325,194.450178,193.143219,77.533949,46.231522,105.686562,66.158752,11.142653,20.605829,62.241646,95.836533,84.761238,42.501534,-0.263913,-12.655547,15.984293,43.160483,70.077293,77.45339,85.389407,89.436056,120.367828,57.003167,-15.451176,-48.726913,-5.771991,61.056803,72.987986,93.830428,115.543314,99.862728,44.359467,43.58133,84.128257,106.322752,135.098532,131.883714,96.727323,67.57796,67.718002,91.206333,102.936193,157.212027,203.231583,230.778574,140.332452,70.140102,-30.664955,-17.641404,56.439233,73.298415,110.314581,124.235784,66.519473,-21.524008,-32.227361,5.530027,36.991748,107.465368,116.044578,17.840972,-58.362634,-45.397927,33.566767,80.045243,128.691456,124.66004,126.759812,154.729,221.973607,145.290241,61.178849,15.500147,68.341365,149.84131,154.332598,186.200344,210.248436,174.694924,123.842971,145.625546,172.85819,163.477672,164.468574,180.57522:30.638025,-2.694891,11.907882,136.337501,194.956912,263.044407,269.795044,209.10267,130.370945,87.473295,-12.79938,-33.371261,17.997313,56.460859,64.651642,30.299658,-65.456879,-144.909832,-151.17545,-98.338083,-64.964549,-19.458324,-19.305398,-137.132968,-294.510877,-294.262853,-170.201457,-105.570768,-3.519555,34.10453,25.867627,-5.798527,-33.515122,-67.195514,-94.753482,-100.561528,-74.389933,-2.350434,15.639298,-24.934447,-87.144808,-115.971789,-152.056984,-142.473461,-117.923026,-118.321655,-127.01078,-142.650749,-219.7868,-314.663409,-324.002095,-242.616092,-205.886345,-199.888937,-211.562943,-258.403978,-325.056295,-363.622538,-413.165166,-400.638422,-337.456799,-319.347928,-332.196696,-338.314679,-282.469022,-191.138626,-147.339388,-48.054536,-27.976978,-110.594116,-170.970615,-232.949652,-298.888,-340.651567,-355.630314,-330.702378,-298.056726,-299.693896,-297.765308,-282.892137,-243.327791,-246.203044,-234.178824,-125.847521,-73.321443,-68.535071,-98.894056,-144.162266,-224.252874,-304.789838,-398.374678,-361.687752,-230.41332,-201.120309,-254.188171,-307.050969,-379.816881,-377.810042,-335.076457,-236.27786,-229.587959,-248.981222,-227.317754,-165.447489,-212.034015,-280.283335,-357.097959,-311.972149,-122.319574,-45.273614,-5.209209,-15.301993,-68.589602,-189.818707,-191.406187,31.628943,158.122558,226.111228,198.956987,133.668732,84.130116,68.878662,48.735473,60.656851,139.261912,170.254222,165.055502,152.646251,100.812122,-31.458951,-42.422879,161.570057,288.732402,338.220857,266.034812,92.859102,-24.860117,-73.991284,-122.669458,-87.810814,63.609748,143.612995,251.877424,257.068142,211.917832,183.92816,193.942501,255.057727,255.253187,165.826251,123.58626,61.895697,-20.14165,-43.586355,-15.653374,15.105011,73.95833,101.057768,131.483405,133.165565,115.229717,74.970886,70.593341,74.283537,54.018138,-1.469933,-17.755968,-49.58845,-107.66428,-149.323336,-197.227235,-171.635356,-57.55181,-10.608146,15.522178,-6.051688,-114.397658,-220.829232,-206.801146,-77.245316,-25.053494,9.079302,9.826438,-17.059818,-90.576754,-116.263967,-51.787209,28.594679,162.986473,196.382271,181.593663,137.13022,24.860105,-67.279139,-69.907958,-20.333423,1.267867,73.849411,109.451988,51.079107,-135.347049,-178.397167,-61.083301,36.712462,138.223015,153.005075,148.664052,105.989759,-7.77231,-66.20209,-71.360019,-11.249101,34.208422,61.596623,39.970876,-7.845197,-35.889121,-54.580003,-56.427891,-14.209911,86.480407,103.139291,69.447647,33.35953,-11.205396,79.002854,152.030225,202.406416,174.090795,151.517288,152.772471,22.493034,-149.174992,-158.581939,-45.199404,9.299343,-13.428497,-66.00442,-158.539846,-186.077337,-193.912576,-211.262651,-246.975778,-299.997297,-292.24576,-233.53349,-209.985705,-238.40538,-354.843454,-404.979336,-373.834083,-299.377627,-174.26033,-139.055248,-92.462317,-91.201398,-184.390817,-355.950253,-376.699711,-191.236636,-87.820005,-92.097281,-134.031496,-137.010036,-147.977308,-167.470245,-144.485493,-104.727116,-82.34347,-93.896942,-82.186183,-73.662066,-81.999309,-140.840681,-161.957204,-116.343856,-81.231904,-43.177787,-54.985946,-191.287574,-345.475166,-371.038628,-319.80954,-251.839245,-125.314857,-114.659722,-185.810849,-237.551555,-321.114753,-282.357566,-233.937787,-215.132677,-251.052774,-287.845718,-276.737632,-273.581677,-295.115923,-318.956611,-332.373682,-279.55989,-110.445423,-52.196214,-50.195786,-86.969315,-122.130815,-48.941555,10.408286,151.42864,224.399172,342.448079,378.808046,385.87003,254.66897,152.477201,59.149178,101.905981,200.58329,186.361671,69.264977,36.491906,81.076289,79.614382,53.552519,96.461926,143.622059,165.406692,141.225677,64.359885,-11.490007,-40.649427,-31.198871,19.171474,117.123723,118.125359,27.1759,-10.5517,17.452003,31.569231,6.907843,5.321746,31.17732,54.112994,52.570523,81.253859,73.868344,16.860775,-80.494546,-62.939612,51.544757,89.948049,63.518372,22.587573,-35.767536,-38.829235,-6.730268,83.059825,107.060732,145.856072,165.298465,115.120393,-51.627938,-134.180333,-158.696466,-94.630029,38.16207,69.551423,109.069556,123.475303,84.708339,-4.183317,-30.336358,5.205527,71.360783,227.63402,255.870689,139.774028,21.272469,31.990756,122.290059,177.653269,282.127196,303.837056,281.015507,271.941684,241.773631,98.637155,53.08979,151.927857,229.380301,258.654992,247.026978,268.444189,227.025925,176.241134,148.96405,195.532227,308.29773,342.606562,343.677114,296.432145:106.664603,69.187847,63.565276,103.795318,145.998996,257.932308,282.039581,206.361585,105.562965,91.961332,127.857302,140.685545,93.366453,53.374338,-28.99162,-68.645282,-108.44812,-169.900889,-202.487444,-174.866261,-127.615071,-41.597934,-20.602617,-62.488972,-164.651832,-194.862727,-140.446512,-61.606036,78.750498,105.252673,93.390405,72.158508,20.355778,-25.772724,-30.951583,52.700764,129.13013,203.453886,164.128782,52.353782,48.557534,35.350104,-33.421835,-38.192234,-12.785642,-25.379142,-103.396376,-134.874904,-154.0794,-210.970311,-249.624151,-264.063451,-239.649884,-183.275809,-194.500625,-339.528662,-459.798223,-450.077555,-365.274835,-347.605538,-387.568336,-409.369073,-413.607657,-398.471106,-347.615439,-296.234527,-246.671272,-127.053637,-90.893187,-79.814675,-110.657054,-223.510793,-338.805884,-389.314592,-411.414626,-362.103512,-251.129071,-246.346901,-318.194837,-348.716874,-329.689998,-245.359481,-194.724957,-70.655682,-23.203944,-29.638906,-80.570779,-204.834183,-261.216392,-267.292638,-268.541979,-258.82876,-203.168358,-168.970005,-177.203779,-225.212426,-304.998125,-324.383897,-314.815316,-270.057464,-250.669651,-218.237137,-205.775092,-206.824637,-250.05574,-289.450019,-292.103098,-215.515257,-27.539268,20.587,18.306206,-13.065028,-94.681644,-103.556793,-50.235214,125.503298,197.81608,236.284839,222.428857,185.05096,112.163019,67.127129,27.533675,61.97125,225.585887,301.406864,297.188528,225.772369,74.002712,-17.987894,-2.164697,148.495815,212.672458,229.541241,207.09868,141.288171,27.845772,-31.767259,-60.035404,-21.572854,89.518206,145.254027,219.429812,239.051563,271.027657,225.160632,190.190592,200.441959,228.753543,214.653112,147.378231,-7.57031,-32.951067,-15.751883,36.671704,73.219804,134.983697,141.882504,108.076376,88.664719,61.516889,25.104734,10.637224,-12.861049,-15.961736,14.604096,19.064178,-53.929838,-139.856578,-148.038034,-99.011001,-64.398371,-7.732362,16.252065,15.44033,-21.235186,-111.155869,-174.159919,-181.854183,-127.649248,-69.994964,59.188456,85.477982,27.548436,-57.708928,-76.193824,-33.946659,4.879688,54.460335,73.787085,98.932074,84.742881,-24.538513,-164.129454,-175.225097,-68.247511,-4.533883,43.261523,26.720323,-49.459684,-169.269565,-210.846803,-148.072685,-72.46572,25.555688,55.085018,91.738488,58.283128,-97.879255,-143.141876,-101.068967,-28.835909,-18.16963,-12.079669,-30.678486,-103.348471,-94.155913,-64.863745,-51.96467,-61.399905,-45.554953,-17.095021,33.86849,32.709902,1.4494,11.457057,25.493723,57.496391,92.065984,173.602224,177.16469,77.182944,-40.605016,-67.27142,-64.482446,-55.402922,-53.566621,-58.34206,-68.352577,-82.095686,-162.196967,-279.449793,-296.037605,-231.681264,-195.375804,-156.960362,-149.086244,-174.702812,-288.454708,-358.73175,-419.95819,-393.731329,-279.136684,-216.143576,-156.016624,-176.974994,-286.763199,-390.53903,-394.868328,-315.887165,-266.731275,-187.74248,-161.905054,-148.709457,-160.072356,-151.944989,-102.736806,-72.264365,-19.979751,-1.438285,22.997133,21.578197,-25.077283,-92.64729,-97.184003,-63.509278,-61.969761,-74.093466,-89.519061,-216.483176,-355.201746,-367.894885,-276.99542,-200.17983,-59.158068,-8.796505,-14.057643,-91.214083,-299.730596,-391.691972,-377.615711,-308.353687,-285.306568,-288.984692,-327.316578,-449.315157,-475.176563,-450.307511,-375.609074,-328.327188,-220.603876,-159.047556,-56.83175,-46.755135,-121.760466,-153.773669,-98.936629,65.310125,128.877609,206.868764,230.935371,232.122047,134.904767,74.353682,13.506342,14.235673,73.02759,130.486422,186.071574,143.125693,-1.396977,-89.447825,-96.916562,-19.846219,41.775514,102.27331,77.24765,-43.286665,-104.237965,-83.715116,19.013467,73.304041,106.450564,76.146014,-11.356072,-27.978189,8.50916,35.847651,38.511275,49.506592,61.042187,113.891017,147.527502,166.488627,54.099443,-37.717,-126.242933,-88.381037,26.721093,56.217041,38.748252,-13.318688,-162.439401,-190.459154,-129.436333,-8.963619,14.80666,67.667344,92.580886,59.70676,-53.307065,-106.328175,-152.012215,-135.492253,-15.322501,54.571767,103.527253,99.307442,93.218096,9.128008,-30.129625,39.667201,112.296256,172.590887,148.425109,75.628806,53.784556,52.766986,99.734541,151.435765,250.064828,295.153997,372.814269,379.450599,297.011196,181.137748,157.249311,205.112831,260.429897,332.871012,326.88058,278.364471,195.774205,168.101292,238.468043,308.085763,390.571027,410.048692,423.09611,380.517234:106.5438,114.629186,136.603482,241.222749,319.121082,463.030192,473.205539,329.907749,171.861083,127.375268,69.997883,34.134965,-58.602389,-64.421381,19.576056,37.494734,-27.954307,-133.520795,-167.211976,-160.066134,-136.466214,-94.64356,-78.045681,-78.606944,-129.033503,-168.784217,-188.416939,-112.251808,105.326561,161.856997,194.716461,205.181508,172.848523,79.873105,65.120892,131.195401,183.999191,232.427388,202.479321,93.496351,36.728444,5.222645,-120.709385,-181.936134,-230.736273,-217.140314,-154.496633,-137.893413,-183.711619,-286.763259,-310.599324,-253.761957,-217.183335,-218.748064,-249.706642,-343.077713,-411.363563,-406.091451,-338.282151,-299.685101,-228.148199,-201.675491,-197.690851,-206.826638,-165.432201,-55.122448,-11.472981,28.770746,36.426107,2.01384,-61.846825,-201.583141,-257.734612,-281.140355,-336.462335,-346.551029,-327.188696,-311.669176,-309.915354,-321.208203,-300.285046,-255.282176,-238.72082,-173.003867,-131.070929,-53.68065,-28.808017,-51.93878,-148.799227,-192.174896,-190.689088,-148.611841,-80.265005,-72.142825,-106.444486,-145.736383,-212.865891,-261.62692,-276.385815,-215.098225,-153.14959,-92.635763,-117.028273,-216.966858,-242.370562,-226.423278,-202.385868,-187.468612,-126.064153,-88.155398,-28.604695,-21.221845,-39.599771,-92.180406,-121.142917,-37.558636,78.9777,283.454464,320.618263,232.840359,40.036858,-20.146673,-23.487046,6.271914,67.192468,86.560611,79.494706,59.547216,15.777861,-30.198886,-31.086963,44.513659,97.948401,168.140405,166.697756,84.664435,-25.280949,-79.322998,-160.602343,-151.790376,-33.378738,32.098721,109.663722,124.462917,137.856419,168.20569,200.896701,271.578589,277.437572,217.609503,173.805918,94.294881,60.024736,57.20406,71.184524,91.170109,137.368676,161.239982,195.683258,186.078079,143.276365,138.489487,147.650846,158.809554,154.200813,145.74948,140.514951,85.696082,19.902014,4.69117,16.141794,52.721279,176.585495,232.328766,231.083215,182.206965,67.823002,-93.362889,-146.249566,-38.811544,75.672298,189.38965,170.474555,96.058695,59.012219,34.941481,16.656434,60.398446,181.329897,212.365191,221.116694,209.282406,144.237316,14.725739,-38.799316,-41.729969,-7.29286,58.934188,76.290617,29.862421,-118.865654,-174.530485,-119.768249,-21.434216,156.437744,191.633639,122.358532,37.153229,-100.355449,-114.047948,-80.550452,22.225217,57.843016,40.031815,-5.432758,-95.728197,-143.481683,-146.973715,-88.028179,-44.540549,6.885648,29.402638,83.097112,89.414712,54.912977,35.518425,46.106141,82.699017,106.574535,177.31818,181.973654,21.408236,-139.618159,-148.989337,-98.74826,-73.792369,-82.842041,-113.881946,-171.604471,-184.157883,-166.9588,-211.899364,-293.012278,-387.193829,-342.185599,-188.993167,-160.285287,-209.231752,-303.17446,-369.085757,-427.096519,-384.477364,-273.22308,-241.711455,-209.702689,-211.927213,-275.230076,-356.810523,-351.657773,-240.631352,-202.101376,-231.76123,-241.527051,-154.511888,-66.005803,-69.74973,-104.564184,-106.844903,-123.217233,-142.940914,-175.321059,-195.131116,-238.246405,-264.163223,-261.41582,-198.657289,-155.280157,-90.581813,-94.235177,-231.291937,-399.413112,-431.381736,-375.563849,-313.589847,-214.247935,-184.276739,-149.400028,-159.177166,-258.947011,-333.671542,-339.816146,-325.727216,-297.523505,-287.828782,-345.871589,-452.234831,-390.699084,-339.415428,-235.933257,-176.545697,-116.369804,-120.870892,-114.724218,-107.71312,-139.99062,-186.770273,-175.538619,-52.524335,30.504287,181.889233,233.721705,245.832357,193.226838,161.07481,118.173356,117.259595,109.035829,91.111584,53.262559,28.554523,-65.348631,-162.731947,-180.650837,-190.361931,-211.81829,-223.354413,-193.019262,-155.518994,-186.624974,-196.050231,-131.614661,-64.627156,29.799872,43.962805,53.229132,51.15438,53.913424,35.818057,-6.264689,-73.617974,-58.046183,63.751059,117.151816,98.053551,-10.095041,-69.52251,-147.179804,-126.219283,-14.766651,22.795456,34.672087,6.359567,-91.883498,-105.582957,-81.264381,-26.160056,13.855752,126.229845,163.662654,152.120804,92.081656,46.29869,-34.534657,-26.725046,72.403409,120.939122,147.428057,120.660202,44.664635,-6.894554,-13.859333,41.218902,88.438908,182.017595,210.726605,142.258355,-16.330641,-58.29234,4.675882,91.783252,234.595565,254.122056,227.620999,217.096196,204.765053,149.959633,138.783816,204.231277,236.388639,228.777838,209.713213,179.82956,169.609167,176.977071,231.126858,260.705467,265.538026,272.047228,351.927176,367.428618:97.450223,53.736342,78.088306,196.670303,262.191377,356.044581,351.234583,218.890006,89.630633,63.862777,73.496605,71.360131,11.822057,0.271926,40.466722,40.695045,-66.907074,-212.146277,-244.2452,-200.363988,-144.343495,-46.848582,-34.914738,-77.164541,-169.869955,-237.188216,-278.295399,-209.949864,-4.844016,68.207285,89.887085,59.542298,14.314982,-26.80307,-30.203734,88.318763,171.32426,228.982615,199.63671,146.158759,174.271122,151.001456,-25.88266,-106.485839,-104.843644,-38.092995,68.898476,54.82911,-88.174062,-195.820278,-190.832769,-118.275681,-97.40769,-146.749833,-203.117003,-300.93316,-367.729268,-394.606607,-358.961348,-291.588725,-182.943626,-169.382181,-170.461382,-166.593613,-163.876613,-196.604631,-189.506784,-96.019371,-36.993197,27.116483,-2.133273,-120.441242,-191.88512,-230.834761,-294.44278,-294.387235,-241.952277,-216.757541,-223.841667,-236.755343,-222.812728,-187.216056,-151.051755,-37.564954,8.744829,51.328122,48.985201,-12.757435,-119.049553,-158.92673,-119.360011,-41.070272,115.220683,146.657284,67.34235,-1.068632,-82.39403,-167.888621,-213.595376,-225.583341,-189.481577,-116.939864,-120.027821,-187.225449,-254.590731,-285.844382,-282.733397,-224.508291,-88.272911,-53.984959,-47.995001,-59.424197,-118.034424,-233.735125,-247.859212,-97.013465,10.54768,125.390534,120.191658,53.99302,-6.041308,-35.558981,-44.687639,-0.256234,134.379561,180.363929,153.442748,83.856184,-86.581366,-161.188403,-131.399188,19.794231,97.287793,174.581401,160.539216,37.592085,-123.223911,-191.574957,-227.607125,-177.563751,-24.451672,31.338706,54.663128,45.255374,91.94976,155.983323,161.772772,201.747191,239.804973,218.060665,133.969548,-16.242389,-17.448956,-16.531522,-53.523744,-45.941512,90.374961,179.795718,197.57877,110.561415,-53.798884,-61.255119,-32.46518,51.857792,101.537719,141.437862,102.957351,-18.176671,-71.584559,-77.593317,-14.496134,64.257601,225.857972,264.309808,216.716803,152.996291,39.918902,-38.387098,-67.465944,-65.457797,-33.474885,54.084714,92.169305,95.39855,-2.39316,-35.950433,16.106869,73.367531,158.881939,186.986538,203.550658,179.188138,101.772954,41.03478,32.184077,43.90007,31.628738,-5.192892,4.364947,5.173359,-155.039101,-244.22662,-200.880801,-69.01836,146.638244,165.636914,86.18895,25.212952,-97.459146,-114.512512,-68.21195,29.055231,61.405162,89.03384,68.746509,-29.200993,-112.244312,-126.896338,-77.005088,-19.564359,99.756688,136.55442,116.345557,79.793513,55.458628,35.054137,13.83361,78.376362,165.869933,271.270931,241.505001,48.923634,-156.800355,-195.811323,-145.140723,-118.006297,-131.749657,-127.822863,-87.650455,-97.477047,-196.35932,-287.679058,-299.573658,-267.487624,-230.403178,-170.962684,-181.104124,-214.769094,-241.731157,-303.324514,-394.10112,-376.547498,-298.29087,-258.567983,-195.644931,-193.043847,-267.781827,-361.946983,-351.837721,-210.454634,-143.6626,-100.003459,-89.217799,-43.27699,-63.537198,-88.364722,-74.129442,-55.052688,-44.205185,-35.493962,-29.584495,-46.764356,-68.8489,-43.812521,-28.998287,-19.528997,-13.695393,20.621592,15.655893,-103.940535,-285.78372,-334.627252,-257.865052,-170.442867,0.840665,58.228991,4.763224,-73.768865,-153.510578,-201.863739,-239.460468,-268.605814,-245.533989,-197.424836,-219.621803,-319.508294,-352.582891,-355.428549,-317.196289,-253.412121,-103.613909,-42.656787,57.304739,78.428907,-8.964346,-162.937514,-175.420338,-53.32181,26.961137,149.372743,180.241051,175.237714,122.084328,82.908458,43.209287,51.845706,46.252317,28.39464,14.251188,0.346013,-118.37015,-286.727008,-310.425368,-199.351346,-113.293113,3.240474,11.374278,-48.995412,-155.242102,-203.964255,-175.306252,-97.909423,32.552252,66.318962,99.771231,91.787109,35.200498,-29.266143,-51.118686,-76.876372,-68.450476,42.538884,100.21846,58.225938,-126.560732,-214.56865,-285.681944,-253.491398,-143.128915,-93.890347,-48.096757,-75.669064,-186.092737,-209.910958,-166.155434,-6.906105,75.216395,155.185182,141.160855,86.097534,70.215918,42.450445,-44.185213,-38.198597,137.925828,223.096606,176.666472,91.570359,22.188874,43.670183,47.998248,39.819461,30.910164,60.99022,97.007755,96.302806,28.425749,35.958329,168.82822,264.094179,396.133304,412.828399,391.236851,364.304625,249.565111,123.425099,123.892996,263.853307,345.995246,417.197293,403.444269,328.46933,269.776719,263.969178,303.895308,341.274457,435.334918,491.498386,566.495052,550.374881:106.539347,84.26724,125.931452,251.971968,319.454936,481.050467,540.657237,479.497836,287.743338,191.844864,41.904812,14.458557,38.093841,64.613139,106.8825,95.85766,5.729781,-82.353926,-100.376473,-87.939159,-73.106076,-28.39056,-10.570962,-29.997126,-47.396963,-40.876236,-10.312834,25.927686,134.935943,176.242327,214.805166,232.340881,263.974968,245.816766,217.503905,196.410298,226.693565,283.458253,248.160588,109.098578,109.061765,100.963517,-97.527736,-206.297066,-214.599102,-142.135228,-53.771301,-87.037332,-236.094438,-277.413872,-222.818824,-55.333976,-24.760223,-139.352077,-216.222381,-258.795251,-201.620623,-175.006794,-131.087576,-102.321076,-39.701472,-23.777337,-50.358615,-75.344699,-56.545759,17.684161,42.737056,105.027158,135.058767,110.057974,60.659874,8.084264,2.81239,-53.170318,-215.666642,-264.785467,-329.15488,-358.521766,-369.199183,-347.052471,-293.169869,-279.166911,-269.356995,-179.79227,-117.68601,-35.108699,-11.382935,7.454137,-37.946106,-69.367168,-66.335994,-24.397611,58.178205,80.418514,85.647429,59.8021,-40.881996,-210.719184,-296.841851,-338.482085,-294.031848,-196.850187,-174.891609,-144.653993,-70.901546,-58.131452,-113.059952,-140.306119,-128.576293,-93.958353,-36.72773,-47.926009,-139.51906,-262.337559,-295.208505,-196.273452,-98.86989,67.287551,134.035389,154.70927,-22.795815,-108.697404,-148.277881,-109.251087,-31.18699,-36.079054,-116.79661,-141.824511,-107.115,-105.923037,-124.521096,-74.996636,-31.079692,-53.410544,-110.113633,-224.185419,-300.504239,-316.182841,-297.557167,-267.331699,-183.179012,-142.133469,-89.851467,-82.803298,-65.34416,-13.137056,15.230732,90.468089,118.572375,67.749285,-1.363318,-108.000395,-69.967405,-22.877367,2.001661,-30.700393,-117.142287,-138.302648,-118.348905,-90.338929,-7.123924,69.21138,74.28548,42.73554,31.395014,19.425698,-7.584068,-119.467845,-178.231782,-175.122729,-151.36439,-130.149062,-81.114443,-54.591254,0.263035,17.93509,9.797273,-90.965161,-143.073379,-136.518485,-80.276787,33.385178,43.617338,-61.389011,-178.396007,-187.660148,-121.272836,-58.297098,92.015365,156.542631,184.501366,136.297503,16.123089,-104.001087,-166.395382,-165.955382,-104.849142,-15.655621,-14.33218,-68.192927,-152.961417,-167.188068,-50.366409,41.848405,130.057853,121.225443,60.915908,12.742578,-89.709422,-90.910648,-37.112529,77.393643,88.767798,20.481273,-38.076959,-145.329539,-76.688068,7.182969,59.17256,19.690029,-28.1968,0.121902,115.32811,157.294427,163.372451,83.080707,37.884617,64.135047,120.381383,164.428323,143.418701,72.185079,-39.73656,-92.170061,-105.716695,-83.87355,-84.646201,-101.154646,-95.77212,-75.117909,-40.137517,-90.095747,-150.370278,-207.430739,-162.960543,28.60513,111.666081,116.878435,-46.417458,-148.051206,-253.589635,-218.542303,-84.152334,-35.647566,9.552866,8.253497,-39.790727,-174.226747,-223.784196,-149.438249,-66.943523,9.531779,-3.91535,-51.704153,-22.463724,5.817496,-10.462927,-40.967711,-87.764816,-104.374558,-148.579218,-184.178236,-221.325943,-197.798959,-198.501703,-179.981553,-125.953733,27.446603,60.008221,-60.045324,-215.889179,-236.99423,-220.856487,-201.513218,-154.83217,-132.3799,-98.15089,-111.692251,-207.935569,-273.00169,-283.585676,-259.492698,-215.357272,-172.128284,-216.864817,-349.394253,-369.749273,-331.766422,-208.318047,-149.336307,-124.379657,-148.630762,-157.266307,-139.25641,-119.316283,-123.057106,-116.001641,-57.887336,-5.652838,145.937415,216.933085,213.139548,61.800185,17.117282,43.30475,69.338211,49.975257,9.822855,-48.887053,-50.10263,-64.003616,-189.913139,-256.944302,-247.378904,-183.035287,-84.516385,-80.662772,-123.167176,-148.8472,-148.749226,-116.578967,-78.813091,26.144877,66.351675,36.344007,-15.077277,-57.180777,-93.052107,-138.891577,-176.633319,-140.274344,-16.866996,26.058594,12.368434,-44.20104,-46.025754,-9.268266,10.29633,35.148489,39.57248,26.248229,6.203506,-22.815729,-19.110552,-21.965042,-2.578525,32.178636,119.775926,158.119531,223.571969,227.075249,171.939346,32.359342,16.698093,87.565878,133.231839,199.987459,192.1241,81.799017,-9.952447,5.145948,110.851163,129.612039,85.281932,64.549546,30.336032,-11.253642,-27.699024,-9.643991,45.666869,197.878624,242.858069,227.231934,200.932164,159.047069,81.075839,40.109676,27.520637,66.119094,182.898489,209.683546,177.846899,186.350175,204.66538,245.640746,277.142597,319.107663,334.53465,369.592828,371.948348:97.756118,7.731237,19.637177,194.805481,297.989846,412.147602,410.114834,279.051093,90.894193,31.083995,9.956902,14.541525,-12.59191,-22.123269,-16.985102,-30.2512,-75.045371,-149.050784,-187.486397,-164.970429,-129.799255,-101.633616,-112.1848,-174.8696,-230.426161,-244.304151,-181.036099,-106.486123,-5.516891,21.715285,83.074069,92.599737,42.434017,-13.039967,-2.923524,119.737993,198.536526,292.238045,283.178298,170.323828,53.166594,3.345089,-51.817733,-47.911985,-8.849983,25.162629,58.464919,8.11092,-189.498089,-275.907367,-234.611559,-74.216362,-17.33964,-27.403041,-67.065422,-131.549947,-212.887603,-265.344273,-247.198361,-147.763462,51.042931,85.868238,38.791707,-22.6161,-121.28058,-79.71881,-20.782443,137.868324,216.589444,254.151444,186.665619,-2.272396,-83.136724,-103.148729,-145.674446,-139.536102,-88.153646,-81.523538,-109.800311,-114.92707,-112.301997,-129.746149,-93.122858,104.750957,199.82649,261.929739,242.194822,154.451388,8.331917,-53.486111,-12.846614,86.916803,250.174868,268.206818,222.052906,168.594384,2.858646,-128.328733,-133.223509,-52.703812,-21.612229,-34.146088,-71.964447,-186.477325,-234.828648,-212.387779,-107.705853,-45.903608,47.835301,66.569556,-8.693901,-93.092452,-218.399528,-259.58464,-266.354031,-196.883225,-108.2238,109.902036,169.698446,90.057307,-46.36325,-65.65962,-53.012222,-34.611502,9.786019,10.437486,-17.461974,-22.94235,-76.88966,-213.198955,-232.005373,-126.948815,-64.979533,-5.530759,-20.590303,-170.615389,-333.794998,-359.683771,-293.616305,-230.04868,-127.115311,-95.861048,-82.89176,-104.251176,-114.545798,-31.967579,9.016975,67.620245,92.566563,110.931206,83.23355,-5.783723,-12.876344,3.309347,38.417666,78.1497,170.356224,169.480694,54.360843,-1.463925,3.539304,76.340696,102.866685,127.588344,119.215724,105.963114,123.35377,130.956464,47.787029,18.421767,47.188376,85.451534,157.719884,183.959394,168.800218,132.21907,63.059862,-30.147866,-80.496017,-74.278976,-8.550967,102.006896,92.427011,-14.738481,-114.577807,-160.40466,-194.262871,-148.859036,18.363194,95.975406,155.564611,124.565811,-9.445427,-144.69417,-176.65946,-133.922035,-75.234485,31.812706,45.799115,-41.237412,-199.365673,-242.518399,-161.428492,-63.608042,102.212428,142.429044,76.90201,-38.733973,-265.195322,-269.537156,-197.595904,-4.264086,65.98246,71.02989,25.702327,-49.983324,-87.100734,-120.768915,-131.7515,-85.39017,2.808366,21.602306,23.852819,0.828649,-75.048871,-86.196982,-50.039977,42.375345,68.627188,73.970606,55.667408,-33.748883,-124.114383,-142.703426,-137.674119,-131.273336,-140.199995,-140.365622,-118.464784,-115.645579,-139.598513,-200.946506,-242.562104,-258.381084,-199.58245,-21.058306,27.915853,-21.393502,-191.854561,-277.902578,-315.985102,-269.29272,-188.011286,-162.087371,-65.473196,-27.226956,-106.150434,-274.50096,-296.007047,-168.820562,-80.272321,-2.754571,-12.334002,-35.790322,-36.211668,-52.911207,-85.914379,-63.63168,29.534238,59.581431,47.672054,15.241314,-56.9876,-112.722224,-123.613723,-70.237707,-8.969839,111.596395,121.343802,-12.35013,-201.627175,-252.182678,-191.413838,-109.067514,-0.92033,22.496747,49.33559,33.914595,-34.55605,-101.825166,-144.431454,-183.443952,-153.180334,-55.457597,-59.217013,-201.427699,-279.054382,-258.310426,-121.26916,-28.00286,74.413328,66.274031,21.743649,14.614839,18.238692,-85.798202,-151.26968,-86.981126,36.13594,269.992288,323.230256,273.080363,150.977376,118.406467,128.144012,141.356962,120.375322,97.450075,50.839867,12.045749,-129.856816,-303.073317,-333.874569,-248.914125,-187.827981,-138.275835,-161.761821,-231.982026,-203.486555,-173.772481,-121.947616,-88.773422,-31.875945,-16.955074,-21.369006,-42.171175,-79.36275,-116.710622,-148.931688,-193.875597,-179.830318,-91.484893,-59.278724,-80.301767,-155.156855,-192.466447,-227.131438,-200.496419,-73.589979,-20.035208,-25.0569,-74.307807,-191.71126,-243.441911,-215.919581,-55.751734,44.231621,199.052668,227.62402,163.123187,7.761652,-54.712045,-66.043457,-16.338369,116.450565,155.915491,125.415508,72.541206,-35.540881,-66.146049,-24.01792,94.927562,128.367582,167.940224,184.48991,148.378674,17.964328,-26.877392,-4.240864,54.819149,237.658607,328.548898,381.202759,336.194422,204.664313,109.237528,116.918839,230.376243,266.740548,268.234838,278.039612,334.769106,336.062471,305.875655,308.160169,362.189984,501.76821,567.102832,635.948557,612.890461:-60.419836,-28.809851,10.686567,70.613784,79.728589,123.972091,155.378966,147.671621,93.683933,60.856352,-27.98566,-55.470406,-56.645218,-28.91349,54.595852,57.329412,-17.716628,-18.425038,11.113296,26.648038,14.364498,37.310143,67.013632,96.508893,108.992647,100.622376,67.220533,78.009503,171.55228,236.206693,327.842413,322.723748,262.29308,217.309377,187.513024,145.342544,159.255011,236.4333,263.35339,250.035482,206.181967,154.685685,-45.498919,-126.635616,-152.182374,-133.635128,-138.449189,-171.069237,-204.626863,-122.968848,-54.784967,107.623425,170.784733,163.907163,100.460923,5.355708,71.330231,92.448727,30.925345,13.491069,58.725072,67.214507,-9.524673,-50.390514,-29.926659,25.640971,44.488329,143.33682,199.440466,194.507954,143.983344,71.392077,33.362802,-7.732617,-101.563208,-137.704401,-203.669071,-224.54124,-236.157932,-227.620663,-152.329114,-121.520951,-156.957771,-190.867479,-154.695145,-11.271474,63.427071,88.027122,-31.898805,-64.737773,-30.114923,17.621999,110.519555,137.578021,120.74646,73.479721,-31.820642,-101.969631,-143.646993,-238.314989,-257.925204,-211.43983,-176.344699,-126.120003,-100.499378,-106.317916,-143.803839,-175.074676,-286.862516,-339.780709,-333.941555,-288.821139,-229.291094,-275.028497,-315.436616,-314.28319,-254.436564,-95.396536,-48.682885,-72.217096,-120.153935,-127.956596,-174.343319,-205.32844,-239.65042,-242.39995,-239.08446,-237.769671,-202.267356,-154.265529,-167.66278,-203.046377,-189.034033,-182.141547,-226.892273,-379.563352,-498.669279,-517.321368,-461.767952,-403.200853,-320.853793,-302.753815,-266.206343,-262.765932,-276.988767,-226.314664,-176.584896,-92.432662,-93.886827,-147.768228,-151.228785,-130.913335,-138.392757,-144.752909,-137.999598,-123.638058,-123.336589,-149.318403,-196.095702,-191.558757,-149.334176,-130.331127,-133.856391,-120.355782,-102.087041,-119.277117,-170.103199,-303.787914,-361.435686,-374.559245,-416.350563,-402.058247,-285.578592,-233.944748,-242.447802,-286.752991,-319.72528,-284.115974,-267.366323,-221.945405,-209.348788,-233.673752,-263.458861,-314.159339,-339.123407,-357.96607,-361.959962,-323.141154,-196.685116,-128.060456,-36.297163,-47.565964,-180.188086,-294.863204,-297.554792,-204.457801,-155.393194,-169.494964,-217.710099,-252.00272,-150.758314,-94.943155,-36.446343,-9.81311,67.76917,94.622568,62.48555,-2.214261,-106.529429,-83.798972,-55.761463,32.428603,73.462298,34.142081,-34.774601,-120.916199,-60.522448,-6.381987,70.517312,80.409093,62.27817,72.888569,183.238093,239.677383,239.266934,182.621521,183.536194,199.042047,195.913689,191.731546,185.438707,148.172815,172.476267,194.818659,128.451942,60.887058,16.834706,51.942391,129.674793,147.843442,167.723905,159.845021,150.519061,175.55238,198.560184,190.995727,176.815203,191.572963,203.655438,180.828559,114.830135,110.943699,169.582327,212.671319,258.397629,225.519084,97.144039,22.970268,2.4125,-16.069082,-1.578887,65.367513,94.544079,100.944114,70.346344,49.265075,9.851351,13.568404,54.629381,73.039198,74.821795,64.230973,78.5412,43.679932,-10.549251,-24.993762,32.026196,140.738168,157.272549,141.577714,163.132976,192.773133,205.575524,169.041694,52.823554,21.581542,44.628412,50.021261,-10.483374,-96.330513,-121.271346,-92.361463,-53.119123,-5.89447,-5.260059,-7.144098,11.798563,6.014053,13.6182,57.541597,92.844098,41.012816,-62.0039,-62.295204,9.108403,65.164085,47.941349,-11.125487,3.274132,107.932804,148.848056,136.629698,51.388896,20.021243,7.893439,23.898054,73.130046,85.179593,54.683721,17.27485,-55.463396,-98.37909,-119.574049,-134.188316,-109.27435,1.45827,52.042857,90.722349,119.602186,125.339997,109.774444,127.811919,236.757509,274.956593,217.437551,160.478477,124.397591,68.111915,5.422807,-19.092572,26.164059,78.583728,57.546369,-12.200639,6.362826,33.246736,68.782423,75.917539,55.323386,46.048933,60.173385,58.821869,8.063123,-2.430131,29.169096,99.22009,123.493398,178.171239,210.398686,257.878075,246.218004,195.929574,59.745834,31.4784,95.152568,165.683125,271.396236,246.460771,82.082885,13.08338,50.321472,186.194852,201.480463,75.852057,17.06859,4.09624,0.832482,-21.832421,-40.66034,-8.557687,108.076031,152.619856,145.573272,103.20325,3.519479,-101.242015,-126.952532,-72.805286,-32.422302,8.758227,26.527288,52.764505,32.880571,26.213774,99.036768,160.9653,217.368608,228.765715,335.379124,418.184809:23.615828,-3.358531,0.07075,46.775583,103.625429,254.063455,277.686112,191.487583,146.449529,116.422013,-66.223165,-166.919239,-223.41664,-178.92637,-91.70758,-73.389358,-34.738333,-57.226017,-84.773992,-20.945174,55.189542,141.116833,147.349773,86.867603,-37.870165,-63.450902,-16.936501,34.518801,185.234413,269.056674,362.707356,361.690299,308.334963,219.540081,183.310463,184.927259,211.218749,248.85818,242.031821,183.501364,167.485648,157.403214,43.565296,-20.243352,-96.909588,-134.153846,-227.805609,-259.205625,-225.432177,-176.970542,-183.281137,-143.523525,-83.389798,46.75133,87.915031,47.900654,-80.31498,-123.494394,-136.136261,-113.231937,-84.646578,-103.625742,-157.610515,-137.63098,0.262305,27.249139,-5.552955,4.249813,44.781514,73.119309,58.510145,34.385999,-15.040672,-57.353737,-137.762407,-188.677058,-346.872084,-409.374432,-410.591476,-378.955345,-318.626902,-267.393035,-257.700363,-262.828159,-238.998514,-67.678763,29.989071,70.01448,-50.333634,-111.697589,-138.563706,-92.815073,-2.285263,9.549749,-16.301135,-59.351402,-194.828085,-327.810783,-364.664459,-364.639579,-349.63022,-301.807739,-262.21316,-161.285021,-65.607974,-68.462264,-226.770598,-322.698863,-362.083728,-296.736392,-182.611347,-192.695979,-268.060213,-364.811487,-412.686686,-373.842707,-283.581699,-93.687136,-47.59231,-78.655264,-86.691749,-67.346034,-106.717545,-151.188515,-194.516321,-193.601651,-200.178318,-215.048903,-204.823314,-151.110376,-132.012848,-62.293811,-11.96266,26.704264,-13.805589,-173.907256,-290.304765,-308.95018,-280.146178,-235.666655,-143.385672,-130.479887,-159.99801,-166.851735,-108.466316,-38.29687,-30.438604,-5.86842,21.874491,26.66285,-15.42179,-133.64281,-192.13937,-191.596778,-142.541445,-108.557019,-126.660635,-171.781216,-189.975548,-153.513839,-78.022315,-45.87783,-39.578358,-41.759455,-50.661113,-74.149859,-92.053302,-155.549185,-207.246998,-216.570397,-209.591705,-201.333083,-212.977476,-221.54194,-207.881876,-197.708489,-183.432191,-192.46186,-208.360888,-166.42485,-108.026551,-26.727349,-20.576187,-49.759759,-98.449051,-120.658135,-100.900938,-54.782231,35.047016,61.488957,65.58362,26.155317,-82.215909,-164.013235,-199.148569,-142.949818,-64.043314,-18.75341,-69.565973,-183.663911,-195.95455,-162.742931,-44.119447,29.819418,157.803491,190.970419,135.409899,44.618282,-93.583039,-18.219016,36.327237,44.272021,19.760164,9.955725,3.166494,-91.004128,-133.058435,-79.580188,61.334329,88.107227,75.56855,81.055489,122.392338,144.400844,206.842592,252.08646,253.418745,240.550097,235.495018,255.991472,265.679075,215.35721,183.42181,190.499008,178.182165,146.525854,61.979319,46.427207,90.538592,115.734777,105.800919,57.201116,63.425357,125.170471,144.242506,159.988263,173.949646,165.674493,59.711848,-2.553374,-54.787959,-29.47257,98.370512,173.061871,225.769627,171.104755,-12.786814,-106.903987,-100.345243,-57.270059,-50.12442,-51.701806,-49.028699,-41.805193,-35.952715,-51.219762,-98.269439,-110.576282,-149.860397,-176.804171,-187.356857,-170.96992,-129.810328,-133.84271,-156.599591,-156.394744,-115.989593,-29.878068,-19.112361,-24.47613,10.69474,-0.694871,-113.5143,-153.973774,-151.495424,-144.387704,-151.810941,-165.38188,-191.021009,-165.223133,-141.605249,-109.72825,-101.617114,-103.076774,-114.505305,-135.128559,-129.196423,-120.597647,-91.438481,-63.009838,-41.278536,-62.244642,-94.366779,-99.104864,-95.38214,-49.348749,-25.702764,-4.151312,18.570875,174.246113,255.158723,203.957285,41.086741,11.454212,3.412192,9.592366,51.764958,79.265278,100.222565,91.266391,91.151507,15.817734,-65.801082,-126.647215,-89.348072,-46.241532,-61.481045,-39.227439,59.793305,69.239427,41.162743,67.210004,176.493602,203.184031,155.831003,102.522142,17.599581,-20.194974,-41.777226,-46.33777,-20.74279,17.358402,17.546325,2.955392,14.925653,39.344288,88.783053,89.387298,31.496135,12.764605,87.09628,145.012387,158.25779,59.383147,34.014544,66.333589,75.718865,79.918057,117.362187,207.241969,176.380223,118.000011,33.618119,43.459386,128.125188,181.324991,266.986448,255.408258,106.347153,14.579984,27.532044,66.360533,54.804008,-19.920835,-55.2608,-104.370574,-105.43717,-95.03711,-64.419622,-28.026644,57.974439,77.562515,71.785676,73.153236,91.312849,18.141481,-47.956247,-90.870137,-53.277339,52.672103,85.663944,138.400401,214.249511,204.652371,100.804851,74.263631,129.462362,185.855335,283.170304,317.15485:-10.086066,33.285225,42.2451,90.63287,157.190371,295.700613,310.574558,198.966472,65.189359,9.64546,-49.712129,-30.748277,41.989448,76.642941,154.285399,168.506742,94.851948,-25.164264,-50.533106,-10.447552,14.599409,19.061688,16.831648,28.142894,-40.863753,-106.974226,-98.085366,-5.109188,129.107933,114.332932,30.241438,25.534087,101.510344,106.382084,78.438613,88.362064,114.652519,118.834263,99.971714,92.037423,140.718652,129.383897,-18.722779,-92.503452,-105.38156,-75.065266,-56.309794,-70.460641,-128.749941,-166.016948,-129.745246,67.807221,158.077665,156.153969,93.243113,-18.231304,-92.851699,-132.884828,-154.395856,-100.274907,32.660691,53.043459,35.06867,31.735358,50.484109,94.394546,132.856467,225.755294,254.868497,222.780737,176.479487,145.515167,165.723729,98.736664,-121.366551,-160.431287,-150.303128,-178.03477,-167.792229,-77.698721,69.495103,-10.41515,-55.592409,32.227084,134.065217,275.364056,290.697392,221.260445,92.49024,52.922424,86.435576,145.143515,228.119359,235.221487,189.995308,125.953976,-46.11223,-122.473098,-101.432664,-47.871221,-70.755878,-143.554883,-133.499731,-80.041953,-85.686574,-87.045659,-54.269122,-48.949843,-122.876693,-168.409982,-190.330562,-185.752683,-212.439631,-285.177742,-300.695277,-218.768093,-145.399285,-29.867694,9.356734,35.323436,-68.974173,-117.738164,-105.208013,-80.889391,-93.580489,-118.082447,-175.9072,-215.831433,-267.459884,-244.620259,-216.704746,-171.971551,-170.625955,-176.560523,-182.69305,-248.220858,-346.014842,-378.485279,-387.508,-365.685241,-265.772479,-200.930671,-166.440072,-207.882786,-246.963404,-198.513865,-175.1257,-99.353313,-42.965051,51.005301,50.115216,-62.823824,-119.722574,-108.170153,-67.599983,-13.075484,103.213591,96.188185,-14.091709,-40.469326,20.790484,56.210012,40.149893,7.22821,-2.438681,-6.567964,-17.597123,-100.829723,-131.81055,-94.716792,9.991551,36.160537,5.758205,-1.796894,55.600485,51.371205,-95.554515,-177.902219,-169.445547,-149.522234,-130.321245,-58.899454,-41.8946,-101.584283,-180.361638,-211.621366,-282.340999,-279.473184,-123.718255,-22.184924,16.782268,-57.011848,-225.167778,-286.961881,-271.493288,-159.55917,-100.359181,-61.612187,-82.737954,-169.9608,-235.592232,-233.504533,-140.014336,-70.247306,19.044265,31.699709,1.877497,-49.823358,-156.926597,-204.198515,-198.305504,-66.75891,10.309259,19.642171,-35.216104,-116.555742,-50.130829,7.642153,88.815077,102.246569,81.506472,61.997053,17.224063,-5.440166,-37.56487,-57.765441,-53.246977,30.745303,75.929225,52.52699,10.179064,-35.024637,-62.539851,-76.492927,-74.50992,-69.076497,-76.517871,-64.697911,-20.510636,-26.279368,-51.16197,-11.734904,-11.000556,-43.506984,-12.750536,141.086378,195.275014,154.484278,10.973009,-40.634993,-86.513913,-81.769159,-15.907262,38.247611,89.01373,36.727741,-126.139805,-170.192938,-153.897639,-86.767044,-56.846047,-45.468352,-31.993247,60.958004,87.786678,61.086029,35.79706,36.30227,6.386538,-7.902117,-6.920271,-2.59626,-8.506948,-71.295011,-93.487459,-13.813411,69.612203,184.89705,174.333278,44.310657,-1.143655,21.111286,11.206289,-12.961237,14.398089,59.478706,104.98237,81.5264,3.317225,-53.781427,-83.073777,-112.244338,-100.907718,-39.732388,-22.182772,-110.56396,-210.161953,-186.510923,-26.32816,59.787109,139.417265,129.628641,57.905759,8.099207,-62.420705,-60.485805,-32.456652,85.786831,145.377041,201.725917,205.422034,169.835891,81.095327,59.623668,107.032762,139.031287,124.137846,91.551929,65.239756,51.618844,-65.047036,-242.418076,-293.343781,-251.876468,-193.930286,-97.57457,-65.247102,-37.729389,-99.801296,-146.377007,-121.520804,-23.667297,161.641169,180.343668,126.967668,104.625462,117.462247,55.994693,-30.808914,-146.801339,-127.865565,12.926057,60.172979,-27.297719,-89.066911,-48.758084,-36.571509,-76.227498,-103.186423,-89.399031,-58.607155,-38.805826,-1.63839,-5.951762,-11.812287,41.854515,86.446637,169.782203,215.646036,227.800529,93.21399,29.811483,-8.503528,18.269215,93.024284,107.859932,82.576019,66.514421,82.554353,60.25256,17.052203,0.833039,39.331379,122.328969,138.834104,81.642411,-25.155598,-47.993642,32.348241,107.946811,175.043883,167.608799,194.086046,211.794954,169.183868,85.298101,53.202068,29.569779,25.434682,47.166554,91.718041,176.386363,187.64069,172.971052,162.172024,197.590618,334.135399,393.506858,427.731773,429.523442:right
68.295518,161.008525,166.17693,73.826191,22.370977,-23.779866,-22.252041,7.787894,17.156596,18.259217,57.728916,79.015998,73.003384,49.783632,40.263197,82.080172,168.47581,123.435913,86.46556,47.985734,20.773007,-109.952421,-172.708417,-109.478678,120.918753,205.670679,246.001278,212.554158,148.946302,141.437901,127.267018,123.522072,154.082264,223.355578,262.857189,254.333213,194.584735,50.331461,1.134123,-23.691813,-47.725673,-60.858333,-14.940268,23.769766,46.612988,13.842784,-66.774874,-51.211948,79.174709,131.471313,95.776481,-36.090755,-80.034665,-48.730258,-7.753897,30.5643,74.778956,118.584612,179.059735,168.874682,93.002013,50.549415,4.621455,29.438525,155.487148,190.097918,132.012609,-18.731973,-43.156716,9.549487,43.309523,97.312778,157.330968,199.85142,275.684709,270.123124,153.929048,77.734463,16.452646,49.328803,91.800267,7.859071,-20.458992,2.887582,30.287795,41.909354,36.613033,64.912866,50.718487,14.312413,9.205862,28.497286,-12.374606,-68.787231,-151.81977,-142.487816,-49.228332,-16.501874,-56.535005,-175.8554,-184.723304,-97.323921,-72.706425,-115.232105,-109.176139,-54.715824,54.083407,78.619102,72.376716,35.930589,-84.267306,-138.911528,-157.543313,-40.450578,-10.35249,-81.637836,-105.491312,-70.981724,-84.378085,-182.779466,-152.612756,-75.751295,59.34587,81.549173,44.10814,-8.812491,-95.683924,-84.800346,-40.739885,-44.933432,-20.520899,55.701446,62.177451,21.817825,27.799715,115.447553,95.734728,43.30833,-12.366967,-26.280778,-110.311345,-172.596198,-203.167029,-141.974841,14.436418,54.673636,24.37653,-78.415453,-103.478447,-39.356924,22.349008,110.952748,113.731598,126.853025,201.898988,197.734388,31.385266,-67.689518,-86.617241,-5.05354,128.179263,115.680781,104.328105,125.746188,139.606636,100.846413,63.93567,56.318274,82.123495,78.531486,59.430293,63.102605,84.22177,56.579715,-48.784701,-50.226669,64.432958,131.608758,121.133413,95.128459,87.080938,-33.205042,-133.55169,-218.291336,-165.852797,-140.445042,-102.885637,-115.604041,-216.02996,-251.280927,-213.719261,-155.443877,-44.608056,-52.451747,-90.10108,-141.24632,-148.693831,-169.27712,-181.197596,-180.347948,-132.338357,-90.708087,-32.653239,-27.54721,-14.673018,-0.458119,35.267319,71.484677,172.754016,172.556814,102.668508,-90.019658,-158.224661,-231.549113,-268.926395,-319.465414,-234.541892,-147.707557,-14.474534,9.88267,57.119311,68.790824,-8.747306,-44.719219,2.761692,49.353161,1.598111,-194.712585,-265.631671,-284.824461,-269.905278,-237.029674,-236.575611,-249.928441,-229.340165,-184.984445,-127.169719,-168.078231,-315.100201,-335.138358,-250.059443,-200.272445,-226.249404,-280.845676,-272.395941,-245.367421,-237.486043,-207.514825,-190.483715,-169.936869,-101.826552,-83.656729,-66.03173,-47.369398,-13.633462,-4.034295,31.59704,76.025668,70.189604,56.076341,89.146772,148.109726,131.897484,103.350163,150.398275,159.929434,135.160346,118.081621,87.646769,71.92024,62.008382,95.423414,209.155137,243.214198,213.132041,82.719017,34.306936,60.977902,103.920788,159.50761,185.5054,199.101836,196.1564,167.648867,98.848575,67.33362,-7.901687,-32.86873,-15.203216,30.699682,39.119311,12.272235,-16.334086,-87.150654,-103.726658,-28.740646,96.709983,150.254619,207.666708,152.613943,-147.012542,-286.860803,-297.834241,-201.85855,-47.262522,41.946309,69.406034,9.499557,-56.054113,-128.676603,-118.105315,-60.79645,-67.461898,-86.830376,-62.870762,-43.381001,-92.328644,-133.31338,-119.336686,-52.872451,103.703741,181.959605,184.246339,112.677592,63.526495,-10.735867,-26.308029,33.637613,108.848734,105.363187,49.801433,24.006609,45.336085,88.672266,128.225856,112.063611,98.108734,133.893666,139.962018,48.253558,-55.23345,-261.22763,-297.612722,-215.630241,-127.717447,-91.866279,11.616704,37.624388,0.736358,-23.147537,-36.816264,-38.579166,-10.310679,99.998393,133.948278,56.586563,-5.171131,-75.450466,-91.209054,-40.759677,118.875744,197.772108,300.522994,309.72644,230.597723,145.952726,-43.217815,-89.277284,-11.425661,138.028375,166.994524,122.160012,87.253947,76.942915,98.434207,112.938599,86.441303,74.642205,-16.686545,-82.332093,-108.051124,-80.625585,-33.008812,13.851855,132.757407,139.039871,106.011215,56.024621,55.86965,40.035682,6.167425,-34.103911,-14.664036,-13.24641,-71.251828,-135.110272,-259.668221,-290.644655,-300.662138,-289.633344:122.002338,248.512772,283.294894,199.504054,98.919635,-19.186775,-1.387097,64.827063,76.506677,89.101623,111.245335,87.98929,4.493477,-18.556825,1.654263,42.720949,124.087142,69.27098,22.344886,-9.933927,-24.421602,-107.276324,-127.848702,-3.268331,208.860068,268.42167,219.455633,138.202855,84.686976,129.723881,202.201588,207.632855,215.744864,241.511999,252.775369,236.827608,178.165435,-35.214606,-116.136121,-119.105924,-80.428998,-69.966313,-54.415677,-71.142599,-109.231455,-106.847418,-51.821674,-11.630669,10.889574,12.417951,38.959963,32.039326,-21.682058,-69.648907,-15.13725,136.367437,171.237075,156.933003,127.433707,129.240052,169.021322,166.448534,59.752911,7.532946,59.208335,194.609946,180.058037,9.270183,-52.161527,-75.613976,-81.554397,-77.568279,10.998988,62.967847,120.656323,117.810733,33.979487,-46.907042,-155.201336,-127.541882,-1.689528,60.908268,62.596461,31.206016,7.063942,-14.024059,8.94517,76.504643,124.038036,148.11687,143.959734,112.036098,59.323492,38.785104,6.923181,17.095246,69.413198,68.078053,35.684802,-42.481919,-62.106391,-59.930634,-57.702086,-67.935713,-6.997471,62.979138,154.771081,160.631847,164.608791,147.681089,25.718131,-41.895107,-45.525008,103.702097,142.592288,112.236771,90.997162,43.125184,6.212192,-9.770892,83.973702,118.249537,73.967646,22.218766,-13.899238,3.706072,5.182544,-23.887029,-52.843169,34.381515,71.852577,30.504536,-19.625994,-70.256653,-34.967807,93.424671,93.801183,74.465635,71.236849,55.194623,-18.757878,-43.03913,-26.911091,6.544354,115.52551,250.420332,271.313577,158.149254,89.627952,60.181336,79.096067,114.260734,133.449658,153.295599,228.362232,236.67864,113.941832,44.361133,62.839006,112.357202,109.654445,99.079909,147.265823,211.218399,179.52273,54.631436,18.699564,46.39848,159.558474,222.394118,256.433677,225.102892,126.198564,75.749387,57.131553,99.404776,154.454769,98.658169,69.28547,38.121871,5.852008,-137.365911,-203.304448,-210.142108,-145.235573,-121.927243,-106.290459,-128.308912,-185.793095,-195.910802,-200.658523,-185.871208,-93.717761,-47.299813,-62.852986,-104.886308,-143.277732,-268.389364,-295.870322,-234.29509,-202.685814,-214.070995,-233.700935,-229.543325,-155.342389,-96.102543,-31.143881,-34.00367,-39.886495,-25.547259,-58.995775,-214.855694,-293.632045,-390.802289,-389.667994,-289.994181,-212.655817,-210.213491,-189.541822,-140.584479,-18.284571,-2.627599,-70.987992,-81.404533,-1.046337,-5.303442,-78.184009,-212.077627,-233.05658,-289.495049,-342.938064,-359.737191,-210.865231,-168.364182,-212.987061,-236.498859,-228.814398,-230.691328,-247.664253,-237.814163,-162.512156,-84.888191,-85.947513,-113.364495,-100.822893,-86.892587,-110.055729,-125.763955,-45.082112,-11.31019,-47.842569,-98.179811,-175.075717,-207.440516,-201.079156,-122.189207,51.232884,56.932491,31.307645,48.665754,88.831296,118.366657,93.118279,20.428453,-13.350626,3.558131,46.528962,30.673215,-68.32985,-115.697754,-148.926989,-115.03076,42.549105,150.826882,154.366011,137.393683,135.653584,114.740185,102.287208,106.911106,115.038865,129.755572,201.221325,227.435062,160.711681,75.659541,-46.791318,-41.455934,68.376321,169.592037,155.137814,5.538133,-56.21816,-55.331522,-33.489996,-11.083782,97.409087,168.952577,130.474927,8.240247,-217.758017,-243.679745,-147.028861,-88.45412,39.046152,253.655528,291.101055,82.02169,-59.627728,-114.100493,-24.72755,167.311213,180.880531,151.841235,131.975786,123.298724,48.096656,-0.421571,-26.944692,5.933787,98.570542,149.915645,137.303269,70.003165,39.341357,-42.185609,-75.74879,14.228941,184.013649,197.768576,85.790988,11.274566,-48.550188,-23.128051,50.995509,60.982415,43.179805,17.434185,-19.289405,-101.23835,-117.383353,-150.818257,-186.673683,-217.738124,-106.806632,-24.810257,50.366166,33.771947,10.289746,9.310658,-24.17908,-36.202048,10.992569,97.342819,104.667331,19.506772,-43.181558,-141.040993,-147.42267,-30.357434,171.095166,260.628265,375.351372,373.529851,215.017097,100.393902,-32.669085,-40.216768,-16.995604,30.43726,50.924451,60.420461,51.927607,23.679248,26.613038,76.045314,108.521292,97.920386,-18.773912,-88.73652,-118.830023,-99.497382,-72.476211,-46.67045,36.947641,60.253184,30.886294,-66.53705,-100.981047,-115.53927,-117.950763,-126.972683,-114.593602,-123.84167,-175.829082,-192.452532,-229.784145,-288.451179,-423.871708,-419.136541:183.951241,295.115868,271.001177,128.505345,83.452355,76.50944,78.71011,73.633566,155.870725,242.723943,292.181889,193.115504,-70.734292,-139.448656,-115.5936,-57.510336,62.581046,89.900393,67.082516,41.48493,46.33858,1.225769,-37.377294,3.779313,161.172737,195.768923,130.896413,83.557572,34.384005,16.84206,12.434796,37.505767,129.520882,237.468849,225.886497,19.647982,-91.330988,-143.391142,-120.012958,-150.463561,-188.17776,-150.307677,-74.541598,-83.123929,-115.356922,-111.329025,-101.940868,-101.571515,-82.449123,-33.988921,-41.55103,-153.983132,-201.57217,-159.807481,-80.548755,90.391783,165.169639,167.752695,156.019536,152.186374,127.891847,97.51918,40.5111,42.03125,119.310115,187.371369,153.818157,-13.974613,-72.892822,-108.916426,-114.038817,-72.681162,20.526373,52.981159,30.697684,-23.320459,-131.104836,-156.316457,-130.557889,-99.994759,-56.328332,16.452333,54.668387,85.174603,85.354551,96.081695,113.402556,164.88515,234.302273,265.774567,264.633622,227.08626,128.384773,85.178273,48.93108,55.050673,96.953912,169.848585,167.860464,21.29682,-66.276433,-112.368409,-74.798521,-13.536768,26.688993,68.88412,122.000355,132.033414,190.198478,216.11535,167.491262,115.090738,81.094634,159.50416,192.481482,172.610407,124.954212,-0.278132,-56.22664,-102.32684,-34.420478,16.742869,54.802263,29.196995,-65.853088,-112.362901,-135.664071,-103.247977,-21.275624,-3.942861,-35.614697,-88.750741,-77.260235,-65.875093,-72.376746,2.085816,139.78545,179.698887,181.994116,151.01002,44.677692,-11.28931,-21.390802,32.519201,162.386823,268.134525,281.3451,180.613751,106.182526,31.987853,48.378286,135.627572,153.144096,133.262394,147.026594,182.173613,207.307061,182.388078,104.954858,77.747321,61.207841,85.641503,121.813342,182.873373,155.351688,-6.688284,-52.912631,32.270511,195.565581,239.817242,187.495454,129.043382,72.952506,66.980492,38.894706,26.091131,58.142133,140.427571,133.761667,12.972526,-50.777773,-162.075122,-204.279647,-216.049306,-168.924007,-140.255753,-134.846123,-173.374282,-246.163581,-251.408497,-219.613017,-198.35194,-128.674382,-23.011646,-27.721593,-180.461613,-270.963582,-375.880967,-368.249516,-275.294118,-238.813649,-250.941607,-263.235627,-246.311165,-199.58375,-187.322312,-161.383084,-140.83322,-107.256009,-126.591065,-180.180005,-326.645951,-375.187368,-402.629915,-395.548989,-360.417309,-293.723541,-243.444841,-173.740329,-182.406392,-216.309267,-203.583995,-150.664878,-128.88468,-101.789085,-152.550993,-201.083841,-251.979717,-254.922084,-291.73505,-316.466484,-256.239244,-97.114907,-70.797916,-149.5211,-184.390193,-140.410988,-96.867804,-50.908075,-43.502177,-51.957814,-55.682587,-46.996778,-32.715852,-25.192274,-35.09554,-61.356574,-77.935123,9.333624,38.770527,-4.426994,-52.597053,-158.7103,-209.468778,-217.9067,-154.172544,-6.025878,3.873566,-31.930622,-34.803256,4.96626,39.733144,25.471005,-2.687062,-0.682585,15.160372,17.44662,-11.453443,-63.66798,-74.489244,-76.936761,-45.509771,100.295086,181.985575,141.914481,-1.517347,-25.799722,53.420425,111.934774,148.102564,75.15719,61.971304,109.864735,126.493497,53.762739,-27.139418,-122.502652,-86.999011,85.93024,202.769099,191.23168,60.913137,-14.477914,-118.099271,-117.665532,11.75747,156.622537,183.42702,151.588473,107.393271,-34.952364,-115.790454,-159.961341,-93.901957,131.464888,297.512006,300.525263,169.28404,80.969028,-2.48286,45.06742,218.513297,273.044754,261.827106,214.560261,167.401374,43.345482,-5.33373,1.19513,58.834772,193.742487,247.348218,223.01093,108.880068,49.788621,-15.240568,6.092114,141.783099,271.776543,289.52385,168.643134,89.364643,42.403324,41.584209,22.309686,15.531897,5.364639,-3.791073,-15.470008,-36.807179,-41.574492,-118.466418,-178.183752,-154.514234,79.959325,168.583184,145.071332,84.836444,39.331228,54.889494,82.966336,64.574527,11.29343,98.119464,142.088592,117.289596,82.910495,21.198494,-0.38106,47.564948,245.400762,327.791811,313.98299,263.834083,184.301748,138.670688,36.43788,1.293305,-1.229803,88.42176,133.757912,110.520351,58.622658,37.190359,77.182915,120.874303,63.44173,30.332199,-42.653284,-72.982552,-69.259991,-47.15926,-20.809926,-13.365325,29.769356,63.120516,41.016556,-43.621536,-59.321043,-58.393341,-73.586946,-88.766416,-18.226967,17.095698,25.903141,11.013431,-96.955282,-203.131986,-358.550579,-351.987946:235.141551,298.260826,242.747718,73.253527,-1.769004,-99.238466,-100.248541,18.036568,128.270621,135.472284,88.199112,35.341296,-92.98776,-137.708805,-149.599218,-105.927135,45.254561,112.543221,94.493045,39.285351,17.590615,-51.032899,-95.168145,-87.599994,75.35342,151.534229,201.107013,174.103222,75.525565,36.488597,19.071861,27.25325,49.827702,148.295859,203.842995,154.427033,50.207657,-113.571844,-124.400413,-87.492526,-74.18429,-62.90286,-51.911194,-71.736796,-97.399676,-96.8255,-153.2208,-196.799756,-193.68969,-103.005145,-91.020407,-158.182048,-187.548386,-125.842925,-58.340456,27.816448,48.38752,62.179613,94.711068,101.119046,85.467645,74.469258,79.193196,85.697929,61.41225,44.285253,52.29133,26.989609,-13.136646,-73.567416,-65.162364,-1.027858,51.520886,84.385141,119.301476,90.922303,-16.200474,-70.187772,-135.600213,-123.123274,-32.701889,53.740794,74.955516,17.105137,-39.951973,-73.698785,-40.974221,31.021021,37.919304,31.872796,29.683001,20.582316,-23.475808,-59.47708,-129.509897,-123.14266,-29.29633,2.880602,-29.373308,-145.739351,-186.675755,-163.552488,-131.059024,-129.62887,-125.846843,-81.749983,6.807504,22.256825,14.41975,6.837741,-14.595552,-42.213692,-84.186907,2.506026,65.421402,79.614422,28.752301,-65.906345,-91.321825,-121.976133,-130.069976,-116.296063,-93.704948,-106.769147,-122.542083,-93.81087,32.013897,77.368421,7.156118,-98.540414,-103.735643,-82.760129,-74.419786,-61.703294,-55.100652,-22.551931,1.880291,13.256292,22.932393,-9.933068,-150.723992,-217.00941,-208.636818,-132.543828,18.795571,85.714333,94.084016,34.964721,-18.220501,-81.552157,-69.276199,15.246903,29.239525,1.267033,-18.579016,1.037879,31.574381,24.840072,40.137673,81.6106,142.824701,133.36785,129.791449,117.455413,93.79808,36.124737,34.814845,85.934081,117.297876,130.130592,139.92441,121.209129,52.966915,20.130279,11.996583,43.339982,109.357779,122.578859,115.077921,74.786856,32.709369,-91.361955,-128.787568,-107.996178,-74.748756,-63.352056,-92.995199,-152.833549,-244.78519,-240.98054,-176.428761,-123.961449,-21.472214,14.694184,10.822618,-55.467145,-117.023863,-186.999444,-148.137052,-29.376779,-73.826863,-94.440091,-0.613822,60.770339,78.314881,46.836378,39.860819,93.492994,199.652248,135.687073,62.807239,-82.873119,-142.128416,-207.506103,-218.89206,-236.419157,-214.674878,-156.934843,-20.484379,2.109858,-8.009248,8.449343,67.294967,74.850289,17.316372,-78.446051,-114.566258,-174.550069,-208.113699,-254.815524,-241.867036,-147.040073,-110.531376,-136.290583,-135.588416,-89.468027,-32.81111,-59.855139,-146.537723,-162.464507,-157.758324,-142.05123,-131.079606,-146.480975,-182.85823,-244.589657,-240.893144,-186.864256,-114.274081,-70.909217,4.811532,3.241757,-100.250634,-157.376121,-137.765929,-66.249997,27.733344,-8.564997,-40.03503,-22.261883,46.069646,147.816011,120.844252,15.72614,20.524575,43.430212,54.982008,36.889765,-53.763714,-107.343914,-113.4492,-46.994662,105.747487,119.645454,93.953081,60.916182,57.772251,42.842135,23.732965,-4.460001,30.609012,66.133508,115.121481,105.10887,-19.511293,-108.896652,-181.18338,-136.273812,-3.85428,79.075316,92.617209,26.419426,-32.752751,-120.120249,-138.89536,-108.054814,15.624356,82.301601,83.336722,-5.380553,-227.317103,-287.294078,-228.765874,-140.657257,29.677816,126.272171,105.589989,-77.065139,-166.877054,-204.275427,-148.384257,6.661363,59.77548,60.596798,64.155993,52.29584,6.615728,-15.307216,-29.412598,5.424032,131.222722,181.038648,162.430282,119.290676,107.971839,75.552498,90.719681,220.165449,277.871736,269.016793,236.517003,224.59149,265.07565,296.788295,290.061964,261.623812,232.724527,275.379413,286.162588,200.178184,127.867275,22.486188,2.78822,36.143005,108.58385,129.2408,140.018541,149.395614,168.421569,140.75839,46.208793,29.357573,32.065107,60.974583,102.193034,139.797162,106.35155,18.04612,14.284451,90.044656,163.159387,213.518155,344.534055,357.658116,214.75109,110.835737,-25.612214,-40.235198,7.163223,89.730468,125.947965,128.908939,91.242466,5.356748,-10.075421,6.07083,1.17243,7.583537,1.52961,-47.891143,-199.163631,-257.897901,-259.799871,-205.632987,-79.662762,27.870229,47.676668,-57.792369,-118.838653,-97.209353,-48.348852,4.136797,-26.215926,-36.806649,-35.296502,-70.410385,-225.917613,-297.387175,-363.085207,-361.063258:142.37247,296.908778,285.677018,130.564836,41.180631,-74.84289,-68.063592,66.74181,155.024481,143.447354,48.832337,-13.912225,-97.827656,-110.849161,-93.928077,-61.618308,48.968476,166.908811,193.128916,173.102851,128.77023,-20.323704,-72.039123,-8.016736,159.36327,220.202928,236.427743,196.345398,103.789646,69.067808,33.618243,39.95015,85.838444,140.804628,145.686467,35.40847,-54.924447,-176.06843,-200.17571,-215.489682,-141.702377,-80.571813,-48.83645,-78.302209,-102.808631,-97.621704,-95.223915,-91.802015,-74.133138,-77.163335,-113.007249,-220.415436,-247.269718,-219.150246,-172.388055,-53.21474,15.762796,44.854891,96.931761,81.121967,-6.568564,-33.106182,-40.036077,-37.246603,-14.92269,62.286831,85.250564,7.469703,-61.151499,-111.576454,-81.723614,-14.610856,4.041321,33.536431,86.782399,63.168958,-81.932169,-162.199301,-203.196387,-158.11018,-76.714709,-18.404307,33.640582,72.607054,32.492616,-57.021594,-55.04006,42.972248,101.772638,88.200391,13.258965,-25.044371,-71.123547,-91.265228,-107.813458,-84.239204,0.464216,95.229904,119.504753,66.730502,6.353938,-80.675872,-72.376372,-3.381334,35.13176,64.292481,111.417306,89.228181,3.345612,-13.992914,16.068289,36.633247,57.696152,113.883417,140.75756,117.984818,82.273343,-29.407121,-104.505453,-187.506594,-124.333119,-77.067535,-44.944332,-69.417884,-157.370697,-202.654718,-214.779795,-172.799913,-112.290297,-88.249967,-82.606084,-124.118523,-148.126444,-142.166108,-112.171426,-21.237476,25.980584,17.886158,2.463658,-0.770159,-42.924383,-62.683328,-14.888999,39.295584,97.384889,106.82363,111.049827,70.66462,17.212558,-83.932558,-73.587637,45.35278,79.993706,66.010355,44.90333,26.658827,-16.515415,-11.252933,56.497673,82.6124,60.529216,72.863023,115.519102,141.767908,104.188796,23.873234,35.332985,155.516748,234.599802,230.20895,153.819016,106.451007,54.941934,53.233698,58.167204,55.358631,83.78336,164.835185,169.05881,36.894726,-71.261694,-217.829669,-193.948829,-47.67804,-68.661374,-129.869585,-197.510306,-197.211178,-205.429822,-222.393724,-215.225938,-168.053371,-33.167217,38.530622,10.667683,-150.095401,-216.320141,-239.265819,-216.40367,-147.210113,-83.993105,-71.527281,-102.009677,-119.780608,-96.477155,-69.599513,-6.599371,24.783298,30.811061,-27.749753,-72.332446,-190.463398,-249.543412,-320.339093,-318.62468,-278.165712,-215.304447,-162.976836,-84.735851,-87.405379,-172.633053,-233.473738,-253.515652,-183.254499,-19.585165,11.659889,-26.248861,-143.059647,-186.958772,-249.036917,-261.773576,-205.729569,-106.850522,-51.104948,21.712571,-5.976655,-122.465418,-131.071846,4.563465,87.868264,142.734618,69.522854,25.277118,-11.014966,-17.107464,-68.833219,-104.614627,-158.430575,-123.886303,-54.360281,60.879232,58.941216,-18.900188,-43.12336,6.946535,54.807543,121.480028,172.939948,180.825446,147.013369,125.565811,99.189651,120.523611,214.837444,239.900617,235.01983,179.49309,116.589814,21.688251,19.172421,66.698076,107.873158,216.333729,319.593842,331.933224,228.353431,151.675595,56.807048,53.542206,83.256546,142.3124,198.030629,236.346109,187.157907,29.459566,-29.862584,-7.920011,57.904311,175.20083,221.490251,211.442741,155.849587,130.401401,38.021051,-17.96231,3.038666,145.055881,188.698636,121.039302,15.425338,-168.567049,-199.029888,-158.927576,-92.250891,131.631653,293.110619,270.209601,98.521836,19.770274,-94.876391,-118.722961,-36.148018,124.762848,180.077024,199.08594,163.13455,51.511746,3.106859,-20.613087,13.206698,140.922086,232.028508,213.892602,129.0981,108.499604,59.226626,30.801194,63.579851,160.844025,197.971056,222.714724,211.133577,186.119047,169.775898,132.779138,131.61904,157.662406,193.20235,190.836905,89.212945,15.932808,-78.288006,-82.678826,4.904006,164.60331,211.242134,126.850128,48.916076,4.52441,10.167116,-15.121354,-27.823965,7.911015,78.400647,69.774325,7.410494,-11.570882,-60.265185,-72.984777,40.414741,249.908643,331.251592,384.910866,340.0112,170.842655,107.981734,92.608769,106.829224,111.088219,142.806601,162.452853,127.501149,76.434292,-13.682479,-20.607139,37.551205,89.231646,96.490493,12.909306,-72.786937,-196.3904,-212.912839,-171.246302,-114.110059,29.944653,124.173526,131.976081,89.026048,56.919888,-23.535088,-51.134818,-27.868589,60.500734,99.91314,72.489655,7.996105,-129.809711,-189.285894,-256.541875,-249.326175:85.14514,165.782091,136.882654,20.54544,-13.332628,7.0166,33.870139,32.62576,-30.043321,-41.333818,4.686848,22.528806,-15.173157,-34.725198,47.306791,137.985583,232.413142,177.8895,166.077716,155.437803,118.243131,1.978146,-41.722361,-2.490477,201.468037,284.796472,295.530636,253.164138,173.179337,142.20429,113.136294,119.399779,133.006135,148.364122,161.681743,97.54747,19.618722,-73.166461,-66.734217,-12.537477,43.916581,57.243408,32.421714,8.059316,12.47289,35.220461,48.757548,43.333232,45.724646,38.303893,-11.340325,-177.118776,-206.540143,-122.273525,-85.510443,-90.763285,-61.279468,-2.996981,102.504835,96.363434,-4.759175,-37.70117,-20.098977,7.409602,50.866831,67.518962,64.582606,51.0439,57.012214,65.879965,46.696634,16.839795,106.88626,177.967409,221.858458,171.264558,72.547438,67.403867,101.628303,121.766077,128.488975,60.666354,15.82993,-49.35439,-50.504189,-9.622013,-2.622288,-10.730656,-23.160648,-47.265421,-66.274259,-52.150589,-68.203962,-117.331606,-221.662652,-224.084126,-126.151137,-53.382729,-62.496319,-130.278245,-140.126336,-108.384199,-102.087891,-95.392566,-72.316756,-66.836513,-87.894938,-102.313406,-99.235335,-108.268601,-206.806246,-254.133953,-223.860937,-111.120939,-102.369915,-140.497082,-136.146323,-145.930784,-192.999079,-256.64349,-158.482846,-82.231665,-18.584004,-26.632729,15.147172,43.514825,-21.143707,-93.369309,-185.914216,-132.328198,-92.745885,-91.950095,-96.328088,-55.646954,-17.102176,70.764692,17.522104,-54.496897,-105.965018,-94.76511,-164.907942,-256.393719,-369.980671,-325.917639,-176.640563,-174.049263,-179.550637,-152.613648,-154.470181,-160.139439,-133.714243,-76.817198,-135.467602,-167.406363,-117.051357,-71.515035,-99.991463,-159.023901,-164.03595,-92.681898,12.872758,12.910686,20.309652,35.041072,31.323946,34.376675,52.701841,111.037331,78.404071,20.247577,-78.889471,-77.694352,2.407651,3.228816,-92.990349,-96.78949,23.084878,51.290297,16.856393,6.386482,36.529533,16.797291,-35.872332,-77.748012,-65.674449,-68.520717,-69.28484,-79.246088,-149.045691,-187.274556,-152.064013,-67.169628,93.780557,123.953713,103.893402,32.534734,5.355998,-18.977424,-38.849813,-92.444135,-64.441738,-10.944855,43.549315,31.847508,44.236409,70.526526,144.397847,208.694996,331.660879,304.63683,231.041639,75.620491,31.764485,-20.250403,-38.978683,-13.55777,92.030888,151.450835,225.64558,225.78675,198.445946,181.024314,103.638183,69.748796,74.073789,52.475748,3.074541,-104.731848,-141.555115,-169.03772,-141.82524,-36.893037,-54.458237,-120.940458,-213.842659,-211.428582,-176.999979,-187.529996,-245.215985,-243.400068,-175.132666,-123.728175,-127.441198,-169.686493,-183.53342,-198.800092,-206.601796,-184.701816,-138.111403,-122.670606,-105.115329,-100.240839,-61.453586,-35.1449,-10.640331,10.30385,107.502155,151.726099,123.281023,67.821682,84.575448,127.909101,113.538642,96.940472,155.817198,182.142656,186.589751,147.480844,33.877505,15.762742,88.040902,136.410852,172.571539,109.902317,74.592916,107.762586,158.59168,174.604976,139.50705,119.070462,165.957447,169.925358,116.036632,67.034067,-29.703733,-55.652178,-42.90411,-7.528918,63.606209,95.919909,114.880249,103.992406,50.874077,-79.981514,-107.154136,-74.026938,7.888654,65.160012,110.476832,59.534419,-149.421817,-242.90965,-224.800633,-129.053495,15.231458,34.49489,30.468271,-31.547157,-83.920986,-120.917874,-85.485142,3.97892,-8.937814,-29.789276,-13.384949,12.937833,44.180359,29.165196,-1.022367,45.875157,220.082697,303.581536,315.039087,266.459561,176.304338,-42.732087,-73.739636,103.951732,296.208988,321.936741,290.66455,251.153353,174.089018,161.514588,188.931529,205.900005,211.903355,211.333689,218.39673,202.32729,151.530908,-27.725628,-93.293889,-68.61451,-11.681259,-18.940083,-39.586388,-25.45384,34.078472,42.393752,3.550495,-18.018836,-34.000676,47.191203,113.310347,125.780405,60.58035,-36.056005,-31.609008,22.947968,131.24766,201.852916,287.248157,287.833801,229.945232,171.331976,37.774045,11.884101,99.399061,211.474189,205.197751,90.708472,46.513949,76.950822,121.788796,162.208184,93.799617,47.802848,-57.574283,-142.383359,-285.335628,-274.371458,-95.472242,2.23406,69.969887,-11.677172,-58.228369,-102.535509,-96.50307,-44.099895,-9.763852,55.753575,57.899602,22.726937,-93.003119,-152.247353,-249.701683,-273.504853,-233.759704,-192.276428:180.191793,290.430565,275.743103,130.667229,70.383616,47.725479,67.74022,155.015452,210.147371,185.522828,105.901232,84.906406,76.275964,74.246464,94.003316,115.552778,134.498533,182.131561,203.343865,136.669657,67.322007,-35.927094,-51.719048,14.46485,207.106736,299.11694,332.143297,268.536393,128.520699,98.075075,88.0463,89.07359,103.942504,169.529469,198.736174,134.162008,31.240611,-159.586751,-167.171312,-52.707253,-0.366127,5.231512,6.015025,-21.363469,-86.351261,-92.310494,-65.498471,-47.021089,17.603773,114.463904,87.540755,-152.254662,-243.63179,-213.794533,-152.703454,-51.592848,47.440576,96.713085,109.407952,76.031401,17.360958,-8.623433,-49.288953,-42.77458,33.327469,151.988635,173.628465,57.158284,-34.849082,-111.469269,-84.411458,15.300103,108.148037,145.252064,98.198638,7.09538,-117.816424,-100.393776,3.460423,31.857456,39.659614,45.818133,32.208323,-28.527801,-61.509678,-101.608302,-91.469874,-27.667283,-15.011578,-35.11038,-74.78184,-81.610316,-101.629916,-127.627928,-157.723813,-138.627968,-54.292755,28.553135,51.457186,12.138733,-39.293818,-105.071661,-92.321994,-7.103311,38.934164,43.395382,21.341685,-18.436363,-100.44996,-114.530931,-75.578223,-27.628371,28.615098,18.264489,24.819874,30.010174,12.654224,-50.958015,-88.241381,-127.031039,-107.358976,-85.281238,-60.947886,-84.064933,-150.472265,-158.287168,-149.919461,-148.765364,-115.855242,-29.475055,-16.705439,-107.039713,-136.154888,-85.035026,-54.506672,1.378557,44.018377,29.473911,-15.595234,-29.388744,-107.148098,-170.071653,-219.785068,-183.479235,-56.649284,33.44574,25.670238,-100.321014,-156.553485,-136.485534,-71.547957,28.395324,-64.72333,-119.88033,-57.641861,13.562495,0.294795,-87.478849,-156.708053,-71.707606,124.882391,143.385004,119.207493,79.721981,67.171538,15.34731,-2.206361,63.003169,130.31447,134.396583,152.096274,159.944118,85.394957,8.947896,-81.343612,-72.491699,-16.087902,46.241489,65.708501,24.389148,-31.437246,-153.809356,-190.989887,-178.48491,-100.765304,-65.001986,-71.328901,-110.908883,-181.101987,-197.458344,-170.6122,-128.563023,-37.22436,50.87915,63.326913,-32.626341,-99.47993,-190.409481,-212.644002,-190.364412,-138.362269,-122.507557,-80.888869,-52.245843,-12.021922,-0.730865,65.322629,134.021397,244.723485,199.715788,140.028375,21.469254,-37.93297,-170.411649,-204.992606,-135.168533,1.492111,56.074327,98.36583,69.215824,-33.726456,-66.021742,-48.948803,-9.671908,55.800212,43.989347,9.688558,-110.227878,-183.301426,-269.085962,-241.837549,-87.96081,-47.843305,-89.66308,-130.755885,-112.922657,-86.187416,-101.747232,-142.871915,-120.832157,29.284347,120.428535,73.389303,-127.510694,-202.063345,-217.323588,-174.953315,-66.340647,-37.488576,-45.066094,-25.088689,-1.585676,29.049747,35.64097,74.859404,112.677121,189.358446,247.031066,244.617938,207.536895,201.215637,183.421212,174.912526,235.542695,362.60261,385.190799,276.664685,187.728277,89.488505,79.554925,93.010433,135.053979,263.815744,318.885385,299.399426,203.4198,158.521801,93.703685,72.875723,107.953564,221.429741,272.492585,277.446197,209.714041,49.59089,15.855318,30.620362,53.832046,127.159512,220.50972,230.361987,113.657342,21.814018,-85.869823,-77.027706,29.094131,122.133668,133.33915,66.19622,-4.25732,-120.445794,-145.733285,-118.638257,-57.901915,110.493762,230.683539,230.632389,65.471436,-55.838915,-166.931059,-127.76327,28.901349,118.948868,121.723712,94.795661,65.928429,-49.392278,-119.508628,-154.108999,-83.189799,118.592789,194.568753,172.431371,64.60931,1.83384,-74.502364,-57.949336,53.09459,137.503618,163.683996,164.370676,140.012497,143.989328,182.996328,217.605761,181.679603,100.365944,165.233483,201.088677,123.390842,24.809987,-152.02856,-168.382865,-24.021693,91.367672,74.636225,14.303834,4.246614,-14.412589,-38.631913,-83.623508,-85.237376,-68.749315,-40.109038,-10.248219,-1.473172,-47.253131,-153.419408,-163.67112,-80.902108,63.816343,166.108785,302.747564,256.76154,56.646018,-1.317728,-9.610499,-0.263323,-1.734502,63.872089,122.295726,138.380315,87.954973,1.606962,-2.16519,44.324597,99.143661,106.018205,25.720807,-51.89422,-166.338124,-181.819348,-149.274999,-102.577872,31.667963,108.187449,78.310228,-40.405149,-61.751504,-24.796137,3.9337,94.927903,192.398866,200.887935,102.804768,14.160088,-158.114257,-225.930646,-233.324518,-144.931293:-41.370373,-43.051893,-28.469315,-0.067658,18.594001,67.231342,82.154642,65.888088,-4.554224,-31.033286,-11.571859,14.849876,29.087419,26.780021,114.119098,213.954243,335.033781,258.848713,216.522589,125.074637,50.862808,-72.636788,-74.512198,23.926141,120.937173,148.213856,161.047865,135.393255,69.033822,62.161659,92.569145,119.885254,181.107306,223.546722,243.395941,240.384336,201.504287,91.53457,51.871551,66.389398,165.137782,192.68425,179.582014,174.783481,258.302523,317.799433,304.024056,235.470356,161.33303,229.170373,239.781759,128.483594,59.406443,34.915505,58.425378,75.059219,69.235096,66.372847,35.626574,7.81665,-14.564013,-15.775325,-77.927242,-99.519229,-24.675726,66.696558,79.150066,28.247668,-8.753154,1.62805,19.183526,0.949912,98.254006,188.594602,241.759541,190.259946,138.314815,186.897182,321.372785,349.609985,279.576584,130.674319,68.024275,-37.517154,-80.419685,-123.721342,-137.164669,-166.565912,-173.776856,-157.371919,-91.82357,-74.871019,-102.771798,-131.164453,-167.491012,-143.563756,-54.351013,-100.330895,-153.20393,-188.501915,-146.582323,11.018936,56.229295,-13.831722,-128.215963,-147.575318,-151.797512,-148.828561,-150.785737,-189.912596,-312.970725,-324.175997,-253.416315,-217.637911,-200.911999,-156.496016,-135.91734,-127.234029,-163.253073,-245.967939,-155.748315,-60.86915,45.972473,46.87363,87.29126,107.678225,-0.771454,-100.510319,-239.203297,-216.689476,-162.761012,-70.534961,-50.336358,-33.476721,-13.768497,54.749465,51.038529,16.352806,-31.876579,-26.129253,14.263758,-3.841697,-156.812994,-225.694418,-242.11757,-195.307592,-194.184776,-239.811345,-246.020766,-168.58444,-118.149459,-117.234751,-238.311269,-264.023833,-178.330878,-131.378348,-129.790966,-138.56548,-82.908687,-42.296364,-37.28046,-39.300239,-24.750394,-51.28746,-82.464719,-127.030419,-149.038113,-176.224381,-131.202819,-108.609921,-125.959521,-134.425459,-120.083819,-130.90727,-140.505801,-106.011426,-45.911089,-75.071633,-93.366003,-82.348781,-68.634006,-105.434505,-141.398377,-140.876571,-52.882208,-8.333076,2.906794,-52.290344,-196.706235,-217.986876,-114.94673,-43.53579,10.179503,24.240958,33.404345,-7.455508,-27.902439,-45.29382,-72.914935,-156.827938,-188.992144,-167.438323,-94.434011,-76.249626,-62.06938,-29.009437,95.297817,160.52711,283.642205,298.882856,239.990113,145.097593,146.468614,151.029003,134.599096,146.435545,233.432994,278.985098,335.329186,319.76986,193.946365,139.609941,148.267678,175.504972,181.56753,166.310031,134.379638,-33.048366,-116.44746,-146.64158,-111.254247,-48.364445,-69.409132,-114.398247,-188.855194,-186.078503,-108.920154,-73.474903,-97.115908,-138.978473,-187.788067,-196.474238,-204.700781,-231.59395,-228.946902,-172.353415,-127.227407,-17.4682,-31.512916,-78.729034,-119.149557,-115.306556,-74.749736,-23.361764,98.566941,129.437724,98.958163,70.067832,88.596613,148.559404,185.683444,222.454388,204.074948,177.443657,217.483244,243.051934,270.699156,260.969499,250.431051,276.522207,331.405665,324.403817,254.389352,223.01956,239.445479,322.122783,364.474339,327.879487,260.984361,218.157988,269.851326,267.128793,206.137789,166.113007,137.036749,173.221174,282.191598,317.927022,326.997205,261.918118,230.660393,176.46682,131.359131,43.062259,38.939137,115.494189,179.017602,188.007223,203.259253,182.342127,25.876708,-48.976477,-16.127088,79.09835,265.324264,291.619201,231.480095,80.362775,55.023397,86.782894,98.814769,101.760133,103.279608,119.1073,163.316424,154.912805,96.359375,88.866052,142.481986,189.479515,297.85702,376.246084,376.653547,333.558708,312.704147,215.539679,147.90423,118.818425,171.035093,172.448391,171.703962,186.329278,172.010296,122.523749,31.066555,31.064453,49.374828,2.329214,-4.436926,19.965468,6.684976,-105.042033,-175.68759,-264.215336,-232.538005,-202.930956,-173.389142,-146.923748,-58.376144,-42.923973,-114.116206,-156.151254,-140.211282,4.583122,65.078726,51.613417,9.359394,-61.487678,-88.838188,-60.706035,110.750076,208.539615,312.75907,295.135003,220.761369,204.156079,152.278871,126.283523,164.666129,192.60151,157.321986,124.150339,161.463962,220.837678,223.325006,214.79757,111.048111,38.670353,-72.360307,-110.174081,-86.089499,-24.888573,61.502678,70.269386,54.514392,-1.075848,-29.822811,-57.700983,-48.803499,21.711709,71.341414,144.721953,154.547241,131.428574,16.878608,-51.013411,-113.740354,-104.412194,-46.686208,-10.150511:98.451311,66.536219,40.126575,-7.985221,11.165592,115.8588,134.431294,14.98472,-139.517163,-140.388077,-12.862554,43.748559,29.608879,0.001217,63.173622,152.173772,269.830955,168.514713,79.507715,-54.543022,-93.106593,-139.920461,-138.181701,-50.337408,49.894938,79.501502,95.875235,65.435584,17.863975,49.619573,129.617506,134.821556,151.737302,247.876604,284.271472,212.490491,128.399099,9.385476,-15.369889,-29.512894,5.447911,50.052066,145.701181,166.347266,168.805862,152.545168,84.58362,76.273129,123.409977,140.126279,118.687343,11.861634,-30.894329,-37.511751,-27.662855,32.993719,165.825811,206.172393,193.450384,163.870121,102.851475,77.612374,55.441266,66.514211,109.639463,137.894337,139.338663,113.045177,102.253759,102.736914,92.397795,20.418473,9.920113,71.365005,195.52779,207.077302,226.062901,263.013201,306.832452,297.876665,229.555701,106.47478,58.286202,6.908147,6.888939,54.139863,62.370476,-3.249654,-96.633682,-102.788827,10.79065,75.271534,37.826013,-52.975153,-206.854958,-227.145695,-158.177906,-75.397447,-96.963081,-216.734828,-223.513205,-122.373682,-102.021172,-195.293577,-256.743239,-202.841634,-61.181242,-57.654969,-146.197837,-193.843248,-293.942862,-336.651791,-348.275525,-277.525752,-247.659827,-233.720988,-230.359582,-238.686021,-277.81316,-351.816377,-277.715514,-209.73593,-87.678952,-37.817018,41.273462,32.654598,-140.788355,-234.408244,-293.617743,-246.599375,-211.416587,-160.044971,-124.369175,-5.714804,48.250419,80.743193,-17.962899,-77.999667,-122.748903,-120.385883,-132.833429,-180.688039,-354.195345,-407.487926,-333.81668,-154.818651,-115.291197,-195.017046,-257.651299,-263.012636,-198.636855,-43.72287,-20.286293,-39.366973,12.365408,52.064925,9.31066,-54.66891,-139.281822,-129.60722,-44.806129,-5.135498,-19.56581,-43.653313,-21.310742,32.414624,34.143381,8.657857,-31.025429,-35.024501,-2.325936,13.727794,0.025026,-33.654496,-96.931832,-83.058053,35.628506,52.877737,4.75582,-78.595904,-101.036834,-157.109267,-186.413248,-199.156863,-176.617726,-152.909571,-87.912283,-69.887071,-94.746133,-126.823371,-167.25927,-148.621246,-61.150185,-34.817614,-42.121246,-39.593335,-50.017372,-146.989958,-194.204802,-179.784101,-53.893082,4.797746,-29.519942,-102.228918,-92.247794,5.80746,182.845372,229.539306,290.975703,304.900627,269.613342,142.226415,83.885634,-8.642098,-38.322032,-31.422875,19.119752,52.349147,122.13596,153.356032,222.196723,245.751887,216.042663,180.876436,171.135145,224.830574,204.520208,-0.373383,-122.665572,-253.16948,-261.218988,-195.217071,-87.294776,-65.223717,-79.745848,-76.438593,-37.440985,-50.710291,-173.661093,-214.3639,-174.578147,-145.299604,-166.315008,-236.523226,-260.829081,-291.447087,-291.513312,-215.153087,-180.67262,-206.234748,-206.714974,-167.061233,-94.276742,-86.909336,-81.217935,-49.400029,7.401435,13.229898,26.540826,70.517804,96.422636,136.939532,151.830401,221.149207,254.02124,226.120186,199.415439,210.960372,204.59025,195.002902,231.804947,253.39557,207.840643,184.089936,231.358823,306.943378,283.154275,196.18793,202.19296,303.102067,268.581275,190.36176,80.026761,66.974264,59.369236,43.952177,20.336947,33.29854,88.976598,126.388051,129.020024,61.470468,-0.880477,-101.150669,-97.929399,47.705868,183.123651,198.251711,180.285017,138.53144,-72.689823,-196.763954,-251.829469,-176.458123,-29.956906,15.813001,24.792381,13.290627,-6.259518,-18.336191,14.533425,112.698517,79.714113,31.189591,15.619437,39.455092,74.805222,74.197646,51.04543,59.342831,182.932808,375.115068,417.348677,345.406644,275.482121,127.027736,58.850509,42.493149,193.841556,255.91964,212.48219,136.365608,34.653149,4.87246,-79.703771,-93.660536,-2.306259,71.884745,71.711577,19.167731,-48.050806,-223.024735,-259.626868,-193.340458,-121.23339,-100.129513,-46.690402,-19.697433,28.386046,35.656932,-4.984403,-19.587191,15.070412,64.594182,85.757124,74.251625,26.606789,-79.790708,-91.375556,10.148354,142.363673,187.047056,288.990385,341.116784,351.161747,287.673116,81.688608,5.70174,9.540124,97.764113,145.801925,265.519,303.161608,256.198789,198.378967,138.718868,172.647605,169.792585,9.728356,-97.44232,-114.252196,-32.982262,104.445589,140.696717,184.418299,190.098185,173.338278,113.534238,99.759215,88.9219,61.738068,36.011752,112.046242,117.995616,-41.926115,-149.550756,-233.305354,-210.740489,-114.070556,-69.393955:127.632997,120.892871,66.237793,10.208629,37.103908,106.719646,113.666809,106.466373,69.322446,40.532705,41.953832,59.070068,44.740243,42.860229,176.502143,277.46571,310.54441,193.511817,181.389804,178.725831,132.870976,-26.909501,-88.076207,-50.371641,110.867619,170.570881,217.807402,205.399243,151.700352,147.083609,182.560799,187.292223,162.669067,207.457067,244.208948,180.214255,78.436687,-46.913384,-23.938869,113.992399,167.537729,124.781124,16.905927,6.517119,82.366411,117.385374,88.069131,53.579342,57.264626,130.95883,147.501345,76.283824,3.083699,-106.750889,-107.788985,-40.437309,-21.584108,-28.891236,-8.233696,7.494113,-23.776338,-70.944842,-138.381464,-119.880721,-18.612837,27.260616,17.009916,-43.397528,-69.368468,-47.854017,-2.848743,64.090439,85.859079,108.895403,143.372439,132.115795,75.696886,50.315007,22.982132,30.123549,66.551234,13.406717,-39.747543,-135.343813,-165.205684,-137.834352,-85.44086,-13.853889,-53.579061,-83.061182,-85.086646,-69.792275,-112.131429,-170.146169,-184.389301,-115.347162,-7.702781,-16.308767,-14.918041,-38.33133,-69.95655,-71.789477,-33.87701,11.13051,-57.643939,-77.516517,-20.870405,12.11435,-34.464747,-105.376905,-218.780116,-239.912492,-227.893529,-118.46118,-29.677261,46.399019,-12.444737,-173.760822,-206.290268,-176.851849,-88.791372,-27.561494,70.819468,71.249513,14.718538,-6.760977,-49.538723,-64.864656,-62.678092,-103.890282,-135.963659,-118.779119,-64.016078,28.605919,47.354701,63.689364,25.39516,-8.834804,-31.911432,-34.489013,-103.636731,-158.495445,-206.667407,-184.281784,-128.157919,-125.571291,-135.657326,-157.178408,-157.943736,-132.386318,-122.889589,-164.985213,-199.323728,-174.294699,-102.544816,-69.402,-2.935382,0.38432,-54.229544,-47.367417,81.847038,110.948936,51.244305,-59.987871,-70.410791,-12.979725,22.12683,22.159123,-37.387536,-32.584427,59.815552,82.321748,10.387724,-22.395556,-0.579723,6.913591,-62.219727,-69.7639,-10.012805,57.482657,10.600884,-153.804608,-196.218815,-135.414227,-22.996714,-3.278081,-21.163582,-32.763348,-77.863614,-126.325733,-181.84735,-139.154001,0.282762,66.443242,81.889888,34.666007,-27.033572,-132.53139,-155.378856,-161.953781,-158.102164,-154.785402,-113.214357,-57.268703,79.974265,101.22893,76.993493,120.335894,271.57023,228.453549,172.983114,108.865139,79.327712,20.33686,17.251903,60.690633,74.190091,94.726228,177.245852,180.30602,82.663292,36.478389,29.993752,54.737959,99.606328,110.937977,89.84325,-25.429449,-113.024808,-236.967631,-191.340522,42.191783,8.286126,-86.399416,-121.011593,-78.304585,-10.084202,2.554195,-56.91799,-109.920539,-144.354736,-86.716456,-71.696211,-144.341537,-200.550673,-245.637066,-224.65864,-126.835056,-83.116572,-102.369349,-147.008263,-135.797315,-33.893903,30.813613,130.641753,158.250402,182.858129,211.899386,202.288972,135.921541,131.264904,170.539774,176.749617,192.600456,205.742684,204.045615,234.530416,231.139891,157.556396,145.38498,203.347587,235.541417,235.982365,145.721431,124.648401,199.644949,236.323986,191.334496,164.897973,239.219202,282.009483,230.496396,113.435117,99.046645,139.900835,147.30051,143.044667,165.274571,201.227491,177.064016,171.457122,200.044219,221.493223,190.504581,121.900067,40.34374,122.821847,122.906695,5.694718,-37.661941,-78.4847,-109.031067,-93.410181,-3.210495,204.673332,193.328617,115.020096,-55.410464,-87.680501,3.227448,75.231328,178.785798,173.655618,122.693479,4.388443,-36.765168,-62.199993,-63.034343,-79.614577,-48.808263,153.579012,335.294421,347.05681,201.547874,99.324851,-11.857202,-16.084985,12.42477,71.978434,114.226333,169.906422,175.130952,168.532178,160.348495,143.753393,144.641224,122.295244,65.253693,64.487416,93.082026,83.794122,-32.199717,-121.208707,-214.935672,-99.855895,-24.993287,21.375283,21.192467,55.845034,51.856894,-36.655643,-69.050994,-38.172136,61.7121,96.972666,63.696518,3.465883,-126.080292,-156.330029,-102.557132,-14.029711,21.36965,110.72277,148.400929,181.557795,179.78141,125.374011,86.54027,18.183823,6.441434,29.6609,65.262951,73.917723,104.421698,112.052735,100.925932,74.189336,49.585454,-0.715631,-27.547673,-107.98798,-159.258566,-198.38007,-144.354469,11.846198,17.542327,-32.95607,-120.021431,-110.423789,16.962218,94.706202,190.049813,180.623424,147.991169,35.413125,-30.708658,-128.330577,-141.979256,-73.844504,-20.761096:right
11.022719,-99.002593,-104.045308,-35.237542,-3.863751,39.88363,73.935687,107.027226,-8.276686,-65.91914,-67.365257,-37.356399,7.497544,16.937342,28.536859,43.117658,52.505967,16.196215,29.587647,131.550151,174.241331,193.516972,184.144785,154.125115,115.209575,121.164439,207.354112,251.594929,289.040818,269.114613,160.666575,120.524079,127.233945,165.871496,156.677407,58.425115,11.981581,-1.835948,-5.176609,-133.979534,-323.995516,-336.893201,-210.529778,-134.600807,-26.906056,-26.647186,-175.527323,-267.417751,-308.187232,-153.234944,-60.960027,50.089821,58.491003,6.800598,-16.298597,-24.165163,-50.594492,-51.155206,-33.943137,-43.463105,-53.251652,-45.653152,-54.540384,-58.43897,-53.289498,-99.220239,-125.183312,-115.369932,-76.404039,-39.079119,-100.750882,-343.64945,-497.097932,-477.441943,-321.984153,-275.429375,-338.404411,-372.154663,-275.471223,-183.173997,-76.519884,-67.294189,-75.507263,-72.337745,-44.239001,-17.954049,-46.267695,-134.86565,-220.879407,-248.24618,-206.114284,-134.83235,-24.80243,-53.362699,-193.127139,-220.224262,-201.207744,-223.696099,-259.305431,-318.457149,-313.033472,-242.540039,-215.780052,-258.935114,-399.42686,-452.066722,-458.814869,-428.331811,-374.030355,-349.921755,-232.218241,-162.664869,-180.308438,-303.626308,-298.908364,-204.433474,-180.270781,-220.416947,-259.446664,-347.956312,-455.341709,-464.31329,-336.502198,-247.008022,-147.491984,-137.237363,-127.486651,-137.103952,-260.22166,-373.092625,-356.027599,-245.244634,-182.268197,-42.101218,15.34329,-13.646407,-199.242874,-242.306031,-140.299602,-53.78091,38.090953,26.912847,-64.850623,-127.548601,-281.456123,-335.798072,-266.514083,-32.599981,63.988752,112.505989,70.530454,-28.749259,-66.441567,-32.884591,106.257732,151.231708,180.235033,197.58903,229.522854,222.212163,165.428607,152.615067,175.912893,179.106504,144.529713,36.765114,-31.527157,-156.551861,-240.938785,-254.533819,-235.64513,-228.360534,-164.741229,-86.393307,53.731038,59.779895,-58.701921,-101.939247,-31.618475,104.912596,97.192315,8.562599,-9.110771,-6.364098,-110.842625,-159.146612,-104.364123,-42.852176,33.550822,52.524403,82.419327,78.771102,-27.06502,-122.663563,-100.8165,-16.377819,-0.604113,37.89741,97.061244,205.44375,184.012467,173.200942,186.860899,191.578534,198.799715,175.908537,72.728429,52.967604,64.509607,42.712893,57.791139,144.947283,185.879507,221.716484,218.131931,188.5347,150.113282,139.91667,106.483923,72.913554,27.650971,34.458897,52.243255,37.896745,-4.203601,17.875647,44.569371,79.242607,83.926218,104.803211,135.588371,183.626097,137.882203,125.752258,177.160932,209.507045,230.320916,219.952148,187.137966,166.232729,93.332577,94.000443,148.105189,239.691424,238.031622,114.057517,24.712749,-36.712966,67.912546,111.925589,110.637002,108.688824,239.240164,327.829366,333.029257,255.266209,124.511263,176.747186,259.631907,400.652486,425.828867,412.823001,387.474874,281.038177,124.920001,87.250677,170.516532,239.64596,263.136593,214.180037,111.153676,72.73085,-37.002911,-95.435708,-61.689135,81.636757,150.260771,192.434896,177.40022,192.407604,163.68104,110.337151,91.58353,150.138458,314.40364,362.813563,276.301336,153.191002,-44.788056,1.838636,39.299149,32.809168,58.009153,208.587176,264.926099,233.823913,106.102804,67.579557,60.482218,67.532225,58.292788,36.584095,9.149396,17.794983,-8.445724,-82.436366,-64.820143,72.837506,126.112729,89.170992,27.372283,-31.740534,-12.720991,-2.797074,11.186674,18.9841,131.230631,238.922645,365.389664,348.875108,255.224885,166.726816,122.171861,70.619124,98.576559,205.778203,239.448249,225.252401,59.542369,-32.342324,-64.740803,-17.967967,41.849651,32.916863,4.712631,-7.691601,-64.119602,-71.080277,-20.171949,66.189138,43.606035,-65.907009,-77.654159,11.401653,57.046856,42.479008,26.735962,53.187473,220.648057,324.656155,407.307066,385.556135,315.295596,271.782282,263.675649,285.15619,309.921289,256.972202,162.110271,12.102669,0.739629,18.895101,104.683888,167.077826,214.094196,155.995021,-18.953961,-65.857956,-107.476383,-175.361325,-199.013142,-199.069731,-180.43847,-123.831945,-100.274439,-128.322048,-275.946742,-334.189336,-301.422646,-231.984165,-98.554063,-67.417398,-74.779334,-73.469219,-26.54946,14.508381,22.304864,28.289889,47.719575,135.460469,159.584667,58.131214,-125.823604,-166.526693,-157.436575,-152.4364,-176.472423,-179.204471,-114.124393,-76.044116:-89.41955,-170.224877,-160.289262,-73.058884,-22.000608,25.43694,21.164266,-29.521886,-151.838268,-202.097809,-171.099332,-92.884288,53.318396,81.220443,75.466463,70.967431,75.376513,80.487837,92.027111,149.969701,181.674798,194.184991,187.762091,145.69407,83.538519,103.091341,207.577838,226.412294,188.186126,181.058594,198.014413,172.685684,39.791349,-4.84968,14.962303,26.639893,18.821587,-2.646078,-33.294919,-139.319747,-225.496181,-235.003018,-194.056896,-146.001342,-27.278065,-8.25638,-96.231331,-154.089971,-202.386907,-95.04919,-10.75796,80.643535,91.952218,64.91873,21.996012,-72.810699,-102.133389,-59.501103,69.905695,103.449574,108.47089,81.835479,-9.936397,-45.010388,-83.942176,-59.6887,-21.932569,-1.749687,-47.533413,-159.376749,-197.773439,-265.893987,-340.414869,-355.165876,-268.814579,-194.234502,-136.679484,-160.063064,-161.09544,-120.055038,-79.106982,-108.828972,-98.438665,-6.416219,35.045973,0.675116,-59.753755,-170.527391,-199.027852,-169.150636,-98.334659,-82.859448,-74.820685,-81.175907,-135.113041,-178.984678,-258.999911,-284.46553,-280.482514,-261.586667,-262.210744,-315.15713,-360.524152,-455.246127,-517.933696,-506.984706,-420.069526,-377.117182,-344.343498,-349.248668,-295.46272,-242.001772,-243.464706,-306.575078,-286.638854,-218.649247,-204.490578,-195.010943,-196.370213,-278.099785,-408.464253,-415.672832,-308.754312,-229.276121,-108.627155,-102.539937,-175.109448,-197.46847,-173.127728,-121.691512,-109.073383,-143.567818,-157.738626,-134.506214,-133.722349,-215.207623,-251.676941,-194.232832,-74.62386,-71.068759,-102.087171,-116.754462,-202.6896,-271.501379,-341.699157,-255.192519,-180.829341,-24.908979,39.682664,91.694946,72.527701,11.470855,-18.691546,-12.040016,82.79545,147.163019,216.80377,212.92503,156.192637,119.890431,75.581524,102.714446,113.363388,88.050747,79.050286,60.030474,33.5913,-44.356593,-136.959094,-167.360706,-168.187794,-137.40161,-8.559919,64.014428,92.20735,22.053115,-147.379947,-102.700285,-4.621632,194.710011,243.739559,173.712972,90.797102,-30.85691,-32.265434,8.669604,52.002198,40.481142,51.511775,64.649077,10.824483,-52.677457,-150.141816,-120.015789,-70.962675,53.838507,110.043588,142.304784,133.493862,152.788271,215.171824,237.64156,221.765361,207.430636,182.695518,140.777753,56.676105,62.657623,112.418922,154.912278,187.450861,228.125203,218.161259,176.68716,182.851369,218.155,153.473669,120.710687,126.547551,149.55759,166.665716,137.443838,42.461408,10.218514,-0.201996,50.450851,96.531138,185.156163,203.318169,206.632245,219.015599,247.716642,218.49029,204.777349,254.846273,303.857983,333.726727,304.468029,215.718608,171.326655,112.596856,216.758481,336.611565,505.711296,493.310609,348.409822,261.130091,122.673788,163.889929,234.69108,320.932922,334.839233,399.92258,438.795746,425.615035,381.299839,313.323558,331.858297,369.435072,489.959103,556.534377,623.379471,613.839466,471.642613,240.910188,181.293717,212.533149,259.011622,265.535785,203.274062,85.981997,67.463002,18.483306,-21.515538,-0.264954,70.974941,94.760445,108.794565,112.408651,157.033382,153.689802,106.801018,50.293793,77.509154,206.567683,249.354175,150.435621,35.748839,-127.716978,-123.679721,-94.334204,-24.742601,14.16021,69.461783,86.048139,87.691429,-3.928582,-36.735606,-24.467525,-14.687752,-19.712483,-35.393249,-61.018967,-46.401485,-24.357746,-60.153666,-60.84783,12.903007,53.57741,54.113713,21.59767,-49.722238,-74.584486,-49.013224,24.338502,48.372422,149.033548,239.674393,345.220691,327.407827,284.63458,290.868649,285.550993,254.203393,241.194053,224.424684,222.846797,203.509343,96.744222,55.877735,72.048335,90.021709,33.81263,-26.11626,-91.286764,-85.602391,-55.532786,-25.84926,-0.363244,67.024235,78.193068,17.222225,-8.055969,4.797361,-30.901726,-36.847761,60.693371,118.77541,180.840432,195.017332,199.055985,179.913157,145.549699,242.931797,292.782878,276.541068,253.60385,228.398556,192.617415,99.359606,68.264377,70.453387,83.06967,86.733998,76.337774,37.811836,-125.784274,-210.74623,-245.289501,-109.906378,-71.146464,-109.662552,-132.416409,-149.695822,-162.938353,-205.198115,-254.617161,-271.986448,-245.835885,-191.339717,-90.925886,-103.875325,-192.885259,-199.010297,-132.619973,-101.041489,-118.645611,-141.358484,-111.419971,-36.945593,-36.832732,-123.09564,-219.063983,-223.81594,-208.282421,-225.990697,-282.546701,-289.64501,-232.705937,-196.105705:-180.768697,-45.059427,-5.23534,-10.188137,-11.691501,-4.177528,-8.031288,-49.087728,-95.021578,-68.663706,71.625161,138.329945,172.12713,151.044483,126.483151,131.722493,136.866569,138.993874,161.163716,217.642727,217.902821,168.648283,154.892795,138.437591,114.878623,147.295669,255.743303,267.013252,172.499653,103.242661,21.093735,11.579837,-8.961701,1.313213,22.046416,40.23676,38.956429,45.671776,53.930933,11.70483,-120.741541,-152.156947,-80.648138,-19.673832,44.859278,42.512144,0.378326,-43.503854,-139.11366,-78.773125,0.294597,64.613225,21.043118,-105.12172,-139.432723,-139.619531,-46.757021,37.504886,151.261186,147.141898,110.931894,102.111869,90.055113,85.564234,35.388125,-29.063686,-21.432992,26.115789,21.998414,-55.462752,-118.224032,-245.795624,-258.828932,-200.925897,-54.031266,-22.630046,-69.364836,-102.204591,-99.82471,-80.87742,-58.941836,-32.39179,-9.57643,57.190825,78.597861,28.195974,-14.94558,-56.244612,-119.309849,-152.166458,-117.259205,-58.700247,-7.681313,-55.12241,-205.425096,-269.504711,-356.960658,-377.386184,-387.691137,-387.345916,-373.48644,-407.665374,-468.531974,-590.181837,-569.79992,-497.546713,-312.719099,-249.063816,-274.463164,-336.911992,-362.380528,-318.155576,-299.669718,-355.272291,-334.951377,-228.543127,-189.192837,-193.091705,-241.619226,-403.393281,-473.011484,-430.791583,-317.783856,-289.662331,-299.662875,-331.388423,-390.822034,-386.64976,-315.003658,-285.630935,-296.479958,-241.619947,-159.177863,-66.918061,-113.802977,-320.783439,-416.059147,-348.3105,-130.898841,-70.434732,-84.081499,-128.069479,-218.896374,-261.857791,-290.761241,-187.582241,-122.068353,-9.879213,21.800702,15.073914,4.491595,4.869608,-11.616606,-0.389909,120.855764,196.261998,303.349543,330.725448,272.539695,184.67813,43.650542,65.96516,100.282231,152.277202,156.683115,96.412968,42.872384,-68.608907,-88.612502,-66.129259,-42.505825,-25.725604,68.052327,110.427162,89.15715,29.959393,-101.666494,-87.387516,-1.665348,195.909869,240.955417,171.005551,110.587001,44.02034,-25.153672,-36.685624,21.287189,51.796019,49.692375,14.88994,-79.344199,-125.345191,-184.39638,-109.574958,-39.04288,82.852585,131.431609,203.363606,228.405702,221.176564,175.604862,196.818526,287.339677,305.881483,239.046665,180.516773,118.271602,103.224225,71.511218,175.982498,273.469756,374.81755,343.796469,241.694017,222.095287,197.945449,169.561195,194.022379,270.012005,288.94266,293.387001,273.997964,200.381595,159.497017,90.540094,127.396445,197.333932,342.233976,373.768575,345.893052,316.826044,313.067755,382.014106,411.523406,433.845114,437.568533,426.891539,388.212189,255.574655,209.52171,216.158947,263.247195,278.398247,325.672585,346.931712,307.601545,245.107516,138.068003,222.95691,313.323901,429.723129,456.529365,492.284142,474.420764,351.991945,291.257307,242.123278,277.551874,312.941946,415.926237,464.33252,463.369959,424.10711,330.755559,202.709074,139.662912,91.054489,126.665137,231.298629,230.76845,129.989521,60.323475,-89.84106,-83.201133,-16.90966,43.623807,20.828174,11.252192,49.600596,127.164415,116.555553,91.948886,77.76241,96.695348,170.621346,194.933261,104.248246,-8.631125,-164.385866,-59.156477,4.77406,32.873924,32.88742,31.208865,24.784589,29.434098,31.003522,17.39236,-25.337137,-40.607444,-68.303735,-88.434667,-107.223425,-100.117418,-91.503708,-73.286991,-49.052343,-4.263715,15.130294,62.156719,75.372356,31.548351,-25.795889,-0.389082,118.903577,159.905209,190.341999,216.361503,306.27605,329.529174,296.511415,231.66363,211.543285,251.121422,300.170092,337.216271,313.284174,215.493953,90.459203,67.397205,134.191752,168.145596,86.979315,-13.489186,-128.089781,-109.667893,-71.015924,-92.812335,-69.626261,23.893,40.308727,5.715339,-5.379884,-43.798308,-144.342837,-155.605968,-73.94534,-3.450109,164.377115,208.020751,101.03326,9.020416,-38.626603,97.75575,152.896886,160.903408,153.410631,144.355497,118.332742,33.486042,-10.153641,-3.595136,40.495757,43.685771,-26.332652,-80.796379,-216.229016,-296.521186,-396.034317,-307.434519,-225.723764,-159.183193,-186.247803,-257.591744,-281.669467,-356.392002,-470.327716,-496.943736,-406.846182,-290.947506,-99.522777,-114.463629,-233.396514,-239.920049,-186.795663,-127.15572,-93.787591,-61.879619,-64.426167,-99.31164,-146.338309,-304.212966,-398.865843,-376.202502,-251.211853,-192.943029,-174.914344,-208.59823,-237.106748,-226.191425:62.040778,69.75766,38.170129,-27.458517,-12.398263,98.022851,147.875183,137.825151,-15.371272,-60.851862,-1.581385,57.968382,128.154386,113.292057,26.739707,4.493065,-0.06206,-5.249237,24.927202,144.761885,172.736037,105.798607,58.233313,-10.628094,-40.371856,-3.660214,112.962028,147.266252,152.396477,130.314774,69.771239,46.283544,28.006096,67.701235,76.142319,21.421119,-3.096535,29.0758,49.195472,-33.765391,-160.65053,-162.680094,-71.94692,-15.715127,57.702118,63.902299,3.999501,-71.155066,-220.689779,-109.455507,42.12762,270.510585,275.614086,118.11913,34.722776,-33.061975,-41.300376,-32.253764,-31.237832,-40.687525,5.154658,33.07595,-4.571339,-47.546476,-113.43633,-89.487933,-41.850873,0.512051,-29.052046,-103.940437,-134.140822,-245.281184,-349.737447,-329.687984,-186.43465,-109.264657,-43.571507,-93.194325,-251.320931,-291.126651,-293.001901,-194.650307,-119.021,16.32574,58.191578,-17.223758,-117.842316,-234.657801,-231.22521,-236.517829,-224.491947,-178.390668,-121.192172,-164.582048,-258.555135,-244.72034,-204.490479,-261.674149,-301.997584,-350.485032,-346.558647,-336.38853,-368.779033,-457.511931,-462.817831,-447.099783,-401.494921,-368.104824,-329.563725,-353.044753,-405.414096,-390.897567,-371.067289,-423.306675,-425.935352,-394.838358,-386.097168,-391.523679,-415.967664,-529.569671,-605.177562,-570.741677,-431.039652,-385.26876,-361.618196,-360.568158,-359.386608,-366.268966,-387.572467,-347.894921,-298.024883,-210.205221,-181.623164,-144.077338,-147.474999,-227.958962,-311.26365,-280.53716,-101.523522,-36.193429,-44.635539,-89.023147,-187.691096,-239.520857,-314.71516,-290.30034,-241.472677,-86.611286,-5.136615,65.662872,54.096002,4.748981,11.740368,56.887149,167.37552,207.765238,245.932409,243.180517,246.206737,254.345207,243.973704,276.874357,306.517468,297.777934,279.526913,244.836293,185.065557,-10.915322,-108.647423,-83.505638,-22.291251,-14.249141,71.957759,148.842652,197.481926,137.36584,-37.995327,-57.50791,8.516072,171.535379,218.553728,166.269113,83.214203,-61.68307,-146.531828,-162.847557,-95.024067,-29.19346,114.399286,172.798545,170.481835,102.313869,-33.266512,-5.128736,39.522728,103.074479,142.177056,224.079466,247.978544,267.762597,236.745645,222.309884,238.980982,255.690093,234.442893,191.259571,101.790495,76.33079,74.799986,155.414796,222.066614,377.584748,434.888859,398.508242,326.365348,248.39145,278.330054,289.381854,269.45343,256.641831,249.089786,243.256155,231.566431,214.44273,127.406638,123.023267,174.372058,253.012548,251.871302,230.974757,244.641108,281.404354,254.424235,239.870979,283.770339,341.616269,401.173727,371.346062,288.998002,259.891672,173.893194,171.118232,255.540356,431.871504,456.708167,355.739034,251.441439,64.521571,61.90496,131.489166,277.192018,315.587727,357.174392,371.353318,353.39225,311.255823,197.678875,199.221633,263.875868,390.844715,411.696462,391.611708,378.642135,325.804697,194.93042,150.278125,191.50574,238.040701,271.009757,255.090382,204.819063,162.663933,1.914599,-88.16605,-62.47813,68.741805,132.474668,153.180846,134.628937,170.931526,211.397758,181.079221,87.812701,92.141194,251.497294,319.287346,224.158163,95.523537,-94.14178,-51.770246,3.119633,38.807146,37.041732,80.860158,127.923951,163.376926,32.663783,-37.416729,-86.605514,-75.835863,-55.217468,-65.524839,-82.841401,-73.014044,-83.855017,-100.859222,-75.442669,-9.161062,5.251122,-10.151576,-19.065139,-28.377617,-66.256821,-74.913113,-37.897522,3.542425,124.982393,186.142734,247.357295,236.071903,116.449565,-9.257492,-12.262716,82.609773,136.227288,171.891301,174.952932,161.460543,39.182169,-7.131851,11.102213,35.614738,37.554092,18.736512,-18.994375,-39.467263,-98.156179,-108.803303,-86.399263,-62.021841,-72.521513,-97.175192,-86.622516,-31.965102,-61.248424,-93.178853,-67.37168,2.84347,176.308547,223.402435,190.433594,143.830883,77.139921,103.344642,138.358352,197.705525,224.60048,201.1555,133.377513,11.215475,-26.268628,-20.370901,14.311979,7.027676,-21.40063,-11.116536,-30.190344,-96.475743,-261.147978,-316.720621,-321.646058,-346.611541,-345.097214,-295.85436,-276.767611,-307.653283,-403.347315,-443.258111,-379.230808,-266.898308,-60.289749,-28.871819,-65.531886,-94.418378,-167.145981,-165.853692,-113.954584,-47.888402,-51.595504,-74.549594,-98.538427,-192.900382,-266.52594,-264.243172,-231.7049,-217.91569,-189.394222,-199.12055,-270.46816,-287.301535:34.666456,26.976093,23.914902,10.841022,20.122065,80.300769,96.015625,35.173033,-30.05081,-8.423841,95.420065,148.043699,191.525053,155.711843,29.097473,-24.518644,-69.315852,30.053582,87.982194,122.144195,112.995414,65.990695,47.96095,3.114573,-62.571254,-22.469039,142.216851,177.967972,95.468225,16.641975,-79.203785,-90.013486,-104.261069,-81.281988,-56.099379,6.228261,35.326793,34.645562,16.448051,-34.39058,-103.40153,-103.693233,-20.81713,37.467592,115.041997,116.728946,85.088381,58.203727,-47.354428,-91.189566,-40.830928,129.742836,185.793602,129.298,52.259057,-40.434918,-48.587553,-30.375737,35.849951,62.485489,76.413892,58.944357,14.842672,-9.869513,-110.952318,-111.578771,-28.85291,106.828482,88.494358,-23.737001,-60.464298,-152.237029,-241.514427,-205.553548,-33.546053,20.107089,5.030439,-33.71653,-107.815106,-140.983792,-192.498798,-198.04955,-182.793479,-58.679419,34.593087,55.18621,-34.417221,-173.222171,-147.610319,-127.944994,-90.170343,-48.056125,-7.559018,-46.563738,-146.419734,-180.531433,-296.334252,-383.14423,-368.177495,-322.778427,-318.357549,-336.97825,-373.539668,-498.647821,-534.40546,-474.070491,-276.645131,-208.03641,-211.600445,-243.593161,-264.643563,-278.875806,-336.798363,-273.718696,-203.596115,-117.865286,-124.698059,-217.645732,-282.237992,-461.619407,-613.118731,-589.82536,-402.614291,-335.459332,-331.747272,-345.156713,-359.359382,-398.53059,-483.932768,-385.290887,-314.165915,-238.400858,-195.498131,-86.141253,-67.047146,-172.259485,-311.913201,-300.29326,-125.678833,-28.308484,31.85821,-32.943143,-235.672319,-295.893539,-286.204912,-210.29144,-167.699147,-51.227127,-2.771917,1.889992,-15.840936,-40.584322,-57.561546,-44.583325,31.662286,96.849557,242.951261,282.607646,245.682474,183.366468,101.561037,194.190423,259.918239,325.475418,323.940787,226.233131,139.116684,4.527489,-20.066301,-10.968715,32.532275,71.528139,137.18665,135.078769,62.150463,10.372257,-67.814974,-5.988427,73.890442,184.723766,180.804323,93.950589,49.213364,-18.401144,-117.012093,-148.497417,-66.683755,34.527571,179.687265,165.396814,15.049565,-79.097421,-206.115052,-113.117078,-23.128263,90.062729,119.075786,157.108334,163.436324,157.251054,183.528582,216.806011,259.722654,258.126092,189.770895,121.493464,19.393013,9.627291,44.963432,157.4414,211.937482,297.975228,337.076608,338.939877,285.691797,147.095178,144.101943,204.402372,298.103323,304.942569,312.358041,311.004259,250.704267,205.925596,127.512782,135.771113,193.016257,327.329777,356.472015,343.310049,343.223283,352.561242,314.191505,309.142981,361.172482,392.823422,411.768233,396.09949,319.013296,252.394366,98.188082,119.891194,221.609029,418.530847,460.779548,414.012749,335.921328,160.450108,138.140569,193.467531,310.216298,363.667443,470.220484,478.828822,350.653678,257.011291,158.50342,239.536305,311.463408,414.506586,416.865245,357.404837,325.828419,213.167338,76.527009,67.288626,170.210241,255.433759,391.205467,377.338171,193.100021,95.368312,-3.914473,4.474422,35.138774,142.23285,195.099393,210.012667,178.165536,129.16003,108.206485,97.882473,133.996544,188.983587,282.452439,277.597125,121.545694,-7.976412,-173.813104,-69.481392,14.583826,131.452396,167.868543,147.824813,77.150943,-72.071128,-73.5322,-38.734617,-38.813464,-67.18081,-107.715468,-128.797037,-154.260592,-151.722828,-180.078136,-148.509423,-70.647712,59.381011,69.379286,19.727122,-28.050377,-144.70455,-133.171927,-61.279652,46.090596,59.562004,122.461067,168.565398,191.465667,169.736793,128.01074,147.026091,163.137217,186.472124,195.660872,165.39335,126.892864,45.206804,20.390111,46.880549,60.803283,29.773412,10.314353,33.262836,15.693825,-59.456762,-221.327916,-210.093291,-154.138622,-61.499697,-53.502884,-99.379248,-126.800093,-175.723148,-252.651973,-253.196621,-106.586215,-5.119512,167.624438,219.566814,163.294163,70.64593,-27.344215,69.211303,117.605433,162.868457,169.223767,81.911775,-11.536485,-153.543274,-118.411084,-62.329626,-41.006536,-83.239888,-120.225227,-107.698268,-134.189047,-192.912562,-360.208793,-424.324438,-384.646051,-255.420439,-210.177601,-233.94449,-294.701507,-412.145186,-431.17558,-394.861166,-273.555367,-197.238969,-46.221754,-20.340847,-100.083561,-148.946518,-152.802647,-97.962324,-88.554663,-82.4372,-66.37268,-70.659683,-118.849343,-231.942544,-228.865313,-200.640847,-174.718996,-165.345995,-130.300062,-129.567872,-164.380537,-181.216273:95.164503,56.642186,31.743348,28.199153,59.612203,142.769884,173.617466,174.846401,73.812024,44.310544,73.186878,82.834127,55.703963,35.848906,2.557402,-8.633775,-21.255714,20.346698,65.261948,141.231405,164.329354,186.994902,177.188032,98.997078,50.377027,89.586468,237.690422,293.717826,290.398906,227.938193,85.865656,55.391943,38.248695,-45.397158,-92.195747,-119.653398,-100.970297,-40.37262,-22.155571,-80.850765,-212.160457,-236.431374,-183.449194,-128.762775,-6.295969,22.299522,-1.692646,-29.619826,-104.01416,-70.498027,16.112014,173.17045,174.979807,62.358072,22.709814,67.059049,82.754586,27.311051,-84.111862,-89.528437,-47.585309,-56.943756,-117.623453,-115.121348,-54.490344,-53.584048,-86.266331,-152.29003,-148.433871,-92.013603,-108.119061,-251.049018,-334.60999,-317.722163,-219.697791,-178.564036,-188.289687,-241.118108,-303.743723,-265.973691,-166.718742,-150.457807,-141.757507,-92.221662,-60.404439,-37.351296,-60.705407,-144.452393,-232.997461,-259.837406,-229.772229,-166.841509,-0.972402,39.224999,-39.281811,-121.89448,-287.218523,-334.773029,-305.057229,-249.141284,-236.025915,-234.29734,-249.267099,-299.029035,-360.419784,-369.302727,-323.274523,-293.796933,-233.528877,-199.882537,-161.262835,-161.292494,-173.938106,-166.82217,-168.047753,-235.083336,-281.468237,-332.01277,-339.037971,-375.431867,-506.739644,-560.664743,-515.115118,-428.473052,-261.671117,-233.651151,-293.259023,-343.016046,-412.718213,-398.026039,-356.925464,-246.924806,-187.240165,-88.609273,-83.450172,-195.622557,-289.303344,-252.756998,-113.201163,-70.784371,-10.317412,21.050341,32.535387,-3.044968,-155.070645,-241.574642,-193.751927,8.721012,102.148424,158.561404,131.193548,69.683,69.550067,99.530027,172.030317,201.187034,256.937341,271.425193,234.48999,193.199088,133.479538,226.813111,302.164903,311.649873,254.079603,134.787371,56.582316,-165.24744,-259.643733,-211.981745,-128.363691,-138.478472,-101.286541,-11.237054,158.381775,154.094718,-9.930867,-83.723719,-39.989114,69.570027,79.129944,-24.864629,-97.560699,-144.336798,-143.501356,-176.593877,-210.607824,-186.294498,-111.09929,-64.922456,21.245714,25.617039,-69.827668,-144.732408,-126.193011,-77.995379,-72.575537,-38.112648,1.148043,93.600338,149.498009,149.785312,83.604133,51.167659,62.586279,51.0918,-81.773807,-144.343065,-163.272363,-68.476649,7.537157,166.035553,217.490346,224.029068,205.152553,185.256699,132.953524,114.827907,142.024569,152.825555,128.027652,113.249805,138.49173,163.54034,150.414768,150.165052,171.888874,157.534741,122.404939,72.203709,65.126813,95.674741,139.313842,146.667854,211.136037,257.100571,258.665054,227.871349,216.19136,225.1503,148.321785,70.48263,124.173238,278.645613,274.563816,98.078734,1.926047,-89.236431,-66.344211,-30.673201,47.224293,83.225108,183.003692,229.603339,190.44434,108.089843,-24.799332,33.43628,116.620928,222.953466,208.744162,183.570759,215.37811,183.540662,-49.614627,-114.527147,-16.998123,89.829218,217.025949,193.534595,86.307188,58.235156,9.635082,-23.597802,9.084244,118.392315,148.306945,129.924576,102.223779,81.602485,105.880604,116.723396,106.311906,112.884818,234.971024,299.20841,252.806256,161.315085,39.245904,128.628456,226.986015,334.283275,321.288538,290.275095,289.236457,269.122047,211.443837,182.135805,149.212611,125.578733,31.001905,-4.17359,17.088626,43.125962,21.851731,-35.688194,-30.254349,63.601269,118.754774,104.801296,38.467054,-62.139698,-106.784745,-121.690829,-69.477046,-14.726512,92.90676,148.861066,238.201942,255.05693,209.929632,68.286174,-14.669984,-76.441436,-27.24966,67.640998,67.391053,77.86323,86.000536,43.617943,-35.058177,-26.704349,4.399581,-19.719656,-88.649337,-100.073012,-113.629059,-92.537894,-56.353142,-48.188959,-77.242518,-65.936222,-26.532802,15.462197,-12.127712,-24.680285,-17.011791,11.31748,134.50397,193.155425,228.703271,226.548464,201.550343,154.523964,146.979438,140.373292,128.279615,88.05534,59.248122,-8.874278,-40.965297,-5.732468,148.474289,213.940442,242.891681,193.366177,-11.581587,-120.20081,-238.523668,-208.621839,-193.118298,-228.73212,-252.014575,-265.02983,-245.037597,-168.4911,-195.331741,-251.114607,-271.086372,-190.986426,16.297088,43.971423,-44.809626,-57.689956,33.037809,95.915536,97.218115,77.819094,75.350473,62.162236,37.567711,13.293062,58.776117,81.946521,45.887058,-7.176368,-65.515258,-73.77189,-119.841418,-125.008343:52.248232,124.550694,154.269051,171.015572,169.709352,158.647785,158.052381,144.936346,78.487771,82.720996,185.667862,224.281255,215.897702,187.004695,113.667422,59.067028,-83.185583,-114.553178,-51.867952,158.394047,224.399863,130.20591,26.704527,-81.739421,-41.248547,8.947823,146.079289,212.594486,208.926952,112.852221,-78.676859,-97.379428,-66.723024,-71.834317,-57.292368,25.881661,49.746209,18.60824,-5.506931,-49.335045,-82.419806,-48.695409,82.555515,127.348415,157.752158,136.671816,13.011982,-49.311271,-84.277638,3.515539,73.191532,212.611825,261.139453,259.011458,223.443723,160.781857,57.26964,-3.728665,-35.509584,4.488047,90.622842,90.736466,40.773115,7.540777,-96.448811,-124.701586,-75.295908,23.074234,24.854564,-22.061859,-56.398816,-188.74523,-285.987302,-243.733082,-48.758207,30.855132,60.674599,7.940063,-138.161493,-194.178544,-261.768955,-237.478829,-175.656988,12.128565,85.713592,60.74421,-8.518025,-116.620154,-161.203741,-158.00931,-104.144733,-68.833166,-43.750967,-79.893015,-193.603047,-226.431601,-267.569189,-312.951397,-321.882918,-281.545649,-234.452869,-172.241299,-197.602356,-356.625586,-442.494981,-396.879357,-217.565928,-148.766408,-123.064867,-146.72569,-195.04042,-223.575573,-273.306198,-179.596393,-108.862844,-97.590597,-159.492288,-329.368753,-403.377807,-490.235262,-526.181963,-519.031393,-434.373316,-366.092138,-261.236307,-257.101,-309.471331,-345.577884,-432.146894,-461.200916,-423.381005,-258.976333,-177.130527,-113.288799,-131.847164,-262.246525,-379.232951,-329.307719,-71.833619,34.237857,67.205141,-0.606626,-180.173378,-241.012806,-281.309244,-239.867162,-193.416571,-50.140295,29.372231,67.734943,11.527562,-125.658452,-126.349881,-58.039089,107.28357,171.074343,263.534866,277.909861,254.013734,242.605174,226.018371,290.535985,354.106056,428.146732,407.054534,245.764359,145.290467,-19.038687,-98.341725,-76.047127,11.209163,41.583363,91.828599,102.668781,64.684492,17.780275,-106.829748,-120.797083,-56.592362,59.203116,70.098819,31.169221,-13.73805,-117.995814,-184.080812,-197.291492,-149.224794,-79.299343,83.436326,111.566745,27.536513,-44.292052,-142.822616,-77.760748,-20.062242,39.146876,61.637233,123.674303,148.212707,183.36748,151.6422,107.722277,67.876922,89.882413,129.562962,107.462242,-24.557339,-117.223225,-238.167903,-100.308351,23.663268,223.275952,271.749622,204.659044,115.417147,9.484363,45.591448,88.092166,165.978058,189.11257,211.113702,200.356162,134.788608,84.756997,-52.874579,-60.0224,27.18733,218.871264,252.193783,177.149771,132.653851,141.977723,189.354274,201.731571,254.39847,303.289704,364.834311,349.066628,259.829939,206.997894,118.608809,150.645326,228.493671,396.963657,417.947885,281.62939,182.522077,49.645353,-21.823919,-16.942538,121.497162,216.720424,340.59563,349.053587,263.717978,189.430342,53.38123,84.542814,177.680882,339.858859,340.005432,218.464719,159.292556,75.970244,22.072038,29.16506,81.936424,124.005054,244.257305,260.971819,126.716787,31.074486,-103.298794,-154.667848,-122.966909,45.915938,123.068094,152.629079,120.827917,89.717558,109.838188,98.378213,85.866389,137.580465,302.661304,323.208137,164.235758,46.839197,-70.754757,28.47688,102.318903,217.425118,253.752103,215.728124,147.105955,39.432068,8.322952,-1.247361,-44.245403,-73.198899,-95.529399,-80.324735,-39.810781,-57.197844,-197.216505,-196.949508,-89.543728,116.268656,138.548029,17.100394,-78.880865,-213.465834,-217.758407,-180.229492,-85.241842,-35.952675,65.004732,100.663744,132.518358,127.03786,50.263918,-13.942548,-5.22018,62.509044,97.674771,94.719701,62.092488,-1.249434,-23.726175,8.694514,91.012347,88.03504,17.991179,-10.868866,-56.71026,-103.07461,-227.693221,-203.225754,-143.216188,-88.157652,-85.241223,-70.853316,-82.108505,-184.214299,-267.272896,-233.465753,-52.792969,37.867994,166.888234,201.19192,174.393495,108.429757,-50.373424,-87.612785,-58.14024,32.779687,85.062256,119.223751,70.748176,-82.777044,-103.397245,-52.898024,49.54286,77.45416,92.789818,73.90064,-59.743248,-157.877442,-307.623419,-342.451461,-332.260676,-289.807228,-259.230755,-227.751517,-243.038256,-325.694183,-406.657664,-396.814608,-259.797452,-169.99988,-9.246275,46.896417,48.240929,-3.042977,-95.764466,-62.307559,-10.578266,74.855087,91.094427,43.01074,-19.4441,-160.698253,-204.535194,-155.234566,-22.700766,-5.233897,-53.801021,-79.153243,-104.907181,-109.686355:55.308383,-15.215737,-39.0958,-73.993211,-55.807212,32.90068,62.236781,14.915492,-174.882661,-229.062859,-146.289364,-84.643917,-49.396076,-45.832352,24.409932,75.548949,91.276643,46.708158,46.25118,91.513516,124.107232,141.093482,118.482671,98.081694,203.452889,281.568462,377.833003,377.948224,294.966465,207.286245,-21.350771,-119.090004,-220.55813,-218.207283,-221.498039,-298.433122,-344.968806,-363.833221,-321.696608,-206.792251,-236.701877,-280.606302,-279.670559,-228.737385,-102.861318,-58.732555,28.857597,72.354426,49.462274,3.612765,54.245885,172.549426,164.414649,71.63348,47.630035,120.564763,266.133784,291.779435,226.788195,183.144581,155.374513,160.829497,178.182324,194.575353,171.528303,27.58137,-42.724846,-171.934536,-218.083552,-220.148427,-218.303182,-272.333039,-281.06113,-233.312473,-87.044795,-28.169456,17.025925,10.428939,19.828891,43.799874,63.800657,47.149088,34.751853,48.586267,98.800683,237.807765,276.895495,241.915168,167.212467,150.32049,169.208254,217.747864,330.91355,316.935217,146.381767,78.699069,26.411569,-29.503889,-59.261848,-98.762862,-114.609217,-135.44966,-122.901535,-47.80866,-19.346234,-26.783078,-10.43296,25.85738,109.281247,119.470917,69.311517,52.959798,78.895976,120.666346,138.00586,123.993807,104.281822,119.220399,159.527612,208.838593,95.717922,11.251573,-67.424275,-45.496661,0.107643,-34.556427,-189.824068,-264.75629,-376.064357,-397.892243,-341.833244,-125.785797,-13.996772,80.610015,38.268929,-112.54003,-131.598558,-53.635433,170.904656,250.443975,314.050851,321.648947,324.114922,306.978092,185.047863,113.956486,166.393154,326.165254,366.788625,353.249026,330.037693,273.393956,206.820939,221.784743,325.274012,325.999085,180.944908,131.147496,196.229446,231.517741,156.321033,84.015038,89.898801,116.722587,125.79871,82.927504,11.944914,-163.442096,-271.435825,-264.155864,-122.657569,-47.03393,24.52222,41.939462,81.011951,86.692207,24.822452,15.749285,66.124824,148.789892,138.476635,-2.115618,-88.56075,-165.962896,-209.625136,-264.234551,-329.125787,-295.083734,-171.332574,-152.006258,-214.33725,-226.476615,-181.959707,-179.483474,-186.801122,-179.264272,-174.124651,-184.438399,-180.690849,-87.126227,4.185928,-7.86973,-72.752727,-62.444715,37.879834,51.797094,-33.003881,-72.262295,-109.827127,-143.276618,-134.615541,-49.331413,-17.454459,-65.094971,-116.517959,-144.468084,-99.358156,-84.995789,-101.867655,-137.291489,-198.679868,-196.106154,-130.110417,-90.99443,-19.805727,76.322446,114.16825,127.426988,119.575364,100.051542,73.435114,14.327129,9.813759,25.721449,98.660927,148.008161,186.437106,167.77641,145.466725,145.479246,97.676602,112.055193,179.886868,217.300357,120.26829,-148.320677,-220.807173,-177.514265,-98.409914,-125.642847,-229.067521,-236.602355,-129.263984,-61.615754,-25.203576,-62.309537,-154.699379,-111.638224,-47.924516,-10.601348,-49.493476,-111.701953,-107.758687,-113.970512,-250.13079,-310.649303,-256.062155,-177.772624,-109.647842,-120.794787,-146.419939,-167.70033,-222.161362,-206.343984,-199.027305,-226.983962,-241.963854,-262.836963,-250.620054,-155.513684,-146.573742,-190.881888,-209.823965,-148.342802,14.588828,54.287462,25.357001,-9.764131,-72.721438,-51.458676,11.770135,136.808568,177.041025,250.91503,288.452333,313.414057,210.347752,158.947187,108.440659,73.391398,11.720011,35.085401,164.539846,192.977662,33.986826,-171.979371,-176.696983,-87.007772,-60.567809,-116.323359,-192.001045,-294.335474,-195.935952,-124.731214,-79.634088,-103.231595,-105.315334,-39.813339,154.057895,233.507724,272.047695,111.988313,5.11297,-87.504808,-56.786289,5.304205,5.08835,23.350493,18.331923,3.372262,56.458,96.628029,80.398171,41.970532,-29.495928,-66.565814,-160.667312,-187.062601,-137.975339,-34.020321,-23.913821,-7.517115,20.936571,64.50237,23.561897,-22.315484,-82.170144,-76.865338,-18.868898,10.521163,71.804873,114.209148,157.32541,113.763607,88.427761,50.500999,46.341604,88.551788,118.165555,144.07874,137.379396,138.798318,197.102006,253.550538,321.08113,292.691869,142.605156,63.194149,-60.80844,-153.411116,-183.231527,-182.741246,-133.509029,10.68063,36.17606,-30.275511,-45.894921,-19.704077,7.163785,7.564324,42.496365,62.736141,41.472411,23.86121,39.08879,73.357906,94.684453,151.826651,182.551298,232.249159,225.911469,122.133887,48.464552,67.24257,164.787264,213.240998,225.305079,175.405367,38.530267,-7.766992:30.298122,-49.763369,-63.293629,-67.748274,-35.607557,123.72017,187.670573,147.418373,-29.71676,-78.039431,-35.436554,-7.933075,-15.027809,-7.051212,85.80435,125.687609,76.285989,-1.086338,30.014556,180.319519,242.405283,295.452133,294.943795,221.513791,133.168771,156.230396,281.273783,324.192314,355.942774,330.05091,178.409376,101.83677,1.965202,-95.766603,-136.844807,-162.981625,-154.738582,-168.099732,-202.060391,-280.486158,-339.982089,-349.822071,-303.951897,-244.296795,-74.554655,-18.852102,-31.545729,-48.683559,-47.135588,-17.439657,16.3051,100.045883,122.818856,45.327535,-16.996886,-23.366162,63.464068,108.867865,169.088315,145.205127,15.725438,-23.994745,11.919033,57.238073,99.5868,56.770154,45.663929,66.889459,79.156129,50.65811,-9.71598,-199.249293,-305.462928,-269.914322,-117.850547,-78.674353,-111.133547,-139.335846,-111.390816,-54.342591,20.805777,36.776102,52.413467,69.181451,76.491164,80.84354,64.817609,22.224966,-47.428596,-72.635624,-3.106883,79.588437,150.295416,75.928722,-111.094265,-130.158607,-129.107563,-140.280755,-110.412751,-54.535603,-58.135437,-89.309577,-86.457625,-89.928522,-183.544694,-203.281099,-160.517763,-148.575054,-155.016567,-139.270692,-51.82992,-6.697319,-5.517402,-55.334364,-49.77431,-23.99803,-22.633044,-16.938756,-4.792547,-33.353594,-192.799769,-263.860043,-280.19401,-221.071498,-72.2141,-57.535541,-141.361124,-163.392406,-168.91952,-219.634,-209.592095,-109.058664,-53.229722,46.179693,66.599784,-33.520209,-166.796859,-149.292316,21.738775,104.005061,186.197812,204.474677,191.736259,133.113074,-64.515516,-97.757691,-4.927909,189.929769,232.53936,231.971645,209.68665,153.115767,103.128267,106.802754,172.685908,210.02016,235.580693,209.231594,126.063339,114.774493,183.280489,273.470431,273.863982,139.433971,41.961734,-127.844302,-215.432605,-389.722867,-382.04718,-298.542128,-174.267836,-172.63994,-139.414304,-60.06908,109.307288,128.844559,17.09587,-45.60691,0.204217,66.834341,30.019977,-96.627641,-140.277097,-166.01777,-202.109189,-225.172748,-206.953525,-191.009283,-189.075,-165.429155,-31.002096,23.860399,-50.68284,-222.263742,-227.696807,-134.979399,-121.518956,-150.077494,-131.079059,8.520976,91.998662,73.111041,7.191329,1.509564,68.641503,96.393201,42.00469,-16.116195,-128.606333,-152.190091,-107.763872,-10.322958,-0.601486,-45.559772,-51.156667,24.546614,34.369987,-15.467951,-91.805135,-82.259191,-28.991392,-23.274079,-9.484885,20.646816,50.025378,42.303591,57.731812,96.387549,108.722197,106.948359,78.851522,26.234548,80.363583,119.045401,120.069922,83.879095,55.239112,91.861825,169.029377,159.150841,55.970669,26.120253,71.077712,129.859936,92.588714,-54.603415,-112.299289,-163.835913,-240.352488,-289.53828,-285.827955,-211.563103,17.363216,101.707505,78.993924,3.489303,-117.031462,-42.751857,44.710699,72.580998,-4.602076,-100.342331,-73.54695,-57.311818,-232.187016,-297.677071,-210.362788,-125.274563,-105.755856,-159.519636,-223.876428,-218.042057,-223.808877,-260.351125,-247.661577,-154.451485,-115.288651,-109.680099,-121.111064,-96.301731,-73.088174,-84.328474,-63.257821,-12.353201,122.754312,156.811278,92.56089,33.740423,-47.684875,-67.952721,-52.927677,19.167082,73.312408,179.082438,203.354595,149.413339,-7.067047,-47.25313,9.324614,34.372125,-45.224851,-104.0149,-98.372667,-51.560161,-63.14739,-181.549626,-184.990283,-65.289732,-13.932992,-61.678028,-127.546313,-169.698221,-85.545733,-50.863723,-48.520174,-52.710247,48.200046,150.051547,293.258904,296.597083,235.97722,177.846823,138.146103,30.91371,8.614273,82.694249,134.27964,161.854044,55.524012,-12.345148,-45.928852,-5.761903,65.863732,51.290712,-57.214859,-109.954668,-154.139941,-59.034788,16.250656,41.700602,-15.284765,-101.396363,-89.305231,-9.486388,-9.989203,-48.829125,-62.754238,-5.63244,135.026439,164.22329,204.310731,256.192834,307.713868,258.877472,275.390437,311.97727,260.37193,123.400502,107.261461,84.112735,13.18642,32.561161,179.073138,243.796229,252.195793,190.833269,19.716967,-37.804214,-116.752975,-188.513222,-198.021148,-209.435059,-202.516383,-109.679322,-62.413074,-52.762601,-119.131467,-141.583703,-106.70042,-78.3748,-69.088285,-59.199277,38.757085,104.774297,173.571282,157.127334,132.744416,88.183457,107.764877,241.79167,295.740766,252.565761,57.185862,-22.636854,-30.517842,7.502902,9.709688,-39.450759,-135.954285,-143.652667:192.165443,134.187505,103.741335,42.584744,21.939989,28.472361,53.890769,130.785991,150.509515,123.128789,65.344766,60.593191,113.91634,125.356682,22.226256,-45.467586,-89.246106,11.899759,86.357183,146.772428,132.720869,94.053691,77.33902,70.595104,109.569968,148.55184,229.649352,232.399795,151.298197,98.617032,20.811127,-18.390907,-138.80472,-186.240063,-161.591758,-117.982558,-117.300196,-151.892165,-177.511161,-194.159846,-184.273355,-178.675918,-154.926243,-118.320417,28.680046,88.43101,82.781121,39.790651,-24.772819,97.734614,216.930391,324.328752,311.604277,299.671284,289.945497,231.358491,146.411108,110.488907,91.083059,103.187345,121.774705,121.798879,106.048447,85.904242,29.507363,-38.492373,-57.621851,-82.334547,-114.719398,-189.675554,-198.932119,-162.775677,-144.030377,-150.760936,-144.542875,-110.440865,-0.253504,41.544492,53.814703,29.106851,-51.969572,-82.795616,-55.606588,60.98294,121.867898,172.054584,165.572475,128.8205,31.186885,2.140264,102.430309,168.328239,160.202047,112.704555,55.400051,39.824161,-45.21985,-156.422538,-192.45348,-209.261005,-193.739759,-192.15717,-211.722479,-218.154881,-169.949289,-110.997484,37.688645,79.640557,58.838982,2.946013,-118.92911,-139.045125,-114.449649,-68.443404,-40.846246,-17.037385,-7.91048,38.003786,54.842431,-5.868316,-187.967501,-230.720652,-169.980457,-125.750326,-65.368725,-69.079303,-184.417823,-255.277297,-339.485712,-324.480259,-287.943365,-183.911963,-103.322496,21.671082,-3.839718,-180.506987,-250.562972,-190.057947,10.418186,57.438369,25.483016,14.79811,45.687174,57.896542,22.587858,-57.861381,-68.772774,10.719105,77.09296,170.595208,179.141388,114.350621,26.107643,39.687208,188.460225,260.479472,244.592575,162.109357,64.147176,96.364638,178.746375,194.229726,222.96628,316.653164,327.672437,216.415145,127.570875,2.607871,-69.417598,-97.711158,-84.01413,-55.565231,-8.530204,13.659165,60.254723,63.062444,-12.392714,-40.839876,-2.389234,110.915705,142.916669,34.087952,-91.893618,-250.907132,-198.305691,-167.201638,-204.029269,-226.554776,-137.891381,-82.785786,-130.882225,-180.754656,-182.758029,-156.402909,-137.036252,-79.085781,-73.688075,-154.972338,-195.015605,-130.873814,-24.134393,-17.406299,-53.410336,-62.249574,-52.009267,-74.029717,-177.896528,-203.713921,-190.994603,-142.422285,-104.278201,-47.132948,-24.872519,-5.306224,-26.515237,-70.14819,-29.586458,11.801373,16.986113,-42.56166,-130.687651,-100.545361,20.426128,33.448598,-110.137579,-162.297308,-73.340335,62.972608,45.503634,-28.88709,-36.475663,5.080375,-13.463636,-41.235301,0.852184,64.763123,139.910298,125.411281,68.837922,67.277758,78.074631,48.202997,56.581758,130.652047,148.491295,79.741563,16.223577,-100.717984,-141.793543,-129.678093,-103.180282,-80.276501,36.780998,90.225613,71.359223,41.735167,56.912809,60.937736,44.526287,12.200816,0.297878,-12.003698,-24.851962,-62.509285,-69.918326,-52.563358,36.495172,88.036351,103.294833,60.770717,-15.185667,-29.621014,-91.329721,-160.548855,-138.864899,-51.286093,-33.367393,-31.989983,-34.563956,-48.658598,-49.700345,-45.827059,-21.153984,32.290955,189.594714,203.805873,53.7153,-16.254633,-25.475231,49.847758,124.595255,306.924918,363.949573,355.005854,288.39577,117.05137,78.086359,103.188114,95.303228,40.450293,-22.39304,6.048172,70.596099,64.98867,-22.447343,-95.740004,-96.356738,-38.633608,8.576914,30.447443,-35.362392,-202.876151,-221.978171,-186.223333,-144.862221,-148.242589,-88.836023,-10.437273,132.541776,155.977789,141.879067,118.212578,66.016927,-101.284652,-134.325494,-55.999469,-7.965838,51.327426,10.248392,-41.540462,-69.67905,-34.150797,33.325735,16.883555,-80.787752,-105.779344,-128.845419,-188.528779,-202.504375,-155.071193,-116.168814,-117.213425,-136.037997,-62.832262,9.516609,-22.029896,-89.422176,-75.602307,3.046899,31.3157,42.661273,37.371245,15.368931,-29.513848,-34.194943,-3.981351,13.297076,70.137813,114.942418,172.164516,120.884587,93.530088,120.483112,165.530023,259.796989,266.414694,120.603992,7.017601,-169.322041,-213.36936,-184.701295,-167.912121,-201.328333,-253.039019,-252.105044,-218.876309,-231.674004,-245.569439,-193.072853,-136.208304,-4.407319,61.98956,133.820746,130.663224,67.208953,29.073401,53.550495,78.92122,67.660857,93.862487,116.999026,94.042658,41.525544,39.479205,88.319358,119.464075,138.995674,119.78579,87.792124,105.984854:right
-41.84846,-2.566448,-21.79614,-120.376295,-159.480363,-169.647129,-182.872789,-238.533026,-257.307903,-255.26186,-245.829689,-274.186962,-391.442862,-411.832165,-346.29805,-283.912146,-138.255441,-98.418619,-125.959085,-174.950543,-165.651009,-80.191647,-37.02983,20.330419,102.664486,152.751675,222.678874,233.684062,226.048692,225.077907,270.41078,310.331518,345.711939,276.422495,231.092528,139.329975,102.50582,125.436316,172.388593,236.498155,249.328085,222.537831,67.757079,-33.704546,-158.316108,-158.196864,-123.079066,-130.291269,-176.3696,-179.428078,-160.720128,-91.694936,-59.335801,-45.701049,-47.439731,-35.909308,-49.357266,-63.510973,-110.499049,-172.578,-360.121433,-431.094585,-456.386336,-432.624045,-374.998105,-319.660624,-299.301307,-326.671819,-366.699902,-374.938426,-328.426453,-237.720639,-240.473388,-277.507925,-368.571772,-408.731609,-483.980817,-489.308511,-397.928944,-352.901557,-323.232295,-285.542522,-259.856758,-274.638088,-301.424411,-215.658952,-98.734494,104.832052,117.361626,62.524809,0.986084,19.290776,64.557455,85.110217,148.404843,176.573766,193.469981,191.244031,197.413533,211.626014,199.411306,142.490977,135.222669,164.827519,99.785639,27.040447,-80.00224,-91.706951,-29.295085,22.209714,39.072153,7.164742,-5.154825,-19.679071,-64.169616,-128.516847,-123.233378,-100.492059,-100.843262,-57.637109,92.364815,174.246324,284.449113,296.538427,182.609957,85.047014,-10.3817,8.827623,68.612699,54.678941,9.273121,-166.052306,-237.627702,-191.536176,-123.026048,-78.767626,-111.660465,-113.333302,-116.905926,-147.773807,-211.137295,-201.981635,-122.490279,-74.567965,11.531364,-1.790246,-37.244701,-79.396051,-87.498033,-73.947923,-33.429597,53.503675,-8.95972,-100.604528,-283.688388,-320.583068,-275.192989,-241.270948,-232.280225,-222.692424,-120.502998,-17.065399,13.149145,9.730496,-38.35288,-175.224614,-224.682825,-251.604384,-246.201528,-244.143281,-237.081611,-252.093372,-305.733583,-300.570188,-202.365911,-135.331971,-18.208307,30.087556,32.197273,4.101736,-14.445633,-9.585204,10.489206,49.449959,60.764856,61.526361,97.719534,108.268151,67.844319,59.592942,116.997048,165.352151,222.655324,131.398636,78.627146,72.351168,76.606979,19.670025,2.136012,52.875628,46.568232,-8.826908,-80.880828,-72.77775,-17.332245,24.646312,83.685846,78.329188,48.125095,17.344475,2.12384,10.173894,20.366267,-21.805049,-66.487318,-84.252535,-30.414977,-20.516391,14.868608,34.866468,-18.396002,-81.412481,-191.140988,-221.079154,-218.065186,-191.332294,-207.667863,-307.236708,-344.621377,-324.981875,-296.978659,-232.790114,-151.205107,-130.767739,-114.654383,-136.648223,-290.065295,-369.053986,-373.913802,-269.91434,33.527056,75.523222,0.891728,-67.828345,-55.198571,-65.522804,-75.055061,13.231027,191.731793,252.700656,266.461379,230.387034,180.686333,199.175093,243.419166,241.533904,216.751037,142.398588,102.551764,43.800396,11.04123,5.961535,42.381621,106.488829,166.139295,197.020415,179.585993,111.827477,-67.706653,-127.188506,-151.545732,-132.399638,-93.98949,-139.93457,-156.754105,-81.826989,-45.990712,-103.593624,-155.326709,-169.242053,-72.111369,-28.749216,-40.627617,-97.173759,-238.92004,-275.846529,-249.680608,-226.721707,-224.397526,-216.96032,-201.85776,-189.701627,-190.175622,-159.428942,-99.619115,94.20309,135.689471,76.6324,22.401619,39.055996,-29.656554,-86.878293,-35.499104,45.313893,120.637345,63.18559,36.83294,-3.92611,-28.181792,-15.0739,30.864044,158.504939,258.682825,255.839611,184.942895,144.570986,72.869269,57.292635,50.787157,39.462348,14.87671,6.868366,-5.204014,-88.930191,-152.339793,-191.034329,-135.21216,16.96251,5.819041,-53.777088,-116.217429,-106.608723,-113.343107,-147.047743,-245.281214,-279.254202,-241.534448,-176.424127,-171.144542,-157.651013,-136.895099,-86.43215,-71.110388,-63.216225,-67.853305,-85.59567,-137.166844,-154.460027,-121.130387,-81.904578,-47.485572,-36.882531,21.046843,-11.543623,-64.805755,-99.557595,-61.728391,43.306913,70.6097,53.501665,44.561881,36.058034,-67.02734,-135.57593,-173.990449,-137.898663,-88.17288,-100.834446,-124.386111,-113.317009,-97.928235,-61.232589,-69.881604,-170.202629,-225.589591,-199.027435,-20.659022,37.745363,79.449251,79.661233,14.688609,-3.376813,76.234432,128.925132,167.324518,149.25882,138.450337,39.540341,-64.156213,-175.915609,-116.081412,79.466107,149.192088,146.659716,142.501068,135.982942,79.063858,63.889945,135.642939,197.044065:-134.449879,-55.084521,-48.960759,-50.235904,-55.169457,-69.86245,-58.604286,12.622532,15.607068,-33.763152,-134.853762,-154.842303,-108.707937,-62.71567,-2.201705,21.796164,60.69873,-6.055021,-70.447584,-163.335161,-162.496488,-79.779124,-35.790259,37.059777,143.83586,185.981067,194.924571,169.18756,159.577843,202.85467,306.161275,348.923851,406.382073,319.421635,226.666691,66.686916,29.63213,46.835406,77.224969,101.924602,80.659104,80.499783,70.543196,18.200977,-142.626078,-177.874115,-114.455712,-80.82674,-116.992664,-201.314106,-215.897502,-195.315281,-173.470042,-98.010936,-53.730845,-7.725126,13.688537,6.415928,-139.959765,-243.231036,-326.93521,-310.791618,-286.727571,-287.579604,-267.65755,-220.346582,-218.532046,-314.354937,-363.977058,-331.921066,-274.695539,-228.937602,-300.24577,-316.451576,-309.922116,-331.539544,-408.992854,-432.938543,-431.203051,-418.772622,-418.66816,-389.994768,-336.509568,-322.067805,-401.598186,-424.316271,-285.735855,-7.595524,-31.578069,-90.759724,-147.582747,-157.221772,-150.989461,-120.128541,-14.984962,53.762966,182.031221,148.560031,86.134203,25.572148,42.550059,97.277218,113.881758,123.953323,87.343141,56.037013,3.172766,-8.027964,22.060384,37.547276,16.049653,16.86661,75.501424,62.201799,6.955264,-77.236412,-70.537046,-19.599799,-3.912346,22.627925,47.178999,44.900732,53.036411,77.536821,71.93677,18.687421,-36.048288,8.230956,120.138708,68.58132,-19.331826,-172.769815,-189.20646,-125.823889,-68.700405,46.304726,42.026784,-6.214044,-107.205859,-144.718988,-159.205067,-124.237281,-41.669906,-33.35201,-49.333817,-10.751005,-15.445345,-150.997084,-222.850589,-225.891115,-166.781088,-47.840798,-29.607606,-62.099757,-175.837879,-226.559489,-219.756986,-172.10288,-146.894727,-171.529342,-136.655921,-7.97321,19.809265,-56.633547,-118.676971,-171.203918,-161.657595,-109.888677,-49.568275,-13.119926,18.66378,-34.969603,-192.394357,-195.219814,-60.512471,-12.197917,-11.4861,8.955151,37.903767,10.561059,-47.328122,-90.53579,-62.366123,-40.417485,-80.056387,-78.93207,-39.663588,-36.219001,-68.110641,-61.776081,31.489915,78.359155,87.997416,8.52284,-31.720396,-59.731706,-45.910228,3.277262,23.250176,36.568334,-2.879275,-25.724653,1.330744,20.606565,-17.707685,-36.872026,-0.374777,40.418226,75.765994,-28.770323,-105.610405,-185.733742,-182.029695,-180.373548,-191.673521,-146.461408,-36.447947,-12.73069,-33.001418,-55.884167,-88.299726,-89.484313,-83.562936,-94.896121,-161.152836,-225.142998,-234.324407,-251.924726,-281.621069,-358.499076,-370.08387,-273.471351,-127.96478,-94.778194,-127.854287,-189.050954,-289.279218,-281.839547,-198.086854,-150.013292,-48.104432,49.309222,70.899271,6.752567,-60.689243,-148.705667,-134.34048,-21.83927,54.844378,73.732082,118.674948,101.16088,-39.85588,-79.07593,-18.514443,29.789005,59.56073,17.600853,17.555277,58.69317,64.405499,56.750141,74.174108,146.539985,166.411937,136.844036,35.356641,1.68176,14.417813,12.076552,-55.430982,-51.67523,50.35857,40.760787,-6.351248,-66.521206,-75.06927,-90.564966,-85.487374,-1.962307,18.939549,-34.312627,-156.497781,-190.981115,-225.617466,-235.513588,-197.030954,-147.506729,-93.12871,-122.653408,-130.120783,-160.857805,-199.199442,-237.431338,-197.747673,-47.149234,-8.610212,-35.151445,-70.897821,-75.104947,-72.207419,-41.83488,78.692305,128.720077,143.237411,78.573781,29.26523,-125.581688,-178.903529,-79.14125,37.796397,223.727603,233.403942,180.70377,126.295127,150.369718,177.657046,167.420944,185.389097,209.471391,196.745917,135.573479,110.819987,20.774298,-31.18929,-14.418891,54.268173,139.578099,20.172258,-68.222858,-158.314996,-189.352228,-260.903797,-248.913782,-143.579306,-93.670158,-26.890305,-79.3469,-124.788597,-117.743933,-81.405475,16.797681,67.801966,100.245505,31.55502,-16.018835,-53.421099,-37.476327,6.770153,3.411179,-90.062297,-119.605332,-38.048109,6.429458,-12.849502,-16.479222,12.480818,90.295881,125.651983,177.178422,183.857231,151.720296,27.22499,-19.571114,-12.769354,12.350022,21.067661,17.254187,68.663603,135.904803,122.923252,43.213844,22.696451,28.458744,42.694338,96.680495,186.5563,235.091759,240.825645,180.55933,74.831879,88.074613,189.256812,224.542011,250.671903,221.53331,183.685243,91.078831,39.502769,-13.331009,26.54429,216.082262,300.04431,259.261148,170.338582,157.523948,144.547419,148.203422,189.764906,202.776605:-22.229578,-6.569681,-18.386164,-43.555666,-29.201864,31.836476,74.479093,168.810572,127.445478,48.072124,-98.693151,-134.655653,-99.466136,-32.838158,97.04261,134.186684,142.865374,37.591056,-18.268235,-43.869757,-25.421757,45.222467,93.556577,150.48373,157.533384,174.195556,211.063638,203.559956,142.798169,125.491541,171.526219,219.813096,273.830379,235.69094,184.815009,36.843266,-3.886425,51.003073,95.370947,120.169338,98.594366,71.511226,-53.95139,-120.567687,-156.803849,-141.263358,-117.141977,-115.560577,-159.129142,-231.387336,-232.166309,-165.113281,-135.489638,-124.124143,-117.212836,-47.547436,-12.003731,-49.083056,-190.213692,-238.215411,-204.487022,-167.280043,-161.484821,-171.685224,-147.684032,-120.434703,-147.600652,-244.785435,-258.407473,-188.362145,-138.79182,-86.14063,-160.113382,-211.242673,-244.459758,-253.732554,-326.772967,-362.787674,-363.531427,-342.170226,-340.985793,-359.67886,-345.80757,-368.601972,-417.41115,-426.277401,-352.192918,-187.347886,-171.076082,-207.765514,-264.820269,-259.332108,-198.461973,-177.335341,-168.978248,-139.153418,-22.602882,1.7585,-26.0243,-37.451815,4.524631,91.623868,88.165936,15.462883,-42.542779,-79.525966,-178.021052,-191.211092,-99.330296,-56.893629,-69.76168,-69.54217,29.817398,78.187819,41.51627,-33.001559,-28.266983,30.427843,58.101105,92.963943,62.635482,24.034789,-32.752782,-31.210508,19.253041,47.867367,101.703727,131.042181,158.845335,93.298805,19.560645,-100.50689,-89.877155,11.036453,39.462936,44.443528,20.889686,-9.417164,-88.676128,-113.676531,-102.202557,-88.242419,-67.724537,-55.116924,-59.766691,-100.579957,-124.620994,-166.338629,-170.215428,-157.451068,-150.587678,-114.359092,-76.189576,-95.572815,-193.484935,-227.782991,-207.563198,-161.454439,-78.586172,-72.145842,-109.823753,-85.61235,-52.785653,-77.821803,-129.357624,-171.282265,-143.571061,-64.370913,-8.938614,22.164737,38.004644,10.260948,-19.692471,-3.96292,19.333175,18.758048,27.752604,40.32545,30.907912,-48.711348,-89.335367,-82.554313,-50.158998,-1.525802,-4.987713,-5.248593,17.230758,17.917372,14.51742,42.36354,127.960288,140.275273,77.33515,29.561424,56.133668,141.855462,153.626966,134.195411,132.309745,150.530153,119.976339,78.976511,42.274606,51.399496,64.940409,64.952838,32.144598,5.637521,-25.123622,-53.933763,-79.007454,-91.781045,-59.619849,-13.705533,-44.485393,-90.373997,-0.308308,10.291329,-98.536318,-157.397037,-184.445619,-154.505833,-77.168859,-71.529875,-135.104239,-166.165513,-175.44033,-254.054574,-282.267962,-263.736157,-251.302547,-229.376196,-185.22639,-188.110813,-243.702138,-254.533645,-200.263682,-158.50963,-85.259095,-53.087283,-6.161365,-12.227427,-28.877837,-64.060006,-72.178779,-75.554789,-86.993534,-98.670143,-38.516892,1.085246,1.950802,-54.226638,-140.997999,-119.166043,-26.664979,3.993833,4.288921,-63.102462,-75.686401,4.72542,78.554467,163.1728,150.856286,105.355256,92.164803,90.843076,40.36583,-9.310343,-49.350027,-37.154798,-13.316289,1.406625,18.726558,-22.757606,-31.834657,-16.060451,-7.767062,15.922491,24.556636,50.518713,93.916286,99.029952,61.300498,10.70263,-133.571598,-185.234054,-171.698031,-117.178426,-31.710049,-90.059655,-130.102998,-134.452531,-122.193165,-136.53255,-130.890414,-11.518066,83.414196,78.719885,9.722694,-34.115589,-39.596339,14.672803,132.79168,156.61635,153.562912,123.585279,98.74466,15.162922,-28.517246,4.696033,85.688191,249.754635,263.166617,209.69129,145.853905,150.208608,149.471288,157.571835,195.24462,199.480836,167.385782,106.947828,90.241871,82.766179,72.660563,51.040684,55.96957,94.49917,106.143816,70.124381,-81.905898,-152.583426,-172.756819,-151.941118,-161.392264,-153.550216,-62.676953,-41.705683,-56.775403,-68.887695,-64.759393,-9.780014,39.73761,114.004315,114.013463,87.320468,19.355276,-0.902281,-21.34557,-23.330923,-9.228943,-4.474391,4.581869,4.203965,-11.082241,7.416147,55.718,142.817711,168.810488,199.742629,148.172551,98.226287,13.981139,-15.677283,-14.363719,14.920566,41.425784,37.059069,64.157215,101.79611,87.29541,9.439274,-12.213809,-7.778526,6.174298,98.875983,171.062888,141.521167,69.232893,80.717693,145.701061,171.882371,218.299413,229.955616,177.967797,108.806783,100.802532,72.528488,58.137061,94.504803,143.00367,250.755429,271.290494,249.051902,236.68209,241.170133,197.463212,165.760287,140.475024,140.652798:163.490369,147.060748,124.72324,71.402867,66.46851,79.469634,47.259592,-20.974614,-12.315689,-37.500092,-139.488559,-169.578624,-122.210133,-73.682699,-50.262051,-56.969151,24.551092,91.489211,44.122551,-47.425362,-14.980447,86.45143,75.676966,-3.047984,90.760592,186.310781,266.63407,222.394749,107.68415,113.559334,253.064761,329.017223,387.540402,267.248925,163.309122,-16.888664,-45.82666,65.994705,152.427603,219.506798,145.392271,74.98762,-67.010031,-114.405508,-189.018323,-235.15747,-309.940296,-295.452826,-155.240347,-98.267642,-146.174039,-258.690296,-257.156708,-127.87627,-67.829022,-55.202826,-49.117398,-32.566196,-98.048433,-184.913779,-305.574673,-301.081349,-237.894483,-213.662653,-164.216383,-117.118792,-139.332833,-280.940255,-327.476236,-279.562474,-225.463509,-143.635544,-161.637601,-209.404231,-292.518559,-319.802281,-369.133147,-368.480826,-308.63224,-266.435217,-163.343058,-128.072884,-150.643332,-228.309878,-259.172225,-205.716873,-121.895902,22.281644,10.081317,-25.966026,-44.771987,-37.231833,-24.016863,-1.490766,80.378357,117.942311,149.327701,127.931099,108.283609,54.747653,26.312375,37.791116,79.447685,112.642024,-18.52411,-105.726197,-190.823326,-192.155917,-183.683034,-182.99623,-191.77318,-193.572531,-160.339006,-162.689361,-199.531413,-253.676147,-229.195487,-110.519527,-59.606449,25.378233,82.343566,81.854179,72.295617,65.767194,4.590948,-40.45377,-72.653699,-43.202487,29.803524,-18.19854,-94.958682,-261.339221,-291.751943,-187.85068,-122.464357,-89.941778,-83.984584,-93.701764,-171.96124,-217.948079,-257.959993,-239.848308,-142.315951,-92.884945,-65.00732,-127.173478,-166.105079,-219.357978,-222.82429,-144.008903,-74.393623,30.704478,6.710852,-54.642153,-183.638214,-214.88996,-180.103682,-131.9325,-72.620802,-67.852152,-63.293089,-33.500866,-6.247578,-53.197717,-137.258945,-259.755451,-260.031201,-165.461874,-75.328417,-75.40871,-117.317951,-135.749053,-140.463011,-109.330284,-17.132666,7.015716,23.418886,94.0569,141.105726,105.727049,16.634636,-95.225944,-66.931279,25.477061,35.328527,39.461404,74.1326,96.950778,159.39156,187.924664,189.978236,179.496039,219.267511,286.66703,289.552227,237.473062,212.356109,227.439159,248.926944,252.630059,207.080612,164.602977,58.479535,10.025849,-9.831498,38.341432,102.531094,65.881115,-43.011319,-87.361303,-94.450685,-106.872307,-128.822781,-213.461795,-240.023585,-152.84537,-9.681816,-11.852667,-106.600661,-133.227299,-139.781417,-155.286316,-212.869596,-216.979389,-136.584353,-81.224914,-120.268676,-267.622486,-306.67575,-254.691978,-205.677229,-140.776512,-120.281044,-128.138876,-153.583321,-190.222988,-319.789881,-353.733097,-256.72781,-135.194832,126.436473,198.773595,152.663503,-8.518203,-67.179003,-66.848561,-36.275201,31.054838,118.068706,151.219227,130.643042,77.568084,9.236803,47.519193,172.104823,205.356762,243.501923,207.372372,177.970137,143.085505,110.436598,52.575318,50.346255,66.954897,62.109062,30.83307,-48.522907,-49.537586,-6.040154,-32.057755,-178.251845,-221.600917,-176.69556,-112.659758,-97.10895,-61.309786,-58.515143,-69.523413,-49.211262,24.976353,19.70966,5.402389,7.747101,-20.697968,-141.954504,-178.093304,-176.876208,-174.078717,-195.167647,-165.658652,-126.966556,-107.874509,-134.614483,-161.954462,-119.709726,80.868981,212.619382,205.42333,147.926038,119.361748,67.4753,66.011343,139.853924,199.437118,274.087005,207.708649,155.862954,62.55987,29.435404,36.493277,64.718684,166.28172,288.56207,294.934474,214.493593,165.6081,83.995329,55.864545,38.273826,54.17053,121.612868,162.724286,142.653185,26.354297,-24.538904,-14.528696,29.099471,57.50812,-47.222366,-116.605531,-233.918415,-285.131751,-320.211709,-283.136852,-228.96437,-240.331065,-231.985178,-177.946707,-165.791175,-174.340665,-186.024682,-169.898373,-130.305005,-64.601065,-96.039064,-114.556183,-99.447596,-90.293978,-90.299477,-88.87427,-103.90788,-102.00048,-37.250898,-52.986422,-109.027791,-156.55988,-111.686956,14.963428,47.415222,73.397714,54.021563,-3.292573,-143.669687,-176.978142,-158.868239,-138.131376,-125.69818,-123.19586,-71.084593,18.580916,31.207828,-52.633806,-111.484853,-150.276458,-130.698385,-46.613797,82.371215,120.5777,79.269969,32.545129,3.525007,47.388956,185.806752,222.90039,189.667424,122.681473,116.799594,102.992018,61.010081,-6.831579,22.111726,152.34906,189.974291,170.753094,145.579682,139.205357,115.381326,124.463158,212.454839,263.493079:217.864243,145.628547,89.117499,-8.583288,-26.705714,-0.443286,23.374116,89.055166,81.945365,19.915577,-111.19738,-128.993598,-38.851836,14.48645,11.465086,-8.002895,46.907452,150.859475,144.931641,19.361247,-21.268043,6.060519,12.428831,-6.42198,90.804873,153.393373,128.021348,40.555696,-73.444181,-38.653128,138.303845,211.611172,191.895358,-10.143547,-92.589851,-155.559586,-156.982709,-90.097466,-18.993322,96.199857,83.54816,44.92646,-111.036178,-224.591987,-386.804016,-394.259305,-307.599427,-245.522318,-146.871805,-155.649519,-188.294389,-230.859355,-234.143981,-192.792752,-144.041606,-37.181902,10.610546,10.414688,-57.205743,-115.486024,-186.922581,-182.875791,-117.575513,-68.69013,16.450736,-1.398412,-62.32844,-213.506556,-246.151058,-175.828037,-127.771074,-105.664911,-128.53096,-139.962714,-157.285335,-179.515816,-252.845108,-265.470192,-216.084615,-181.755254,-160.379451,-200.840357,-202.906423,-202.045181,-222.260696,-231.329629,-197.111604,-83.130185,-25.574822,-49.936879,-160.768788,-212.105895,-205.459151,-133.627861,46.559161,104.418211,88.054305,-12.910694,-53.715243,-120.275897,-130.61357,-54.221527,17.599671,90.215892,-22.50297,-99.770369,-175.416049,-176.117638,-131.138451,-99.314527,-61.376187,-55.770376,-70.564238,-144.791383,-196.1592,-238.584796,-200.421889,-61.636291,-7.588684,54.238149,46.014707,16.670712,-52.145931,-89.126181,-129.905526,-113.661463,-11.120769,56.71448,106.486263,17.434908,-23.908055,-90.037644,-110.428749,-97.924795,-74.563867,-4.963478,-42.187447,-112.343499,-215.892814,-237.129798,-233.284375,-208.737518,-128.005787,-76.089431,-25.528779,-95.443395,-139.426948,-202.909793,-197.68149,-87.784328,-30.267945,7.167035,-14.662758,-51.909381,-169.844293,-206.854177,-155.01396,-93.609442,-27.690683,-34.756216,-92.019265,-103.619842,-77.022686,-80.547157,-122.248649,-175.415405,-161.037843,-73.448399,-29.676556,-45.442862,-71.735219,-75.738913,-118.251372,-126.87817,-34.12101,26.160295,60.303367,4.950277,-38.998139,-146.272766,-171.68115,-105.993154,-56.552372,-35.546111,-59.524767,-35.396178,32.338477,32.4586,10.50788,27.952765,123.136225,167.008602,175.677566,137.685671,131.35601,120.35161,119.141422,146.686818,155.044975,155.288368,154.634828,125.942116,8.440777,-38.201076,-0.912587,67.831282,140.334863,118.243706,43.223494,-40.883917,-98.289366,-234.436195,-282.082706,-253.496343,-188.848645,-25.088694,68.904577,49.973555,-71.48593,-134.291797,-172.549722,-143.973502,-88.775621,-80.875706,-67.205596,-52.371169,-74.375297,-190.050441,-233.484403,-213.756145,-174.697294,-103.99283,-50.509405,-33.591581,-85.91334,-158.850539,-254.955302,-233.991775,-108.420164,-25.459465,140.830469,182.984762,154.502925,55.853255,6.240841,-41.693171,-35.027873,51.401774,153.678259,147.080274,40.842002,-7.911111,-3.656061,42.816121,145.70682,201.961525,290.898466,226.795668,172.835545,109.256445,90.120679,75.315586,86.902782,129.540143,124.319498,90.020711,-23.633254,-70.280681,-63.715645,-30.270936,1.006608,-1.405098,-29.294801,-80.106664,-72.805061,-7.970895,1.228977,-6.473396,20.615335,100.375677,55.490072,15.601375,11.426719,-0.611564,-74.661617,-83.16862,-35.932017,-13.970448,-14.035134,-69.204836,-91.153246,-88.326122,-81.738742,-107.778545,-110.13147,37.79058,222.199501,232.552196,129.768924,63.710832,15.778251,58.804104,186.900979,214.704702,198.222787,202.095595,195.274046,92.37361,49.943143,97.345383,154.514149,279.277445,305.001015,239.766701,110.817253,87.288154,93.423045,114.099656,134.865045,127.783459,130.095501,136.237701,119.81019,38.088205,-11.18219,-58.05558,-34.951086,74.691405,18.122409,-95.13891,-268.105567,-304.112223,-321.287371,-289.554411,-195.836177,-163.441578,-134.680574,-170.961742,-186.364096,-180.131174,-182.67966,-183.73102,-150.368964,-42.4183,-14.799028,-38.733393,-76.254069,-83.062017,-84.644998,-76.443721,-40.535647,-3.29649,70.200907,-5.872163,-87.11775,-131.316428,-59.548763,129.046697,183.881873,205.847607,123.230882,59.473395,-18.709007,-31.965514,-25.877339,5.73278,93.856917,113.489984,85.614827,19.24538,-20.696376,-75.70786,-79.736036,-69.488442,-39.217795,148.791999,299.643073,283.066992,170.906611,126.157705,117.633841,167.697937,304.117023,338.738504,291.358035,170.542014,123.435329,55.177664,49.335732,135.609946,190.026128,231.730168,212.333506,203.119116,164.971285,112.696478,45.2588,80.843946,219.560493,273.369665:108.749745,149.084268,132.340819,73.109236,77.415742,95.960413,44.202072,-101.288811,-94.088717,-58.187065,-28.384808,-53.405618,-160.940352,-203.425833,-222.815709,-190.636482,-46.299055,-6.380411,-42.447617,-59.14303,-20.867125,49.348305,55.743695,86.338573,165.893418,192.83841,240.42948,249.426321,242.662605,254.785632,282.330614,292.096977,337.956878,287.516208,204.190613,70.242725,57.634796,117.725331,158.385586,204.371414,155.61612,89.691662,-87.476456,-177.337889,-291.666951,-303.659581,-270.80876,-227.760627,-123.419704,-150.96154,-201.528602,-227.318458,-188.513203,-77.16011,-54.722975,-129.51004,-165.126226,-113.977904,-33.049665,-71.099986,-203.648439,-225.41946,-167.030479,-124.400632,-82.986863,-95.360655,-102.999518,-154.61817,-194.406022,-157.467666,-78.946074,7.599071,-67.984986,-109.297931,-117.863567,-118.639522,-196.947448,-223.897909,-182.91251,-157.731316,-105.782561,-35.019617,-24.256693,-55.228565,-71.089806,32.05941,168.509187,404.640619,347.232781,250.089865,121.766228,104.063615,115.77915,145.32246,211.744932,211.007022,140.720982,113.114804,126.406738,90.71433,27.429849,-36.791425,10.431103,138.900554,40.369662,-79.51531,-236.319011,-255.576198,-297.538837,-328.424489,-332.270898,-306.233612,-284.106197,-312.15852,-323.195264,-294.076354,-243.106286,-140.640173,-110.540996,-25.769192,125.669261,193.787231,233.958165,183.340236,3.737498,-59.538621,-61.965107,-23.792703,8.901196,-128.556961,-214.146161,-316.036287,-325.859438,-250.00393,-208.372733,-216.14424,-221.56192,-193.317489,-179.069665,-211.849817,-242.854374,-210.515181,-121.403026,-89.661674,-32.083587,-30.680248,-54.597839,-91.828543,-106.790143,-98.705992,-47.179955,59.486004,-58.211922,-166.723853,-270.983123,-257.349301,-227.252942,-240.842142,-253.391248,-218.939373,-108.431165,-31.665051,-18.970826,-90.136485,-176.470778,-335.834353,-368.99285,-401.82057,-445.961718,-434.868473,-320.641504,-262.560162,-199.397332,-170.191336,-129.406313,-103.881098,28.90139,123.981992,113.233668,8.016207,-41.280012,-2.878124,58.729616,96.979646,101.11222,144.37422,203.839867,169.619181,42.228529,22.851448,139.047206,229.29514,315.50503,250.203803,222.732274,206.098526,175.111126,85.682583,88.040103,192.903679,203.424169,151.794067,41.088725,17.606788,84.342363,160.81249,253.709474,233.347249,113.11915,44.342415,65.862545,115.806733,96.103491,-10.876706,-53.389162,-13.635745,85.977323,83.541003,32.447453,15.046848,-41.949439,-87.61344,-153.409579,-152.181867,-119.239042,-131.192208,-154.077399,-233.138181,-286.331126,-329.379359,-302.339906,-218.409416,-141.723476,-115.624103,-125.69683,-173.126819,-304.018674,-335.999806,-229.837948,-95.320313,153.749817,141.759239,84.791855,27.127539,15.502059,-0.441723,18.356384,134.470555,207.183117,192.0159,172.736126,211.477292,358.848679,419.984399,446.75075,434.228474,394.814505,301.108741,259.819454,193.39736,149.375272,99.660281,97.39666,86.44126,88.280212,80.780537,33.130322,9.733813,-60.431607,-113.502241,-188.663393,-203.761286,-200.603088,-159.906221,-128.099665,-40.919528,-14.020778,-38.215579,-52.898648,-24.533911,-39.416748,-94.847163,-209.387648,-227.853152,-201.334116,-172.515268,-147.074606,-180.842534,-269.045757,-246.75102,-205.537136,-144.260758,-152.970689,-181.944349,-116.093404,158.624797,211.445075,145.913661,112.711099,133.469174,42.735791,-44.964861,-100.856615,-59.359692,48.157315,96.400542,89.089703,36.865765,25.293322,72.955706,87.576032,75.320556,166.046905,211.32394,151.021074,72.410357,-1.118748,24.694246,34.564041,-18.080229,-75.465197,14.741618,42.189125,-33.614467,-93.79905,-97.140524,-57.941239,-13.062558,-12.972054,-41.696517,-136.251987,-162.957157,-159.526233,-161.290286,-238.699785,-294.18177,-323.954247,-274.205738,-247.477031,-197.956678,-189.893895,-214.692967,-229.519445,-221.656375,-182.753668,-181.998409,-234.071398,-245.701343,-147.148338,-87.792781,-123.86219,-169.068235,-107.929784,-15.173146,-18.318126,-42.856375,-48.253543,-45.883345,-47.097449,-48.335667,-26.432876,-43.789422,-184.661918,-272.438514,-357.6041,-347.811069,-323.531941,-341.550486,-351.708123,-231.08165,-168.799107,-131.188548,-154.806404,-242.042194,-264.189158,-169.163752,3.705085,27.1358,-72.395819,-135.074291,-141.79938,-81.881804,31.039013,51.817101,75.845151,86.94379,70.446692,-0.23262,-34.417306,-34.726106,2.610657,106.060854,192.405694,207.609819,175.52567,148.302484,120.756054,131.571385,201.538943,253.744361:231.281108,253.843118,207.781364,61.74444,36.758375,75.520463,87.100842,116.178691,164.567375,159.57668,80.945848,23.743496,-40.387189,-21.459537,57.075223,92.850045,172.813746,189.447661,159.748524,107.003084,105.562337,118.279991,125.490962,191.230302,243.395282,220.264687,126.262205,83.410026,60.64872,90.297939,182.686999,224.875711,257.925675,117.581157,0.910382,-150.636598,-147.934647,-31.787607,29.124753,96.831601,78.485387,20.4604,-149.003222,-227.716562,-328.638341,-351.385082,-337.735259,-292.0312,-185.33616,-198.934687,-238.054093,-288.114027,-285.788155,-217.997823,-184.243309,-139.389416,-61.871119,-48.015218,-123.394186,-184.695818,-239.030308,-210.227088,-104.399527,-67.852467,-61.976161,-94.822041,-115.774822,-186.279379,-211.995878,-153.479008,-83.388703,14.411922,-17.470696,-49.635709,-81.665939,-113.909546,-242.472482,-268.133547,-168.128674,-99.76362,-20.425871,-39.465897,-74.846014,-133.408148,-149.84696,-136.706674,-84.519894,81.95041,160.382289,142.274692,13.083707,-74.161177,-123.991832,-61.456815,92.580561,140.959016,172.556657,91.460871,20.641121,-109.058215,-140.505504,-82.815009,-18.001454,18.600672,-131.234598,-220.794932,-286.483994,-260.317674,-217.037065,-230.351509,-279.23113,-278.382353,-236.763666,-265.499699,-311.059785,-379.682618,-369.036715,-235.998818,-140.276454,33.110934,105.287957,87.063425,-27.424466,-105.967102,-223.203774,-229.988448,-152.883911,-101.004203,-64.64176,-144.853707,-202.698614,-341.732607,-374.037189,-257.31031,-179.030938,-126.065318,-160.289972,-208.780107,-316.919907,-351.077829,-374.092343,-350.297766,-227.782825,-163.450067,-94.433314,-109.714357,-152.45761,-273.699564,-317.838606,-299.378149,-220.546934,21.405673,152.901302,121.188613,-74.597941,-176.740822,-263.301773,-242.115461,-123.67251,-66.932602,-67.791907,-95.407255,-78.712285,-133.087886,-203.984853,-259.278078,-239.387063,-182.649166,-116.041661,-115.881604,-204.01257,-240.458913,-238.875331,-218.333234,-129.621201,-43.945681,115.678574,52.762617,-38.56127,-173.717825,-187.443369,-106.238294,-50.76743,-3.113407,33.214831,55.086831,63.167399,54.107956,63.111628,94.623073,202.18004,260.307598,326.302784,316.782683,290.514098,228.050046,223.385111,260.000936,262.416716,262.537521,288.153529,258.696818,114.120016,46.821687,27.472807,74.564205,169.94903,193.868699,173.094629,43.710914,-15.854827,-83.392252,-116.1621,-159.242922,-132.325464,28.658436,101.373071,35.719627,-112.840848,-128.917196,-115.596626,-117.803671,-100.195769,-62.43084,-7.896636,-68.066909,-110.322971,-166.551512,-171.74705,-108.168892,-59.503555,4.515676,17.555213,15.651304,-16.102339,-66.363625,-171.969809,-182.896658,-92.326613,18.557712,281.017348,275.056004,185.489043,89.333287,99.011065,141.651763,149.223576,148.971729,206.456224,244.287392,256.157469,234.820024,254.748078,311.954835,424.931849,460.237103,479.974717,388.094513,314.897922,186.682155,140.879236,93.843848,98.041825,113.300312,75.540238,54.540201,42.044959,37.761568,19.021347,23.338728,49.668487,54.88042,43.632014,24.589362,44.220943,103.675193,99.823116,72.493015,97.834844,188.386711,178.311181,116.766503,-31.516895,-79.443623,-97.341217,-72.258895,-46.935805,-77.758754,-133.357687,-94.965079,-87.355287,-140.827647,-161.271838,-104.131909,-24.492911,179.252642,267.902954,244.376979,139.99146,77.930156,-10.329888,-8.672231,71.023061,118.674175,171.157135,158.074323,126.289505,37.729612,21.258848,69.378018,98.053624,167.898288,227.941446,189.701821,20.126969,-60.337956,-145.030363,-139.824558,-61.410351,-16.53798,3.790906,-29.705611,-29.038958,-37.912234,-61.545907,-72.442385,-50.881425,7.572183,18.712096,-25.905009,-195.164733,-288.653953,-376.283309,-350.290051,-279.103766,-264.563062,-250.680038,-280.620303,-296.840833,-310.668512,-336.12723,-385.13464,-354.42193,-194.071738,-120.392505,-151.763922,-218.895893,-230.169763,-278.436162,-293.940577,-213.580433,-151.760665,-102.986028,-137.088577,-173.925607,-251.74107,-252.197097,-156.299956,-85.169676,50.17351,79.667351,33.110439,-116.503632,-177.740838,-253.828579,-277.470128,-254.424625,-209.611124,-138.429443,-143.090609,-177.440154,-264.230354,-283.021537,-252.457431,-211.959849,-53.6374,121.441595,128.48796,3.245186,-37.86802,76.783854,191.410683,292.333128,256.348732,161.142387,96.904706,60.293975,17.848462,36.163485,122.817545,151.991884,165.153305,174.661771,163.946228,94.833783,56.367753,28.74232,63.939132,223.768244,313.190196:-75.742295,19.098561,40.248474,30.582187,10.83212,12.029388,8.208285,-109.097186,-205.059049,-177.272067,-75.464593,-60.138125,-105.667286,-149.260937,-215.839862,-189.464051,-38.523693,24.542496,11.581426,-30.501152,-25.230184,95.771573,163.624413,206.741269,250.24467,296.990614,369.842132,373.302757,318.316726,285.528463,234.80492,216.796045,243.170144,241.0272,173.100734,31.065916,31.236218,127.991154,160.689096,156.399024,71.167719,11.924544,-52.583825,-61.994296,-155.305457,-247.989679,-372.166614,-345.244487,-169.839157,-60.928689,-38.96956,2.237701,-6.982159,-103.465841,-133.953965,-46.280773,118.446575,177.674092,261.878289,276.318269,202.853783,142.745585,78.147801,100.573564,225.450199,261.974471,233.381042,131.236992,71.060482,72.367714,153.805003,278.502177,243.36918,221.046721,183.714387,132.767964,-5.091049,-28.984984,37.517011,71.997151,75.223369,74.574047,100.329684,159.848375,170.90896,201.934657,252.642064,419.209844,475.218349,394.562909,145.339632,62.998404,87.177029,170.585709,289.027243,292.780288,305.47956,322.472759,285.720545,124.39954,29.277155,-70.984472,-56.255286,-10.098404,-103.932385,-192.45015,-330.501967,-363.110737,-356.291637,-318.29785,-222.389959,-190.887709,-182.84768,-209.310408,-215.557441,-172.271691,-119.222097,20.41273,90.388183,197.352466,279.460574,330.887345,383.902338,339.035958,164.171213,109.616182,120.489997,148.796663,162.601465,52.086913,-17.448987,-57.200804,-37.372739,-3.219206,-8.15278,-36.048286,-37.336362,-53.549311,-105.693042,-123.954096,-127.147367,-83.598951,87.435089,155.334276,143.199156,2.85784,-41.533277,-54.872866,-60.382037,-58.839722,-40.478768,-6.399295,-51.415361,-113.651745,-206.783399,-204.77174,-161.42319,-140.928407,-86.693268,-41.030422,79.561041,152.809392,163.064055,103.504232,3.339098,-262.492478,-354.986827,-393.849742,-347.49159,-329.223765,-278.318524,-243.6305,-203.506324,-189.714764,-118.764653,-50.449792,120.634932,165.292272,139.135545,120.10908,135.193518,192.629362,204.858697,132.195001,136.495147,193.342647,221.581036,167.010993,31.939641,2.301085,44.164067,86.772196,159.793059,153.042868,102.524521,-38.98947,-104.583217,-158.515998,-120.305536,30.496984,79.05197,66.441634,75.157287,86.067442,79.152228,74.408462,100.139509,138.586132,218.902108,259.545584,302.935849,383.245881,354.50565,224.103072,197.023395,202.617609,127.674375,64.575122,16.261175,19.146516,-37.545965,-86.700733,-121.660652,-96.605732,-42.256232,-137.593863,-235.961889,-352.641008,-342.091588,-265.064153,-244.708089,-276.09364,-293.186547,-264.425806,-173.113166,-155.407127,-244.155635,-321.289417,-379.070888,-302.766347,-20.193403,77.366523,39.693471,8.65584,20.039592,-13.877067,-53.350084,-95.339629,-22.044147,38.76399,161.73209,224.708892,318.771728,334.089693,315.502558,297.309415,240.522273,161.251768,153.426518,173.238116,158.138071,90.151352,52.825387,-1.874039,24.314436,59.233635,129.023431,133.819971,18.369935,-65.092257,-185.00192,-227.822044,-267.148977,-205.791367,-147.93794,-55.562816,-46.872964,-48.709581,-43.883873,-101.171627,-229.41335,-268.014222,-277.390912,-269.515077,-221.933423,-192.272093,-237.408685,-309.0722,-374.717524,-297.897261,-244.537081,-140.265429,-110.165867,-85.856688,-67.67583,-16.371152,-29.77176,-58.551566,-72.032622,-75.291005,-138.358606,-165.997645,-167.544279,-143.844856,-29.252141,37.188447,13.132751,-41.016994,-22.055811,87.310484,127.73902,161.156566,230.363966,256.964353,192.241045,108.991263,-14.738835,-7.633975,45.879542,29.026733,-36.124137,-10.330728,26.523299,81.140708,76.927332,56.406047,63.84232,88.275041,105.096079,97.901917,51.497152,32.497261,11.919615,1.15686,-64.027986,-125.103001,-206.343607,-209.263885,-213.452387,-217.824557,-217.793606,-229.056261,-249.757637,-306.368688,-274.570297,-248.455322,-273.925764,-298.331214,-272.862155,-234.000363,-184.810929,-167.558992,-91.922729,-74.211948,-117.974214,-233.814849,-271.820885,-277.109357,-245.463502,-102.507799,21.247192,-9.622593,-268.865099,-422.165066,-595.732439,-601.089586,-547.555044,-524.55487,-478.349795,-443.421293,-419.68318,-339.038299,-311.188906,-309.82233,-324.976725,-359.775998,-345.52088,-316.710079,-253.320085,-233.86771,-245.349904,-255.757109,-233.358571,-209.929082,-100.962552,43.571096,72.343451,34.570072,-16.602268,-109.02391,-112.462536,-7.464667,143.234152,192.767274,198.030365,157.418966,99.156767,136.122443,300.637058,358.514112:-174.441244,-38.492684,-22.582868,-66.271551,-81.192131,-125.955602,-208.192652,-355.253404,-298.335475,-258.760547,-250.545565,-286.087989,-402.212227,-437.282539,-400.050105,-341.333321,-226.253025,-202.834111,-202.954273,-175.77355,-162.491731,-105.239247,-41.130479,81.193383,153.119022,200.492268,340.86917,414.135799,444.496473,377.073544,230.545925,247.764581,422.350522,377.649623,248.614974,55.156993,52.169563,134.209028,157.335422,164.994157,177.271091,166.455511,79.689856,7.327598,-120.016479,-136.280477,-138.445151,-160.761332,-204.304852,-177.536396,-141.376697,-65.725993,-30.745773,23.895222,16.802909,-64.944846,-96.752972,-49.051914,102.709295,115.714346,-57.499053,-162.695998,-240.256519,-226.842328,-190.770974,-157.6085,-118.958903,-85.785812,-127.312853,-210.676693,-203.751605,-128.381406,-69.843069,-76.20694,-187.754517,-267.639536,-369.456297,-366.731579,-304.181744,-278.302062,-218.613391,-145.780091,-124.371383,-117.372911,-106.065062,38.026406,144.372689,274.43722,259.279471,213.380056,103.356111,60.793355,59.865638,116.498193,268.507831,314.165323,290.614734,188.217502,154.422907,142.89355,138.375412,59.732892,1.428855,-34.142143,-1.387585,-35.995638,-174.97089,-213.316944,-185.518704,-143.316607,-30.956111,37.361976,102.667202,-9.84109,-67.507904,-76.489495,-59.54139,-67.591666,-67.656866,21.588414,176.233366,263.077457,406.808734,415.870186,262.43521,138.896171,-21.103717,-17.170419,89.665678,96.7521,33.776438,-103.149777,-134.426616,-118.319484,-121.463883,-225.880852,-283.626327,-254.745322,-185.36495,-185.756152,-178.739253,-117.188964,24.299557,45.385688,50.712822,83.943653,97.353923,79.422052,46.348583,-20.388321,-44.777251,-60.40676,-99.06934,-164.955552,-301.482048,-319.754775,-270.451777,-260.105189,-320.694915,-327.509057,-205.54797,-86.694292,-55.810523,-37.628491,-90.177722,-289.726838,-361.943948,-387.159329,-377.169564,-389.451926,-414.535585,-420.776639,-427.593962,-396.849316,-235.940626,-135.454086,31.694483,102.395457,118.367129,127.435013,120.009152,124.083026,128.950894,112.97696,116.527935,130.396283,143.990908,131.48257,57.232218,15.482765,-14.588985,11.11356,110.258096,109.889565,51.560605,-86.308044,-130.707697,-123.5039,-67.337988,77.547149,100.183765,56.36712,-9.995786,9.624795,136.068085,206.057358,260.285573,243.323698,237.101883,324.185045,364.805456,381.608054,342.921995,215.787584,168.565923,120.679591,115.055394,128.037355,119.286819,76.645354,22.932392,39.612006,22.357023,-22.199819,-44.848023,-44.769117,-91.477559,-199.127407,-205.140795,-141.004241,-129.358907,-156.85599,-123.358861,-78.094951,-7.144934,-29.938407,-199.393176,-278.443398,-237.77616,-101.509236,203.808922,239.098821,173.221604,69.467156,55.443921,35.922977,26.360247,69.042733,221.21233,300.226023,364.907649,365.079605,398.976984,435.973276,460.4887,435.724017,329.330146,176.034051,138.469004,139.082586,123.466908,68.897407,70.517078,153.395752,320.158065,384.475639,363.33298,284.691913,83.633756,-4.195895,-116.760253,-137.094514,-144.228772,-134.462944,-85.346217,63.364246,85.043623,-5.990394,-62.22686,-133.227049,-169.837729,-175.64766,-172.643241,-176.474753,-193.071664,-197.983988,-263.600256,-330.896468,-381.043692,-267.02064,-206.756062,-147.466517,-126.60333,-43.190525,11.263862,110.892482,140.439374,131.845586,145.55789,143.729894,38.928018,-23.924968,-63.42402,-32.981013,51.762707,5.779424,-34.141662,-4.187921,48.070428,102.495355,94.948032,104.946794,183.959634,197.798203,161.388221,127.179081,47.130617,14.617378,-67.399597,-122.606861,-171.562403,-114.853741,-76.43472,-52.223013,-92.440112,-179.312492,-169.409648,-80.004721,-27.437052,-1.951624,95.968745,122.29912,15.842868,-68.904112,-133.40684,-119.801905,-80.450101,-65.373094,-79.313375,-116.300524,-122.079215,-131.927165,-141.911597,-132.96504,-153.345782,-210.588413,-290.604954,-267.858849,-159.200057,-109.721791,-15.085331,45.020521,116.818953,-33.64718,-130.644863,-154.239302,-112.492816,-47.697802,-29.151793,-39.901148,-77.779343,-100.697151,-196.842879,-258.420904,-347.464775,-360.993195,-342.796133,-321.976313,-233.354767,-173.168805,-178.839446,-202.930295,-220.31875,-256.955029,-271.591194,-288.07814,-225.687642,-170.177053,-90.189287,-86.803807,-95.3687,-77.843244,-86.844662,-128.663477,-98.121611,74.123955,103.004497,-17.187072,-114.894879,-186.549234,-138.66493,-46.153219,4.454335,54.53562,158.107095,171.340744,102.073744,63.850352,96.431639,166.067797:39.781421,35.994274,24.240612,-12.376759,-1.710024,77.941098,88.55897,19.645051,-17.378417,0.052309,65.198708,71.793268,-1.893285,-40.824089,-50.455313,-10.338582,128.442142,168.545043,128.509058,-4.045431,-58.197801,-57.183774,-21.796859,44.980707,128.922731,143.25442,101.742682,80.036822,76.975317,108.923057,206.249996,235.947995,200.872153,51.009987,-36.956556,-154.757245,-139.868487,6.090506,50.270342,16.887947,-36.399671,-68.280284,-178.650879,-241.389316,-303.288333,-310.528971,-367.273984,-391.617532,-312.202104,-175.933287,-134.909388,-97.503514,-114.450855,-174.873302,-167.3756,-48.298797,53.217459,65.509529,65.221139,56.448428,-20.500745,-73.271022,-69.210903,0.58848,151.643989,147.959875,96.415039,5.967898,-3.078606,82.175122,140.099346,153.379728,89.434472,78.19501,87.601368,85.653003,78.010207,90.783878,108.217994,103.076516,117.375335,137.889067,130.775939,118.587446,124.680243,170.688907,226.601525,394.915595,424.728735,335.181317,102.255867,46.337471,99.618649,150.663474,163.910392,135.358177,105.609204,106.712406,96.174806,71.732117,55.650229,22.163446,29.201951,63.300041,-49.002821,-165.628287,-331.600688,-341.696912,-320.562896,-325.401362,-373.40219,-388.182065,-306.097656,-190.608224,-196.482646,-306.244588,-327.310536,-190.065944,-82.25066,63.121136,115.701451,133.126698,176.791877,167.511597,60.693246,33.443245,82.596595,97.17128,31.751359,-97.40471,-145.629757,-180.174124,-171.804924,-117.103895,-99.804294,-103.782828,-95.6455,-105.320318,-186.788666,-241.739192,-274.487345,-213.968871,-58.073922,-22.712325,2.724573,-55.484602,-107.926031,-116.530453,-93.21047,-128.027014,-157.674265,-96.087296,10.722159,5.956642,-72.983561,-109.657371,-147.262458,-129.67119,12.307378,91.459887,134.744149,85.089901,47.385997,-104.644156,-197.269883,-265.183896,-250.092815,-256.812328,-304.198607,-314.855218,-269.052724,-220.725208,-198.795743,-226.084417,-190.863661,-98.315325,96.997582,139.503496,119.750622,39.955923,1.746016,-8.026735,2.723897,21.586211,62.742599,69.981355,32.259836,10.885648,24.893695,58.252548,117.558621,141.786756,216.492151,247.906369,215.110046,114.130226,76.601735,76.166226,110.519956,148.973775,109.468233,98.425941,106.909464,94.70996,58.373287,85.048958,188.360218,204.030159,169.217107,146.795756,147.864977,101.852196,58.76155,41.498423,58.801451,73.183939,69.436324,47.976951,2.157763,-12.556219,-63.181627,-88.630573,-103.21198,-99.014521,-98.151636,-137.95785,-163.377112,-146.139888,-101.139863,-49.253449,-63.198482,-118.63495,-147.947362,-144.019997,-133.204713,-146.914151,-220.589732,-260.017352,-240.029191,-144.978965,106.332467,125.845966,61.075975,-28.710134,-44.267023,-33.841784,-13.867882,34.687412,146.313803,192.228118,157.843775,129.857721,204.336443,276.332832,319.17332,273.142308,173.297546,156.390662,162.300144,130.422137,82.994988,13.153741,-0.458737,-43.451238,-118.732698,-142.094937,-83.49958,-32.190231,-43.422826,-92.614161,-177.132041,-205.889112,-187.776504,-101.322402,-76.193507,-38.247591,-18.415525,-34.724606,-59.752971,-58.915963,-14.396563,-22.88878,-115.486368,-161.490394,-187.360312,-172.977219,-147.981084,-158.271396,-191.341754,-192.409093,-186.58846,-148.765333,-127.19142,-94.393817,-36.617883,181.146641,244.215679,180.347991,30.351155,-19.650951,-85.008413,-99.272432,-90.245804,-72.540019,25.4056,128.645017,123.035669,65.100164,77.177156,174.161652,198.583725,192.811433,201.267987,191.211028,118.159676,59.00968,-41.910949,-40.252735,35.99397,62.363702,82.521022,129.49337,165.332431,161.733544,116.399576,57.984446,50.870991,50.777577,82.652377,75.080382,19.965837,-11.314892,-118.389652,-166.594092,-171.08018,-157.576655,-159.075226,-182.889581,-174.55525,-97.734478,-90.144558,-181.953483,-226.453649,-237.675261,-184.008248,-159.601719,-143.7161,-160.998908,-174.773052,-135.929977,-43.621817,-33.397296,-51.408724,-40.232786,-46.554253,-136.104601,-181.894098,-157.836639,-100.719003,1.883911,3.218209,-45.894599,-173.836624,-219.843127,-283.800211,-295.740002,-252.014194,-216.844557,-204.092549,-287.020899,-305.3567,-221.818231,-171.178185,-169.01374,-182.011,-116.71276,-56.931256,-79.288929,-125.826968,-121.360242,-74.537739,-38.451964,25.856845,59.438861,129.944704,97.236224,74.60923,90.425449,94.966342,79.411498,86.38769,128.435286,157.992769,182.313516,223.157301,199.902344,105.155177,102.334357,254.178311,352.35221:right
19.708667,14.966498,54.643525,134.304476,121.53559,112.05746,169.55835,325.985621,342.358647,255.805234,52.649081,20.234123,83.194683,133.989642,189.517354,199.305883,247.450451,216.163136,147.207501,-2.678476,-51.235924,-59.679905,-46.782813,-68.376652,-183.440106,-286.599021,-473.475636,-496.941671,-374.023932,-279.324333,-183.8649,-153.403643,-20.065744,7.987068,-48.451929,-178.759907,-225.480466,-228.055971,-171.183793,7.831089,114.496751,95.058135,-28.105167,-94.933403,-155.18866,-121.415513,13.011444,83.924871,182.676489,125.205732,65.169363,-44.545257,-100.899282,-204.489369,-220.276627,-157.405107,-81.124511,-61.108938,-6.340839,12.89387,-56.300787,-115.933118,-132.24055,-80.224984,23.454645,21.55328,-3.013818,-30.158056,-41.357364,-90.805367,-91.505415,-31.525723,-85.738768,-163.2114,-231.123098,-209.681927,-174.398022,-188.617739,-310.294667,-371.11395,-318.642092,-191.555765,-185.52558,-226.389236,-216.115075,-93.582293,-35.272259,-33.644419,-77.599323,-76.176949,-71.378927,-89.655825,-137.322112,-140.192088,-87.747664,-50.545564,-40.681098,-181.55496,-260.868465,-326.314856,-303.426605,-185.278285,-121.105456,-35.83536,-36.440553,-53.467792,-33.914575,-22.891382,-97.015464,-142.282821,-145.392362,-111.556565,-39.585749,-77.388818,-118.477991,-110.930916,-63.231621,-5.178188,-15.475553,0.042503,68.246828,48.326903,-64.973586,-96.262789,-86.495713,-43.023733,106.12025,177.876563,283.035239,301.808909,273.453425,180.449857,142.782168,163.250252,205.956755,258.997331,241.861362,228.907848,274.565144,302.550212,234.635664,177.070007,150.667279,168.189364,230.086994,258.767996,231.957329,143.866816,107.907588,96.990673,113.180779,114.223921,56.901955,28.82335,12.042272,18.941658,19.666736,4.264163,-44.356203,-53.717105,-2.428612,-7.354216,-61.11963,-149.673378,-172.558523,-217.346236,-236.674271,-232.033462,-179.937196,-178.780231,-249.554434,-302.566173,-406.30738,-440.453447,-467.177231,-460.144512,-390.21694,-375.885279,-399.721074,-370.164471,-318.950912,-218.028146,-166.850703,-34.278367,123.202436,164.67845,143.562034,124.77022,151.709411,183.317508,194.097265,169.979708,152.609306,218.61037,238.704402,181.117034,148.602015,170.674652,180.870908,120.643086,121.310426,144.493597,115.438182,81.935298,83.753868,121.808555,209.450447,241.756869,250.598963,163.562355,110.241962,86.555635,124.803146,233.962855,255.532569,210.280414,154.193592,119.230618,-20.463959,-114.663714,-214.634344,-199.603721,-155.736386,-143.043237,-87.051439,-59.033957,-69.983032,-95.610184,-93.811376,-34.299556,-12.03283,-62.049001,-143.52783,-173.1992,-183.515874,-183.761075,-252.436998,-287.76404,-245.595539,-160.119852,51.965067,71.671331,-4.122277,-122.290279,-115.128726,-3.500572,58.897107,110.497245,45.915218,5.157428,-3.535988,-5.480909,-60.466923,-53.033964,65.360956,130.952179,224.931261,241.005721,216.013688,116.358583,70.79007,59.189088,60.334958,10.319467,-38.29873,-67.486194,-141.249255,-172.264114,-157.339567,-84.159515,112.420803,170.239793,141.849019,-10.162774,-108.32202,-287.359676,-323.140991,-262.009444,-213.256777,-165.241884,-118.291612,-113.337518,-174.622098,-201.567423,-216.13555,-224.669245,-215.71709,-158.275637,40.124413,106.100248,51.400001,-97.684134,-143.159514,-203.004932,-253.27112,-337.31533,-279.284909,-258.344328,-329.333518,-372.817266,-340.156214,-269.816125,-128.808747,-79.780825,9.587837,63.579147,42.395164,-22.830776,-15.034356,92.797113,174.296656,328.246028,250.274567,127.542444,-26.233554,-39.031999,-77.734937,-107.100439,-86.475836,-17.456201,169.456417,234.905682,187.67069,19.72187,-31.614724,22.221463,88.669251,166.031916,108.856005,51.271257,-12.318241,-11.181418,50.168817,108.171966,173.827948,154.387499,66.884416,3.285111,-12.420438,-49.995368,-65.928405,-35.882475,-0.710345,-20.668512,-105.937706,-93.936877,-6.681342,5.4305,-12.061497,5.236022,51.154383,64.580375,101.823969,42.72523,-44.666587,-218.855898,-245.491164,-114.898281,-10.155976,90.679196,45.627125,-3.168393,-103.397529,-122.772649,-87.882393,-67.991453,-59.771583,-40.433448,29.707303,-13.876802,-52.62815,-100.201791,-117.565581,-101.108413,-67.213903,0.620273,31.797444,39.713417,79.946526,80.550774,-24.071499,-59.595993,46.561507,146.55022,236.475491,115.785001,54.058681,35.289266,55.342009,80.668874,98.391022,227.260884,363.430704,347.653515,162.687016,40.600186,-106.4553,-72.295822,116.610299,175.549621:75.02375,83.781454,77.004125,59.210724,18.51293,1.908596,73.838179,252.518101,240.854179,148.861654,-28.410212,-52.979251,45.399693,126.281173,169.700807,139.689936,140.450863,116.639371,48.030079,-102.623112,-141.329808,-160.234335,-153.501376,-60.763576,-56.038485,-173.228262,-442.3957,-499.634799,-467.03279,-392.239774,-173.639072,-64.7795,78.660283,53.503677,4.217017,-113.967393,-178.321988,-213.696665,-154.450786,47.347533,163.947638,129.874207,-63.520319,-152.341253,-179.799753,-118.092682,30.176989,83.794804,128.393477,37.286629,-36.595104,-151.580669,-168.48324,-150.089128,-141.941549,-103.263641,-35.052287,-23.612149,-38.603839,-53.538045,-104.848358,-133.033571,-148.938012,-124.594556,-38.625885,-16.920828,-49.000462,-80.051095,-64.425491,-84.826966,-119.131263,-116.16546,-70.930239,-112.399934,-259.514484,-285.017605,-229.217943,-190.657889,-169.799097,-189.680783,-222.775054,-188.44646,-149.862656,-135.008881,-169.452524,-204.307278,-174.250403,-56.398324,-12.10153,-45.020006,-131.637601,-149.197995,-117.114037,-77.20144,11.629419,24.802059,-60.511483,-216.116438,-298.090121,-425.412721,-405.113382,-172.828416,-60.85463,12.388934,-53.626861,-110.148844,-199.092649,-222.871646,-197.167015,-143.316279,-55.071575,-50.281956,-108.765872,-217.099459,-248.878283,-225.454903,-195.024781,-156.673462,-148.855035,-90.166254,16.798628,7.894979,-113.547909,-143.476726,-93.511943,-52.679389,-25.483878,-21.943155,52.701257,85.704659,36.665213,-77.702125,-68.419351,98.682628,179.412801,224.600182,250.204934,276.433771,275.299955,234.240473,116.817252,79.167441,96.38652,125.678575,187.330745,232.276575,235.109461,234.831382,229.308603,216.248433,222.987985,233.316716,129.534985,46.217093,-25.318875,-38.315361,-131.075707,-163.606266,-134.498872,-99.817688,-56.952918,-115.072555,-139.487592,-94.694092,-71.812567,-114.35529,-137.58518,-150.850755,-249.176333,-296.229301,-319.486774,-336.066509,-410.408648,-428.255366,-349.03781,-268.501072,-161.85292,-248.474897,-316.219951,-341.645088,-291.905015,-149.019197,-82.977793,46.212453,131.983627,128.960117,57.207817,37.709521,90.229724,114.604076,91.80817,93.112529,178.192276,215.973045,178.300929,50.072516,10.610129,31.926282,74.137164,144.770128,175.353752,170.821671,140.879345,129.181051,103.372926,101.814682,140.253996,161.46518,178.368873,121.787759,54.233695,-35.650267,13.254541,261.258027,352.144833,313.527984,155.357396,102.070469,9.470495,-47.21628,-100.098595,-80.328991,-84.292722,-122.147205,-120.907806,-30.372899,-15.913515,-73.880001,-106.549901,-79.274563,-53.266433,-135.177156,-302.226451,-334.300505,-269.013494,-226.295148,-245.485142,-278.769851,-221.014221,-134.298446,-6.676703,-2.572458,-17.73865,-27.479589,-8.75994,69.809667,104.170648,142.135529,159.010968,139.415815,48.274507,-13.842492,-72.911528,-12.352023,171.730511,202.829571,163.483197,160.716077,181.293575,161.536593,120.639682,76.524871,86.73888,144.089311,128.58424,64.871891,-102.787168,-160.318735,-113.71829,-18.999892,154.506533,208.29326,259.538366,150.065305,54.576609,-126.385517,-195.11896,-207.09684,-134.099298,43.943804,41.818032,-48.585736,-260.348702,-308.07225,-243.820039,-159.507372,-25.199173,-9.586782,-45.535817,-66.14726,-63.463454,-104.87096,-140.908575,-188.24069,-214.34194,-269.454805,-232.83286,-178.87605,-119.699918,-148.279917,-200.447707,-176.349024,-80.81523,-29.431936,36.68449,-7.024798,-24.301589,38.77428,98.788925,161.748027,170.10397,293.961947,371.798783,295.594413,66.64344,-19.058741,-100.321132,-98.675196,-14.112,63.478126,187.453079,159.992285,78.245511,-122.460549,-158.196459,-78.996972,-24.109945,64.69912,142.633688,167.353386,146.455511,84.757533,-58.409026,-89.756171,-58.83968,-12.05492,65.642408,57.350108,41.096104,8.934994,-9.182947,5.314458,38.410873,18.269471,-75.432579,-78.617215,-9.582199,18.419752,34.585279,59.99432,160.208041,207.176592,246.328122,78.934208,-93.988768,-310.254297,-265.686137,-50.787411,31.394178,164.910055,242.211516,183.702508,-28.41235,-72.307909,27.123737,115.679076,198.466968,178.425342,160.718621,163.575149,119.319635,-17.836719,-46.537973,69.274443,159.184419,260.708684,256.157294,229.563631,170.208578,114.568343,-23.493821,-10.187644,204.379298,297.796885,310.400669,223.481729,193.726449,127.958869,98.183288,136.902292,197.930482,313.382589,317.968491,271.683943,179.685777,122.630063,-21.723746,-28.35874,151.77913,255.035043:66.080224,-21.985801,-64.324722,-106.394158,-131.244938,-93.807844,-14.695976,110.925121,57.149467,-3.523283,-77.174726,-88.317991,-83.252035,-72.064177,-24.548997,27.912554,119.643985,86.219043,20.440152,-156.129928,-216.781667,-228.191129,-197.077351,-56.714594,-1.323149,-96.095662,-338.273623,-389.407164,-348.895476,-290.025488,-149.357727,-67.99643,73.608703,88.327856,48.400888,-97.564529,-167.542624,-200.954651,-170.566959,-75.272511,-14.472895,-20.052454,-75.624992,-102.289398,-105.571193,-89.12694,-57.084138,-15.65562,105.789288,73.529579,5.446994,-100.091583,-126.666715,-147.654996,-125.525645,-21.599628,17.99834,5.213678,-3.002083,6.996272,25.046982,2.157922,-88.114623,-71.833192,82.447564,46.871137,-54.702623,-177.994769,-155.407032,-86.524607,-97.147067,-112.445232,-69.802076,-96.925995,-221.817201,-235.674475,-140.797223,-96.727447,-88.411724,-114.69461,-169.077669,-178.885766,-189.570296,-272.083161,-283.415516,-114.420655,-18.6397,7.195524,-68.537268,-117.326109,-225.416468,-237.593108,-112.053076,-37.612614,1.40727,-5.350692,-22.332488,-117.00735,-185.961429,-302.765016,-325.062444,-244.536421,-162.052412,-25.261125,-39.681542,-96.321172,-209.032933,-236.689124,-177.525417,-101.50456,-6.11051,-8.799185,-53.69503,-133.764191,-162.060612,-130.515235,-81.1739,-24.20718,-37.560954,-23.602982,135.355519,174.488675,9.68285,-121.681043,-217.233846,-167.068183,-75.750144,-78.854288,-43.907384,99.053676,115.588626,-47.781992,-129.932459,-56.374416,56.465943,182.997209,147.911619,104.433691,14.051731,-18.198991,-32.161967,-14.234024,37.810529,52.831114,35.941797,55.726635,99.262376,149.612003,145.645771,180.854402,226.356982,277.16791,168.238037,97.417591,42.889887,13.118661,-130.022478,-177.805014,-135.041478,-83.485992,-29.207146,-47.353587,-54.967107,-65.440119,-81.274262,-161.43836,-192.327943,-118.354905,-39.495728,-59.010129,-188.025775,-275.340707,-357.844153,-332.09501,-227.710406,-173.26373,-146.142497,-252.855005,-292.845982,-290.395605,-265.370834,-163.849439,-78.776641,87.797517,78.379261,17.178524,-55.086572,-46.192951,-19.12626,-12.681399,26.68737,46.489834,31.173828,80.03537,124.873444,63.389588,0.475698,9.851771,52.473429,93.799553,124.72728,128.562481,76.826527,48.507258,85.410352,152.205077,234.594156,223.629913,162.173386,106.59496,81.126277,39.705364,58.134156,192.428002,249.671102,270.937006,249.180174,213.768398,53.443703,-38.029707,-115.72074,-78.010528,44.370168,58.946948,43.521596,36.856827,-6.112925,-115.143874,-118.577196,-37.734485,-12.795016,-42.654284,-165.633389,-224.516939,-239.17861,-222.639343,-224.476953,-225.866743,-169.547667,-99.396983,50.692441,31.466764,-15.581528,-30.494602,-1.51236,35.82857,52.983454,144.598656,189.977838,146.973228,21.836478,-15.407317,6.902612,69.243367,169.259398,169.67292,135.602388,86.338703,54.930248,-45.103142,-94.883123,-59.593236,14.839286,122.931591,75.153594,12.712087,-72.997465,-98.570359,-163.13793,-186.81974,-102.804738,36.644075,278.702566,110.167829,-32.652362,-171.035295,-170.49496,-90.564801,-34.436072,83.012956,117.891211,45.826977,-173.217984,-242.111686,-232.019368,-166.006464,-28.640209,-13.137207,-96.394247,-102.269892,-50.903626,-70.730839,-154.777437,-261.718839,-247.347312,-168.036455,-164.455959,-178.135988,-132.065875,-83.4732,2.671946,36.062119,73.513129,94.505138,129.778759,74.099771,52.477269,98.792716,150.960421,268.336462,319.187319,391.217954,374.190206,322.696749,156.30342,63.951747,18.933102,76.65972,157.440842,139.734666,50.259184,24.089494,35.732214,25.118695,6.599702,-6.321766,15.774589,134.550292,199.533328,173.148284,73.70744,13.238786,-47.279612,-7.725807,131.051111,163.682459,84.063916,-45.544427,-52.026719,-22.017962,-41.385698,-47.25693,11.036667,86.843365,-38.084067,-100.935266,-92.688215,-42.547087,61.03751,109.354557,198.749684,235.040854,252.252724,94.079327,-32.558048,-176.373197,-149.07821,4.545126,75.90043,208.985155,264.579588,219.475759,73.441001,24.813248,90.876813,203.058775,375.769621,378.680733,308.573882,225.135621,149.150301,16.669464,43.936429,230.867767,271.357377,230.311887,221.713566,222.937428,184.161935,124.235064,7.261533,46.803953,326.541826,442.00624,388.861605,152.839308,96.492314,86.721927,90.322155,123.105355,149.699208,204.210318,285.7255,301.214945,219.059112,137.62057,27.920691,59.48218,198.145644,226.926922:77.104548,36.338946,6.248506,-33.564213,-43.615048,3.73947,59.150014,198.536908,293.671514,275.963489,158.074579,106.537664,68.807597,80.44022,157.213358,206.960116,276.455165,269.301396,230.930597,112.13176,72.427236,66.766399,53.34839,-11.27116,-66.884133,-125.203114,-267.133497,-306.766309,-302.154194,-265.540268,-165.887644,-106.355045,14.762182,13.256538,-30.575324,-141.689948,-189.106841,-168.64681,-99.008811,26.243523,18.699961,-29.103406,-118.712458,-139.561659,-125.426945,-91.089545,-13.859208,38.060847,160.11016,102.971507,10.75933,-117.463017,-132.313275,-137.042988,-141.492583,-96.576197,1.414976,22.414533,36.081379,59.00753,94.670409,76.39823,43.854825,79.015584,171.192354,115.636293,61.66399,16.37081,5.992075,-52.001818,-91.47082,-114.931556,-64.547414,-82.023326,-172.364859,-182.748442,-138.589489,-112.518998,-103.695591,-135.364435,-209.628379,-195.580714,-167.477937,-184.54027,-218.177315,-138.562138,-29.309849,99.472051,59.635621,21.511882,-65.627283,-96.010847,-46.730438,12.496841,52.789509,29.480664,-32.826766,-105.663757,-133.888708,-195.895961,-240.792124,-244.616264,-177.68699,-23.375689,-0.493402,-39.569167,-94.176321,-96.355227,-114.369362,-123.544082,-99.48535,-76.888993,-57.772695,-79.67945,-92.453989,-61.965335,-6.219619,82.953322,74.073813,39.707967,94.533823,109.327025,62.607481,12.142306,-107.840252,-138.494719,-103.789432,-49.973506,89.17047,132.605858,94.046214,-29.557198,-62.556633,-7.551265,50.463319,135.204501,154.748037,141.680306,141.353188,151.065312,105.600098,70.281452,58.724371,65.35813,38.05104,24.121775,69.661508,183.553384,198.545832,175.658505,177.388652,205.50754,153.532007,107.92132,62.968427,37.037834,-79.102922,-134.872122,-156.142773,-110.808903,11.368143,28.391644,-2.555165,-84.499016,-104.879911,-114.544956,-146.143275,-216.118018,-168.815552,-137.912629,-175.565406,-223.533142,-242.841847,-221.974682,-225.502392,-246.581932,-268.333574,-280.413482,-294.713131,-306.52322,-286.207273,-164.641678,-78.509709,54.693115,118.764448,139.784124,141.839408,115.802459,63.745629,69.25618,122.923004,131.464032,107.742376,137.994493,159.104186,133.010036,107.773549,137.721566,181.537894,186.713638,106.804469,95.202036,144.042072,169.474036,193.017203,207.831422,216.041252,203.859545,179.608078,106.718587,48.866798,-33.115224,-13.519767,154.58542,234.119272,237.399193,135.831185,85.805176,-46.747501,-123.309243,-190.173359,-162.511195,-106.640839,-119.038969,-153.31445,-153.085046,-165.448162,-179.732019,-151.053384,-63.644985,-58.039305,-125.857045,-229.041198,-289.3901,-315.555716,-277.427858,-235.48776,-237.728557,-203.193133,-133.174335,78.241506,95.444523,9.572119,-130.814883,-133.584194,-40.606073,15.875337,72.248947,64.866738,57.438753,50.123732,33.954498,-6.65394,8.347715,91.12926,116.445628,109.544295,50.195652,24.995478,-1.419732,-15.107755,-26.512313,-21.74108,-14.386478,-23.351134,-51.524486,-135.247512,-171.95054,-225.2624,-214.212233,-54.265069,69.908012,192.556529,-9.348471,-138.880871,-263.966872,-258.170259,-164.704761,-104.374539,-29.823661,-74.55839,-131.999021,-201.402816,-206.138261,-237.948163,-247.720593,-172.672718,-119.148177,-86.453505,-59.609703,-15.317734,-30.46299,-119.158695,-294.480094,-331.243721,-302.071374,-208.702548,-194.971728,-257.704131,-271.397631,-170.399335,-103.027481,-24.513788,11.120712,70.003879,33.890606,16.119761,27.596137,39.200743,107.572956,179.503873,301.949329,223.801769,134.125425,-6.98487,-57.898765,-132.179252,-129.294194,-29.971847,29.83975,76.953806,67.661069,59.709162,-18.365808,-60.088105,-9.794341,62.342224,179.47718,166.709857,113.64137,21.235437,-9.973859,-20.901472,23.387337,145.246596,183.079346,170.881679,57.579921,-1.404361,-119.377711,-176.605743,-174.701028,-113.251585,-72.226249,-143.429522,-151.25951,-99.466382,-60.363915,14.819163,57.983647,116.354525,112.910367,66.265508,-42.542881,-119.331275,-251.474673,-263.627467,-130.511492,-33.878221,96.76908,120.009578,93.183111,32.990551,14.139637,7.914356,30.182289,56.72535,36.578762,8.641357,21.144571,21.133294,3.74356,-5.893465,17.667735,46.343503,117.8817,199.038385,219.99062,197.35735,142.828467,-32.445401,-68.301546,85.557029,198.621861,251.42428,100.944479,43.995999,5.287922,3.885435,62.024703,113.699363,204.248083,293.107561,311.969594,216.845402,113.213682,-73.27561,-84.850608,36.704195,90.935204:104.253563,59.734182,31.992892,-50.078865,-102.742255,-100.524834,-28.021734,160.749543,200.570197,151.807674,69.314994,50.249669,-1.271852,-35.065036,4.342092,107.273767,282.572102,244.116691,167.288794,-13.457426,-63.151808,-44.043107,-15.183309,56.708533,76.756033,18.034868,-124.661231,-159.401993,-161.089272,-135.401584,-28.355614,53.944756,153.158534,19.650962,-55.676675,-117.243037,-128.844958,-109.15456,-62.671451,59.156843,67.96168,22.312264,-76.107631,-111.703592,-136.156678,-111.953761,-10.670945,60.874187,204.468209,167.712823,71.386244,-92.105975,-90.876607,24.064538,51.077956,16.658745,0.345985,7.762186,32.205922,34.090982,32.303952,28.988218,5.285007,29.910715,176.762363,206.026822,145.643546,-30.398407,-111.110523,-168.72043,-135.766396,-17.876393,-0.857009,-69.200984,-211.210229,-208.775241,-100.142111,-48.894395,-1.152474,2.328874,2.865548,-64.853244,-132.471546,-245.191879,-247.94399,-123.061044,-37.069681,83.905449,101.85301,64.21596,-70.917514,-117.759417,-97.506842,-58.849852,7.469392,40.95305,94.979286,25.872736,-72.293232,-286.461793,-321.858332,-220.847985,-154.391326,-83.287785,-64.303656,-69.780783,-110.416632,-139.355701,-151.595776,-121.232284,-37.048002,9.262146,93.749051,38.62879,-45.843705,-146.859357,-121.307948,0.098899,44.619524,75.167206,112.092351,124.135746,41.916008,-33.440527,-137.09283,-164.339511,-190.580266,-168.778818,-53.021391,5.082881,-25.230538,-136.300321,-164.231478,-116.114079,-66.152544,21.062173,27.443766,-2.492189,-57.098324,-87.862331,-163.122872,-173.474039,-113.297309,-75.118835,-53.520744,-57.86668,-42.655766,1.846419,25.146635,88.405599,112.757959,122.472874,79.446478,46.614465,-27.285872,-94.367498,-233.087076,-242.480766,-163.516748,-117.839433,-52.127891,-39.635703,-56.710632,-150.281507,-201.817672,-220.244528,-183.503019,-72.378841,-34.588995,-62.000735,-176.011907,-238.868448,-251.244904,-195.103343,-99.506919,-93.561394,-141.083073,-212.066005,-247.222536,-291.439019,-271.831242,-137.321103,-54.828376,94.824951,151.083126,121.096623,51.88844,51.493777,36.457601,-8.403658,-53.136618,-9.633718,86.958213,48.979511,8.311643,-56.814184,-60.696422,-3.252033,31.047688,80.553399,105.051437,101.433705,59.328395,36.574502,75.951936,128.653461,184.741578,206.07506,251.890576,127.552391,22.953995,-75.75056,-32.872793,128.025582,177.02672,210.238607,179.310584,94.367215,-148.313282,-230.304033,-267.581191,-234.347481,-95.622669,-24.044772,42.796552,-10.842392,-64.45393,-153.812598,-163.674485,-136.64167,-130.290423,-136.808226,-215.770298,-272.366667,-269.177246,-239.069849,-279.187598,-307.620518,-218.627341,-114.893206,67.331326,76.044193,30.349872,-67.138736,-94.121137,-47.870529,7.028203,51.469039,27.329396,31.976167,17.801052,-16.429156,4.070434,91.916977,229.347303,213.479746,103.042118,65.491927,70.82229,27.520229,3.055089,29.790279,50.186529,65.320687,78.259419,66.990339,-7.622349,-46.702091,-80.587664,-84.264695,-1.543532,114.475646,274.592271,108.188956,-11.534917,-109.385993,-81.953864,-8.71619,-1.329963,39.576464,115.211603,84.922177,-73.376981,-120.898835,-103.265237,-84.150952,-71.366497,-69.596471,-75.831115,-37.889897,2.616416,1.801584,-53.660858,-154.09058,-139.91526,-10.845539,-23.899695,-78.921656,-98.652789,-72.824451,-11.343568,21.217831,58.171741,83.060739,160.425051,135.850425,101.897519,68.025335,67.729921,122.977972,180.225117,304.157574,288.042291,202.152744,19.754585,-34.219575,-88.599627,-93.360433,-24.874281,46.282685,131.322274,70.416714,33.111967,-49.314059,-92.35993,-88.568128,-37.143156,66.929414,74.789512,59.251007,-6.314885,-75.658831,-166.00109,-131.757818,44.507355,117.404385,74.443573,-102.596105,-141.091866,-191.163101,-237.550013,-216.094624,-133.614432,-26.281658,-126.868068,-219.665202,-315.689693,-279.605498,-98.040388,-21.890174,-13.208731,-40.22778,-57.077996,-163.708659,-245.948916,-306.196449,-262.338265,-98.787638,-19.537801,104.210913,126.732656,103.057913,50.446351,23.800145,46.349063,103.797871,167.583062,158.728429,156.145245,122.894215,58.31796,-60.43445,-55.555482,67.662587,124.948237,183.023304,198.861587,175.654132,107.838326,73.304819,-15.506199,-18.318127,160.371799,270.345927,305.713886,171.856208,125.487746,80.215204,69.984352,94.231451,118.231041,166.163986,265.705357,317.08584,286.826493,183.358625,-42.313966,-63.323473,60.347014,127.402704:10.450422,49.124909,51.01059,76.726332,122.716586,249.290558,300.291231,363.178455,380.864526,368.065467,303.974305,238.836264,113.51476,123.339783,282.384492,361.045318,394.46061,318.538736,278.106345,153.41638,82.994166,66.199741,111.913848,141.893831,-19.734595,-142.481237,-288.917011,-274.140271,-129.892019,-49.957098,3.435166,-10.934126,16.824001,44.603936,7.480724,-73.179212,-80.462034,-58.086477,-47.806404,11.063104,110.660211,104.087254,-31.107635,-91.333387,-68.978652,11.746154,166.180902,208.605109,257.095985,206.058743,142.994519,-21.307071,-99.193829,-162.227503,-147.424679,-92.100576,-23.583788,9.975224,64.119248,90.963837,143.492964,151.727611,109.53434,93.019508,115.902866,105.106094,75.338967,38.153577,34.655929,39.703438,58.035743,116.2058,105.396053,60.740866,-26.911076,-40.082384,-40.116963,-57.955161,-123.543549,-146.966568,-131.278232,-69.299877,-61.723642,-134.83591,-157.625403,-26.123743,59.656316,75.683719,58.653672,80.925889,111.693858,99.271476,18.80994,-4.479967,53.633938,86.300169,53.505976,-11.575154,-45.698269,-174.140116,-239.490805,-221.325996,-125.436987,78.896904,123.393705,115.574174,117.544921,102.640855,-0.761959,-44.530197,-27.633108,0.960384,-3.955876,-62.300004,-68.22836,1.708161,47.903723,46.461533,-2.789489,-60.020554,-24.375195,-27.824963,-77.35626,-94.468508,-107.202629,-109.677649,-107.438417,-68.088889,151.006019,317.663532,288.208012,98.047803,34.898525,77.351761,132.733247,178.40491,133.463884,91.30115,49.566179,49.081729,-4.702495,-32.52831,-22.464098,-9.840694,67.702097,191.403162,182.657517,32.249797,-26.780915,4.869504,60.820442,107.524026,75.920092,45.532115,-43.640726,-89.358298,-182.780087,-207.140949,-126.323765,-38.510424,90.420671,40.069234,-7.818572,-50.142281,-87.3037,-190.785584,-196.983151,-133.085368,-123.613021,-157.703957,-220.823472,-242.260084,-309.727382,-343.901761,-391.086588,-421.858937,-509.748389,-506.769954,-433.255519,-274.323074,-251.254143,-238.691655,-174.074897,53.668493,157.305605,147.006645,118.785165,100.012897,36.359468,25.717102,31.668437,20.787025,22.445676,99.059396,132.507236,112.122683,72.191245,52.425898,71.179945,54.296048,-8.304595,-10.605514,50.380448,69.428438,45.590676,59.385979,194.301263,251.994194,246.854419,155.182356,94.287364,13.28243,41.926947,221.732869,286.303594,240.714593,115.972158,58.032525,-76.965071,-151.642673,-228.799965,-191.640522,-30.452702,33.324235,68.232806,-41.837496,-112.617961,-144.237964,-106.123629,-34.170328,-33.184821,-80.703332,-138.014018,-162.271829,-163.587852,-155.59603,-197.954479,-221.724344,-163.275951,-87.734961,57.024319,84.205747,56.915359,-46.899766,-96.419729,-80.730883,-44.989226,-29.997114,19.233263,72.894599,124.240742,90.920878,30.455129,66.025745,158.377442,167.106395,201.555951,258.283157,247.544236,130.43028,50.570663,-32.330603,-31.249183,-34.06247,-24.425293,-1.091984,25.686325,-12.522235,-158.587573,-177.315974,-58.429164,21.65942,110.238149,12.922152,-81.896445,-225.851967,-244.258633,-191.519252,-149.726681,-77.208159,-1.850464,19.221738,-44.341399,-106.956531,-152.415748,-135.172317,-107.442875,-76.094651,97.238413,227.916585,176.428386,-83.846797,-179.945663,-203.111553,-196.64918,-236.235194,-221.748695,-223.021601,-334.262215,-393.912773,-387.447453,-338.390277,-243.751283,-188.732938,-54.516917,1.029426,-16.695321,-129.835327,-199.338225,-181.398481,-69.946808,145.422592,81.157118,-5.239387,-51.341112,-26.677383,-44.076946,-84.415486,-121.232167,-87.272117,69.706503,142.202758,94.162261,-50.572502,-74.306648,9.424309,64.083065,114.159063,122.725125,81.342492,-93.218749,-148.146251,-80.787323,-7.259726,74.136648,71.497253,-18.403434,-156.049191,-192.387937,-227.285021,-275.554425,-381.588259,-364.464579,-214.772697,-181.769149,-213.479447,-221.406269,-182.630878,-80.965386,-50.959814,-80.51678,-105.705006,-74.671801,-105.898303,-198.688811,-386.68364,-390.244607,-191.967628,-89.419344,-47.136915,-92.845906,-92.338005,-69.829931,-75.830852,-118.712203,-142.47906,-187.379636,-187.732064,-133.784247,-94.792124,-77.41347,-57.00684,-63.198929,-46.149888,-19.546736,31.729454,124.954824,182.321183,244.000771,232.574473,138.703538,96.160632,139.649625,203.628413,240.351187,154.226241,107.328308,44.023618,35.723657,59.575297,90.619434,193.944319,262.086144,236.887733,81.025587,-17.500419,-103.781301,-50.245652,70.914842,76.418794:144.520063,88.804802,17.688257,-65.414049,-61.855246,26.518183,103.353149,299.333043,390.18004,340.894393,178.290479,121.989134,75.97864,80.646508,174.787283,260.548045,374.376803,329.70351,276.003248,111.159563,24.393395,-8.020123,38.911159,142.356241,144.071564,75.172208,-90.756276,-140.974679,-163.070652,-124.86805,37.478532,135.755212,234.829328,114.035443,41.444047,-28.361733,-37.620724,-6.077646,36.554976,106.105599,73.116251,40.233775,-17.512297,-52.356056,-56.737339,2.883377,157.385412,222.825219,289.520534,201.738123,110.001734,-65.799478,-103.226324,-81.913342,-52.734129,49.502005,158.316693,155.934017,66.918531,38.11803,59.729392,88.985599,152.539355,189.803755,232.375427,156.299546,95.566807,-17.513512,-63.390789,-52.372162,5.476956,114.18893,65.736724,-25.024181,-163.39279,-158.855035,-107.336321,-94.512452,-34.165268,10.788544,47.706481,12.397658,-12.333042,-90.875917,-118.236075,-20.441517,79.34339,188.158657,130.06406,98.662965,80.769756,65.974595,32.513178,44.37319,92.402571,104.730523,111.559193,35.791565,-47.235509,-238.723598,-296.429888,-250.625912,-173.914493,-16.777634,55.059741,33.731997,-121.345517,-212.098192,-252.40086,-202.254956,-118.573708,-100.264265,-14.728686,53.383668,22.653781,-62.705268,-63.640434,-18.267485,-8.120701,-19.093253,-26.142247,-32.363233,-89.994036,-147.083615,-229.170183,-209.897997,-131.994105,-109.400783,-47.48921,4.709617,5.195817,-43.349335,-84.497576,-103.981994,-56.323541,86.051599,127.105838,89.907418,-21.3236,-66.470161,-123.77941,-139.769934,-132.612976,-102.800594,-52.328099,-79.933111,-94.839452,-113.015643,-120.761074,-101.130051,-69.61871,21.857702,65.5393,31.01022,-109.95533,-173.818577,-228.425813,-219.973482,-142.643892,-74.011454,34.587914,-13.212556,-64.689637,-147.175035,-167.223703,-148.679214,-125.748432,-60.211091,22.135449,20.213013,-97.938129,-162.954342,-189.784095,-177.962279,-203.852276,-215.178162,-218.279913,-278.380512,-299.973068,-302.777611,-299.536672,-213.222591,-118.212865,60.380346,129.740954,124.705975,46.057905,-0.522637,-43.49697,-47.412777,-59.58246,-50.27322,47.086139,146.489319,142.608208,21.705093,-43.646761,-33.497669,48.67044,233.337237,222.349174,137.595398,-15.652654,-43.507807,10.605671,90.110768,249.554445,291.104174,282.874512,141.100118,50.986647,-62.807833,-65.273645,60.761572,151.636808,235.411602,159.597695,79.369656,-111.586803,-191.739054,-232.706182,-184.854371,-63.333106,-27.48313,8.016004,-41.111394,-108.585016,-210.645624,-189.102868,-49.003879,-7.858821,-22.598287,-93.674439,-148.168147,-217.697047,-222.464655,-239.801372,-249.753188,-206.751605,-129.405809,65.933744,39.095223,-60.153363,-205.150912,-191.19393,-52.813148,-9.67345,-17.380052,29.173798,67.689907,55.165317,4.994763,-34.199923,17.406078,147.723491,187.184685,236.618114,182.151257,126.934763,80.368601,84.655938,48.342072,15.611135,34.209274,133.352534,156.955064,83.847346,-8.532115,-150.411087,-137.445906,21.959463,127.109251,260.019182,120.729334,-5.574475,-186.363085,-204.023651,-58.304204,51.897734,160.626951,112.819747,58.477333,-66.774639,-122.501421,-180.283466,-160.397502,-61.229269,-25.52905,29.442561,101.859172,102.753945,-25.133016,-110.736591,-152.903655,-111.033098,-46.530097,-107.611794,-172.457441,-256.272381,-250.141411,-173.115718,-116.646124,-0.339274,50.434156,93.946179,9.844109,-51.905427,-140.208192,-151.263569,-47.605813,60.216642,204.974517,74.123281,-22.535704,-104.349334,-123.153448,-176.240092,-170.693455,-80.275973,-29.322643,53.626564,78.30785,45.029886,-103.113789,-165.027914,-116.864184,-33.284149,110.562149,187.0978,176.147356,24.410379,-80.631487,-158.272238,-92.435929,80.676431,106.38551,29.767599,-103.587785,-155.69277,-264.417339,-332.02221,-358.202877,-293.150216,-171.66222,-134.616586,-133.813867,-220.545525,-273.531219,-239.753796,-171.922592,-94.937041,-83.893294,-50.284707,-113.882716,-199.804451,-336.443234,-332.642975,-182.204044,-87.206065,36.835808,59.791122,36.740298,-30.729516,-49.049473,-21.912718,15.19201,26.651925,-17.45115,-89.099479,-64.183749,-56.926383,-99.955962,-128.809959,-130.068298,-98.394333,20.89489,120.174991,112.323239,52.634923,36.859419,-0.749568,-2.720215,121.571186,214.421484,293.195354,160.396266,67.532546,-36.754228,-19.893403,142.169871,212.623774,216.054332,250.29769,282.307223,193.828458,72.785869,-103.055441,-82.687355,70.038792,127.852907:145.217241,119.244057,95.625096,167.750216,239.398008,354.507392,393.242321,430.387749,421.545237,406.453991,360.283821,329.230025,263.383303,261.127317,307.57591,310.436875,276.713594,231.237284,188.540541,54.91054,-5.309986,-25.973808,-7.397076,-37.562806,-130.598015,-154.407253,-111.388871,-65.851839,3.0571,28.056882,66.950292,99.185824,208.226369,191.085639,133.843071,71.108193,67.16296,86.402916,109.789466,165.520601,136.045172,64.234785,-54.668371,-62.110647,-26.186086,15.663232,138.166412,184.681217,192.149771,56.245939,-24.761749,-97.963024,-104.51648,-160.299895,-211.738693,-262.131164,-195.055995,-148.430801,-78.816151,-64.04568,-59.889321,-43.139329,18.881464,39.156492,72.569451,109.712552,103.980701,62.629795,70.793356,182.242577,246.284889,262.687392,134.180539,84.463209,94.53294,111.965407,46.389374,-23.28496,-121.320371,-116.784295,-20.361398,41.979654,36.332976,-16.376084,-45.672146,-20.321589,32.365672,106.025491,142.828501,159.706958,163.574703,155.626912,144.063435,137.355224,82.518701,50.416244,64.404014,77.747253,41.052573,-46.400016,-71.94149,-56.826417,-6.730544,148.829117,327.609302,382.32158,320.614099,248.0209,184.451581,186.299835,165.782048,150.399069,166.706806,178.367292,158.916852,119.069499,106.83293,91.562836,95.352256,103.045067,71.400098,60.565346,112.558403,146.538319,117.905364,82.961009,87.784478,123.588037,233.098815,345.392758,356.685392,283.094963,240.867073,210.077205,195.37162,149.916748,168.105351,171.432956,71.361038,-3.79856,-66.984225,-52.071266,-13.779406,3.886618,58.888053,91.092918,79.496671,-7.714311,-69.883187,-134.997271,-105.851121,60.874076,237.455674,260.589709,181.351503,130.371631,60.975033,34.628095,0.51763,9.5616,67.439807,83.231627,97.377466,149.716285,138.110195,23.737405,-26.052809,-14.35218,70.196851,79.625969,-17.505338,-124.338571,-396.363907,-501.080108,-560.825176,-553.698487,-575.223265,-568.821188,-492.82416,-234.445523,-146.023458,-118.258771,-96.859944,65.365241,239.54851,264.535251,212.559635,190.396354,180.514767,161.292932,71.772332,28.433053,21.513133,96.107042,125.773727,156.049967,154.317037,64.781597,-12.388573,-87.172668,-15.179679,9.766459,-40.707777,-95.939425,-145.566814,-105.420292,-9.321926,-2.488526,47.838456,161.672226,163.131553,144.227775,189.702185,275.174511,252.403225,167.796188,127.515562,97.188024,56.830696,63.490906,110.307143,153.19584,244.397384,259.13191,198.17354,62.109926,9.947569,-3.908978,14.33256,22.802377,-8.037182,-90.697752,-142.512931,-166.533697,-174.253505,-156.000855,-149.990039,-176.310422,-215.350659,-196.800543,-109.789351,-51.782147,-55.020586,-139.535882,-186.243464,-145.445612,-78.074267,-36.120046,-31.980987,20.145528,145.190148,163.047354,131.838861,142.17565,191.117287,194.488346,218.172433,230.248064,191.647573,89.971023,47.129485,-59.522394,-109.425387,-100.445602,-5.482814,1.383101,-48.610319,-82.240392,-169.905405,-194.183109,-170.489051,-155.059531,-153.49375,-202.438569,-225.629042,-174.873199,-138.534789,-170.225728,-183.368257,-51.986489,114.566262,128.805656,62.227861,38.919547,23.522988,-6.438385,-89.627071,-90.311214,28.986136,118.032254,100.425687,2.892285,-55.881123,-172.669151,-217.781764,-259.928746,-215.908699,-189.968261,-249.254462,-314.604021,-367.179772,-345.053217,-272.434485,-213.929581,-23.968116,67.317467,35.411296,-77.124192,-124.833742,-137.571672,-86.14857,61.261872,74.781266,17.98461,-35.246387,4.995564,48.248208,5.300621,-76.387675,-65.327221,29.42791,95.075533,97.662484,69.061073,51.859911,60.950886,95.886834,161.574029,84.523593,-1.173434,-117.215414,-136.78721,-186.367408,-197.609699,-106.289991,-44.618903,-66.838891,-214.823025,-264.621529,-350.584575,-396.187657,-382.13259,-325.558466,-269.350684,-305.783898,-302.164582,-234.163858,-204.587544,-167.940642,-142.036986,-112.229433,-108.972947,-64.425052,-58.486122,-98.455156,-186.233241,-200.679557,-149.61824,-111.415387,-99.239412,-106.371947,-99.486029,-126.613767,-147.111403,-159.886424,-162.617565,-160.179259,-131.53305,-17.432154,30.010378,7.931331,-74.725544,-114.781657,-118.453205,-72.466479,59.194646,124.741914,115.797075,126.447369,160.563177,193.223315,190.893781,224.059932,255.362607,249.042384,107.317374,32.38023,-51.745245,-59.246239,11.451482,71.174858,148.662962,179.196613,176.88179,100.441938,37.098884,-67.006918,-81.485059,-60.0705,-51.991033:-0.585908,50.6603,85.062443,169.643555,193.581171,248.014682,306.360561,424.317549,442.048536,404.997288,289.663317,257.040886,281.50685,302.762069,298.804685,294.068269,328.197602,260.250085,171.626275,20.14513,-8.482371,51.299532,78.578177,-49.624915,-218.218272,-236.66485,-223.054115,-234.349035,-228.419589,-163.347124,2.506501,50.600781,112.579168,148.647933,143.768049,79.382649,19.723821,-54.340104,-40.374021,55.150389,111.746725,88.817345,25.996197,4.350625,-17.665865,12.466746,137.885957,185.811289,199.151884,132.575549,79.771552,-14.576196,-40.352571,-103.237802,-153.329143,-203.11832,-118.546791,-53.518727,45.944072,57.548147,4.651901,-23.013334,-32.003435,-31.400453,-10.562928,65.293489,83.54605,91.397107,116.924754,149.139459,130.964963,108.529517,119.749722,99.396331,30.615091,-3.68095,-76.541533,-114.025533,-204.513366,-236.005026,-210.397762,-177.410237,-179.703687,-160.089017,-118.096426,-13.222878,-7.121832,-76.422391,-37.7625,12.896253,34.712927,3.902208,-72.910766,-81.725489,-18.184741,12.023317,-11.978453,-108.468487,-123.159903,-74.332732,-64.410159,-80.483113,-59.262349,67.683677,184.210058,187.89347,150.794984,140.186489,97.261414,67.586318,14.906469,16.469102,121.636831,208.502236,198.726524,119.312924,75.830983,47.078483,58.173213,44.748337,5.837162,6.525352,55.049535,74.680073,65.820896,64.583944,91.90652,129.03981,318.924157,471.611182,447.127559,312.350215,289.680354,352.679841,353.164631,237.540889,193.236587,193.244492,162.273331,132.250416,29.982565,-13.928821,-15.952454,16.669476,155.059366,280.932278,270.373921,101.712191,-8.101966,-103.626155,-63.446278,83.245914,150.236416,135.451668,113.813996,123.466171,79.669378,21.096331,-37.88077,-16.670935,37.413562,-21.899195,-65.78006,-53.949032,-35.840904,-91.543691,-139.554358,-192.432787,-186.312764,-180.153302,-211.144831,-270.079936,-414.575455,-434.914556,-409.881734,-440.970942,-549.682501,-505.157886,-415.410734,-224.948676,-182.776401,-158.819861,-118.0174,40.063966,188.074879,205.945049,146.231901,131.928507,188.484443,221.829324,184.5917,112.0206,24.333318,128.690859,191.369336,190.664369,136.016248,-2.575172,-69.246723,-103.86126,-14.524648,-0.514494,-50.053636,-71.746985,-63.804909,-39.074877,4.396771,29.142819,125.86069,132.015885,74.105466,29.278691,101.619871,310.849309,348.06203,237.924666,70.644801,12.164982,-38.270503,-47.893376,-66.777999,-58.01839,9.764172,52.05651,75.766412,-40.989165,-86.492275,-51.494454,-15.977274,10.101753,5.223472,-33.285857,-121.183838,-179.953592,-230.047964,-216.203318,-211.933059,-224.475416,-222.443081,-181.4996,-42.129945,-61.684496,-135.282218,-227.008006,-214.403808,-131.090568,-111.075298,-129.155831,-75.470183,-13.083383,84.333396,76.384937,-11.697884,-26.001764,14.798139,37.855234,109.091602,157.051308,132.151525,52.308131,27.399144,12.43007,5.871771,-38.649116,-79.101423,-98.600287,-170.773985,-225.988741,-291.670232,-250.916264,-84.708963,-30.147076,-18.132702,-106.468337,-168.089889,-241.996771,-250.97475,-270.557111,-270.884982,-178.192462,-56.884115,-35.943133,-40.75201,-64.428343,-170.742772,-221.230924,-251.340072,-211.113631,14.868449,225.599643,221.514995,58.049433,-24.572097,-168.853257,-238.539018,-297.774495,-277.229538,-277.126372,-322.778999,-363.744626,-421.836201,-409.377299,-304.78459,-235.902588,-98.382614,-20.464579,-47.020411,-165.898403,-178.132512,-77.450947,-24.655011,61.607456,97.1268,52.004717,-56.900836,-82.536755,-123.420207,-128.770612,-83.229818,-37.43332,134.884889,211.700329,160.615503,95.210209,126.235052,209.75331,216.023367,185.983136,140.143848,103.940251,63.567972,51.491431,13.034569,20.413786,110.716841,153.273475,137.977232,30.90571,-5.388546,-32.05537,-46.186633,-99.831829,-131.298901,-152.470994,-110.237644,-89.530896,-25.87854,16.879712,47.07389,36.998513,44.972672,82.276578,172.894989,127.413557,58.462884,-55.138615,-77.840816,-44.338845,-9.009032,16.152742,20.816678,30.580086,28.958518,-6.924424,-148.422262,-194.038842,-144.780848,-92.096054,-34.310926,-29.664991,-28.623765,-72.25328,-121.361046,-157.621175,-131.532186,-41.120058,56.953829,70.715877,49.979719,44.023474,5.552975,-6.647994,73.423718,132.242539,146.591346,5.330482,-62.328873,-103.466398,-76.376685,23.905431,58.697032,93.136094,131.412874,127.094282,49.97439,-2.829763,-57.362247,-36.452145,45.620763,68.716864:44.314699,99.916456,100.379225,17.121583,-7.760646,69.089118,137.863817,240.43568,278.211344,266.341098,183.442237,134.784095,65.213096,49.614006,104.258783,185.128872,305.951003,279.610736,266.38445,193.25998,94.935384,-78.572671,-67.554723,103.014993,133.815625,44.488286,-112.926135,-109.509972,-10.690087,26.460328,41.491306,56.887807,116.496024,58.858169,16.245295,9.396042,28.779546,45.76331,37.69602,37.338505,59.120772,52.220378,-21.428197,-61.181729,-28.160403,55.531772,225.415683,266.566037,266.970817,138.830037,36.183209,-121.102092,-143.296792,-87.337471,-44.974819,-23.814187,4.007648,32.857071,51.522471,58.678877,103.540442,118.076929,96.587124,88.898372,138.088929,154.488495,134.537715,100.024546,80.985005,84.249942,121.673723,150.358135,58.454157,6.255771,-58.539137,-82.973017,-143.52675,-140.148431,-3.268332,73.46026,76.524971,-9.770234,5.726432,89.508014,105.320096,130.568968,128.98108,76.037117,168.939706,246.410379,251.594551,178.574065,81.28764,89.853055,72.854774,36.003315,43.540563,73.218237,36.994981,-45.199943,-67.372287,-70.246354,-41.079292,49.9353,130.032467,145.856642,129.531093,104.776475,6.871359,-39.046171,-48.833481,-17.43037,79.113877,91.697179,50.6801,-19.382798,-27.909597,-34.204312,-54.333282,-112.875187,-67.94007,-10.768534,68.418551,82.132862,37.027481,-26.075871,-144.863696,-149.438215,6.160763,175.546561,181.807025,94.63381,57.999573,44.361898,47.056083,67.241527,125.917166,142.186574,122.202586,93.826912,40.156035,37.665819,61.58407,64.424683,39.153967,-32.686235,-55.411674,-49.858846,-64.975399,-101.573572,-60.873571,87.984094,59.220573,-9.755201,-81.837088,-94.436714,-134.37547,-132.272071,-64.407445,-28.954057,22.00067,75.251862,117.49302,152.351797,108.563551,-14.41043,-29.913807,51.309565,110.43174,88.482702,-21.696848,-92.395004,-199.497808,-207.717999,-210.551815,-261.165413,-377.870471,-290.053296,-193.89522,-72.082803,-66.480905,-47.423938,6.714003,154.267301,279.439626,322.340267,353.429552,325.77128,171.770321,85.433793,-24.061775,-32.152452,66.395976,174.693933,165.199567,52.585214,17.025057,87.725668,148.885358,157.961384,90.900108,88.123813,80.472196,41.530869,-14.932352,15.726612,149.244011,194.718066,179.993467,107.76643,93.295967,104.517675,108.320441,122.392065,136.774685,160.808452,168.455467,144.213369,42.041949,-27.289208,-164.757118,-185.395863,-88.090521,-13.102392,80.932962,23.998318,-40.830688,-94.477232,-56.20961,46.400371,38.130252,-98.097693,-143.947436,-118.50046,-119.664757,-157.383947,-240.867463,-256.09022,-186.341661,-120.65572,-26.367304,-42.089861,-85.633914,-166.232213,-163.974056,-91.55379,-77.48955,-120.850159,-67.050013,2.525052,85.9812,74.587548,30.475085,41.622298,107.569212,134.332314,168.563685,188.044558,168.24842,69.095332,28.090291,-43.571662,-91.57431,-113.125833,-43.9765,-37.470907,-78.216591,-101.706399,-158.526959,-194.908115,-204.849761,-144.039237,-6.160935,-91.747888,-173.066449,-232.00741,-212.34767,-120.880232,-71.781456,-30.16166,-11.928605,-34.699748,-169.062146,-211.394578,-168.568191,-124.430443,-76.491676,-62.739446,-13.89951,7.535333,-15.948041,-95.150917,-123.4271,-127.674699,-124.51506,-160.765824,-224.654453,-253.710541,-315.12391,-338.078941,-300.828709,-246.322051,-151.933204,-112.54903,-0.733584,37.654313,-18.199198,-167.654608,-214.065187,-233.887033,-210.954454,-127.861542,-79.027654,-83.748734,-105.191068,-100.715558,-50.812438,-19.273931,7.449758,-0.025633,7.439698,77.177754,87.085958,-31.680995,-104.872672,-62.194891,30.336735,139.097313,89.309105,15.61689,-144.645563,-175.385521,-121.564828,-68.252592,33.906662,73.906862,109.499998,45.385392,-21.309549,-187.068015,-255.480953,-226.260122,-129.222519,-26.79162,-184.236049,-259.397257,-248.002154,-207.526662,-178.60296,-174.135213,-137.343571,-98.814156,-14.85572,-66.128654,-135.947164,-225.118742,-218.130923,-133.32093,-91.265539,-47.019841,-31.341068,-40.606474,-63.837168,-56.725981,-30.846358,-36.306694,-97.486448,-144.578631,-221.958786,-196.600799,-147.327725,-87.512614,-109.50562,-142.360856,-105.572369,14.793836,65.104222,52.815898,73.469502,126.983801,169.243562,135.956927,100.313137,131.293671,179.69227,64.643251,-17.458029,-87.835787,-66.184282,28.580482,71.687982,122.647558,157.446211,151.112242,67.458713,9.931247,-85.742808,-96.581707,-24.307727,27.434244:right
-228.356537,-376.945176,-381.183388,-333.382128,-330.480506,-269.947307,-187.095603,-58.04865,-57.922057,-67.933552,7.632167,79.517743,135.122276,102.088025,0.252441,-48.950348,-136.731012,-125.039169,-51.421637,109.28138,119.283707,19.423004,-24.679798,-50.618688,-73.245121,-102.08151,-185.051662,-229.632502,-239.727623,-178.433704,-15.030897,40.184937,79.416968,69.02656,78.500705,124.91986,145.736806,163.12478,129.883404,-30.386803,-172.712094,-209.243912,-168.097437,-89.215533,70.460313,116.297782,123.030119,98.179076,50.79737,2.527432,-13.741076,-8.884953,8.514733,55.952129,67.348339,32.392939,-90.72059,-149.93235,-156.86769,-126.89452,-107.846998,-100.756819,-11.84117,49.507778,133.967465,129.993522,91.740501,50.6392,66.683985,48.705346,-26.031064,-212.509342,-238.253656,-191.855118,-53.430754,22.795688,115.92195,131.919808,113.23141,64.337874,-106.931748,-265.520385,-288.25658,-220.086725,-170.118689,-123.010814,-133.314271,-149.192349,-124.163779,-140.527895,-146.568725,-85.363316,59.512444,94.153947,135.203684,166.402966,157.790141,12.898116,-18.912546,60.208817,107.125985,114.445219,91.484765,40.388003,-11.423118,-28.511115,-6.79845,21.162447,74.503662,99.003318,111.018236,84.587607,-30.178571,-172.46085,-198.502685,-90.153719,6.256825,187.50985,266.532732,340.499457,208.90006,111.167813,18.827468,44.170334,178.558051,246.821515,290.750214,260.087157,118.570127,-90.137968,-152.837163,-61.953418,43.861964,197.250321,211.092542,93.912463,-58.979284,-104.236674,-135.536027,-105.081403,45.253248,124.185547,160.133226,121.960771,35.929224,-107.280254,-185.188476,-181.173274,-87.886519,113.185286,140.737901,50.892689,24.014454,72.109169,188.581857,237.348507,343.057253,375.089559,275.618841,168.102136,18.378932,-45.963997,-65.934229,-42.418554,-23.59858,-35.295348,-74.03713,-214.63639,-335.280928,-367.765777,-375.195338,-344.332993,-233.811882,-180.251225,-129.602394,-115.930625,-55.107287,-6.889563,2.42436,90.597454,171.33321,240.126258,178.278879,-48.910704,-187.489678,-204.521475,-176.716565,-142.71684,-63.579761,-22.32502,15.295595,-12.303566,-106.023884,-175.001779,-185.553919,-103.503499,-25.583719,78.479857,66.646597,-13.151252,-70.401729,-126.77703,-223.051829,-207.876227,-113.817811,-67.004643,4.915756,-10.231686,-171.50318,-280.663193,-266.008067,-212.047094,-210.558765,-229.664715,-232.805345,-182.585277,-97.392675,-94.203481,-103.964628,-77.967019,24.908577,95.524686,193.975577,188.151817,114.704011,25.090966,-26.274343,-109.548206,-103.292756,14.348216,68.370474,75.563923,-7.050819,-73.395144,-212.559469,-253.908198,-220.949543,-145.270285,-33.117541,-50.33992,-122.336387,-121.258948,-111.750789,-82.823474,-54.238595,9.653762,14.987086,-43.556182,-154.157698,-219.346692,-227.621149,-158.966796,-49.357643,-15.71473,70.485994,98.434408,110.149287,76.592083,35.343307,-35.692681,-42.919969,-17.664321,-7.294671,-13.22378,-49.803007,-90.568233,-182.735248,-192.270306,-111.405751,-48.692381,67.790028,109.770896,162.136694,178.389671,175.951817,210.202478,257.479614,377.795691,418.577713,408.48802,367.420543,358.699224,362.222565,380.313613,458.749405,526.708547,629.569686,608.857082,456.744349,311.770527,273.944106,283.314647,307.742487,337.729212,349.775991,357.853824,309.787129,282.595999,251.519674,237.098993,209.851231,221.359209,295.648558,330.484923,339.492677,234.545489,191.885354,205.690383,211.776122,142.593787,91.489639,49.855418,101.076285,116.375141,100.369925,90.190316,121.335638,186.562601,357.030252,384.59495,274.972952,149.504057,155.830276,290.313552,327.595131,256.098916,212.035903,161.368022,58.414637,-12.939211,-124.383945,-149.317277,-133.896879,-83.646615,36.655089,33.471622,-140.318667,-255.349291,-225.528652,-87.206588,-25.762311,28.219914,20.73806,-35.655842,-129.153332,-163.083112,-91.912801,9.748499,219.107312,280.87941,249.338281,195.967389,192.620545,207.708669,165.845013,139.34119,186.082453,290.674108,301.358985,225.997557,129.903805,92.321105,38.061129,39.896267,154.051671,239.800353,297.829137,258.689668,163.951125,129.814393,120.303932,114.487812,151.779316,282.885478,305.423566,158.97603,-85.718488,-183.339103,-280.436394,-275.17997,-178.10549,-89.643033,60.902075,87.810621,124.488707,102.132438,36.473655,-49.277586,-23.853679,53.768902,59.602404,67.304723,136.268644,153.6292,167.403314,195.119741,249.364224,259.954744,224.44986,167.323954:-85.462737,-109.841549,-69.885749,-34.289938,-72.202285,-132.840685,-114.990447,-92.04297,-179.747503,-211.848622,-153.137429,-83.289315,18.111676,12.571258,-107.673445,-182.000973,-233.39828,-97.017254,-18.341511,9.437321,-28.114209,-90.889276,-102.751508,-128.226435,-178.89729,-179.057144,-81.752451,-45.424529,-96.910338,-121.865809,-80.374747,-72.58723,-135.581335,-71.721454,22.377169,127.347638,98.114035,-11.289411,-32.597354,-45.283516,-205.981322,-310.220643,-328.339085,-241.240522,-41.430077,35.63199,107.459231,111.618023,72.146284,6.137076,21.053869,100.618981,94.787097,1.136194,-31.529,-47.491706,-86.726875,-93.965734,7.160204,84.077103,120.598008,89.223137,107.44631,160.288678,208.730224,153.012694,141.785684,162.198839,138.851208,-5.469803,-91.736805,-220.602088,-268.243314,-262.292771,-162.0999,-84.099999,50.921367,95.926144,89.217005,44.737473,-51.583407,-139.099989,-149.339639,-83.16973,-45.467654,-50.649488,-104.538415,-227.565704,-226.681522,-207.234331,-176.475022,-140.570741,-30.158407,8.277852,-1.177558,-33.189815,-128.183716,-188.566402,-160.974807,-48.559805,-13.841784,-3.245228,-9.999135,-41.111565,-108.337894,-148.415048,-133.587216,-62.522283,76.132827,99.719147,72.346299,46.402682,-43.193658,-173.403318,-201.726216,-118.901802,-29.919205,132.266384,158.40492,69.821374,-97.815287,-142.210727,-67.583008,2.884065,53.362223,41.210182,34.817452,40.573685,-60.764534,-249.159148,-261.837736,-86.918315,22.183796,112.009249,81.667067,-49.129029,-144.542988,-162.676184,-117.942041,-60.706388,59.480378,110.666462,150.038226,116.902951,-51.135095,-223.58506,-240.942333,-127.803336,-39.157639,96.6785,107.969224,-4.502071,-125.228554,-119.568683,-3.518992,48.199909,100.203302,101.32634,-22.971749,-139.101613,-339.568104,-380.001484,-338.284196,-205.19099,-137.660893,1.513487,45.392055,-42.485334,-261.431069,-317.314172,-296.447884,-258.350724,-165.806847,-128.792389,-117.712642,-123.782877,-117.573454,-112.246634,-98.800049,-27.05119,22.385995,68.960048,37.387882,-72.465757,-184.593042,-243.120972,-274.419789,-233.51279,-119.033339,-76.966668,-61.970506,-87.184354,-158.465455,-201.463206,-195.952653,-120.663206,-67.55607,-15.235679,-38.327085,-120.922971,-164.592318,-191.946289,-259.624866,-274.562496,-207.464222,-139.114144,-68.314323,-86.425107,-194.606265,-335.36853,-348.772045,-250.850283,-202.018135,-157.920011,-150.027157,-157.260322,-196.118516,-209.613674,-159.004633,-99.677163,44.930258,105.820929,116.895454,68.596036,-81.653107,-215.605693,-216.029521,-129.58618,-97.602306,-61.007092,-46.06479,-46.868918,-87.193129,-114.15798,-171.850514,-183.964049,-116.519109,-59.970183,-7.244582,-8.086225,-17.193864,-57.230717,-58.927968,27.404585,69.140942,39.954637,-13.822725,-42.18357,3.934087,-42.213871,-191.88677,-185.090261,24.461875,130.994558,118.422977,10.394625,-135.47277,-112.601294,-122.706395,-145.391369,-113.827516,-33.933938,-33.917989,-109.044932,-197.234305,-227.353953,-194.960838,-138.501066,-44.869876,-11.854047,36.346815,42.47835,76.526624,135.396117,146.484594,233.121953,324.592095,418.127348,381.791182,331.202696,418.072506,445.395659,462.986656,490.327481,556.706509,578.758552,575.753693,553.235343,522.538868,458.559553,418.69809,425.217638,453.643727,493.773191,506.24902,452.537456,274.586599,214.73695,243.826455,273.972104,250.168066,237.924099,216.447614,165.876592,67.141556,96.762798,145.68381,240.762872,251.638245,192.352181,155.058089,105.761443,60.139303,44.62516,89.930095,137.321531,219.561072,275.314793,378.430947,363.991941,226.748991,181.590092,224.628981,321.774116,348.51891,334.622551,271.402832,123.19578,114.807883,118.312048,78.25053,91.444386,199.67091,230.288147,225.746359,214.007729,107.423103,-44.783182,-65.664358,17.001093,93.815566,207.085027,192.564229,45.275458,-94.44174,-135.349211,-86.812513,9.086544,196.532939,228.084764,166.939115,127.589433,161.814835,277.490865,288.207514,228.395772,214.580725,223.677737,216.861528,204.697819,193.979909,153.267671,39.137129,17.056518,124.051489,224.535137,336.97335,312.478731,195.582612,179.203004,195.915249,197.118345,190.446531,196.490953,215.998856,221.624191,118.776749,54.093625,-50.115682,-65.570213,30.081954,111.665056,161.774351,118.35769,42.570715,39.835149,43.089534,17.008238,-2.763758,15.601607,40.013455,62.653107,125.730632,177.026786,265.552813,294.381262,315.391794,295.532015,187.117536,152.551984:-94.148096,-170.000753,-174.930238,-147.590356,-127.523142,-102.268519,-115.58975,-194.662891,-262.907947,-250.496772,-145.303758,-91.932338,-53.676577,-69.413392,-107.787825,-108.00659,-107.136344,-120.418814,-103.483971,-46.558446,-29.952115,-53.233111,-98.418013,-209.421852,-258.491533,-220.522733,-34.256571,33.621091,26.200631,3.416129,-13.996372,-31.189589,-100.630825,-79.189613,-4.293072,128.444177,135.451158,55.723068,5.329686,-83.903237,-205.607343,-249.300045,-206.951741,-141.585819,-18.668796,21.903258,31.745842,27.346735,80.707918,115.605755,95.861103,60.01598,68.795871,102.381927,102.036395,33.311429,-31.715449,-0.8786,144.615611,188.107522,173.904359,159.799203,169.704668,168.127738,87.643938,17.003389,55.434069,169.247406,151.785679,-32.309299,-131.593229,-254.851202,-260.871658,-225.882757,-133.276285,-96.726781,-59.80736,-42.242763,-5.235766,-14.334209,-109.328991,-201.878375,-212.21869,-178.63744,-153.939904,-111.073076,-105.140002,-148.519316,-212.898413,-238.944923,-295.545905,-309.169647,-248.803217,-196.406956,-165.894637,-192.044108,-229.328352,-159.524705,-88.06677,33.157476,50.138173,9.61901,-25.29071,-82.880565,-123.751309,-131.806575,-100.014565,-62.737651,34.639138,68.660177,52.697775,30.461968,-1.63688,-50.228443,-44.988993,7.186164,11.403021,-6.512028,-13.393819,-49.719233,-79.503791,-73.243265,-51.275296,-44.000704,-12.574652,-1.618033,3.145566,27.03991,30.678089,-146.360265,-212.624492,-155.522539,-89.385518,-39.158494,-37.401369,-11.165198,-43.80562,-68.334898,-2.341322,68.106914,168.106258,182.993264,130.611699,74.003209,-82.208827,-265.997911,-306.927725,-231.411669,-152.496081,-53.458711,-64.133964,-114.760553,-108.925262,-98.692587,-68.615407,-52.987798,-16.412005,-3.078222,-66.825067,-150.89593,-328.734177,-339.795126,-267.496791,-93.201687,-17.021302,104.199695,109.189756,-24.345178,-157.874266,-171.484614,-133.659327,-108.459429,-82.874855,-94.360393,-133.379372,-137.759627,-150.028575,-178.985092,-145.969401,-13.019982,21.789121,-15.957572,-62.037681,-160.968182,-279.125369,-320.81786,-309.878821,-269.206688,-180.827455,-150.656648,-119.816329,-101.9568,-61.308295,-122.624406,-194.202214,-263.821261,-230.681949,-178.374066,-195.319572,-205.861647,-218.856826,-240.167421,-205.310134,-152.526215,-72.769627,-66.134693,-98.122112,-112.495865,-155.28369,-269.724677,-301.024231,-222.21562,-145.335433,-64.820482,-95.404103,-240.78786,-336.886186,-322.058961,-155.824994,-52.327651,93.337412,134.930383,143.164711,106.457206,-7.211744,-70.64385,-55.46788,-8.85326,-2.701707,10.783332,13.438017,-51.258666,-134.831417,-141.407637,-115.127182,-103.74045,-75.742104,-51.082499,-1.184097,16.018702,2.077275,-73.649348,-87.891884,-37.173298,2.491817,32.048454,2.896953,-77.53345,-130.916283,-152.676982,-118.030636,-75.805764,12.315058,85.110941,161.997781,89.986406,-118.076353,-155.634678,-141.481992,-148.775479,-169.926962,-198.112087,-201.828212,-227.625061,-265.038436,-258.184126,-202.704885,-171.836998,-84.448372,-30.763259,-0.320297,-26.624535,-45.282837,42.016777,114.811989,255.093215,300.900282,366.024262,402.917055,438.816954,348.933179,307.506256,352.930842,419.608877,519.294098,540.400372,586.83182,604.938678,530.566693,397.008519,385.394267,469.833166,524.331574,590.838128,575.232556,439.530081,286.063446,224.89224,147.737845,142.697675,190.542644,222.476057,186.824837,104.219925,-30.146584,4.391939,58.573443,160.623854,188.444786,177.493547,141.641458,44.524427,-41.552316,-58.082001,17.490866,83.115751,178.377398,214.755945,274.822061,274.274176,168.560067,74.629295,111.034787,259.689496,295.093363,271.006313,245.499487,196.150744,87.316305,30.353149,27.869596,79.284068,207.029435,259.178616,282.088236,242.93646,94.666995,-4.531249,18.342815,131.309488,172.155509,191.558456,146.873016,-0.414732,-16.507274,-3.386937,30.230466,82.583831,165.774086,170.257127,152.379178,143.521142,160.464684,188.507405,177.842487,155.576505,174.540775,221.88363,230.478925,230.925104,158.748784,97.880691,50.591941,90.706981,228.553154,267.249156,242.832128,220.404818,227.765437,258.755103,247.365688,173.090538,157.777255,233.031163,276.516859,259.290066,171.676015,149.79574,140.156904,127.228109,122.012087,142.851593,137.159498,109.96494,106.090277,118.546277,112.732267,76.315603,45.63907,11.447417,5.693855,4.746315,94.315497,160.884556,254.837215,267.298575,269.358352,279.4577,265.480872,216.065533:-216.465647,-373.49967,-409.067967,-374.374095,-322.649798,-158.186723,-80.222825,-46.962743,-104.373776,-106.014416,-1.486386,64.838056,94.431493,61.607437,-30.907284,-79.913109,-152.275371,-122.468856,-72.999166,6.766288,20.531273,-20.285642,-72.33369,-120.126039,-64.86555,-64.006374,-122.508986,-150.359279,-155.756005,-129.192622,-92.767786,-90.115845,-72.048432,-37.788567,6.139128,143.479561,190.335131,192.109559,174.762885,158.043314,149.943079,146.416115,148.775094,138.838016,97.373591,99.753634,155.444283,180.068393,186.535036,135.177845,107.113787,96.499688,118.489639,160.457998,155.799149,107.108717,21.467879,-8.756035,13.302694,26.591841,-1.353092,-5.937847,38.612832,69.887887,115.707508,87.746738,65.424319,71.976939,83.176516,74.001487,39.026841,-86.462761,-162.842988,-170.866106,-134.934635,-86.350822,33.538203,64.604573,-4.148584,-87.163444,-259.818722,-335.317,-313.656249,-208.136823,-167.026587,-159.00665,-192.399627,-253.407792,-180.553097,-141.788798,-179.7974,-218.430151,-188.071292,-104.0153,72.110869,93.120975,3.347223,-78.530409,-64.747697,33.132544,68.702089,68.528866,54.432783,18.923784,-128.055942,-202.091273,-134.755919,-17.513949,139.123179,152.856696,105.001253,53.281756,-70.173985,-174.004722,-185.483073,-148.970826,-124.115055,-37.042116,14.984872,67.289686,44.903678,13.712339,-22.700077,-6.307841,63.439338,107.87542,158.818653,131.197465,13.966633,-60.912472,-77.533723,-85.278816,-61.325885,61.153254,130.130819,157.932911,-10.554852,-95.04435,-92.522521,-23.909003,128.378932,183.39964,189.60624,152.504826,36.57746,-163.948672,-252.323775,-279.920073,-220.147745,-58.175958,-9.570137,-15.015608,-44.144243,-27.405526,117.647303,225.243193,339.870789,306.341723,144.884943,66.028468,-55.41427,-125.403884,-123.000676,-49.293346,-12.304487,0.087584,-23.752093,-104.251354,-208.867827,-243.234757,-206.273148,-159.721029,-69.323584,-26.207588,-39.661066,-103.82724,-217.822873,-202.943464,-135.902672,39.220109,94.118716,64.491624,-15.61169,-180.19484,-254.816783,-281.607882,-303.567332,-271.594298,-110.859284,-34.12806,-16.711513,-47.361521,-107.806861,-225.598359,-269.87736,-206.758503,-142.946923,-75.098057,-58.738159,-23.49061,-107.31759,-204.20603,-281.417466,-223.533218,-43.854408,32.289769,90.197619,63.871442,-61.893582,-182.187465,-199.306096,-185.081697,-166.389107,-98.338084,-86.28533,-154.521517,-243.3205,-250.489724,-142.835905,-56.465317,59.04936,70.95057,60.330421,59.879166,22.934585,-69.298968,-94.003151,-78.998578,-56.032982,35.111448,91.444854,109.964629,1.859715,-69.218595,-189.949103,-212.543201,-157.864801,-105.545494,-71.939721,-92.211715,-110.733427,-118.511247,-129.222339,-143.872482,-142.940804,-103.808507,-76.125754,-50.777074,-126.430317,-205.780306,-278.537765,-223.513065,-48.562275,20.322866,83.73632,53.661472,-96.656625,-167.865782,-149.329731,-127.121345,-151.670591,-204.452767,-202.635261,-162.359825,-194.358741,-239.169878,-244.000637,-192.557084,-93.488478,-58.896531,-8.296957,-2.348942,-18.984412,7.186937,55.446953,165.236178,205.114702,272.653267,305.504581,338.50495,302.806698,271.205428,248.352864,272.51287,373.691589,444.247301,545.238218,542.92796,467.903844,358.247158,309.303471,306.850366,356.562543,408.526404,370.185014,276.917345,244.015531,221.618659,180.033589,164.977709,140.133117,153.435561,175.016808,130.241178,7.940128,13.606582,59.768593,151.492481,167.851389,161.172442,148.067588,81.198711,-10.590807,-43.476902,-40.383233,-7.276467,68.384687,104.443639,167.244368,191.349583,189.913654,122.857901,120.107652,182.647184,203.699456,210.458884,196.249255,103.087603,-7.326434,-40.671665,-56.291899,-33.220299,43.120119,71.705857,91.028586,70.98076,-49.816757,-146.97887,-124.923295,45.102883,137.995084,188.327104,123.316302,-43.138873,-65.711185,-48.210169,27.842235,97.626089,215.462308,228.251472,147.507886,91.640313,106.451291,225.849354,251.133745,232.371033,235.549258,309.509989,338.15606,346.06344,300.361524,240.269119,151.366174,170.41441,305.595387,371.872522,382.410471,343.358771,271.516869,174.845795,145.854104,202.350743,256.515691,348.364908,365.805453,277.269483,101.665742,26.140617,-54.757841,-59.128893,-26.796407,10.590826,89.963389,103.804583,99.113998,82.790759,51.720884,-29.817376,-36.517713,40.297671,86.75345,128.99845,159.598993,178.103132,186.999401,183.965538,212.864074,247.380281,301.97548,292.134318:-179.132105,-242.748943,-245.134092,-206.333975,-181.689974,-120.973892,-95.630782,-110.622574,-165.718014,-152.05119,-7.55618,83.547577,180.660706,155.993391,0.579392,-66.481454,-102.279683,-104.177857,-101.307917,-36.519463,11.270998,41.082247,26.682809,-2.39981,-40.872309,-35.296119,42.269837,66.267899,28.988506,-12.102008,-121.096098,-171.458945,-215.660165,-171.897982,-109.781668,46.366005,112.584662,161.62893,134.761599,76.638896,98.419681,127.320649,200.608584,207.493171,138.807424,113.9512,115.901951,114.471073,61.116299,4.949537,22.646941,90.746571,106.971438,105.468395,82.896878,-16.037055,-114.37457,-113.688529,-34.784664,-14.612499,-21.29968,-15.177002,-25.776711,-49.872902,-64.160898,-40.078965,-19.588982,58.697241,99.778987,120.993932,87.088749,-15.666977,-49.870312,-42.940321,-34.864951,-40.118299,-31.483092,-29.844204,-115.388862,-184.858296,-303.102445,-370.526183,-365.795381,-293.364265,-246.287606,-206.897782,-232.315892,-322.047334,-399.440744,-427.928291,-454.425045,-428.55246,-254.15854,-151.628598,-95.693118,-155.250564,-322.502909,-354.314192,-278.612296,-61.707631,0.489482,-18.04437,-66.52204,-162.791692,-274.265195,-318.552881,-262.456712,-172.648203,-20.870479,12.378388,23.200691,18.430811,-61.806533,-240.364443,-279.189202,-200.764382,-126.228332,-23.023018,-19.10048,-75.6809,-121.895817,-126.389505,-83.559037,-34.217892,96.973642,156.396493,205.125842,179.731694,18.1718,-113.070046,-106.845018,-15.740893,22.898799,46.375915,42.580653,-4.243839,-70.879117,-64.298225,40.963794,103.108369,171.062094,161.837428,56.147333,-14.856165,-146.218748,-264.801303,-295.706223,-266.693883,-224.570569,-156.179094,-148.993537,-178.098413,-230.87563,-243.385448,-166.424737,-79.345902,102.3145,141.611076,31.843778,-69.221078,-162.175752,-105.522826,-67.420613,4.198549,47.734068,115.774324,96.560686,-23.350439,-133.796063,-164.140323,-89.28476,-5.338772,81.743398,60.917522,-44.865095,-93.164426,-172.071042,-209.208021,-168.379267,-18.890641,24.215455,-42.265872,-131.050479,-297.602625,-405.901074,-433.980344,-402.084998,-349.614851,-204.765905,-136.628199,-119.891128,-159.368421,-214.891455,-259.963518,-284.79374,-241.58149,-178.832957,-90.370415,-76.505961,-93.374954,-194.182462,-256.056931,-252.82445,-166.000573,37.516886,96.130195,105.705264,65.923988,-102.182345,-248.70613,-230.8532,-104.910311,-70.324155,-64.185735,-79.749451,-163.521638,-264.941871,-276.305821,-189.852509,-113.642467,49.074977,109.068011,136.944426,121.911546,91.069403,45.404046,26.366077,48.981667,91.216589,146.568679,131.743848,35.566236,-90.007182,-116.700929,-65.540516,-23.392192,56.779681,98.457215,94.311909,32.572909,-104.687546,-158.220764,-151.119473,-103.918201,-79.491983,-69.813012,-89.661555,-121.917459,-135.266857,-152.797988,-135.670334,-77.812621,109.543768,199.794528,252.818281,203.666656,32.682988,-66.801042,-58.447303,-3.749676,-6.844928,-53.325698,-63.249838,-90.19492,-166.230756,-165.848753,-52.174652,-15.213313,-35.718927,-29.540458,10.987249,-1.261491,-37.649573,29.859475,87.491544,202.701241,259.867612,376.949772,423.235762,464.276429,449.215015,427.971586,403.638517,423.310937,534.914889,606.8389,674.429755,654.15353,548.338543,410.170073,371.258263,395.396507,443.699171,555.54645,577.807132,484.71045,296.650335,228.10797,196.342315,217.732204,319.529516,383.249516,382.043439,295.552881,91.106724,25.988381,75.663208,246.930215,310.929803,336.428203,292.126515,160.386669,56.604946,11.332348,-14.795527,23.633397,149.686254,195.405861,223.867393,220.818137,165.414575,102.78154,121.343409,206.882806,224.037189,199.296025,177.934714,132.638045,62.278824,32.009602,41.46613,71.377321,131.85481,156.912481,176.559449,163.317564,67.8762,-44.689652,-44.781082,85.660522,182.686443,318.991907,308.796555,168.85399,51.502333,26.658691,40.098901,68.227457,128.93473,155.533414,185.299438,181.871339,139.164872,121.17923,146.304876,222.289687,259.954075,321.012426,333.107463,300.653228,191.299505,143.025891,151.086161,205.382286,328.498771,350.301092,288.862677,241.87999,161.710303,114.934761,120.979701,162.502938,180.290929,236.116056,268.597513,260.165641,138.829956,80.955498,53.918344,80.746597,152.710791,181.326591,196.599277,178.574274,124.094717,88.064649,79.158785,67.020547,81.515956,155.966689,172.205169,121.997759,70.610915,70.068734,142.824196,199.67045,265.857373,267.183803,225.556677,192.289774:-197.520664,-335.117945,-399.519331,-426.937442,-381.037262,-182.190075,-71.256755,40.436107,-2.199005,-15.520948,114.092581,216.375002,241.300374,165.995873,57.868426,45.507141,8.058044,-11.66185,21.903694,132.567267,181.073214,189.464308,126.98514,-19.5411,-26.165778,-13.157534,-88.637236,-163.094739,-192.117528,-123.912279,-25.005028,-40.836925,-63.106803,85.759713,190.132623,263.527166,222.613854,149.520353,145.89823,165.659116,168.721557,160.577212,145.268499,151.207087,211.754387,245.771413,218.958263,161.514289,73.269608,56.536389,57.303471,28.204342,-4.795773,-52.173693,-50.73199,-41.721923,-147.525363,-226.589082,-290.040396,-269.589623,-190.974755,-158.167733,-168.035541,-181.245536,-110.21463,4.964753,39.573271,48.367783,29.873815,28.378872,28.601818,-38.703112,-46.291972,-9.002469,46.524827,50.470862,51.663574,60.479868,49.691366,17.991266,-114.881213,-327.774611,-403.26984,-378.804971,-298.72436,-152.102608,-116.625502,-97.711578,-106.028326,-113.493644,-112.546014,-93.819574,-0.940872,58.765161,160.424124,193.114571,138.322336,-7.465814,-14.916932,69.787088,83.322915,85.702959,114.166209,111.667654,-9.857344,-57.142152,-41.031051,21.441708,184.58039,225.721172,115.329789,7.620444,-167.087386,-306.760054,-341.296566,-209.425479,-73.146271,120.168494,144.682855,143.409106,97.103381,36.401236,-0.306349,69.606305,231.005261,259.331161,200.54978,133.04256,19.37628,-9.554316,-12.474944,3.967413,25.965922,114.019115,167.419019,145.276167,-7.053196,-44.918959,18.646307,85.58779,184.075044,207.345566,182.452209,137.981806,29.883579,-139.178731,-201.904435,-150.078703,-73.226444,35.005864,44.39484,-3.137851,-15.985786,31.603413,252.772839,374.713243,447.89016,397.720468,303.54226,277.769076,186.47869,122.318191,122.774275,78.182732,8.700839,-162.52292,-237.479977,-305.086282,-322.818005,-364.257222,-390.409236,-326.672044,-134.625925,-65.001031,-62.032919,-112.627243,-188.693587,-152.393428,-96.020273,13.375943,29.790516,-22.979345,-86.403471,-234.051146,-270.19983,-245.65354,-196.239242,-166.923233,-51.734568,-2.232832,-13.188148,-42.354273,-90.36887,-187.886957,-223.04274,-167.217049,-106.097495,12.275835,58.578302,50.358567,-71.468106,-132.848213,-131.825658,-64.645054,40.757698,43.74669,13.383541,-1.016588,-51.362398,-133.808684,-170.676302,-199.435472,-187.843525,-168.261584,-178.376119,-181.675381,-201.929685,-240.903935,-198.050249,-110.147158,16.38721,41.935324,105.811418,155.696593,209.027128,75.010231,-13.16371,-42.041221,13.650729,146.25755,194.195732,189.291141,-2.203184,-115.425052,-226.507681,-226.610744,-168.20819,-118.870178,-81.434479,-111.212425,-183.231967,-229.507706,-239.865756,-226.579211,-187.829714,-65.602215,-35.103914,-77.458767,-172.320962,-235.285289,-300.712147,-250.522125,-52.728808,26.336629,47.87496,10.987373,-35.196204,-24.075598,-13.443747,-9.766727,-13.001805,-37.15412,-63.294204,-64.396604,6.425364,-0.933375,-110.843498,-142.441521,-56.080293,25.066579,116.397961,122.497529,130.670604,117.555548,114.48476,131.615976,125.850303,119.193434,153.752358,274.135634,293.546947,241.647255,153.24244,159.481832,256.840861,344.072418,518.917278,544.909313,423.322326,221.595926,177.741083,257.017663,327.158537,391.259055,364.703112,268.926712,244.493404,241.183311,224.264114,233.740067,284.222115,293.110538,275.194641,269.46083,249.693272,159.087508,111.781905,78.828194,89.271786,124.041183,104.305328,-12.662945,-5.616708,43.366097,76.800302,44.485786,-4.116555,45.797059,237.811784,277.88854,190.357985,94.348295,102.079456,233.747644,299.552565,292.942228,223.030884,64.751717,-29.251618,-93.260584,-241.745557,-260.624377,-170.248645,-102.762075,-27.778563,-54.290557,-184.247675,-267.586063,-264.954173,-164.226494,-90.740548,35.552244,58.989608,-34.103198,-177.071858,-201.359874,-107.445416,2.258516,229.343684,294.100984,249.529258,162.617959,38.037427,99.989705,155.326533,196.631763,207.399068,286.591242,310.180315,231.944646,152.019972,140.767089,123.916076,143.840464,296.797639,391.320623,496.61831,484.54884,302.690434,72.082728,34.897963,119.077433,210.390483,440.500429,511.594175,364.962589,26.537327,-60.945429,-45.177669,-31.877828,-28.674399,33.172328,192.116103,190.462319,78.755965,41.194407,49.820227,51.175491,55.244088,124.636318,165.519193,178.40655,119.555877,82.670727,62.86376,104.536022,252.977,308.300369,280.346552,223.967763:-188.715158,-210.935539,-211.487438,-179.722284,-170.580155,-128.976423,-68.808248,32.421022,-25.186243,-39.54918,119.567865,228.489017,294.574593,242.949801,48.921512,-46.388387,-164.966979,-196.51265,-176.775726,-54.834418,37.540608,138.027218,100.345747,-8.230196,-61.14127,-87.02242,-97.043527,-98.962937,-151.036533,-171.094209,-165.628782,-169.239635,-201.559797,-143.984205,-54.919864,137.839502,186.142489,194.141885,192.956787,228.65212,232.72845,210.099874,218.473461,260.935561,290.466695,232.132047,49.499884,-3.13925,18.218349,76.401871,71.025527,7.415597,-0.769138,73.714622,103.666962,37.886232,-136.36699,-200.025407,-200.052774,-163.360831,-80.174015,-41.611181,-56.887443,-105.67731,-136.147935,-57.699585,-2.648667,112.161645,157.452877,178.358697,131.449374,-9.890881,-43.94317,-24.959093,-13.933088,-20.558051,31.117154,68.387164,1.058011,-97.872978,-262.629369,-315.672778,-319.841272,-281.118348,-223.700648,-119.800388,-135.403432,-272.156092,-362.585716,-371.955166,-323.516605,-263.148521,-110.14196,-44.943269,14.03379,5.792207,-60.702576,-112.789627,-78.932346,69.917747,106.704389,67.761111,40.352316,-3.752389,-115.73454,-164.401094,-85.457236,5.80461,88.824773,85.313331,48.340399,4.917311,-130.759247,-243.97562,-238.540174,-118.469005,-55.998066,21.868644,30.124731,-15.754394,-77.099748,-103.514123,-91.248339,-24.293466,170.395955,237.865732,215.170146,143.008401,20.453926,-58.482392,-108.504657,-126.012027,-53.950915,145.378042,201.720653,166.539404,28.579427,-16.757379,20.329789,84.692481,215.813144,256.244369,204.846458,107.77017,-138.075724,-309.01986,-308.58358,-169.330308,-104.551175,-60.494815,-68.536602,-117.561881,-161.334552,-147.197489,56.409499,203.094617,324.582488,281.192036,146.475525,100.759782,46.737273,1.167359,-13.613315,-11.097129,6.15664,30.672522,3.816434,-136.106807,-274.700984,-315.165904,-262.004476,-169.146691,10.243291,53.432074,-8.0705,-92.155459,-246.472649,-233.162426,-140.222845,28.322086,40.848939,-33.746617,-107.42908,-301.643971,-415.354838,-420.466053,-355.846772,-283.229995,-92.840739,-31.181957,-59.826158,-125.94589,-280.113784,-352.774829,-320.993809,-165.504485,-88.087018,-12.611677,-21.601933,-88.763847,-179.196996,-211.702136,-155.614614,-74.357569,91.48275,146.810312,143.160147,83.641958,-72.324768,-138.718714,-121.791496,-87.867464,-95.131011,-129.828392,-152.994424,-187.561804,-204.37192,-224.445367,-213.380684,-150.307071,25.966883,87.632065,130.571329,133.204752,87.757019,-46.834996,-100.566088,-49.475594,42.704873,190.972623,197.738088,81.583256,-118.858535,-185.224688,-134.018354,-51.941974,74.59253,104.991895,69.070976,-10.418772,-188.874141,-246.425121,-224.812706,-163.058575,-142.662938,-80.262983,-38.593627,-25.580435,-195.775945,-294.904754,-280.692517,-177.518598,1.808959,60.720162,146.052163,147.583619,27.62757,-92.577678,-94.810842,-44.077977,-3.138,70.749566,55.676557,-46.441487,-88.598321,-72.500808,41.881544,106.021102,138.37421,121.330542,91.601664,69.892593,27.967891,95.222027,151.42764,202.38257,212.442492,280.370113,325.933755,399.383426,402.898733,347.038294,235.565294,248.185767,432.878842,568.110872,718.360302,670.957451,455.026651,353.749893,370.906572,474.480806,528.485046,573.186601,549.136842,452.267993,351.880025,294.136506,247.80342,291.41386,434.09083,486.087941,477.913792,404.620164,222.527219,169.717214,188.621156,249.358804,289.94226,371.482239,365.377636,225.05437,52.548643,4.986514,67.560296,157.947848,312.211096,348.144752,363.402463,349.761667,266.546324,158.095325,145.32551,221.99006,260.188571,237.163727,196.738888,130.33226,48.521448,-7.018804,-71.643021,-58.272827,18.334645,46.981993,35.938792,-2.301872,-118.639649,-170.112868,-120.917922,78.921485,173.902305,255.071611,231.175732,128.104112,14.127007,-56.356051,-95.38616,-12.994996,234.480489,306.685038,253.744866,177.315711,69.47301,69.665633,116.817084,219.883165,244.601331,275.342445,284.757521,230.254874,102.659434,64.710798,99.437599,165.887088,362.870156,447.990126,464.687269,414.49755,278.457013,101.624421,49.869012,135.662174,238.440308,371.94894,367.689488,279.373155,150.491722,75.989261,-23.852348,-22.987174,88.31602,168.108763,198.333565,124.876177,-7.243243,5.706643,14.292906,-13.735466,-13.46942,70.465603,100.15255,42.108812,-28.057581,-37.295218,54.346423,155.217071,290.667479,290.761512,229.665465,192.866229:-100.256599,-124.965768,-168.952344,-159.601712,-89.511721,82.937192,146.819522,200.078847,196.218087,195.577113,251.453011,298.623434,332.225244,313.697675,249.878478,212.789159,138.783352,39.739252,9.876164,107.51648,195.987007,247.511504,202.011355,110.092125,61.48605,15.85497,-77.739622,-104.539218,-132.87513,-122.671892,-52.584635,-22.782886,9.531619,87.681331,142.764909,178.913149,143.608946,54.565563,27.514489,27.497116,59.873005,59.528421,85.877245,120.148366,134.213431,99.554516,-18.173553,-64.611977,-54.874714,-23.153651,-42.285435,-102.437635,-136.682322,-224.289095,-273.293723,-369.750973,-443.634458,-482.808685,-572.144971,-596.266677,-514.852109,-432.357393,-353.408075,-348.003802,-291.741708,-239.238038,-223.32834,-172.915284,-144.12748,-70.559781,-29.819071,-18.695863,-50.370522,-20.950671,90.904154,100.506498,0.449853,-33.271168,2.077876,3.992122,-131.64736,-258.070261,-236.211413,-116.561628,-89.84219,-87.324999,-83.618484,-63.281942,-13.548797,5.852413,43.309851,83.947461,153.211456,160.569753,198.425921,235.858337,238.788662,126.433158,84.609774,81.005399,89.776326,96.602868,95.280405,58.132283,59.719204,92.948866,190.117724,235.75082,246.857127,208.535514,75.515813,-8.728464,-140.407438,-167.761342,-165.838152,-176.402277,-163.892317,-49.408672,4.726444,-9.775783,-34.293027,-3.171176,56.760412,53.770962,54.976905,111.14311,232.699006,233.226218,181.469245,133.645431,99.453676,68.810905,101.713283,233.543501,278.583137,250.400727,189.504618,171.280496,144.278139,154.857089,231.891318,262.539284,254.728624,246.008881,240.675352,120.696679,32.015308,-58.722552,-54.283426,-15.403142,-8.116838,-44.423648,-39.828534,18.611475,233.629727,348.427289,470.372837,459.67679,363.896682,336.067752,382.462694,393.04043,329.226182,147.954653,84.314517,13.878234,-44.413453,-207.595521,-234.905931,-203.666209,-150.910194,-119.814166,-11.883171,54.267908,137.324167,134.083641,102.615502,61.289912,26.060684,21.092822,45.369378,29.110237,-20.023237,-103.364718,-116.772406,-119.070369,-48.373454,34.124333,166.884153,180.623979,117.802634,62.676423,-20.090463,-0.270895,21.655442,66.017536,113.819298,241.793086,275.060083,240.759037,156.809606,109.039603,51.648243,60.047318,78.230796,66.934378,36.987082,13.29459,-91.477388,-208.347977,-237.081299,-227.194088,-213.66031,-224.575444,-238.203561,-223.80504,-162.284157,-155.626707,-144.799715,-87.256529,66.494865,111.306689,188.74439,237.175643,220.337906,54.310374,13.519746,113.683158,212.354129,350.650876,349.83928,200.374014,-23.535562,-124.982142,-231.051116,-222.070043,-174.225792,-149.423176,-75.342349,-52.836718,-124.359918,-327.918232,-386.273856,-307.295077,-209.248,-27.510387,5.837823,-71.076259,-194.814244,-254.398261,-342.860371,-330.966845,-182.502777,-107.629716,-92.63285,-110.72112,-50.939257,7.809995,2.042761,-17.3983,-27.030934,-31.192623,-14.706532,37.097867,103.836176,112.767919,43.324664,9.854686,-0.232632,-0.112689,-7.309423,1.319801,37.108026,-39.529343,-113.943064,-190.895979,-202.772395,-222.386041,-211.848712,-112.212597,73.534754,113.467901,7.82417,-52.274068,4.857571,106.873132,275.468867,299.378418,237.329694,76.323758,-0.369437,-39.367595,-5.765635,49.179624,43.350427,39.367121,109.081023,131.473482,132.913997,149.142959,226.619724,247.861568,215.446338,188.366746,152.84935,74.049442,26.387964,19.942743,44.365929,-6.254667,-93.256576,-204.269051,-94.31528,-33.571173,-36.16637,-85.800468,-179.17003,-166.598495,7.275807,101.979355,137.608429,25.651432,2.901549,93.576321,150.796544,157.658534,116.688561,32.042164,-17.98175,-48.498825,-167.445137,-248.358923,-348.485163,-314.336545,-145.728358,-113.993838,-202.241897,-236.753722,-194.765538,-132.784594,-147.520999,-140.467373,-91.644707,-35.320026,-131.373004,-186.819621,-153.429081,-67.330469,110.00635,164.171112,152.397012,86.274232,-51.298053,-82.256726,-68.241039,-85.771247,-127.549991,-125.148157,-57.601672,13.322051,-122.539003,-201.183547,-221.118251,-152.827712,37.613255,123.538451,209.87806,182.109958,-2.753711,-201.646922,-234.378753,-104.343643,32.83261,301.459334,357.770422,270.400391,129.51841,80.506052,14.042451,22.654639,164.199824,249.105624,293.332731,261.251709,236.756904,244.285008,209.545187,109.38921,97.294641,156.650603,180.014436,185.523871,143.743486,91.501147,14.347967,16.871522,41.327028,49.734474,77.410114,101.259561:-161.335598,-256.749319,-301.14029,-366.529157,-356.430899,-192.707431,-83.261971,54.547127,112.189155,135.837769,204.500489,226.003215,173.776277,140.835975,154.371336,171.340768,151.524034,80.034221,63.953739,100.035173,128.067219,148.767681,120.120601,39.157364,51.311957,45.199715,-82.010374,-152.157495,-162.805676,-110.114237,-2.072731,30.808037,72.213983,108.714861,141.773674,175.884933,147.527127,70.86608,46.618474,-13.766567,-117.778848,-167.210492,-154.536703,-82.912831,68.285879,103.578522,97.415305,89.428834,102.69818,61.290095,24.01488,-7.392275,-7.186649,-41.114205,-80.847781,-130.166753,-220.326494,-326.852047,-475.597602,-457.931895,-336.364341,-283.149103,-208.141385,-162.418956,-61.150552,-45.47548,-51.700973,-24.111158,-14.300088,-60.564542,-93.463649,-124.596818,-143.892601,-140.621352,-25.998143,62.500197,132.369392,108.746287,30.495287,-26.652018,-208.920236,-410.724407,-455.735523,-396.08997,-340.936891,-240.398686,-185.747885,-77.257942,-20.177662,-17.83319,-2.599039,21.131968,84.598599,122.05108,199.186953,237.440127,244.097575,115.107069,79.985434,157.765198,208.374261,213.993025,189.085778,135.905321,103.875875,108.95486,174.363026,211.855019,214.555354,193.996142,169.188672,139.427276,-34.670554,-213.721171,-210.503089,-46.813954,58.701162,239.017973,287.502802,293.209141,231.816801,203.689703,239.216972,286.664085,372.546685,431.852479,523.730456,482.936118,249.339209,103.060048,107.314161,177.165181,217.043188,292.077602,297.042926,229.303669,176.101738,141.443651,84.532903,117.332409,261.758261,307.389359,292.765958,270.263735,247.216056,140.8314,71.469982,49.935823,105.040679,195.910638,186.023094,119.860235,99.154907,133.954295,312.828509,405.405875,487.529911,490.18506,438.604645,397.643191,377.963487,339.577586,275.497372,129.39949,56.949242,-54.776728,-91.700022,-167.00889,-235.955182,-265.796729,-256.703772,-204.95877,-99.916744,-63.058121,22.596267,66.223619,124.887026,165.154881,172.693093,152.169254,142.011148,130.678779,95.185482,-18.956964,-16.591426,4.241604,17.022363,31.787441,58.960686,54.412165,33.515534,18.159275,-35.782961,-67.891671,-49.138531,66.882507,137.069331,221.860902,231.176383,226.842265,218.018412,194.331894,125.367065,104.072505,90.811123,84.776544,68.740428,61.502514,38.787322,23.756432,35.758498,74.521237,54.543357,-62.396812,-94.867999,-44.823507,48.044409,82.242984,152.667827,200.50197,307.642325,356.886448,398.048518,374.082123,286.823195,218.529798,199.011978,183.640671,176.63762,173.373565,192.728953,246.21409,159.132613,40.485213,-190.746847,-242.832622,-188.207513,-103.236819,30.612945,36.07859,-17.702833,-100.722621,-144.229685,-111.250568,-5.381272,206.86682,199.09319,-2.831772,-133.380317,-162.933872,-188.208656,-172.832816,-93.11726,-44.119812,11.373206,29.101571,86.137588,80.945369,74.095043,123.786056,134.826168,51.747642,-7.785814,-69.131417,-8.541368,31.683331,-0.873507,-60.566016,-78.801721,1.398615,205.922048,251.664632,218.079298,120.195963,66.63783,6.12914,7.30782,87.183504,154.111647,231.486906,227.740344,227.714226,248.215115,257.273036,286.724796,329.098737,381.064099,341.278596,187.047674,74.464903,60.937214,94.351465,112.540663,148.213457,170.121633,194.223148,203.660892,206.270695,216.076857,234.903699,276.706672,277.616981,252.076178,246.50054,254.177444,226.655853,205.644595,189.654137,186.785935,140.809335,95.280011,45.505527,117.215598,152.438817,107.78578,23.473062,-123.128551,-92.84045,166.310415,275.871122,254.46846,71.907895,40.22596,170.325826,237.070088,217.913988,189.218567,181.893854,84.784893,-22.014971,-234.79045,-311.232261,-351.776749,-299.850232,-206.132085,-234.873351,-339.769249,-280.110815,-211.796976,-136.056123,-126.357576,-83.122206,-64.91557,-114.765696,-215.245105,-242.46859,-183.132555,-118.39651,-18.494788,27.773507,99.639112,96.417031,58.997622,-0.082336,-59.76203,-145.283852,-132.056775,-54.136206,-37.576012,-109.723469,-244.970017,-286.461224,-264.482757,-210.31127,-52.032139,26.082853,82.505946,67.184104,27.407481,-69.979014,-132.405201,-146.455614,-83.164659,90.687448,137.688514,43.573774,-171.708145,-260.099202,-313.911539,-280.33093,-203.418867,-161.73314,-36.393217,10.880511,6.85157,-69.753391,-107.461001,-116.373941,-71.456301,31.162902,27.878059,-21.172524,64.006595,84.811499,6.59779,-19.406338,8.158515,22.887054,2.267534,-7.280667:-136.724823,-135.730461,-122.629462,-56.601912,-33.084792,49.675742,113.411963,190.039988,168.147194,150.344024,162.470843,186.113077,208.132681,192.636184,118.709228,68.495954,-27.989231,-65.283681,-41.118223,71.386559,124.915922,160.41676,122.952749,3.90759,-18.360768,-25.076509,-101.214236,-146.393345,-199.312018,-206.296482,-191.606108,-182.074142,-164.979179,-53.98226,52.373057,182.992415,142.642222,23.356673,37.400864,155.889342,234.22149,258.163031,287.698028,293.607124,263.684586,206.759634,40.508342,-8.183362,-7.70573,-19.819468,-24.122235,-34.079223,-69.7814,-125.186666,-123.021336,-169.60997,-277.808727,-308.782326,-275.437347,-235.936197,-222.640829,-242.089049,-255.718201,-232.465587,-130.180697,-96.750228,-104.967523,-48.377476,3.391199,75.941406,83.916677,39.935253,-25.34178,-51.757341,-60.585713,-43.995656,-14.147729,-11.356847,-19.039204,-24.680913,-99.339764,-271.273417,-307.981186,-181.434137,-85.092572,-19.02641,-54.833358,-136.819204,-111.917482,-101.591311,-125.95123,-109.409353,28.965013,90.713089,67.350063,27.306793,51.839047,111.425065,109.886056,91.40584,87.397536,110.226913,132.772306,106.485387,-35.515375,-90.469294,-41.028585,36.14759,136.780317,142.248603,68.216263,2.551018,-147.906113,-288.872849,-317.065012,-246.632384,-163.7615,-29.740417,-34.154651,-131.727178,-152.583071,-121.476164,4.078518,80.015079,140.094494,105.07643,2.510508,-7.789318,36.764229,4.111641,-23.753099,10.719533,62.955245,167.844261,207.113472,243.333881,246.039876,214.424171,117.672467,119.964416,221.137715,261.803078,249.441249,213.356644,113.648481,-49.685849,-107.85918,-92.95606,-57.107172,-63.837923,-104.312764,-123.413568,30.752532,140.401637,330.334897,384.463916,380.624066,345.647126,272.110275,245.798163,254.047442,277.729863,253.480313,133.196455,74.734635,42.950202,40.626102,-19.789511,-76.796164,-92.403391,-90.792314,-57.552263,51.468918,93.99703,100.111435,79.683993,71.039496,66.823846,53.860094,68.421377,85.435464,62.105022,13.886984,-107.554853,-172.632707,-182.426212,-150.431171,-80.539636,102.34823,147.312122,84.762281,10.238748,-86.595163,-42.013352,-5.31115,10.214418,-1.681698,30.278607,66.09496,47.848951,-43.924698,-73.469448,-30.985748,44.354404,149.29503,140.290602,69.621215,41.848814,11.028083,-24.488315,-35.779225,-43.752025,-46.081796,-58.172795,-84.607866,-181.825444,-252.467974,-266.409049,-194.142727,-100.195188,58.107109,77.252899,68.011345,87.34164,147.485083,128.681164,97.149396,32.753796,20.479133,93.111505,156.082145,169.402473,-27.776753,-114.06717,-141.613729,-117.741803,-72.15172,-53.915809,-57.872601,-85.037984,-155.679537,-211.072933,-220.174065,-215.323929,-205.092849,-117.887463,-60.191177,-85.4152,-268.603562,-343.502691,-375.3447,-316.246517,-98.163765,-10.941763,9.477237,-20.246273,-23.939933,2.219197,-2.488396,1.598669,8.526781,-29.806461,-64.89257,-102.22036,-71.386908,-45.233085,-13.722851,0.866109,22.654776,17.298638,-2.249921,3.45798,48.991204,5.479051,-36.502454,-39.042277,-35.405545,-73.07398,-54.74774,91.75291,156.670508,112.469229,6.297591,4.630407,95.702939,162.836716,271.841298,295.98208,280.459543,140.214008,71.191494,124.498495,208.377546,277.271891,248.465994,161.846559,143.303411,133.443186,91.516917,103.549249,205.740509,250.461903,241.428264,188.274657,91.100324,78.358589,70.026054,40.139532,29.81857,18.831704,4.908602,-58.871911,-112.362057,-104.176529,-26.000476,-12.675966,-59.692818,-49.52374,84.518392,152.971473,189.418022,131.33715,121.30509,130.545154,104.062478,41.614654,39.794951,-10.222598,-122.325138,-155.305297,-215.403782,-243.049515,-211.460224,-155.586908,-95.607359,-138.969253,-278.743944,-234.252902,-140.050496,13.817423,28.386893,-6.54752,-13.205462,-13.732728,-118.195135,-190.285465,-179.148827,-107.69112,-0.016041,39.295623,88.047301,64.486929,-53.729933,-113.417042,-99.581982,-48.433199,-33.237555,-21.669187,-14.096193,-9.674057,-79.77552,-130.159375,-89.013457,16.43311,215.535429,256.483704,227.909776,182.704401,100.127814,17.476965,-4.061549,106.799039,206.855729,335.035676,345.246275,260.298977,141.166574,108.36801,69.681176,58.342071,108.365443,167.955096,212.783934,166.837803,59.411417,41.315656,39.573866,13.448419,-0.138965,27.795266,50.938639,12.438396,-33.500605,-27.252712,-15.805472,-6.508824,54.421122,104.521803,190.444192,204.567736:right
64.033145,185.80866,250.217133,263.405701,223.512827,155.939431,152.284981,194.582853,189.729582,146.889769,53.134445,47.993162,132.558777,157.224838,91.570178,61.262481,48.238928,-39.046668,-112.73388,-220.44042,-212.68641,-118.045266,-94.065846,-149.961732,-271.263572,-319.634366,-358.831583,-344.075214,-223.270253,-147.532914,-89.768544,-120.291542,-251.370088,-340.562723,-340.822587,-278.234528,-220.405277,-99.739036,-62.778,-19.015945,57.961281,113.581431,143.358616,96.21253,22.817937,43.578698,145.801236,196.140852,234.833837,159.563199,111.803594,43.670008,20.171641,32.41744,71.871151,120.901798,51.025077,26.020408,66.573983,86.411052,60.916112,29.288512,-32.583938,-61.259036,-156.190005,-275.484359,-316.737044,-364.60108,-378.949201,-364.935738,-330.743492,-280.085486,-293.362443,-287.907033,-235.482969,-222.13239,-234.454884,-218.742516,-82.356385,-2.462187,46.50303,24.317854,29.289215,2.74679,-35.654817,-80.204183,-73.301511,-40.489814,-31.524762,-29.155066,-36.682248,-46.639884,-23.435173,-6.008496,-13.21568,-11.666524,-5.516995,-54.350224,-51.898833,45.099381,98.141065,128.225289,129.442983,194.070148,195.54726,148.594508,109.896596,139.479351,232.385376,277.721946,359.780398,384.255466,351.39044,289.095113,271.440875,232.81409,230.296449,276.466201,304.027367,375.719463,406.757002,377.524384,337.353287,363.938924,438.68976,434.240287,385.688693,389.029173,380.151612,267.061843,251.06517,423.286168,534.429271,523.652955,414.638932,242.572252,206.269274,205.804121,193.651037,183.975926,234.212237,273.435269,245.839912,185.05178,60.997654,-17.632437,-52.23475,-97.191088,-66.788629,93.452737,173.543805,254.365189,229.36934,218.040499,220.589941,218.211096,251.137091,285.119244,301.889398,281.655524,221.044587,140.212601,76.654864,-104.137143,-175.757218,-173.746515,-119.712031,-40.144541,-41.470363,-39.580702,5.076162,63.639311,224.000325,281.108181,316.739202,301.688395,206.782596,95.245169,50.428715,-15.472854,-13.182523,55.732366,83.791678,63.218742,41.112841,90.613944,215.427211,236.496229,224.422348,216.064114,212.452962,210.685167,176.90172,90.777058,33.061022,-11.968592,24.30355,76.058945,54.633217,42.738993,105.885912,97.691866,0.811106,-16.35021,74.238182,125.773253,139.440043,105.650549,-16.812146,-150.520435,-187.88516,-190.355886,-182.304968,-172.576479,-139.769445,-2.723541,86.152444,72.403535,-4.142681,-22.568743,2.17699,22.389538,49.951899,52.365018,-29.735449,-147.278449,-169.32297,-157.243474,-121.454397,-16.151279,12.696752,-38.836348,-158.379097,-185.629714,-191.29173,-192.705692,-167.36152,-142.301711,-70.879111,-22.518859,-6.57409,-162.188846,-251.650902,-296.684136,-226.969847,-44.180945,-7.116791,-34.02903,-38.362338,-29.215628,-24.723952,-17.516026,23.866509,46.62837,94.583377,120.616717,88.449213,-39.70333,-85.603128,-79.685562,-20.980923,128.954624,168.302127,90.572187,-79.797349,-109.841461,-106.136983,-131.546353,-211.23317,-227.411278,-215.809092,-211.481652,-198.900465,-148.323639,-130.784665,-150.762166,-174.295082,-177.077872,-129.636148,-10.446002,-38.572495,-68.348599,-59.795592,-43.39976,-6.654449,12.544295,59.545685,88.784422,95.19108,14.37993,-23.506063,-35.059831,-4.831688,105.647389,168.66899,244.230203,224.326529,194.121621,103.426711,50.300653,-27.3617,-53.184619,-65.092255,-46.261911,-44.568134,-94.125563,-103.424716,-107.179962,-108.680733,-100.293435,-90.766873,-125.26105,-236.611765,-258.01182,-260.752985,-294.294333,-393.11392,-417.328253,-368.484561,-307.683837,-249.044924,-386.152476,-477.826801,-587.883922,-596.235987,-502.681635,-403.905092,-191.641629,-94.356689,-109.664784,-223.444169,-261.904417,-208.477375,-148.854281,-66.426201,-65.128646,-158.445889,-225.790507,-209.33278,-126.570674,-82.195579,-18.450229,-2.608681,13.28402,14.195093,5.666188,-9.86459,-13.411815,5.687163,29.414147,58.025045,49.534143,3.028544,-57.312471,-98.211613,-133.22264,-84.905077,47.020764,65.66619,4.872363,-60.991363,-73.847974,-121.390931,-155.059128,-189.022179,-187.115924,-135.826713,-104.372065,-125.075324,-199.133725,-201.839865,-98.063069,-11.512475,71.825514,56.069591,56.427775,67.507776,31.125239,-86.851659,-134.788981,-140.876058,-113.681028,-119.206883,-167.884624,-275.734148,-260.001129,-208.3048,-110.382527,-75.446618,-29.118596,-27.122461,-68.127562,-107.17259,-101.099563,-88.383262,-99.304726,-69.888944,-22.871418,43.632646,49.242957:87.37125,122.33359,105.25627,16.236065,2.116426,81.357522,132.610775,140.979613,44.700632,7.1915,-22.425593,-31.75059,-11.314463,26.541722,81.141337,68.563882,3.440901,-75.445354,-130.866036,-231.814543,-237.654873,-108.29632,-16.791056,2.656665,-221.195959,-323.593967,-407.411227,-397.835725,-278.62881,-192.168155,-76.654461,-79.398464,-167.562914,-184.053171,-160.22564,-114.860988,-91.141651,-36.447765,-5.070613,83.48875,151.723563,142.227617,60.077332,25.3346,19.650015,54.503473,156.451376,189.581939,199.412728,178.359099,131.706553,-25.810826,-62.437874,43.884045,127.137776,166.812349,50.446497,-3.169376,-45.019665,-45.857255,-37.065764,-34.356726,-68.459637,-126.202615,-266.452404,-286.974454,-287.620896,-346.505752,-351.019098,-226.490807,-151.23682,-143.349045,-233.580954,-233.479761,-151.824666,-110.238089,-40.796522,-0.544191,62.902577,60.186387,-3.260693,-0.992448,33.745336,25.338862,-17.412128,-50.423564,-36.684876,-31.709769,-66.081799,-64.232401,-73.117129,-115.22952,-196.094744,-200.682434,-154.947143,-112.829263,-30.79981,-45.443116,-68.736281,-19.334223,36.117026,103.331412,126.681389,153.716019,47.830751,-22.200028,-72.451006,-59.312774,18.946546,86.736686,254.891149,319.994964,290.032579,156.050856,133.36851,158.266051,181.112521,246.339905,283.281695,308.981372,240.991996,201.972596,170.237443,187.966191,272.153241,308.625513,318.585792,304.065797,303.841727,303.859783,282.0635,268.310047,290.545106,330.033631,337.624162,360.138485,319.594169,246.885032,88.28916,56.092073,109.624043,164.393646,233.942724,225.454527,132.592966,-21.369397,-88.012776,-118.275837,-80.944693,43.008866,107.689582,193.64046,196.22748,196.516004,182.00654,143.15583,90.432544,129.61604,260.788199,280.777988,198.464158,73.253583,21.145808,-36.716172,-35.708107,8.207708,51.08341,158.428334,146.882254,89.070502,36.835311,81.401494,229.765063,279.769002,305.607195,296.243813,194.656575,-2.322246,-74.301994,-77.342707,-17.053973,91.824479,117.479692,153.129973,124.738386,98.090518,107.927121,143.608066,183.901003,165.627793,139.567886,158.021198,188.693726,136.753472,83.616006,16.043912,40.561724,138.597241,153.406216,114.908944,44.993711,4.354509,-38.46833,-20.95332,47.545225,60.094235,26.131257,-11.10895,-95.566443,-128.479736,-147.80227,-227.245107,-253.9085,-217.196737,-144.186008,20.14627,23.779568,-18.305974,-26.357238,24.923224,96.593437,78.679202,38.955277,47.146938,40.936019,-16.5433,-49.854483,-111.437996,-95.041579,70.161955,140.671257,75.224343,-121.834294,-153.566574,-76.367851,-33.662249,-15.13477,-35.324025,-24.839408,40.712204,115.513912,-69.420115,-177.373195,-174.558635,-77.884238,91.358141,119.558453,68.937582,-6.579606,0.453754,49.121866,38.426709,3.118553,45.709206,205.467932,243.592665,164.751553,21.763695,-26.920886,-37.318681,14.833248,161.123118,200.442737,147.739761,1.799949,-51.748601,-89.557408,-86.182019,-56.699651,-40.500139,-52.021993,-75.905373,-99.120045,-160.253049,-225.473104,-282.46599,-236.026614,-96.37687,-44.437751,13.227198,-19.356732,-69.837012,-142.424298,-125.07203,-17.805326,22.150832,86.156488,137.103828,177.487855,48.28697,-14.007911,-5.893621,35.576336,96.622445,122.892639,114.143027,8.904952,-15.078978,-22.016356,-48.251479,-122.378051,-126.254831,-44.994396,-3.531603,-26.997926,-118.861112,-138.833789,-133.961414,-116.814541,-36.343013,17.899713,42.822061,-106.019866,-188.510484,-287.729983,-308.306721,-314.664721,-301.886259,-215.425093,-170.902892,-206.669931,-363.952575,-438.778823,-486.577887,-451.066464,-344.347705,-281.110734,-106.084337,-36.59503,-69.274254,-147.568031,-162.938079,-123.380293,-70.3501,59.382389,89.900436,-11.163534,-137.324628,-131.959892,4.776422,87.993211,155.153139,130.089719,29.071246,20.67299,72.196872,122.471009,81.938587,2.60877,15.305965,93.90028,112.313346,48.604009,-90.449413,-138.911477,-95.245939,-16.85264,96.041812,110.463246,69.166382,-73.388311,-141.996735,-206.601504,-225.632815,-244.195762,-216.362556,-114.155905,-85.305022,-136.033355,-244.686485,-263.628789,-154.113794,-63.02897,16.831241,11.16935,37.944873,73.800447,48.047331,-76.349843,-128.966448,-121.094008,-91.155247,-107.089163,-141.743299,-167.068579,-141.554948,-138.6513,-131.216397,-107.46675,-38.929439,-11.270428,5.218306,-54.798962,-99.325023,-149.541607,-145.153975,-113.502388,-103.919141,-76.666474,-49.960782:54.151367,37.678081,16.735846,-26.328686,-26.29153,19.371066,55.011731,102.470957,89.638883,68.697173,1.096431,-30.196441,-15.323877,29.779904,121.583376,137.246691,72.978203,-56.523007,-94.136909,-72.997626,-47.896833,-15.55595,4.53744,-28.813773,-243.790588,-349.051769,-426.166322,-395.937825,-256.758667,-197.966766,-150.976282,-142.559489,-130.558291,-136.828521,-146.235371,-140.091095,-110.416876,-19.888248,17.382388,41.602733,19.732706,1.195881,-38.619267,-51.124514,-40.382273,-19.466213,42.784874,92.427915,162.417157,80.012747,3.704176,-102.087569,-107.980499,-50.807604,-8.850407,4.911019,-75.608643,-94.255708,-118.459651,-144.209336,-150.702122,-129.972653,-127.516061,-159.355328,-258.047256,-363.741878,-404.625923,-426.531223,-399.204124,-258.860054,-163.984272,-65.235161,-155.341945,-205.662639,-200.558051,-161.06683,-78.445,-37.042597,39.29027,51.157714,23.926131,36.388995,44.90639,3.749266,-17.829886,-2.252833,14.833532,-8.009198,-104.250541,-136.630856,-145.007849,-149.869494,-167.575873,-153.778562,-79.102955,-52.215987,-61.775984,-80.360706,-89.339281,-96.891276,-77.570779,6.204835,66.010343,177.305995,148.175945,94.143322,26.918951,40.774823,108.012606,122.850293,169.72894,214.960294,242.738072,216.494348,204.338866,115.583398,56.044568,36.915271,82.673167,151.143621,95.385534,70.139733,103.199223,141.956599,197.806001,209.589479,244.197289,266.246423,261.106691,217.765842,219.995264,266.532608,279.946744,274.229831,282.632518,307.661438,241.358598,181.537774,95.288704,88.306978,116.955676,133.635561,166.571851,183.657661,161.837829,27.523065,-48.488863,-123.339069,-95.030038,74.004491,153.961254,172.208553,110.417563,101.134717,84.902721,62.174106,54.189268,108.426601,249.614722,250.394233,96.094502,-22.134359,-28.403487,16.369714,35.664728,56.993214,96.882416,195.060478,148.460921,94.552637,74.06739,135.926683,266.748799,256.016765,162.251409,141.373986,74.285912,-87.14378,-151.333728,-169.016589,-117.731669,62.091941,136.764492,123.519896,-31.677657,-78.550093,-8.390526,70.667759,138.654919,128.874997,143.612352,159.392641,126.333407,71.364709,49.610783,19.495038,33.302061,115.398875,139.212334,96.759107,2.197175,-36.243147,-66.409556,-56.237953,-5.254587,25.680487,79.033867,72.466291,-33.809515,-145.767212,-202.110102,-276.209412,-249.638559,-108.460732,-48.580578,-5.779516,-9.627989,-17.459956,-42.67492,-23.392141,97.369395,137.285657,86.226607,31.439998,-22.248725,-6.628618,-17.072837,-83.040603,-87.830842,49.38489,138.782623,129.195998,-79.475315,-133.52647,-69.17129,-15.104924,-4.045578,-43.16904,-65.822062,-21.548537,31.498716,-97.066207,-159.932833,-82.802593,25.631073,182.413312,211.785275,185.387503,105.640399,92.725066,84.411218,57.73458,27.248623,55.834777,162.296759,206.752709,216.782729,131.134832,96.614433,112.160592,148.008519,213.112143,231.530267,206.861551,100.110382,48.868373,-18.354048,-34.234855,-10.963244,27.69745,65.992347,28.895627,-72.981119,-74.139872,-79.404964,-132.131112,-121.615877,16.934407,93.908409,141.935197,61.629167,3.212777,-92.403472,-99.747276,-37.225332,-8.02587,2.932582,-12.762352,-77.01905,-135.616103,-148.28754,-115.439118,-79.398506,-30.180676,-18.189813,-18.890779,-57.639672,-74.176613,-104.001919,-111.731995,-79.399337,-49.439517,0.592998,9.794044,-50.157047,-191.852359,-250.029121,-261.420797,-213.122011,-50.405204,28.422126,32.763603,-139.9097,-207.711605,-239.62726,-224.990876,-194.312144,-180.542565,-134.921891,-130.131129,-223.337528,-323.337611,-337.251979,-323.851664,-314.612857,-282.330678,-225.909286,-53.465446,-20.28994,-69.698506,-157.40395,-152.721206,-48.80286,17.971094,108.573642,107.985311,13.938945,-55.016508,-42.957094,70.382949,133.661909,192.105518,201.238661,163.424747,62.708507,50.888786,124.25316,152.630859,124.743562,115.562603,144.466025,122.265834,19.499772,-17.777702,-28.397846,-11.019221,23.546821,86.373592,100.289584,72.56179,-38.693917,-96.920514,-150.30187,-150.960869,-138.605916,-110.862286,-12.385364,0.644863,-123.98434,-246.566768,-239.779764,-141.780387,-90.908825,5.707085,65.189537,128.262656,54.337028,-7.664328,-143.604984,-187.668698,-169.997145,-126.155339,-78.336467,-99.487236,-164.635702,-155.60358,-123.015815,-51.399566,-35.602457,-22.190675,0.177963,35.9166,-37.808124,-111.512526,-230.573304,-237.483237,-183.648266,-155.823447,-112.30204,-110.236318:17.11693,91.495174,107.081964,72.537895,65.548052,114.911514,130.839759,94.162167,54.868078,49.965148,28.283707,28.718468,102.919466,138.717702,127.830249,101.761598,54.182716,-30.511145,-99.86939,-218.719929,-236.560347,-195.17157,-154.703008,-138.401652,-276.945561,-344.037099,-379.897033,-354.37827,-249.585173,-190.323283,-103.11703,-98.261999,-200.711124,-297.018077,-288.533763,-239.181986,-226.510594,-139.849095,-44.206066,92.070863,14.833533,-25.655724,26.145937,81.046758,149.475163,172.712571,238.877984,265.441563,236.852612,92.387216,17.43189,-34.895433,-15.847491,49.240931,76.431879,63.437839,-38.306847,-75.723733,-89.463759,-90.994523,-81.809078,-68.732465,-84.943345,-128.262292,-255.312301,-350.52077,-378.46306,-420.338465,-416.107586,-330.843382,-285.95235,-284.140893,-335.314935,-321.362433,-221.490345,-172.295635,-89.632966,-46.086665,33.84566,68.491886,104.783711,104.951015,94.247599,-12.132491,-90.42081,-162.659006,-135.635272,-55.550975,-88.138074,-131.702692,-182.633951,-168.576006,-99.163447,-77.369482,-47.854708,-44.480537,-120.015769,-173.102019,-139.362551,-36.064786,-20.251609,-58.446907,-49.619401,77.107367,125.073892,96.561208,61.062534,80.487998,174.67284,228.675731,328.675744,358.661209,301.988762,184.072537,156.958495,149.445399,163.844263,204.904218,217.083967,243.594236,232.322813,213.275152,220.200141,246.902884,288.828095,300.339196,349.277217,387.592402,437.358808,380.005717,332.47597,307.274343,325.932015,339.575292,334.371602,309.61818,185.38303,128.126762,125.558361,146.348801,165.550416,172.785887,165.702754,144.556361,114.286019,70.792789,13.794522,-47.738392,-9.197871,123.62804,185.160429,272.541663,267.708828,249.566622,211.210859,185.086569,180.913191,219.706335,284.446105,276.70564,196.750261,80.762541,20.877912,-67.732668,-91.905669,-119.469918,-103.390241,-6.114747,7.227941,-12.265021,25.120118,83.561159,199.983846,226.754043,190.715751,133.603472,-6.045918,-81.195487,-108.200015,-159.036848,-141.688004,-22.696722,31.434497,66.911772,40.735091,44.282326,72.717525,83.787106,134.057056,156.817396,141.787278,112.509892,74.440139,116.982805,127.193001,99.559981,89.696541,81.872254,80.679178,86.731247,26.122944,-24.261148,-68.671237,-42.013724,58.057661,81.16175,14.898981,-41.811416,-95.490404,-104.924364,-134.696289,-193.059849,-166.866755,-53.956213,-20.518116,24.372768,77.545422,86.417385,67.319556,73.294704,153.201952,172.031199,96.206923,60.013654,58.557228,17.808657,-28.655567,-78.91572,-57.014557,41.716132,81.942588,62.254007,-96.591169,-150.025073,-100.52295,-47.00682,-32.461848,-68.0502,-65.768068,-6.985972,57.662182,-51.025637,-119.571127,-144.805713,-90.465108,26.895402,47.700993,44.128895,36.640117,29.223246,-6.96809,-19.685318,12.887024,49.074426,101.721191,107.884504,82.489094,23.426624,-3.990707,-25.031558,-1.324526,115.692542,172.144763,157.838117,24.133559,-16.913796,-69.725456,-108.023514,-159.342911,-153.059287,-125.973237,-134.978743,-157.784815,-140.355109,-157.903677,-238.379568,-240.514625,-128.039268,-62.123405,-34.885703,-159.425423,-206.189428,-201.0046,-190.253376,-174.915552,-144.25854,-42.233193,-5.942199,-27.994675,-118.511697,-144.993063,-116.176788,-56.335216,100.656586,149.752262,132.235824,62.832962,43.817971,-4.706682,-48.720038,-138.283156,-166.753918,-164.253692,-144.38732,-150.571197,-209.563282,-231.699683,-242.671605,-223.295571,-127.843817,-71.124039,-37.001359,-162.371458,-245.234013,-357.724053,-368.031596,-322.123397,-308.189035,-312.961898,-299.187177,-261.06134,-359.799635,-464.443129,-609.140199,-593.291443,-417.884358,-305.497371,-131.216931,-87.678318,-122.065069,-231.108598,-248.418713,-194.197923,-155.492513,-73.078187,-38.53545,-33.469413,-22.460199,-6.390212,-29.424132,-40.208741,38.319442,107.584543,165.293054,98.111053,69.399043,91.08878,133.383122,203.134301,211.500645,197.694829,173.715779,65.791738,-9.823588,-11.635236,21.346018,54.243578,128.477906,164.253317,185.305413,47.194123,-19.526645,-57.721848,-74.766738,-149.654691,-161.204573,-78.277696,-35.196463,-74.49079,-208.83142,-238.818437,-146.874905,-56.213388,73.003752,81.339053,11.226772,-102.034273,-153.857304,-236.404866,-276.61494,-314.876392,-289.402494,-194.389569,-168.868426,-244.544605,-340.922184,-318.678702,-187.613625,-127.22404,-63.673588,-48.960368,-17.678072,-34.719639,-80.680654,-167.724386,-166.2218,-92.725618,-52.507845,8.881339,19.032916:6.835126,-18.51135,-48.564769,-67.844936,-45.863901,37.492992,88.338726,125.880951,61.767207,47.678168,65.273255,76.952622,132.784132,182.743373,283.123298,288.947734,136.593593,-75.339755,-120.052462,-68.888374,-27.160501,-20.423437,-34.939825,-75.012023,-208.758693,-291.719623,-384.556417,-371.061438,-254.612418,-192.693972,-109.985934,-93.247851,-144.520075,-276.878393,-318.295843,-293.16007,-244.310457,-119.448957,-61.128279,-0.720145,-1.464182,-12.046409,-55.605349,-67.575338,-13.786199,44.708225,164.709749,192.709123,152.170358,84.331063,62.055919,14.076874,-15.420782,-70.829402,-70.629742,-28.848733,-83.900207,-151.450051,-257.080066,-258.210885,-206.248525,-190.659201,-154.600258,-141.627727,-226.583391,-414.253868,-505.537316,-596.2006,-566.499165,-423.401634,-360.496874,-287.781254,-230.293135,-201.204142,-163.952256,-137.515598,-17.437223,53.02385,155.536123,182.568092,177.771546,106.102115,44.321926,-57.333273,-62.971546,-43.774776,-60.886107,-150.403688,-230.258049,-245.647595,-230.54062,-217.350784,-216.405902,-202.387155,-114.593743,-90.4701,-122.198401,-156.182848,-174.629534,-243.66652,-256.811545,-146.455528,-38.586525,142.766639,175.515114,148.978791,61.361629,43.400892,131.463709,213.63406,382.903812,435.79439,383.627453,189.905299,115.336601,64.650837,52.759578,31.068172,63.060174,175.572933,115.123432,36.665609,-28.923187,0.083394,96.778404,138.333877,226.642966,282.278135,358.133963,263.973239,178.919528,106.453938,142.566553,256.60683,286.955231,242.33865,114.396382,62.899497,-17.356063,-25.914062,75.653104,137.483119,175.279241,172.797516,155.399368,85.689119,33.24238,-51.135019,-30.062556,167.409362,268.887439,279.595326,167.727146,154.005468,156.905524,152.914542,186.994873,231.015075,301.488006,277.717116,111.310739,23.972254,32.815868,52.736316,46.316282,13.546863,14.831612,59.34479,44.170944,14.05802,-18.995982,4.390083,100.924963,122.832101,73.032558,18.776115,-95.151912,-188.033477,-241.112384,-298.645496,-248.345761,-49.604459,21.484899,34.807279,-41.775261,-71.519309,-106.571865,-118.058714,-103.688975,-71.711332,24.660006,64.652439,76.186282,29.314354,-0.26494,-45.992621,-45.238619,13.669336,50.324744,62.539766,-12.063483,-54.359003,-96.429444,-66.410684,65.990522,103.510446,61.98016,7.258771,-111.402049,-189.557234,-212.165064,-173.252833,-110.928166,-13.501494,19.450033,67.405057,32.302145,-1.968262,-48.691592,-36.563746,63.746265,102.805019,110.34186,110.517836,121.506096,70.98867,11.941263,-80.507495,-72.089363,45.739294,108.991117,103.776442,-34.337808,-62.652608,-6.479427,13.571383,-21.792006,-20.693359,71.89782,108.332224,64.224832,-54.374417,-86.005597,-16.805747,76.660419,243.30185,276.448633,270.669439,196.778575,140.427709,41.723776,32.979918,111.274384,167.742886,266.639235,287.35695,232.332262,149.646412,114.303314,88.841085,125.146808,236.500019,272.276083,241.866424,128.733099,99.485661,82.866192,68.537135,58.00447,87.583559,162.06484,151.905865,57.847214,3.266133,-23.73749,-67.862723,-42.167585,87.812894,146.910831,186.92289,78.70242,-11.228238,-159.366126,-186.078824,-142.184886,-88.501161,27.201663,61.346961,52.966303,-63.389238,-126.0482,-111.787856,-36.58164,96.123106,126.083081,124.071478,60.19967,29.616403,-10.496672,-30.690909,-77.78532,-93.963496,-76.188966,-60.300136,-116.928011,-240.877218,-293.41305,-327.136975,-276.590351,-86.873757,-8.407772,10.281693,-136.609504,-209.41832,-264.996329,-260.756665,-239.121648,-221.008984,-165.729776,-154.805642,-231.469078,-383.617137,-451.910084,-495.348512,-452.183536,-284.892513,-209.696616,-159.714647,-179.063467,-186.777582,-236.486446,-280.517018,-313.996048,-265.759972,-75.700464,-6.532836,-33.494048,-111.067625,-113.102472,-58.68209,-1.967109,120.826101,148.922285,103.025202,25.153383,11.604895,1.113707,0.637823,34.405298,62.892754,107.632266,113.075983,62.885832,-74.261281,-121.850995,-49.753439,35.338987,143.104929,153.700538,121.461931,49.773414,17.544797,-62.257417,-110.865324,-151.295023,-114.902092,33.79359,71.570328,-34.955775,-214.907632,-250.096681,-156.28038,-59.759293,115.131199,162.441492,151.580217,29.200812,-83.308678,-320.611568,-365.188418,-274.780614,-201.460212,-91.151132,-54.290324,-65.521335,-198.483394,-240.975656,-138.954072,-33.428959,105.466973,133.973275,138.698015,6.267134,-105.284121,-253.987753,-228.447658,-32.137572,64.92688,151.535562,130.625044:34.620265,82.951246,138.765524,204.44383,190.859277,156.441811,168.910701,207.680647,157.607671,100.35507,40.941941,73.279105,215.412936,264.738634,246.456742,214.773699,177.508479,102.749404,23.771076,-158.028583,-217.642535,-235.816057,-217.185556,-197.276106,-227.389609,-252.839893,-315.322296,-329.294532,-207.887488,-96.03573,-20.139592,-95.878628,-316.051327,-364.230529,-318.265548,-229.903463,-209.440844,-197.076055,-197.353424,-185.717864,-101.282634,-35.966991,20.556004,-0.024065,6.565299,53.1453,127.759685,140.065532,112.770784,10.771739,-30.730508,-18.545269,8.161363,-15.994777,-48.69161,-82.009336,-127.949447,-121.111889,-6.69149,54.48857,120.040441,109.344985,0.263718,-63.321722,-164.90815,-247.515918,-290.369111,-347.911949,-331.363257,-292.285038,-325.157274,-414.289839,-360.57221,-302.236645,-249.900037,-267.482721,-257.768968,-176.349769,56.685776,137.318852,162.034344,138.215191,134.345921,43.545553,-22.562409,-61.663297,-50.405508,-78.062883,-110.448206,-86.540144,-30.751119,-27.398413,-14.81034,4.825295,55.983678,79.936853,57.357359,-47.253627,-91.045859,-105.360052,-56.323017,95.982151,156.264724,228.654962,241.057532,234.686059,259.546386,298.24962,405.940283,459.482832,543.008461,541.054519,389.526749,240.480243,211.116567,193.496325,194.346623,185.4851,182.80695,227.68691,253.000065,229.473079,203.559955,239.973802,343.477246,343.373747,275.005589,270.719321,277.965582,205.184356,172.603302,206.274467,265.344255,331.400423,309.018647,208.924342,100.243136,72.600838,107.354536,148.395738,238.222199,274.246515,280.268747,246.205689,158.523654,111.991395,97.930962,130.236821,197.440587,328.601151,343.034676,296.337811,231.154587,222.823335,227.227002,217.610082,246.152676,295.067408,320.723664,268.360372,137.111149,81.177589,53.061187,-80.070809,-169.058982,-276.470575,-250.149956,-148.374557,-204.86707,-222.291025,-110.533193,-25.75696,125.008593,157.675732,64.37723,-16.753977,-123.519601,-157.604603,-180.97276,-232.23731,-192.481193,-9.769781,46.562408,25.549178,-55.49899,-69.036545,-57.626564,-49.142148,-18.541794,4.149571,59.195379,81.431264,65.680064,-23.281749,-75.991375,-147.070732,-143.634463,-91.335781,-78.315448,-76.331595,-41.266008,-36.533216,-108.944288,-145.822939,-72.872601,22.262775,131.84726,100.047018,-61.237607,-182.122898,-233.540329,-345.845782,-361.898836,-247.72261,-154.427793,-27.187863,25.592382,42.148108,28.98292,9.114171,-3.29384,1.873023,26.933021,38.689532,-10.466494,-107.831462,-143.654102,-200.356575,-197.081504,-91.84444,-23.660678,19.150639,-132.467494,-219.770823,-239.457712,-188.038791,-107.525108,-84.807608,-17.507509,18.843378,12.036369,-109.725063,-166.774979,-160.625192,-101.654007,12.285725,50.3506,102.908602,62.956394,15.824659,-35.549619,-30.848363,1.275861,10.546391,26.076479,44.352037,43.141126,-30.159399,-61.081915,-56.931953,-5.059068,174.683701,247.556747,202.87553,-1.078801,-48.843444,-43.471618,-59.289206,-147.841052,-174.708095,-151.753156,-126.09286,-84.214099,-57.068797,-62.405917,-112.954532,-140.146843,-117.267969,-45.870338,67.810484,-5.340839,-33.882598,-40.01339,-74.241675,-134.631823,-110.009118,-20.31531,-8.807638,-56.252458,-50.274498,-31.589807,-49.456664,-61.829712,-14.661672,42.708334,155.369449,167.95847,133.700734,-2.838991,-77.317839,-132.12026,-125.544414,-135.858956,-142.606366,-139.996689,-176.580634,-220.369277,-273.563556,-237.283181,-103.769878,-77.521601,-165.572011,-292.010967,-313.978052,-317.717236,-323.373851,-309.942411,-283.592609,-208.225885,-178.266426,-223.804479,-357.364078,-412.555288,-497.785039,-505.672551,-415.540406,-339.81964,-166.718033,-83.485114,-120.189878,-249.205606,-282.061485,-241.14991,-172.602334,-1.031086,39.734626,-58.813296,-186.111159,-178.593272,-66.36738,-11.610779,46.933014,68.373889,123.315095,130.526997,108.557008,61.710621,51.501356,77.384158,101.784483,110.430774,100.051545,81.513762,31.563628,0.175787,31.345007,108.72074,224.562899,206.601461,90.891906,41.658917,30.642642,-57.069168,-105.355854,-117.536334,-95.104833,-48.678976,-32.622357,-26.281353,-47.000538,-56.75953,-15.664606,56.906076,200.063089,212.746383,151.141147,99.619507,83.976438,-11.781236,-93.693939,-216.124043,-235.453884,-218.80261,-205.02657,-234.461271,-267.26567,-244.01435,-157.814256,-113.046863,-28.312983,21.102655,143.865128,169.192348,135.663101,64.945331,38.985496,29.306023,55.501679,111.755697,111.563397:8.172401,-32.722995,-55.034712,-88.154707,-40.444126,169.738514,240.516038,202.718493,87.803936,55.357559,45.208262,66.974726,202.014559,286.771944,336.086244,301.945028,176.574991,11.081547,-57.797705,-133.279262,-118.709294,-14.123095,3.8301,-92.104921,-207.405272,-242.235977,-307.909846,-331.350229,-285.516973,-224.391503,-107.145653,-80.813701,-146.981867,-270.849722,-296.928508,-247.757042,-199.288951,-123.64982,-89.260081,-43.460495,-104.740325,-139.995703,-134.199508,-89.141172,39.333615,84.64102,149.082643,183.749008,171.659427,-20.647325,-119.582283,-135.817275,-57.658642,89.670157,108.533216,48.887696,-67.161431,-112.509019,-134.059882,-115.199895,-29.006892,17.346337,30.257528,-19.842337,-191.625533,-353.751352,-425.344845,-493.94521,-443.721307,-286.405297,-276.311632,-347.282686,-329.767455,-302.073734,-274.30101,-247.694916,-86.83846,31.31618,213.65138,222.024295,74.015042,-46.293066,-71.79571,-144.392582,-174.409607,-171.428841,-146.37348,-102.130589,-115.160468,-122.17449,-120.844955,-120.964096,-99.712313,-66.770498,14.624398,19.449187,-94.209296,-227.711203,-256.350472,-230.12534,-179.337603,-61.680683,-11.201604,85.435035,72.874099,17.458585,-23.305057,31.002228,204.695689,277.572311,380.498187,396.936132,289.043373,127.593166,83.940684,56.144948,69.970006,142.606063,186.880263,218.420478,94.163028,24.598831,1.79362,41.494849,175.834648,242.974729,301.795301,304.643761,291.734044,213.594864,163.366865,150.245703,210.343505,327.809454,332.759927,279.725485,151.355803,73.573703,17.7771,50.189436,195.264788,268.070778,284.500492,230.040618,111.41925,12.33488,-32.769333,18.642106,134.358908,322.533985,323.445706,256.653586,238.651105,220.541442,121.526024,75.02352,104.100836,164.350271,227.575293,206.895398,107.573481,28.501207,8.649488,-39.849929,-82.646761,-163.860073,-173.240228,-153.837951,-154.953289,-149.91927,-144.816661,-133.979996,-3.945669,76.895259,74.333474,-10.25749,-198.10863,-300.695824,-322.778344,-295.090136,-235.530068,-96.135826,-53.41411,-43.026535,-97.37287,-115.689934,-114.40864,-112.908882,-112.184519,-98.316409,-14.660855,36.495762,20.710339,-98.78835,-124.729986,-100.658922,-68.073334,3.855885,27.783758,14.09743,-86.315531,-140.251316,-189.90602,-169.915083,-47.800315,18.628829,77.576825,56.997326,-73.633067,-222.960913,-261.106097,-224.52082,-169.901035,-67.827223,-40.238007,-25.088512,-13.422764,-30.200269,-105.052799,-98.300568,60.928995,130.47363,113.340189,69.602982,-26.295036,-151.811622,-197.070916,-207.634756,-185.269812,-102.076712,-37.191176,7.634113,-163.12797,-233.907191,-242.068923,-221.376475,-171.057236,-113.498519,51.983222,99.984126,42.490437,-107.510546,-163.954431,-140.378914,-54.392386,98.776639,119.074846,105.299076,65.39915,35.053597,-30.784173,-43.974099,7.998392,59.564896,125.329128,120.470887,68.364835,-2.17559,-30.211563,5.258865,86.629704,307.72201,389.018013,327.164857,71.315424,0.575333,19.157735,55.494094,75.221701,61.766492,73.798428,93.426768,76.053661,35.64645,34.260595,34.912219,34.697271,88.673604,151.042623,238.922606,131.057461,54.093514,-26.205833,-45.494525,-52.693083,-25.049572,59.546688,86.601053,99.33496,86.962406,81.941389,98.780942,130.728624,232.523384,282.492892,282.356734,135.226185,69.618471,6.782671,-8.149046,-53.059593,-88.536228,-133.510116,-130.918897,-141.321455,-244.63772,-292.249603,-250.693879,-177.258764,-49.019359,-10.879148,-4.77175,-101.300051,-174.404655,-286.795211,-296.057887,-232.974951,-183.139537,-87.835267,-66.609502,-174.567527,-443.443191,-551.152172,-577.597134,-516.168499,-381.771841,-326.922177,-258.455951,-304.709942,-354.10133,-413.06152,-389.711791,-260.090476,-192.683061,-87.771467,-61.757056,-112.693056,-193.383596,-203.193503,-154.271301,-99.565489,30.42014,91.536607,153.200518,42.65572,-33.609879,-38.23634,19.970344,103.732544,137.926399,241.278162,245.801869,86.028192,-41.546289,-52.331119,-13.716176,51.118384,259.200894,322.114255,224.82478,50.965392,5.327514,-85.028709,-132.514279,-141.699137,-96.53359,26.56942,67.217251,23.341067,-125.833152,-147.132772,6.059859,110.146754,223.8521,243.168924,200.736116,30.480181,-64.460321,-206.635936,-234.635112,-187.180784,-143.490576,-46.929085,-8.972828,-86.452759,-215.967463,-207.706171,-151.728153,-132.326486,-3.744124,106.14104,243.298216,215.304311,183.461512,71.241522,5.169955,5.924663,83.131986,249.321483,277.322305:142.976162,209.721482,207.367185,172.820973,162.874826,182.141017,191.605354,153.580768,85.915102,100.54663,234.0088,283.105473,289.605357,284.121272,267.093184,216.084686,30.778119,-18.04218,8.039164,-65.132678,-160.826635,-281.471052,-279.74638,-203.816219,-83.105688,-20.59054,8.517856,-49.875476,-151.503135,-147.818194,-148.491676,-184.59066,-281.310639,-272.762389,-225.90182,-193.655289,-210.059262,-219.590153,-223.242782,-241.25151,-169.484912,-110.063719,-53.073533,-48.764743,2.531707,33.801178,22.136384,-14.260671,-112.998058,-199.098442,-204.804351,-140.359967,-111.954205,-110.722312,-112.411426,-124.050123,-135.156189,-86.889057,103.372854,184.458771,251.235917,255.319646,239.477279,212.126831,101.492127,-42.767251,-127.080064,-266.623485,-261.334967,-147.06445,-142.378076,-287.716775,-348.854479,-292.81489,-147.187756,-109.728451,-51.328252,-9.066694,77.936506,142.502216,251.256976,173.192689,109.118862,63.519242,73.838207,46.446329,5.906065,16.758012,157.24248,212.395813,264.713043,277.714276,268.522298,243.181753,177.481123,150.271988,110.533691,12.210153,-34.372107,21.240728,111.913787,241.83453,247.740551,231.120232,279.406791,315.990919,347.197833,340.279783,390.25523,464.36219,575.317309,557.835831,383.763579,170.496282,107.775841,125.21638,172.884067,195.439343,161.15795,110.846598,113.498473,115.342059,163.227002,218.088283,279.893574,245.052023,122.414607,85.844185,29.152904,-79.226626,-129.774657,-174.08908,-178.898755,-186.354525,-187.019352,-194.966262,-189.774183,-163.575645,-66.23025,0.308876,137.128995,177.344605,167.434593,135.6026,61.395246,44.370022,78.446678,185.586071,239.252263,355.795542,417.339344,483.923737,422.194304,366.228085,254.218391,218.469311,217.736996,227.320766,182.300228,111.293288,-93.719053,-241.342873,-303.373613,-459.985301,-506.68568,-456.555064,-378.680511,-217.501216,-207.504628,-250.895073,-274.180183,-218.702178,-72.412197,-56.860601,-138.379221,-170.705283,-218.493384,-317.818338,-354.719589,-334.277718,-285.684399,-222.723556,-229.393019,-264.507092,-242.098813,-202.152558,-157.884531,-160.787377,-108.794287,-64.618825,-51.765984,-63.940689,-61.90359,-78.826868,-90.709371,-127.889562,-172.283344,-293.875527,-338.325217,-331.785237,-244.183402,-206.440121,-164.755369,-151.112266,-106.91169,-86.615445,-75.820343,-87.805794,-175.732834,-290.975364,-313.788717,-278.563829,-250.821499,-252.779598,-271.104207,-266.530991,-208.715395,-183.478972,-191.875317,-230.436546,-293.854575,-286.782425,-213.010894,-181.92503,-195.970482,-234.152163,-249.306849,-272.138272,-234.659182,-97.579097,-81.772359,-167.875937,-272.30217,-314.956976,-314.62022,-261.034551,-131.496386,-94.289499,-93.320074,-110.929293,-120.111397,-100.487297,-107.600866,-141.666295,-138.641281,-98.061353,-81.712124,-47.59345,-35.995,-54.62369,-124.7903,-158.895197,-131.399995,-68.733928,6.274418,9.743671,45.375266,79.860855,77.142471,81.467599,113.871457,228.573273,276.445806,311.940125,278.263624,257.574857,237.722729,217.049255,96.881271,29.670438,37.836093,92.001008,141.10845,136.9261,128.047497,78.973999,67.210487,126.162806,164.887804,172.955373,151.778574,157.154616,124.481213,67.881928,-5.439053,16.249764,115.304835,154.182564,174.192541,144.643825,120.792086,63.187615,35.578584,-13.779001,-21.135187,44.426634,156.663602,179.68454,84.563878,-8.34954,-131.976595,-136.694894,-111.360622,-120.618016,-161.985733,-170.38512,-180.423796,-196.853097,-173.901448,-84.993587,-64.075149,-136.77674,-202.404075,-175.430791,-97.042043,-93.242646,-122.058887,-123.353237,-103.703657,-89.820981,-42.709364,-46.337363,-101.605709,-230.034144,-239.906827,-135.218311,-62.648997,79.785842,145.259006,140.548404,143.863505,147.50802,119.122063,93.718376,64.681818,73.731622,55.138149,-43.724871,-70.73706,-79.941709,-88.1323,-55.567888,10.409514,125.099215,64.137831,23.923026,52.504992,80.828063,47.873293,-5.926621,-80.898815,-59.764686,18.090852,-58.763746,-131.573012,-180.981426,-131.651205,39.43944,111.502069,172.726406,110.024171,52.581867,-51.20122,-84.23192,-105.87664,-105.597184,-92.215754,-57.146258,62.132087,107.939679,108.589276,166.377102,226.813771,335.408506,360.643874,356.367793,313.652521,299.894421,234.095062,149.997868,-22.774708,-46.778978,-9.2202,-20.965619,-110.519493,-77.831696,-7.373627,133.228973,164.52984,136.107828,123.994304,195.298463,328.556608,359.249741,275.996775,194.846331,102.420486,98.707533,55.207162,27.368612:158.78361,246.692773,279.864713,293.989288,268.708755,223.277199,218.140315,218.355164,234.396377,235.54682,205.799761,202.981088,253.630137,265.788438,205.360927,155.670122,58.571618,34.208903,38.628392,-33.429954,-102.135568,-184.969123,-185.876914,-164.054297,-166.854599,-185.032218,-227.748986,-231.589921,-161.421569,-118.365958,-192.643426,-296.824248,-368.245465,-218.167086,-193.554631,-295.222296,-326.766468,-294.099152,-268.113488,-175.542904,11.983007,96.471128,95.288903,31.146699,-5.554811,37.297425,133.027449,164.741268,164.710429,68.323983,-10.206274,-154.200032,-167.170115,-96.817995,-71.801188,-59.016387,-19.17448,17.548922,100.886665,139.1432,223.753569,243.466497,163.206673,91.67152,-63.349959,-199.414966,-228.512746,-248.290367,-271.276885,-328.575142,-329.19655,-289.421394,-330.55966,-361.508655,-360.897424,-352.76361,-290.220061,-204.07134,1.179153,68.198304,67.25635,2.548259,7.586717,68.089074,80.938801,48.547502,34.918387,98.752527,241.206699,283.467162,266.015662,234.07862,216.276014,226.279413,228.126512,226.270266,201.590762,139.001839,134.054387,187.771726,229.09731,299.654762,318.196657,343.091606,335.649606,313.720742,292.482977,305.456044,371.23312,423.461955,564.494401,623.617155,593.193308,377.040518,262.811726,173.496887,215.489961,279.205496,252.203406,220.174663,248.237535,241.842561,242.83234,286.054693,412.491822,429.036328,330.8014,289.821261,279.964143,213.838075,162.662727,134.006355,169.973667,239.402469,230.660113,134.840268,66.085598,92.415886,166.18581,154.893303,129.632386,159.15612,233.569935,238.061444,174.144511,116.894992,99.587751,103.613182,150.261052,281.710259,324.254187,347.671604,318.703891,315.571648,338.276437,333.722165,317.855598,330.012896,339.69146,310.308805,187.792915,10.60763,-97.487221,-294.223119,-334.985008,-289.672868,-245.716297,-191.039623,-197.106032,-191.569649,-126.77676,-64.951415,104.562913,169.664933,177.597458,130.58338,-7.951881,-120.359671,-147.959604,-138.480093,-93.442217,7.51808,12.691527,-79.80674,-151.485004,-116.085315,25.852052,71.422233,110.337218,122.898868,114.060821,89.454752,21.750739,-43.751194,-64.537834,-88.365411,-102.524235,-161.661698,-194.535336,-174.909055,-63.030905,-42.996586,-119.398391,-152.971715,-78.598119,-12.617231,21.616063,-24.505086,-186.526259,-257.82512,-237.909049,-196.120803,-180.520638,-162.902781,-179.989507,-178.67216,-31.390223,21.40394,-61.129133,-146.182106,-231.74757,-231.128511,-192.987924,-168.593538,-190.657143,-251.896235,-259.648252,-285.436408,-291.065446,-220.784258,-171.533951,-138.210158,-200.132749,-241.147464,-277.821866,-274.677642,-267.630638,-267.995707,-246.042462,-208.133902,-125.399089,-120.840723,-145.110837,-208.483991,-222.567625,-166.354541,-119.939929,-56.889438,-17.159127,-6.361313,-8.885498,-16.60635,-46.40411,-63.363752,-24.033058,28.165481,96.155111,78.410036,39.567238,-40.566529,-46.136209,38.279977,101.950355,128.105652,4.856615,-17.579911,40.449499,35.412258,-110.481062,-184.331793,-197.7141,-143.294992,-7.389634,60.595473,46.132528,-41.769069,-72.665963,-67.421734,-31.379805,57.206813,44.759127,26.724528,68.272034,106.976106,102.942659,49.217586,-45.069236,-33.216549,59.133552,17.569661,-65.378383,-142.207407,-90.276112,38.850227,79.19173,161.302753,218.464841,227.787855,150.042546,66.441767,-28.76863,-9.454463,34.417768,13.058443,-48.300912,-47.529293,-60.756844,-126.421137,-134.377621,-122.463745,-144.457102,-220.005596,-212.558992,-165.47182,-101.925365,-116.368387,-187.952132,-220.589441,-209.248402,-164.602581,-121.740873,-185.01008,-224.993073,-325.277464,-374.839971,-352.817759,-265.563406,-60.258602,28.542315,30.152335,-24.943468,-64.649174,-87.44917,-57.236459,40.192088,67.885097,17.031753,-70.173943,-87.089068,-93.239087,-86.147812,-29.906294,12.120192,58.11549,10.227715,-14.813947,-10.033809,-0.858376,-22.545424,-62.199476,-137.087269,-122.00578,-2.548374,46.38884,16.504749,-36.715199,-15.332061,42.801741,36.725107,1.050428,1.237685,-5.311757,-86.281257,-151.532856,-232.31153,-216.988942,-117.449015,-75.742105,-75.628455,-107.00836,-74.672324,64.260403,134.214107,230.78607,257.517485,279.66554,213.950297,162.336945,79.860042,38.351918,-29.870536,-39.012358,-40.303183,-54.507906,-111.860189,-113.617521,-73.076113,22.072331,55.431412,82.615633,81.236717,82.626822,138.871479,163.475595,106.025534,39.571551,-24.014521,0.431887,57.982369,56.531233:4.591299,36.219413,43.803382,71.022801,79.667799,88.779077,97.818742,104.857772,89.030689,82.672846,80.370465,100.794434,203.66986,226.516126,107.815695,40.529542,11.874115,-30.378705,-80.889447,-179.541381,-194.137882,-170.541702,-173.12637,-210.66289,-231.947572,-227.644035,-216.45234,-226.829573,-249.826761,-236.402945,-167.591035,-151.532515,-211.896699,-255.880632,-233.538188,-182.92751,-178.853507,-197.059262,-212.253398,-216.079033,-111.206654,-53.208,-51.244217,-62.892846,17.072797,59.777083,42.117273,13.01587,-6.066679,12.760145,20.488586,10.880735,-7.690601,-70.084818,-91.611404,-60.503993,-34.623288,-52.323958,-98.008212,-91.209082,36.096631,118.64784,208.274674,219.599311,146.437338,-46.207771,-120.294344,-214.965413,-249.853887,-246.357459,-203.225887,-141.223821,-204.807769,-215.078111,-106.12333,-55.954719,-64.380127,-68.998559,55.472027,144.20704,158.79445,23.796334,-26.164909,-89.203598,-99.33723,-90.685706,-77.382088,-15.688227,7.507606,6.354494,26.092488,34.20948,29.164247,22.30885,23.013888,26.569807,-21.168929,-119.290422,-140.398658,-83.547764,-19.455331,64.606784,74.887021,111.223777,145.376866,158.328254,199.209641,217.569024,299.228764,372.1819,456.055821,415.866006,220.86385,99.40644,87.701271,102.694921,111.695042,105.88987,106.864566,144.394065,103.759185,55.028812,15.068717,34.623109,102.000014,127.158245,183.172549,205.858253,127.463898,-39.030346,-84.882129,-72.13471,-22.560826,86.367905,117.255535,124.056603,36.916578,-8.072413,10.423358,56.249154,151.192799,189.984616,204.788744,169.503687,52.627796,16.72642,30.748179,100.663121,188.401269,318.419242,297.345947,264.283943,323.912324,312.771787,204.144698,171.203468,202.552573,220.551131,150.09549,64.183309,-65.933019,-38.591868,-56.824109,-258.531633,-356.424305,-397.100011,-357.983073,-241.545883,-198.096295,-215.7028,-207.047623,-155.342297,-58.083231,-50.686027,-65.698013,-81.027243,-178.225865,-241.974446,-227.420442,-202.614834,-209.654941,-223.620179,-228.435439,-201.996724,-71.898791,13.518027,33.922776,-52.436972,-157.071475,-105.634,31.538027,32.963175,-42.261139,-55.911079,-66.403048,-181.436449,-252.463704,-277.911603,-214.407814,-64.503629,-54.557724,-68.333939,-69.665175,-74.874939,-52.717638,-16.831697,27.348019,31.00956,2.411353,-110.791383,-160.765687,-167.924637,-162.582562,-209.860199,-201.31037,-62.147367,-18.510253,-41.839969,-38.823551,-14.496915,22.49358,20.832551,-44.853099,-103.613075,-240.930508,-240.123715,-171.592857,-100.712709,-114.136925,-119.198925,-99.85223,-83.23255,-156.421632,-207.940699,-254.342417,-245.730318,-213.990128,-187.663987,-74.152455,-16.612845,-25.294383,-139.184868,-165.621456,-105.257953,-35.946473,38.127883,9.149096,-37.352112,15.227814,12.469491,-58.997337,-68.519889,4.621154,22.363345,-35.460241,-49.435688,11.492783,63.020122,43.63458,3.077719,40.973404,217.235573,292.172151,276.1522,72.517345,-5.082264,-6.97461,18.248949,-2.996453,-38.102737,-57.227416,-22.501443,54.988047,50.835988,49.410164,77.021561,93.79289,140.534673,159.952329,140.716643,79.403189,68.169245,68.006209,45.903599,-27.608303,-29.16933,74.823474,116.002132,98.297085,142.36036,187.77227,145.276267,83.623488,79.616254,137.359142,222.324529,187.955898,161.591785,103.082238,45.206873,-80.994874,-100.718731,-65.826826,-67.960052,-185.022096,-311.881556,-324.696336,-259.779835,-185.882998,-42.37449,-20.967709,-60.613367,-139.458108,-162.806047,-144.885363,-135.164497,-176.366858,-208.051533,-192.706998,-163.699102,-216.482082,-344.937196,-369.543916,-377.654111,-375.318745,-320.491149,-267.808523,-162.134232,-93.736188,-64.068511,-77.542052,-131.643498,-194.236321,-174.090815,-94.211353,-65.776965,-71.991995,-71.200148,-43.033232,-2.593768,-3.843853,22.885881,75.599675,190.191484,144.838113,103.667518,98.372027,93.659371,71.11746,94.058619,169.208759,169.276756,52.744653,-56.560851,-68.839507,-34.332139,20.286011,194.878115,267.256428,230.682435,53.462306,25.558921,32.028629,-8.335974,-98.263004,-86.766117,8.41017,48.152463,47.314382,-32.204977,-62.705377,-46.295893,18.466988,193.012282,240.600968,242.900734,170.940008,95.2933,-71.581239,-119.641106,-135.859569,-130.101018,-106.956046,-88.483278,-74.351968,-64.742941,-63.83451,-81.303149,-57.875976,53.781385,113.445285,227.967129,266.192122,246.017353,123.266567,36.503389,-38.465807,8.746405,160.558187,197.550164:right
335.76547,256.450539,167.473058,7.552338,-37.024704,-12.001966,51.327457,146.101838,129.545449,103.754016,74.876572,77.661969,27.055133,-44.391964,-138.060224,-104.400168,32.067924,45.848881,-0.429427,-116.003958,-137.481852,-31.094251,44.535853,110.047594,143.633335,125.533801,-47.767528,-141.540162,-219.961499,-200.885335,-131.328249,-124.829708,-98.252467,29.655346,77.723645,66.503028,27.118963,-5.475537,29.044219,192.806365,329.023819,285.626521,-0.138334,-130.189859,-165.392464,-102.906814,-37.859469,-62.046302,-137.34921,-205.693592,-218.657408,-138.678868,-54.491278,69.685731,72.664702,24.598996,21.369128,31.166455,39.844338,25.520596,-40.172449,-51.910869,37.730704,114.075899,207.183078,161.03127,105.831447,-28.786118,-68.920165,-18.764224,25.436324,82.614899,154.065946,151.380912,62.777411,40.001298,49.33975,56.391598,115.756436,190.237137,354.043647,374.671057,353.543188,301.479976,253.510605,170.579204,175.304766,250.277987,263.064594,214.790305,69.366721,14.875393,27.890798,97.96628,227.192718,249.231745,238.522982,156.189032,98.529654,3.977741,-36.561839,-73.088162,-53.976343,11.983603,18.244081,-32.784039,-163.366049,-189.916477,-152.99545,-116.062725,-102.21332,-119.098616,-74.518752,11.250452,5.239108,-109.451623,-158.149147,-91.311938,-13.84913,56.403288,54.37176,37.331354,-65.909807,-122.129049,-137.504252,-76.990093,89.904359,125.921336,122.764333,194.129938,231.974677,158.639894,85.660708,99.001586,161.709158,180.86381,61.989673,20.891179,58.925789,72.170445,-15.129412,-41.16258,-16.596719,-31.91293,-125.904454,-177.878649,-174.959303,-182.490263,-205.640159,-216.040396,-189.992216,-121.905235,-91.923381,-108.574722,-165.102584,-189.472831,-238.777898,-241.56338,-177.948448,-118.643928,43.494485,57.46057,-34.358908,-212.827392,-237.71935,-197.756593,-173.356323,-157.199103,-106.191371,-66.61373,-31.110731,-36.127595,-52.076294,-46.464401,10.700811,60.000223,116.42426,-39.936337,-163.657533,-310.101831,-308.769674,-223.206426,-184.677978,-195.825392,-308.901314,-344.333948,-279.322895,-247.002956,-281.480116,-277.052823,-144.594402,-62.219191,16.525374,-62.583708,-105.849881,-98.827071,-74.235729,-25.778892,-7.763637,-8.374764,43.795886,105.573741,179.390546,141.828085,3.490212,-11.172709,84.521111,134.865499,187.774906,193.529596,160.62948,0.880907,-91.316656,-191.598818,-196.818314,-131.2512,-0.725237,50.496665,89.486089,51.642547,-125.591235,-179.900644,-138.023314,-101.135884,-70.294843,-63.582004,-84.517152,-199.590221,-259.136489,-295.77939,-287.397017,-285.968957,-309.110269,-319.793629,-319.668556,-321.399039,-311.90721,-262.276423,-102.991525,-42.345043,-5.293534,-63.556629,-116.829873,-246.572742,-290.634347,-288.555066,-269.498715,-256.298974,-206.516077,-146.081663,-34.448852,-39.43616,-133.579024,-126.278825,47.159798,121.109716,122.919314,54.171773,27.788996,-24.099424,-64.689322,-141.296963,-155.172505,-156.869922,-165.000875,-161.402355,-122.605843,-111.695597,-131.949458,-117.247603,-16.63041,35.178847,118.415427,119.47265,66.826814,-117.530471,-191.348641,-148.887349,-48.737385,161.617902,266.592739,268.685291,208.297561,156.869252,29.400409,-27.873518,-48.219173,-4.927645,64.527269,-5.017365,-52.991095,-89.117057,-113.946379,-244.335457,-309.184932,-336.776217,-297.036123,-288.273849,-226.498489,-170.764952,-121.805694,-121.030838,-57.121618,-17.616646,-62.684785,-192.008041,-225.059965,-261.850456,-279.769121,-206.81089,-115.619447,14.930757,26.08765,-1.024756,-62.548597,-81.455315,-123.332087,-111.501847,44.502846,131.002221,147.793593,2.904453,-31.861249,-16.06555,-36.347119,-127.742054,-140.766981,-100.15856,-101.192019,-137.255687,-215.78048,-242.531185,-283.196231,-277.197272,-168.631658,-83.564317,95.375699,189.764872,178.527243,72.350779,0.992829,-103.363137,-116.478639,-42.304412,87.233372,86.195088,-55.254473,-138.291791,-272.266737,-311.818647,-298.194489,-232.594478,-39.740798,-15.706744,-78.957715,-176.178395,-183.573515,-161.170473,-147.631831,-160.998263,-233.474237,-254.290603,-218.239436,-193.608768,-193.081978,-207.716047,-238.130765,-234.609854,-193.674783,-284.842136,-358.985109,-371.584427,-321.234888,-230.675458,-213.925718,-216.785731,-185.489326,-161.357133,-127.450623,-96.059306,-8.603919,3.505997,-32.837631,-25.533326,70.40528,157.927789,171.862218,131.12505,89.410262,24.004616,18.972987,96.212758,204.806497,195.174007,75.896929,42.271736,105.121688,170.818993,259.758607,268.952525:253.286154,163.486923,49.323483,-57.769258,-37.520225,19.592795,41.251712,104.197449,127.94571,100.313226,32.608495,6.046969,-66.70567,-97.213708,-38.156251,56.655586,202.166278,139.187284,70.966505,-43.288455,-64.788372,-19.568026,13.776821,26.153973,10.901255,11.845716,-5.889086,-41.971003,-133.875294,-144.549529,-66.301429,-38.12264,-73.71868,-56.033966,4.508881,118.851945,126.750309,84.815667,99.98859,256.04007,339.676144,279.34891,66.223924,-16.495148,-56.086552,-31.895684,14.981323,34.363055,59.288122,35.621204,32.598428,38.277243,34.632403,54.225388,77.0942,120.558494,121.530928,99.781087,94.224111,117.35332,145.440412,139.973311,152.160319,183.749366,195.929648,60.85258,-36.243942,-166.057941,-146.062327,26.02937,99.422004,125.609818,84.377635,72.026135,30.187528,-18.566553,-70.219492,-26.12756,140.832856,216.700435,299.22227,319.809842,311.348523,197.025342,115.570941,64.55554,98.408589,206.099168,257.348745,205.760107,44.90207,24.698167,109.6753,150.25768,174.419274,184.210054,199.21179,130.876122,81.356757,-20.062668,-66.887001,-63.521986,-9.191206,73.990668,38.879216,-10.96592,-133.527633,-172.935969,-128.686137,-56.824236,28.318862,13.361409,-23.278829,-50.103251,-99.006157,-229.482101,-251.741136,-180.420856,-133.149381,-43.534427,27.57191,1.000151,-118.353448,-146.378001,-122.507828,-94.838376,-48.922541,-29.546139,66.636144,177.182501,177.366805,74.644724,41.010238,134.394446,208.101392,233.187807,109.19616,55.103863,36.017329,35.232198,7.37609,1.822116,5.487041,-0.285159,-50.02531,-147.904276,-189.105062,-220.817215,-197.021896,-87.451636,-50.872126,-34.995487,0.103296,-3.380983,-100.545542,-157.979654,-184.476142,-156.658386,-120.272563,-96.126017,55.287138,39.937387,-86.337743,-280.637225,-293.470559,-278.629807,-279.127099,-240.860257,-175.197632,-176.986569,-214.623451,-213.233029,-190.087179,-190.625033,-183.912127,-152.547136,-60.502799,-67.975998,-161.744271,-397.478519,-430.779133,-329.438612,-270.859529,-209.799779,-247.191621,-286.524941,-284.872248,-268.238539,-302.672022,-302.7579,-146.669925,-28.745456,82.370851,2.092209,-11.08699,55.036144,76.852491,67.838506,66.33374,115.420619,192.208042,207.767381,158.632844,95.432821,-18.758939,-16.381846,101.769667,180.000897,310.10542,263.525647,168.507068,-20.669964,-80.701269,-122.607561,-100.577531,-19.922165,-45.389025,-100.132482,-182.626657,-195.520814,-155.191344,-108.338058,-76.205277,-111.071583,-185.73211,-180.319849,-162.741255,-173.059261,-215.049392,-308.117003,-318.906459,-236.27453,-167.069235,-182.048521,-237.060192,-264.182857,-279.038153,-232.27276,-62.571052,17.875805,104.627477,34.664958,-36.291419,-165.108235,-198.027817,-167.610168,-134.300161,-123.073747,-126.593769,-91.913191,10.720074,26.407314,-8.612031,11.155625,180.179386,258.290352,223.235813,72.251642,24.061953,-59.401781,-102.056297,-148.525194,-168.760179,-222.307074,-204.853611,-184.358848,-174.751967,-189.845856,-214.70164,-185.135089,-76.681991,-32.846295,45.521346,105.447896,79.359979,-85.942727,-138.578696,-62.683628,24.717682,204.515738,332.330714,327.251393,185.284239,108.496133,20.44816,2.564228,69.193772,152.116691,248.57714,174.383853,119.750462,28.14568,-17.855627,-126.815151,-165.288884,-159.112372,-153.926761,-176.852338,-188.876192,-167.437793,-108.442224,-76.008537,-41.013338,-36.300959,-0.735897,2.44388,-25.436724,-98.828756,-112.192577,-14.76009,45.97616,34.884116,1.401237,25.527617,24.26526,-25.668001,-54.995104,2.614867,134.826873,176.669866,205.613244,117.046496,69.443761,71.546878,90.671452,75.796294,55.289106,50.606906,38.801123,-13.675972,-162.87472,-211.385553,-195.199316,-135.116632,21.962746,99.307893,215.831488,217.979361,174.468199,50.078536,-8.607073,-98.15155,-110.417522,-24.53334,45.894967,23.61041,-71.14377,-142.559882,-345.904406,-402.940181,-330.490385,-266.522055,-189.934723,-199.855061,-218.598245,-228.656334,-225.394441,-186.282468,-140.44018,-105.628407,-255.524817,-313.254292,-207.57716,-109.449912,-49.300991,-83.892662,-146.566127,-124.858665,-28.474504,-87.624898,-139.943702,-126.945122,-95.15701,-88.82001,-88.671439,13.428203,129.446982,120.561744,7.272318,-54.903977,-71.591202,-26.26647,46.370715,58.899542,70.216263,96.523469,119.228316,144.266397,138.934348,107.029901,91.950022,71.303472,41.204132,39.532353,95.25502,113.99565,124.25691,154.444719,243.167547,267.698278:228.514344,95.387114,29.493377,9.443555,15.513559,0.316056,-1.791239,31.767961,100.298528,109.766603,27.217044,-22.159781,-69.222779,-65.302723,23.876293,90.281041,139.23585,20.021692,-64.457721,-217.044644,-248.791243,-154.103631,-75.155327,-1.571837,-59.651142,-101.271063,-136.49767,-158.515093,-227.312372,-211.844469,-53.453549,8.354173,-23.448107,-109.712467,-111.282228,-87.522783,-80.639482,-16.559906,41.966195,121.821901,27.486828,-52.444352,-151.256098,-171.895179,-147.862509,-103.646209,-7.305893,27.030584,28.038937,-35.841173,-55.011275,-52.583165,-27.480174,109.921681,196.718925,245.692294,75.036433,-14.295825,-24.865726,40.491252,146.15266,149.53619,144.38903,163.126576,144.198331,0.181779,-78.036955,-156.626828,-131.01467,-19.236809,6.827301,7.914066,20.368056,19.370827,25.657178,25.759278,-10.302386,-3.173643,117.77728,190.741983,226.042414,155.532185,145.782839,102.744544,49.10661,4.362771,35.491741,152.070383,180.920318,122.563163,-28.073933,-59.883003,14.801738,89.718696,173.092951,153.231553,20.299623,-72.186541,-64.228571,-34.667288,-27.229638,18.591819,38.265276,26.182485,-0.011434,-23.545861,-125.302865,-166.334722,-125.291193,-60.111496,57.632555,83.287056,23.028731,-153.881478,-251.438808,-390.261393,-402.227541,-357.71077,-325.296626,-203.291735,-134.272917,-191.030319,-336.273002,-350.646196,-300.924759,-264.874985,-183.273018,-138.963389,-55.335781,-61.834274,-95.955988,-124.22864,-80.469811,107.225987,190.379545,243.512213,159.407607,99.103441,12.316854,-20.245787,-57.964045,-46.799705,0.15652,-10.365266,-127.492419,-229.854486,-253.648348,-297.123618,-285.159554,-150.577172,-88.169055,-42.878132,-23.475385,-19.18952,-47.988163,-67.486246,-37.000227,-4.651398,4.181633,10.701587,66.797973,18.817247,-53.519888,-194.407331,-236.425346,-243.273226,-212.54214,-128.840155,-78.458889,-96.525332,-204.073551,-231.524932,-177.356169,-138.803143,-114.584035,-109.84176,-81.896451,-115.750596,-170.199435,-316.542996,-368.806872,-374.699663,-346.820322,-266.979366,-251.320193,-275.693604,-268.241919,-229.521253,-151.755988,-118.829422,-57.846322,-23.930343,83.032062,146.088457,125.611641,75.946203,106.538103,213.624887,210.849308,162.049466,312.103027,397.290771,337.542793,225.541707,82.922641,93.268181,184.488791,218.825607,231.727851,160.614975,116.836608,52.840293,23.175003,3.267302,36.838676,136.505324,105.800534,37.937524,-47.846454,-48.188418,-57.926992,-77.703318,-59.705862,-16.954706,-17.37059,-143.250303,-178.335501,-194.082078,-214.897272,-264.1073,-244.057926,-101.127691,-52.826635,-76.730676,-85.495618,-85.276586,-109.015766,-87.092487,63.268423,147.927397,215.647184,140.07985,82.508369,-22.525386,-53.423879,-58.276956,-44.134637,-47.251727,-106.063894,-93.201156,26.913164,47.637604,-34.276448,-50.809476,86.396379,173.21266,157.224286,39.964729,10.690792,-75.342887,-121.4308,-131.334696,-131.432557,-186.174533,-191.319077,-179.376045,-208.468317,-254.118399,-315.231957,-284.186972,-142.616843,-77.287374,-3.531438,-51.580536,-107.06104,-178.681858,-169.740151,-74.910868,-17.416313,94.786412,196.291182,203.747919,118.617236,54.01988,-84.906262,-120.603926,28.772781,166.901473,252.455102,57.416452,-26.288073,-63.916462,-48.014111,2.365485,26.440562,97.094675,165.841973,131.629952,-18.564136,-59.180756,-40.164667,-25.64787,-23.033013,8.077397,130.269333,100.928879,33.306337,-51.404407,-67.458479,-63.201689,-17.479912,115.661054,155.147006,136.448684,52.460242,-0.743236,-25.380745,35.260816,232.658375,308.477618,300.315508,105.420352,35.675144,39.280036,48.798982,-2.6118,-18.833723,71.396769,155.471973,116.531614,-51.081139,-111.181031,-123.916653,-116.784519,-129.925427,-94.618808,84.06032,89.061492,-2.327128,-172.270836,-207.666512,-204.237541,-184.002379,-128.801762,-116.657274,-145.736486,-238.732061,-309.377627,-439.515704,-424.602265,-265.172958,-200.79662,-158.821762,-196.148751,-227.950129,-236.598933,-210.688757,-126.816069,-65.047844,-9.617136,-164.400453,-241.968237,-219.425941,-170.654898,-155.128201,-152.968024,-89.638799,-51.646243,10.964874,-13.420652,-52.753931,-58.196639,-25.458249,11.825617,5.668993,11.652991,86.527615,115.123412,84.807025,35.748493,-35.505124,-21.288966,76.31859,110.1057,83.319252,36.458041,74.143591,221.595088,247.303381,200.399265,209.741365,289.834041,218.40819,146.850794,98.803522,120.576985,193.850998,232.131473,269.349108,276.107542:257.091217,177.763814,87.376753,-4.339084,1.205711,33.327507,53.73703,134.123492,190.703604,179.084467,132.453751,115.199111,50.287169,12.926356,3.184795,24.402668,74.800022,70.201091,26.997626,-100.024274,-141.414871,-144.411132,-129.804321,-62.649319,26.415649,29.953214,-80.267617,-176.244724,-310.49461,-289.879197,-154.632643,-115.612877,-90.762491,-73.102891,-79.961226,-108.646013,-118.838886,-79.827183,-30.350495,63.515635,93.834522,51.082612,-107.58236,-168.854298,-201.393112,-179.660392,-93.127459,-49.224818,-40.074687,-143.195607,-168.128965,-106.226026,-53.487295,51.536438,86.742697,59.432044,10.290164,40.256313,144.68899,148.38111,65.304814,59.058852,204.243093,294.527922,311.588597,144.455823,79.108179,20.067853,3.69367,-6.627322,4.962162,69.673246,92.287269,55.468206,3.709113,17.46652,36.863167,32.545743,83.920572,141.457605,187.996376,135.792202,129.299721,110.596285,70.300687,-10.235238,-15.963213,86.878336,147.231071,81.089824,-61.640953,-69.724326,-18.99572,22.131599,111.175182,128.381548,84.334686,45.683779,64.795163,72.043513,22.700305,-50.9628,-26.289193,67.012219,65.555561,9.439512,-129.989889,-160.783156,-105.144178,-51.650731,-9.645041,-27.395694,-45.374635,-2.973422,-1.974648,-103.041475,-167.563441,-214.183726,-183.498479,-49.388846,-8.579351,-57.599924,-168.021687,-194.318158,-179.433533,-141.609782,-48.880776,6.596682,129.197787,173.683069,154.806491,57.486693,32.00657,143.664316,226.207114,281.443894,216.143381,161.618426,44.627826,4.775496,-23.195831,-29.150155,-61.983069,-87.862652,-178.147679,-286.969715,-299.317367,-268.713642,-236.656815,-134.236752,-101.701111,-83.665984,-27.667755,-2.457023,-21.790466,-67.162333,-138.17461,-125.135301,-43.556446,-1.696271,64.15571,13.478284,-43.776168,-147.670497,-203.92751,-274.058723,-231.41798,-6.534719,108.269953,64.42188,-42.200271,-39.434643,-8.968203,-31.144313,-71.804483,-39.200163,25.012739,-118.555822,-217.2086,-330.737319,-348.646333,-332.573651,-311.008312,-256.847814,-207.845572,-204.608219,-212.054605,-216.149081,-223.941588,-205.047399,-83.128433,4.169896,108.979138,84.183248,82.212167,86.695685,65.477308,42.985105,72.166194,185.778726,245.714783,234.493068,163.829121,110.419221,28.688143,50.608654,191.37942,236.91245,221.260995,195.856038,198.864197,145.464237,82.52834,-14.366509,-21.572071,19.673848,82.662347,101.262391,70.863667,19.196271,-96.672062,-117.046169,-58.724355,-8.858149,17.743665,-129.515156,-199.56103,-210.592334,-201.161822,-242.332428,-244.096304,-153.469513,-142.718073,-182.351455,-247.796062,-260.444595,-195.579302,-111.514224,31.282272,61.031001,112.070736,114.153788,48.679444,-148.654062,-202.241369,-170.976518,-153.629156,-207.135884,-207.135881,-146.562835,-35.419827,-45.011277,-170.214145,-196.874868,-32.772132,89.57263,167.048227,115.788498,96.163798,-20.274745,-110.675071,-237.503043,-265.1521,-267.540303,-250.25032,-260.979989,-291.580184,-294.792133,-261.447633,-212.521781,-106.390487,-72.816795,-8.476524,23.62852,-6.229052,-128.333011,-159.071917,-70.919208,15.455477,166.269515,232.991812,215.686861,131.36511,98.013736,15.600663,-28.381101,-6.186586,54.074144,139.714128,130.699435,99.635444,-19.487927,-83.603268,-132.828416,-122.338929,-80.46877,-50.075492,-57.132849,-65.513526,-56.311945,-78.009393,-108.549881,-128.321291,-95.870109,-37.204082,-124.968286,-168.727422,-168.017485,-151.843605,-114.447872,-92.780855,-44.708048,8.081233,8.183663,-31.917827,-61.104059,-120.208802,-115.263027,18.1652,122.931666,216.951443,23.816003,-56.198529,-4.565756,30.433475,-30.06234,-59.216379,-5.998263,26.42734,-21.254744,-153.33318,-201.995436,-298.753099,-346.213302,-352.349601,-286.59561,-89.52733,-15.42283,-38.489965,-136.158712,-197.471573,-301.517697,-323.464065,-254.944988,-116.29896,-112.182749,-281.537044,-416.390265,-587.723466,-566.969289,-416.184806,-330.604048,-181.345704,-192.131789,-234.274938,-243.348972,-219.884625,-166.393461,-134.644159,-122.206712,-239.379212,-304.105277,-322.963216,-291.65743,-229.901931,-197.630256,-146.573842,-137.181783,-124.682164,-172.118422,-201.377362,-180.776289,-152.354034,-138.270624,-158.408471,-180.144465,-109.002057,-78.877086,-94.95104,-118.354086,-142.496334,-147.565138,-150.788643,-133.536457,-38.573075,61.002855,97.891488,126.774002,117.347948,129.074381,157.130043,178.914511,152.260914,150.586546,133.971393,103.718163,103.557623,171.163555,379.017501,453.156581:268.246039,150.8714,55.233176,-48.18294,-40.037192,8.406756,32.353012,107.447635,176.584537,169.562033,73.969103,-7.473456,-166.673788,-164.161809,31.953998,141.829455,200.112462,17.843111,-97.452291,-233.41195,-229.086949,-115.278436,-42.264934,82.931335,69.174047,12.404881,-91.575508,-157.798626,-308.336913,-298.915011,-104.415531,-38.766387,-68.032645,-114.343659,-113.079988,-126.085669,-136.518174,-64.701175,2.919831,34.92507,-61.415391,-111.414166,-222.950536,-278.885398,-286.709269,-226.990831,-89.6484,-54.883131,-84.787483,-142.152382,-137.450158,-129.051775,-128.143016,-35.882883,43.938785,102.544212,0.868556,-31.211597,-10.625816,13.579538,58.666,86.624438,182.802039,231.93259,221.435806,118.160883,64.024649,-82.531915,-127.961808,-44.852526,31.592837,89.230231,33.817226,-1.149823,-53.721146,-65.766461,-42.994972,-9.366335,83.540634,126.808263,155.292481,141.975688,117.167115,-50.966042,-142.800305,-118.547775,-21.683248,128.299026,64.754907,-36.057545,-176.635353,-183.889544,-126.079712,-55.20125,98.916984,113.672439,9.034574,-57.911012,-30.753341,12.594751,-12.446898,-46.044916,-24.784929,13.73487,-19.821252,-51.619795,-141.715469,-191.40108,-170.527698,-81.826498,74.672667,83.159123,2.516225,-102.506076,-162.835761,-313.888226,-346.528633,-257.660819,-197.461043,-136.102235,-126.361892,-161.571234,-270.716421,-306.450201,-297.827188,-237.317285,-74.656822,-16.9822,50.179829,23.525172,-36.208269,-125.692681,-88.427394,138.289306,234.046388,263.348429,190.226412,151.308205,57.769631,7.383725,-22.644208,-8.441505,-11.641994,-38.449965,-110.384553,-194.330373,-247.763149,-336.7007,-319.860282,-145.98368,-55.858634,47.690585,49.776621,20.719121,-51.358271,-76.302586,-38.539973,7.287648,53.294128,68.073144,96.980584,11.611561,-62.268699,-195.068445,-230.340581,-219.743071,-186.171567,-9.563721,197.360348,180.586341,-21.907556,-76.177589,-15.578077,21.520689,44.745769,64.488859,54.940409,-98.190208,-197.38404,-417.098298,-491.301561,-438.842762,-358.225273,-240.960177,-229.475738,-249.595619,-261.587711,-254.807239,-254.391441,-238.409284,-103.264537,-4.689114,95.892346,2.133904,-42.00994,-4.348486,63.32706,246.159258,320.993665,357.967258,363.037353,366.256898,244.97204,124.877591,5.797244,73.162556,309.29986,368.490644,286.208281,155.524026,137.364244,134.72686,140.72625,187.727533,199.419337,180.464485,178.591082,164.058477,68.289195,-5.555157,-107.81512,-102.122614,-20.443191,21.323681,31.759658,-79.012912,-140.343493,-214.838755,-221.819381,-143.845933,-58.767801,105.028905,87.553373,27.697872,-103.597611,-164.07959,-128.838048,-8.611466,215.364612,246.961787,235.72723,252.510526,226.457315,42.008645,-39.06744,-49.230115,-31.477326,-57.179055,-121.505944,-123.110189,-66.521048,-68.723077,-150.096454,-153.59763,-2.215851,83.254782,107.187978,86.377724,80.764477,-65.006966,-169.193168,-247.451881,-227.949897,-195.782962,-259.512559,-296.844565,-292.773891,-271.665892,-268.910546,-261.115455,-142.522775,-57.753501,20.414772,-68.627571,-133.853427,-194.313108,-173.222817,-99.276792,-64.828418,46.090259,164.961214,184.663662,108.83179,20.315761,-125.79975,-118.160611,45.574699,124.569819,130.008911,49.38371,25.534073,-10.917768,-18.890209,5.759829,37.945572,137.98475,180.191302,128.101806,-65.625529,-135.348223,-139.917712,-102.671913,-8.167586,51.608312,115.656911,5.535309,-71.003505,-184.339992,-213.05794,-150.149762,-49.73921,163.641841,174.346762,105.138577,-6.306398,-12.621871,41.756515,79.573411,162.939847,211.409439,247.536648,133.107077,66.170207,5.585359,4.368065,-4.600187,-22.061539,10.810831,125.714262,108.976142,-87.073888,-164.221322,-167.173969,-154.264911,-185.643686,-179.983018,-74.273122,-32.997692,-75.508928,-241.175656,-322.152034,-355.509733,-315.321204,-210.476306,-163.03152,-216.842466,-431.99759,-536.716664,-652.277497,-632.822077,-458.258256,-345.198629,-160.319863,-176.495544,-258.090653,-332.176882,-263.733369,-38.913569,25.687777,0.337102,-105.792975,-136.312002,-146.209423,-161.848583,-203.815902,-193.571674,-109.624706,-58.261431,23.822165,-7.13072,-80.25478,-197.316087,-186.55258,-93.107747,-54.438781,-2.607322,-28.893548,-63.195843,-82.564517,-87.637074,-150.03759,-167.291738,-116.623047,-77.967903,-1.591079,71.736525,96.237525,93.321521,87.217266,163.740768,229.720049,293.817903,240.169386,197.418572,129.874672,116.248187,150.838458,192.69957,276.961024,311.442799:336.004183,239.263951,163.42533,107.898446,93.307322,51.361295,56.137708,110.495205,167.119223,169.71386,126.541503,89.523247,-38.977178,-99.526453,-113.298559,-75.434261,6.577214,14.044073,-12.122748,-64.0618,-67.219147,-23.334903,-3.885817,34.071047,108.601392,81.577609,-153.248429,-273.767109,-324.607053,-267.292955,-175.819173,-171.220065,-152.638983,-87.88625,-64.163721,-69.030694,-89.43488,-62.091867,7.976934,145.651784,109.603515,23.19723,-215.138169,-330.061545,-427.579202,-397.427889,-349.653417,-354.340433,-342.914938,-358.160541,-350.319242,-241.953417,-181.560896,-114.586355,-107.640765,-129.445353,-118.313607,-79.760932,-9.029048,-12.087964,-26.593378,1.471844,102.176552,158.525032,238.939311,224.536914,185.548356,76.717918,34.301003,-6.794956,-21.319425,-2.761907,66.204999,59.770603,-14.259761,-32.636198,-21.397509,-4.749175,62.569277,106.84366,175.61628,207.677523,235.435336,241.911635,178.782717,51.21645,56.169457,126.014061,78.397721,8.059057,-80.491071,-65.428633,-6.431973,12.79065,47.888558,51.935138,58.384709,96.490809,104.665633,89.962881,68.662447,6.651549,-9.166009,57.326104,123.298399,88.683904,-27.475073,-64.097272,-126.946054,-148.077385,-114.331236,-67.148102,57.129278,125.953866,104.557429,22.216712,0.931199,1.684505,4.547173,32.750871,82.147441,56.20396,-57.666207,-79.652627,-22.520422,31.565243,97.625081,88.753432,75.985522,191.279326,251.652373,180.260296,87.056211,88.559148,178.231457,280.080746,248.545942,227.673151,148.944186,64.104401,-90.087736,-82.313006,-14.052363,-50.819079,-183.884882,-167.403457,-119.08997,-95.006719,-117.280823,-90.073755,-30.150016,120.17025,207.20087,177.817426,29.883282,-23.39338,0.690421,68.605429,155.766545,150.851623,172.485949,193.170611,154.658261,31.539309,-18.817089,-34.369433,-4.566669,66.368876,121.941563,141.022105,198.306876,231.14725,180.337263,109.436553,79.44893,130.13484,138.579693,-153.309447,-319.148609,-452.001662,-423.35485,-278.726978,-210.886074,-167.481554,-187.630253,-194.272198,-212.153313,-238.776106,-310.703138,-312.983818,-186.276079,-82.296246,36.282689,-87.778954,-163.870542,-197.670969,-166.509709,-71.687777,-24.82516,69.307127,156.168277,172.341697,133.173122,91.981301,68.863253,114.248048,204.542886,207.073355,205.286277,286.554751,321.467919,255.959751,171.191604,32.742157,13.09896,124.804836,300.256012,308.927729,186.749515,102.772173,-46.388834,-82.201033,-86.688661,-76.487951,-27.229953,-6.836815,-23.336177,-75.192315,-109.796546,-159.936658,-163.603756,-187.079063,-251.747731,-273.998025,-292.364575,-300.372985,-266.040327,-193.760659,-31.548981,-4.55436,-61.942753,-144.984006,-187.332454,-311.524234,-360.852728,-356.397482,-349.291665,-386.453961,-322.739056,-262.052715,-244.583154,-308.391701,-396.381272,-318.408616,-19.287697,53.339356,-54.70233,-197.332397,-218.648647,-267.18906,-301.074686,-302.775577,-292.355376,-329.08109,-356.96404,-325.813211,-193.34858,-147.621198,-198.981278,-252.525021,-237.002915,-162.509101,-29.501727,-42.187046,-94.920721,-255.244668,-315.702646,-252.428917,-146.648894,79.995126,193.352298,170.819311,31.395038,-53.377372,-176.431473,-185.56694,-93.131795,-12.694936,90.064836,0.657496,-71.206444,-156.975581,-195.024755,-285.479356,-303.753834,-254.836255,-168.992521,-152.679598,-170.012484,-197.031519,-300.454917,-340.357952,-280.141856,-208.4468,-157.737883,-244.417695,-300.212168,-395.783434,-404.556136,-306.856562,-238.171099,-147.928125,-83.118518,-63.364802,-86.788118,-121.335298,-195.181869,-217.240516,-182.587933,-110.817053,22.642191,-79.63421,-153.045251,-192.142749,-201.717459,-239.645406,-235.032362,-173.411469,-160.225042,-201.53667,-328.368628,-398.161014,-511.398716,-509.684111,-361.614898,-267.101852,-158.306721,-127.462331,-101.935662,-77.665999,-118.977471,-257.062398,-307.882217,-301.855895,-174.468442,-142.341463,-188.521554,-250.99871,-429.967375,-460.297236,-264.128954,-103.80627,122.710779,37.438033,-65.798911,-118.727039,-61.325919,58.156227,62.114679,-65.427486,-206.845092,-215.813756,-127.997248,-85.724009,-85.364896,-108.357227,-157.605222,-174.012114,-180.566557,-302.505702,-383.755971,-388.958683,-341.421631,-281.104142,-275.507724,-312.56503,-293.299462,-237.823864,-162.931988,-175.230003,-206.13274,-186.738104,-134.774229,-133.132189,-139.046833,-60.037869,5.581875,101.768151,110.851592,111.201544,123.9315,156.203187,171.783823,155.716685,111.732282,105.979119,124.327938,155.9488,256.699326,298.924186:273.459902,261.397554,176.690297,38.553421,24.488454,34.556252,35.349846,113.235238,260.340766,270.125434,156.740936,88.823737,-17.420952,-44.749387,-22.923099,4.094648,25.164983,-33.881282,-93.767327,-190.171344,-188.470937,-116.059777,-64.415108,102.983147,187.254141,130.227288,-76.005217,-181.256171,-283.097387,-238.847159,-77.125628,-47.187944,-110.156244,-109.198047,-65.299192,-68.076176,-119.560756,-116.075537,-49.629689,42.279787,-33.279972,-107.147577,-243.657919,-316.347945,-430.20014,-418.37106,-283.33427,-228.367044,-240.918619,-300.551836,-280.507775,-192.125886,-161.27693,-102.028193,-72.013504,-33.443766,-7.592608,-1.632267,-3.308588,-11.234697,-35.201292,-28.080013,100.397185,202.330247,285.791753,181.867112,134.594597,61.121504,19.468527,-15.38869,-7.729609,-17.563193,-82.21808,-120.840125,-150.710081,-136.920827,-91.043489,-67.473056,25.714984,106.46147,198.790575,77.294628,20.241555,2.167788,-2.79425,8.156815,49.093011,122.351257,89.054986,23.738166,-135.729309,-182.654737,-171.337456,-126.173605,-29.194715,-1.83559,-21.376113,-44.832165,-22.357724,-20.319357,-60.364163,-81.473555,-36.57483,72.355496,134.859694,122.46084,-5.045909,-71.905652,-103.590679,-57.187743,103.537481,158.325923,137.528751,43.859703,0.46559,-100.772782,-135.217094,-104.076895,-55.785304,27.153965,5.045269,-55.322807,-172.48654,-190.033851,-117.844785,-35.498622,108.540563,137.336472,171.545248,223.451511,226.376108,123.799481,58.374208,99.343156,190.351519,326.53349,345.048452,308.767352,149.253327,51.086877,-52.136944,-29.449451,28.532151,4.50717,-99.230029,-122.433276,-108.736501,-153.574259,-186.514486,-96.778042,7.086228,155.557655,156.96586,109.225946,-58.962208,-145.252055,-190.803148,-147.059026,-40.79654,9.349816,113.878037,98.079903,32.570845,-133.497329,-206.432823,-236.954971,-176.49351,33.458434,174.536873,163.283372,61.52028,32.787243,54.583893,87.639348,190.595493,255.202087,262.576017,-23.862221,-200.325401,-424.520682,-442.951767,-298.108656,-201.300571,-98.92807,-60.620159,-60.607041,-177.031765,-289.873515,-423.510417,-370.118819,-112.490455,0.077637,61.652952,-25.684892,-54.338934,-86.716319,-93.182086,43.428309,166.116691,294.980006,289.940744,273.794099,110.814367,-14.930294,-58.260488,58.381658,272.426953,288.290866,221.510757,178.073151,187.36264,202.713143,193.69438,160.812552,135.993378,139.079264,193.510897,160.41818,-8.58216,-92.055289,-157.923263,-110.147071,55.947893,88.630769,-20.690573,-171.481354,-187.901041,-141.941596,-108.980065,-30.212277,5.881149,26.044634,-49.566775,-103.210234,-222.432433,-288.635895,-286.364808,-173.92832,92.95893,160.94784,171.087953,102.32105,45.18629,-83.276909,-125.585609,-115.027735,-80.202368,-36.002623,-61.034454,-71.187537,-91.250613,-143.341807,-266.108915,-243.76813,4.188885,120.757136,123.373777,3.932125,-25.472579,-86.27466,-132.053618,-196.666325,-210.522049,-215.39853,-233.22611,-272.920374,-315.725889,-288.768032,-236.911231,-226.594594,-147.00109,-57.499772,111.194171,40.13966,-74.28401,-280.49628,-309.414485,-165.884648,-46.323077,85.232428,94.075584,96.342652,10.655371,-93.726393,-241.954237,-225.756451,-71.264423,19.69929,148.819074,120.399064,27.841469,-175.192596,-206.518202,-166.344999,-143.629495,-84.767185,-39.535811,-56.61845,-130.763872,-167.385287,-230.514267,-237.242287,-158.106013,-89.699906,-15.77567,-149.909038,-270.049078,-384.354736,-323.313163,-123.965443,-74.923439,-64.436501,-54.963739,-62.012479,-92.702139,-118.426572,-193.861546,-202.281381,-75.039719,37.938286,143.846134,-9.113318,-64.551217,-46.359166,-43.107933,-91.97835,-103.131481,-52.263478,-17.703642,-47.828522,-174.435554,-255.70853,-387.130711,-391.325529,-295.023333,-242.14396,-187.97111,-191.664858,-180.842438,-176.713064,-212.922756,-286.028735,-294.167681,-258.116604,-207.958377,-223.852179,-366.326363,-470.925123,-587.782099,-529.282005,-254.037361,-127.91822,6.047734,-38.388708,-97.100749,-157.4666,-142.540042,-48.909454,-0.218785,16.137175,-83.994816,-149.476417,-222.021224,-218.876864,-189.43851,-167.367463,-84.934531,-26.997271,46.259904,-99.588498,-214.814698,-309.096703,-277.159788,-174.385199,-137.906122,-99.610069,-94.392881,-107.453621,-178.159354,-228.319348,-284.347794,-272.775434,-190.872816,-128.647279,-40.810789,-90.775584,-113.751703,-53.651514,9.459592,127.645374,166.573186,170.249258,149.187493,166.953974,151.573054,94.012157,73.723879,149.11633,307.14697,339.766991:318.701842,344.428494,290.431836,135.08859,69.735829,27.152885,42.582691,75.588533,122.29266,146.316361,100.640225,9.046933,-213.799622,-278.396115,-300.858607,-287.671388,-223.445984,-160.458678,-133.926643,-89.988589,-79.635179,-43.765323,-31.529521,-52.069318,-11.104438,32.45467,6.73867,-67.232691,-162.813308,-156.194742,-152.850291,-168.535134,-158.764914,-114.942277,-106.233619,-161.152476,-204.422836,-182.552555,-114.413391,10.270056,-21.573718,-122.36905,-403.414208,-521.084283,-600.859417,-565.873088,-493.021762,-479.457703,-433.256117,-357.481898,-308.118003,-177.58525,-127.258726,-113.96922,-131.964602,-150.725403,-113.755818,-93.743661,-121.436265,-153.269436,-129.029765,-52.416531,117.380705,162.457025,216.220513,246.82988,232.228842,113.601931,17.824054,-107.644929,-114.53947,-96.954074,-95.538849,-98.270724,-86.406617,-84.228378,-87.074362,-57.534514,41.158619,81.593015,159.414657,214.517853,244.278368,308.843487,307.145515,242.377185,215.130376,224.153909,278.669319,280.567068,239.699785,221.233785,228.225589,243.820707,209.550306,167.925677,124.306655,139.562935,160.960707,168.952933,117.141399,-10.689084,-7.040322,112.161768,112.598663,48.509749,0.278392,42.955602,40.665809,-55.762984,-207.096636,-165.815817,56.520095,134.425109,93.784421,-19.657549,-69.235213,-96.423876,-49.951302,85.931808,110.250667,56.548082,-64.328396,-76.378015,-31.005235,7.669769,107.001701,150.743906,170.053625,116.711643,95.04647,7.763843,-49.341002,-37.985449,20.551502,115.887163,166.488199,139.301051,-17.609356,-78.442941,-82.876521,-47.503618,10.436956,27.28767,95.108604,214.979903,263.379615,256.610353,211.545321,183.030312,230.329512,411.306405,506.385766,469.538351,371.906705,359.526278,368.504648,377.680481,407.392772,422.134737,467.769575,466.573132,409.010497,226.687051,153.582871,159.518235,205.924305,203.170702,66.107538,6.654577,21.005304,60.783797,38.944806,2.078756,40.766827,98.44534,85.749375,-150.91672,-256.838392,-314.082942,-288.675945,-191.15365,-150.849316,-174.252101,-230.999055,-236.275877,-237.126371,-248.31823,-275.967639,-266.289383,-162.898146,-76.779237,44.908522,-60.029593,-156.071498,-221.8861,-169.458059,-22.191149,25.420911,70.197667,77.062841,72.715085,92.659521,109.981516,116.993732,111.950149,64.379631,21.769359,3.090729,123.0374,187.678362,203.887471,137.665104,-74.241852,-141.448754,-38.187038,180.541459,200.014079,72.117815,-8.837566,-125.484285,-150.189254,-104.047763,-73.605212,-119.459238,-154.483601,-121.843638,-134.621906,-216.33273,-350.037584,-366.097025,-387.116479,-423.062465,-441.833523,-460.539283,-464.294443,-483.342123,-468.549838,-336.115401,-256.497566,-201.924484,-244.758486,-270.679614,-351.110411,-386.630136,-372.381778,-347.202968,-340.603371,-311.927006,-301.763613,-359.859577,-400.554144,-374.628024,-287.098737,-110.967883,-109.037457,-253.623525,-346.62079,-323.014313,-229.956595,-233.261809,-331.248283,-356.007404,-343.527467,-355.995351,-350.687741,-299.100217,-281.973242,-321.340158,-360.636602,-377.953844,-331.120358,-197.956866,-212.821511,-275.499885,-356.803983,-327.844849,-190.826202,-150.243618,-103.878584,3.029532,38.623207,11.403779,-26.457744,-75.578096,-82.805731,-60.770667,-21.051258,85.232727,69.512226,21.056567,-34.773112,-48.848944,-79.136233,-80.931594,-66.975128,-98.764891,-136.338991,-211.447122,-231.665858,-211.295818,-160.19904,-13.801824,22.135633,-46.896766,-172.044096,-217.165724,-263.409219,-258.805195,-193.519568,-165.480036,-147.85966,-45.53694,18.082912,11.349272,-61.915188,-206.530926,-207.64109,-56.459789,41.565112,184.284196,197.080836,162.608754,55.980246,1.677925,-21.806355,12.01595,61.604504,-1.422637,-81.200555,-217.971994,-225.386037,-189.927539,-181.253514,-152.294711,-137.670689,-142.597088,-146.924607,-136.939239,-103.276482,-97.713374,-137.570151,-172.679728,-192.879096,-103.017744,-67.633935,-60.716637,-77.637621,-110.192412,-87.19874,26.56366,79.667748,198.789978,272.502108,245.402108,192.970875,226.725393,324.752206,287.268464,21.506531,-111.17467,-77.086065,44.853536,101.303182,172.333429,184.149466,180.289892,164.797632,108.537893,2.642421,-48.047478,-81.984054,-81.445349,-54.315645,-23.068873,13.634008,-30.862478,-63.359918,-42.835054,11.614416,99.543536,98.288663,29.016887,11.008417,49.465016,79.073324,88.160662,99.43758,95.506259,109.869274,132.12883,181.538306,186.716809,157.132073,109.374711,102.963833,53.772617,17.667916,22.928279,74.220929:380.299598,354.17275,258.811127,82.367349,34.777125,49.408679,101.062831,174.852314,148.052218,114.879502,30.87995,-7.526949,-63.024958,-100.532097,-185.624785,-193.363947,-126.341007,-82.342945,-74.735382,-58.564069,-58.1837,-28.242403,-5.076118,3.369658,41.627438,51.84613,-52.203289,-142.520721,-266.404015,-271.086693,-204.575624,-157.447624,-55.770745,-14.715064,-25.03338,-79.061482,-119.028064,-129.114896,-73.74941,81.043979,179.263204,159.035132,-76.317735,-240.498009,-409.277212,-377.644067,-284.278985,-291.7787,-368.679674,-452.116754,-457.230153,-339.485765,-271.279353,-226.795566,-235.540951,-262.530558,-260.777365,-230.212529,-132.5713,-115.528477,-148.259174,-142.740461,-59.134934,-8.952837,96.020264,192.12948,197.38907,85.465341,0.483644,-120.243669,-136.313973,-90.337285,2.4636,17.816754,-12.042403,-20.703261,-28.969874,-13.497247,126.987201,222.255305,349.308822,365.85725,369.895826,412.467566,418.119231,365.565745,331.948876,326.72705,365.134569,343.386612,224.125582,180.344066,233.062568,300.893575,354.060849,347.861568,372.754078,342.803806,281.906553,131.128828,50.712925,-14.567536,32.64759,124.788106,30.192356,-53.047578,-142.305189,-136.559796,-134.49627,-161.291614,-216.206473,-210.480392,-80.369888,33.536655,4.692672,-162.772655,-209.879369,-120.904257,-51.552389,-14.738883,-58.23997,-88.744874,-152.214176,-162.328617,-82.620207,-12.078568,69.40597,77.546117,116.964398,119.175666,72.20049,-75.792632,-123.632081,-65.961071,-25.760343,-93.061701,-183.217632,-156.178711,-20.592874,-6.776771,-144.008778,-201.081857,-172.532574,-130.886739,-95.151903,-91.254678,-61.815254,-56.229646,-122.055216,-186.519022,-123.137189,54.646462,71.460341,17.149259,-37.763412,-4.680708,56.938829,55.220048,62.118243,103.295631,234.552869,257.322877,194.046647,6.53796,-47.241993,20.848999,88.002485,76.748681,-51.906314,-65.403098,-16.866746,-8.093455,-25.983015,-25.954013,4.168264,24.283637,13.440784,-137.527035,-220.777599,-275.085703,-257.23888,-218.467799,-220.859444,-271.523347,-340.826767,-375.343553,-411.728599,-410.585109,-380.106128,-340.103942,-203.405843,-117.560308,5.285842,-95.658947,-187.572407,-253.005477,-224.989369,-115.311706,-52.950981,24.106653,17.695756,34.625967,107.324842,94.083481,-15.576153,-34.736252,36.985685,74.234604,99.927727,156.819242,178.209726,67.707191,-62.715994,-265.322866,-261.804802,-105.491996,35.621215,56.10148,27.951584,6.230981,-56.674884,-89.893585,-72.858578,-29.052572,18.249781,-36.541161,-84.131286,-160.051832,-181.048804,-221.527023,-249.843911,-301.971816,-335.268171,-364.198138,-419.382424,-424.717609,-391.364061,-338.259915,-173.464021,-104.132689,-55.833529,-144.653353,-224.686988,-330.600858,-318.531176,-228.129429,-206.325324,-255.019058,-280.851692,-262.752749,-224.301533,-214.449894,-161.414781,-78.417944,117.054287,143.847436,58.975463,-56.353235,-85.790465,-98.354805,-114.438124,-153.810071,-164.14359,-206.722857,-272.443059,-275.113603,-184.506635,-132.889517,-116.003022,-130.783826,-123.225012,-93.151459,-21.879528,-76.818072,-150.333252,-279.18542,-314.794959,-266.658707,-176.774235,41.488489,134.423918,103.399414,8.745486,-14.854729,-21.210393,-18.281298,-43.212552,-59.091819,-25.226774,7.783993,-17.428284,-75.21195,-81.228322,-83.317182,-109.891836,-202.494364,-238.488547,-220.036875,-129.469694,-85.877005,-62.035927,-49.544445,41.831107,81.009379,28.176058,-103.628836,-128.954494,-129.160661,-128.196042,-91.071618,-65.951597,-44.113037,-0.341849,19.635891,26.908728,4.686301,-127.478479,-179.790959,-81.562108,27.451878,107.848285,-28.775266,-77.293754,-85.535253,-105.349595,-172.316442,-168.787239,-106.040483,-121.29365,-166.765196,-236.711633,-244.281141,-192.651908,-127.856524,20.172245,71.218437,90.101999,68.302906,105.203016,217.17462,204.810021,51.056298,-11.513792,-23.549283,69.29984,112.094436,132.57115,101.350274,-29.261425,-75.274436,-48.939371,7.510957,160.79876,252.137502,245.756914,178.996504,158.642767,176.365306,166.345995,6.21118,-146.451454,-140.002714,-17.618,52.329195,119.174702,96.119262,0.420997,-32.397129,-71.596675,-184.919623,-254.749814,-257.60642,-194.471233,-121.61383,-137.394161,-154.377447,-83.71238,-53.327418,-53.74618,-67.02723,-19.230047,44.223086,111.663314,102.966435,91.228793,126.640027,148.699959,96.857779,17.445306,-68.031242,-30.390423,102.227451,156.371082,136.078466,38.042544,-4.56196,-4.741102,41.735296,159.612634,199.31071:225.933039,352.130569,324.167187,134.980261,44.990878,15.472606,67.419198,183.338254,238.93897,235.087888,142.868879,54.134009,-156.618154,-231.762454,-259.498597,-235.884868,-170.590156,-108.163368,-94.863593,-117.985607,-121.869864,-51.141372,-0.16538,83.557948,187.496914,207.940509,28.615987,-126.735035,-278.682998,-246.970592,-162.361903,-150.18283,-152.146322,-162.358633,-152.030335,-125.23245,-124.337829,-123.328636,-106.822196,-28.899652,7.028589,-55.250207,-297.23479,-415.769687,-510.79354,-459.645302,-316.933375,-290.944339,-279.572552,-275.256235,-276.984315,-248.147389,-221.263279,-145.50367,-109.238706,-82.272326,-18.278359,38.805441,63.952814,8.703328,-91.610441,-76.962824,46.836304,111.752457,205.310967,215.241158,194.4944,111.544702,42.08199,-57.183638,-73.892918,-94.191606,-123.263215,-170.011247,-221.525805,-195.934928,-164.228465,-156.626749,-44.575927,42.180813,125.873782,94.113251,83.381435,68.709411,44.5072,-19.719393,-39.387628,-33.948376,45.43224,90.14461,77.394338,11.103388,-99.907997,-81.699194,-2.005607,-15.077972,-66.744299,-22.851061,-5.739952,-55.699415,-105.874078,-161.850918,-143.844564,-6.745033,141.893263,133.14093,6.972628,-32.39465,-55.062669,-54.539211,24.655812,99.753088,178.380693,118.649384,86.552939,13.590559,-41.451014,-49.433295,33.714058,201.349771,155.903945,89.483941,37.004138,50.49237,74.042364,93.879439,178.818131,203.657331,182.364384,217.054841,239.300408,152.537328,76.157176,73.953981,157.529997,353.566185,460.849807,437.522379,240.335276,122.762569,31.831095,64.501733,65.412746,8.248111,11.311241,184.382712,201.435904,62.076443,6.03498,63.603798,132.342827,243.117501,298.112858,255.016568,28.067251,-67.660571,-33.99714,76.229066,261.680665,289.065456,266.009466,206.335785,170.882038,42.78386,-39.095129,-48.581269,30.045544,150.85057,145.361473,132.484753,159.411587,185.126268,155.718703,125.683651,165.853339,210.03032,159.629879,-142.753738,-292.633655,-366.854993,-292.28412,-78.161328,-23.852745,-51.129376,-19.214648,-9.349544,-151.950028,-242.716774,-290.201515,-258.101019,-168.461363,-109.199687,9.845436,-11.363331,-77.938167,-184.06793,-175.849848,-41.846152,39.948111,115.59032,115.640406,102.8543,44.00324,42.034209,127.123176,158.522496,115.656993,81.567277,107.431465,213.752096,241.094238,163.67811,97.208027,75.563652,124.156784,210.830977,184.724436,150.068507,104.728297,46.793791,-171.18495,-231.820677,-168.56069,-128.986146,-116.257499,-79.994125,-57.174167,-57.601947,-76.587468,-101.58512,-106.809992,-146.941819,-238.869494,-287.625475,-336.152022,-327.338801,-266.105978,-225.099484,-114.780848,-50.928318,-16.118978,-153.867392,-235.501176,-319.281252,-308.001037,-230.951195,-211.615019,-244.909733,-277.913828,-265.365695,-236.491099,-263.746744,-321.012277,-272.385543,-65.350333,-19.298598,-159.132252,-303.284793,-283.883698,-190.693252,-177.890674,-200.848232,-217.535868,-300.010336,-332.193399,-284.306583,-225.874509,-268.726041,-381.378545,-382.235948,-293.817274,-220.650677,-48.773801,-49.450039,-128.468219,-289.007849,-325.055274,-254.863912,-169.56512,-46.065872,-16.202818,-9.336825,-47.714256,-92.411221,-143.828705,-124.163941,-29.613056,33.299568,160.619623,60.521047,-66.845188,-191.851093,-187.122545,-216.468475,-251.613929,-241.602775,-108.645096,-79.19786,-153.709153,-225.45978,-348.513193,-353.442103,-253.288599,-210.021586,-229.611185,-302.160415,-328.515106,-370.577656,-374.263294,-321.934873,-271.768458,-126.388312,2.987657,-4.358076,-135.996919,-186.597712,-184.618609,-141.469258,-33.234397,10.553387,65.685231,60.936467,49.899026,19.720498,-6.388168,-38.467163,-28.2369,28.375119,16.956321,-35.906166,-130.296409,-168.915856,-278.31185,-311.498325,-284.561602,-255.419952,-184.284682,-124.058199,-115.868443,-145.617721,-176.247918,-222.648458,-238.315337,-235.247134,-219.001142,-253.476837,-291.336932,-260.122634,-208.453931,-185.016097,-80.557521,-8.787602,117.395789,93.469662,54.678325,57.164084,92.592062,137.720035,109.816821,-11.439242,-52.657698,-42.656501,12.395732,61.531847,132.428999,124.259818,46.402945,16.73369,7.402213,-28.591674,-45.81435,-56.335192,-71.071216,-87.041266,-84.435985,-103.518913,-111.840199,-101.922455,-94.775096,-111.328368,-132.391347,-107.106091,-57.506016,-63.820086,-64.969929,-48.833726,-47.480794,3.545548,45.364375,116.361252,150.093807,205.326866,164.863743,110.198008,65.299521,77.375682,63.922526,56.727418,127.322631,169.374624:right
-244.209058,-201.02787,-199.544056,-218.371118,-231.941759,-312.796754,-377.654577,-383.123377,-156.138196,-20.901552,183.364849,217.012484,136.054528,78.3823,41.000126,49.344496,22.686872,-19.624163,-5.461582,-15.040522,-65.444426,-153.892463,-160.950602,-114.756788,-60.705637,-46.069411,-8.157429,6.875767,4.941219,-9.13016,-67.827017,-83.381432,32.094034,285.918584,392.954414,480.809413,445.003427,258.540295,187.759364,230.26166,337.305336,346.407003,270.587759,198.478103,83.257254,60.2881,-1.433923,-52.039235,-152.793188,-211.439987,-196.70329,-123.47206,-102.354074,-112.907433,-130.880292,-153.448737,-180.468179,-183.282029,-115.320821,-55.159763,73.155914,115.601737,140.00805,144.557774,152.930797,170.921647,187.745472,181.475556,162.192338,171.420711,199.716899,256.548222,286.108585,300.414568,371.113928,389.706285,285.533177,189.388199,87.320779,111.84058,159.535745,84.08254,77.777227,209.871029,277.599969,227.089608,123.674855,-3.015113,91.689861,159.604944,231.419643,231.648055,188.567441,155.527079,109.371177,124.588594,183.758445,206.377147,250.966344,392.844153,432.555913,407.005409,391.267896,413.978681,342.220437,277.464763,247.729962,273.510814,244.960848,148.021545,-70.532501,-89.378297,52.381884,186.837358,216.718607,220.665062,193.746285,93.610495,52.376249,62.001231,153.730574,202.429023,249.293573,216.704281,56.706777,-16.976373,-7.105553,70.49818,191.219988,239.370481,257.756695,218.637172,155.732322,14.968085,-22.338398,44.392479,165.369989,177.869129,175.813137,194.963119,239.288632,228.667273,124.815409,84.016448,86.967608,103.951858,105.327594,73.345095,36.324744,-44.516615,-75.02884,-69.488865,62.321124,162.42433,312.385681,317.566518,240.846478,198.518365,141.953401,135.547053,133.513371,211.894387,278.414529,231.456973,132.814552,22.231143,12.371962,30.618729,109.265216,138.629013,137.084512,125.404174,104.045239,85.807051,42.464419,32.588588,35.545191,25.256874,0.319245,-84.760016,-132.41633,-223.647857,-255.361173,-226.895557,-61.356349,34.150587,143.435226,133.635558,15.124808,-61.308827,-134.844068,-89.426597,66.436242,108.506815,104.384133,61.291967,16.667799,-60.692993,-85.134182,-155.889854,-267.733252,-292.122137,-197.283669,-126.371766,-99.765607,-131.547523,-152.665208,-129.900428,-120.077674,-184.886833,-198.1236,-162.381004,-150.715961,-216.463803,-267.529431,-301.50332,-249.207291,-192.97328,-82.390915,-80.323289,-136.949501,-139.530805,-137.739167,-172.601266,-237.626042,-186.35827,-157.873882,-221.201481,-297.838194,-388.464694,-388.352873,-379.011706,-339.904112,-285.313773,-173.529931,-141.525298,-106.707338,-118.451712,-214.312128,-230.134817,-111.734472,-6.533321,-18.528269,-122.998212,-190.344181,-342.771857,-405.929869,-402.125448,-269.270063,-225.422606,-217.617599,-222.31703,-247.481558,-300.750249,-420.06353,-402.16793,-228.932191,-140.902666,-153.079893,-191.489325,-184.005411,-130.456948,-102.716102,-72.590318,-108.007292,-111.39813,-34.149542,13.66118,45.646105,18.799109,-90.086418,-140.930777,-200.222515,-169.996108,-143.318743,-179.252796,-223.67355,-242.35867,-203.781807,-123.550783,-213.305072,-291.164817,-329.729374,-300.974643,-273.264688,-281.4655,-286.513868,-275.937962,-239.767491,-178.516617,-148.781723,-127.73671,-127.221672,-112.372155,-85.6156,67.986214,222.87215,218.033453,96.242366,51.951329,73.258442,77.870928,-24.611362,-64.051023,6.861031,111.299709,120.447071,65.716032,16.446004,-101.624331,-151.726943,-177.139965,-161.05473,-157.733438,-121.977807,-108.557632,-150.096015,-189.464286,-240.271125,-251.437867,-273.307537,-223.471618,-178.082757,-181.189526,-241.861343,-364.296768,-378.530731,-278.991228,-133.773677,-97.060391,-86.851871,-107.382416,-140.749244,-126.795544,-73.830477,-36.391222,65.947037,110.193034,106.420859,78.753941,50.914799,-42.122447,-84.267088,-103.781358,-149.296752,-184.600624,-130.825758,-63.317919,-29.256681,-74.692153,-174.211355,-176.942201,-97.876388,-17.772431,37.134272,156.525277,169.116872,72.936577,4.922147,-44.910854,95.607469,200.321016,337.119208,355.477002,324.937901,278.164742,149.901978,97.771407,53.005132,105.863181,159.675782,205.571134,179.458331,97.506477,69.349956,57.927361,39.31634,19.833927,38.818429,78.103548,133.46865,118.886444,51.153054,58.204506,147.49019,254.489188,322.149398,354.106682,289.349219,135.096812,113.647858,192.823755,253.312648,258.063071,284.622761,300.338408,288.488623,252.510817,139.312808,100.046677:-149.779126,-247.266818,-305.084017,-373.782365,-384.950284,-444.10126,-489.91601,-464.432148,-248.509792,-141.187813,-15.642247,20.373785,63.879577,41.276252,-47.468088,-48.167693,2.457033,-14.49871,-33.15706,-55.307089,-59.611963,-86.603578,-98.696173,-73.903558,-15.231205,22.010547,57.902013,39.176964,-6.058466,-13.505647,9.649663,70.001761,237.696881,332.85239,362.047247,345.616243,272.689367,83.222156,48.061288,128.479956,144.384426,102.684646,65.065819,84.648555,88.475929,30.649371,-143.099911,-190.116956,-194.446143,-212.31851,-215.679927,-163.968542,-126.737415,-99.168479,-110.021214,-148.298714,-157.260471,-135.81566,-77.440017,-45.619051,40.931241,70.047945,80.879602,101.851379,170.38775,170.968271,144.94031,82.738588,67.623497,90.684277,118.821532,202.859917,225.106441,186.670187,141.773921,164.284499,170.721974,120.076035,68.866555,107.850852,138.021125,70.830363,62.273827,95.165998,116.24632,134.962813,133.414373,135.109563,141.142764,145.706893,157.722636,146.229551,71.296954,26.367467,-13.5032,-3.561829,14.348649,55.449597,87.393547,95.967196,84.523494,101.7731,123.667766,136.966161,50.697182,16.727911,72.820478,126.400094,150.958915,95.866772,-51.084037,-72.665763,-21.188328,46.153732,63.501046,5.939049,-44.271173,-70.00244,-24.869338,142.95949,254.636951,257.528685,192.542093,150.82253,96.076325,70.378611,29.225047,48.610299,125.244305,140.626272,115.209411,26.067137,6.963799,64.638342,106.860796,132.592522,127.851182,154.166102,216.234347,201.761712,89.626199,35.474729,12.823898,42.205329,95.601194,96.706901,82.312194,21.793715,-10.8156,-55.70088,-62.932498,4.105098,158.700913,226.709027,307.432989,308.10226,214.310147,131.340767,-16.123542,-33.043238,60.961739,241.468398,311.766536,282.620664,190.086603,5.605989,-35.721319,3.873474,90.387786,106.757287,77.844577,56.679202,55.802466,65.468391,93.17972,111.81828,87.318672,-16.078886,-52.517871,-87.370619,-100.516057,-163.181801,-214.747926,-229.466512,-56.582522,38.788722,128.066961,113.936158,12.424641,-53.694778,-142.09337,-137.613433,-78.342678,-14.034621,12.860308,-11.120494,-64.702634,-183.317067,-226.656757,-288.249551,-317.179002,-283.168166,-131.846846,-79.383622,-114.950366,-165.100704,-182.145438,-159.631475,-198.696193,-263.279919,-229.710573,-103.6995,-69.327948,-89.95382,-129.607429,-186.657463,-108.926784,-22.642422,66.310408,10.159861,-171.433263,-219.845245,-251.70589,-276.073401,-341.822545,-292.64089,-223.921934,-174.261083,-227.611006,-364.694993,-377.876022,-307.021382,-313.421843,-330.378832,-264.124462,-216.176634,-201.468649,-221.360999,-233.156815,-199.429937,-85.375172,-30.48098,-38.893458,-135.675272,-223.405245,-384.564893,-408.166446,-328.518596,-272.815672,-284.199117,-311.956146,-321.206715,-329.084143,-333.905092,-350.680223,-329.222052,-214.923833,-150.277296,-164.184362,-255.982609,-307.128051,-331.746773,-279.96676,-144.719972,-148.606287,-144.968694,-37.577088,1.983519,-37.009243,-77.709973,-106.286253,-107.795265,-143.900626,-149.853603,-128.739466,-88.147289,-71.812636,-79.015975,-104.575564,-119.181492,-110.167964,-126.942865,-124.210591,-85.990326,-44.949495,-65.917258,-115.348567,-128.478406,-139.726403,-88.111024,-45.407147,3.667852,8.616111,-16.877179,-22.104391,85.993308,220.045506,236.921988,175.75163,128.850251,102.977928,121.211368,145.292843,136.137496,108.96074,143.745498,162.80637,161.223684,149.437831,47.738415,-34.824529,-101.483648,-53.573435,-25.537911,47.350832,67.530283,-21.965944,-128.333964,-293.698304,-285.956008,-148.291657,-73.182525,-81.394178,-162.975264,-223.486992,-255.498461,-192.491521,-45.104656,-24.46504,-21.045717,8.084952,-2.269705,-85.309002,-114.486448,-50.617076,24.255402,118.934631,109.61021,94.188311,20.941574,-29.925658,-90.650156,-73.708875,15.147011,-59.738572,-138.63225,-118.963947,-25.754655,58.011325,3.990818,-92.527393,-61.07608,29.634016,71.461025,137.336823,292.270117,306.565145,215.46628,189.389512,248.821414,297.981661,317.972034,381.826747,397.521384,356.906618,323.154642,279.942736,254.973449,205.941586,237.61703,254.620654,223.800323,208.883265,250.963291,283.342387,296.252974,252.728037,243.276813,254.335825,242.594751,156.834937,113.205906,100.519939,133.544406,228.164678,324.735217,365.407955,355.934897,304.00648,187.466173,152.417241,181.929176,305.660611,360.135597,415.949572,405.091079,293.830385,222.371714,151.041329,169.564088:-19.665268,-93.987823,-131.066724,-211.37077,-253.560146,-336.650835,-358.890128,-319.654596,-198.095638,-121.160371,-39.89199,-49.401995,-64.436831,-48.555826,-8.871308,-1.858298,9.832987,57.195166,49.222577,-63.534479,-125.021437,-177.591649,-155.439226,-65.684539,-23.35709,-23.20286,-46.409999,-65.503784,-102.107143,-109.429615,-72.555507,-29.911205,41.477336,142.62595,213.747466,272.542149,224.560657,34.480096,-17.806011,49.068795,113.672617,106.614909,47.045576,17.98963,1.652358,-13.456318,-97.490927,-138.332968,-168.897776,-147.858829,-145.036315,-209.907669,-254.807219,-266.212839,-228.920897,-156.559311,-116.349604,-93.558099,-77.853699,-90.883491,-82.034547,-42.724819,47.000367,71.322299,78.539388,52.159467,20.918826,-30.9796,-39.619009,-52.911815,-50.102006,13.784067,102.119336,126.861389,95.477029,43.516649,-50.527208,-65.678358,-24.662434,19.817292,91.122265,100.135715,96.039963,87.491748,74.079108,33.87795,40.253936,135.117767,205.288835,192.408417,83.945432,31.760445,6.154078,5.010866,-31.991125,-47.360217,-6.472058,94.244744,113.690797,82.456377,64.041719,43.568278,48.488115,82.238668,83.662975,85.903251,114.517391,122.098803,93.419964,42.605806,-91.500107,-116.164789,-42.439675,72.365218,102.842502,54.602341,-18.451797,-141.477872,-127.824912,67.870982,238.879956,256.871678,172.061581,96.577248,-6.023562,-18.163179,9.136594,26.014626,-8.547731,-40.512827,-23.025302,-7.184842,-21.705194,-26.538243,11.454128,129.758823,163.323744,166.20603,186.890041,171.187239,61.315523,3.650518,-13.302607,33.307491,124.348635,118.605918,95.918682,26.198562,-18.33839,-81.981868,-77.094706,45.04783,190.678405,217.216853,214.192595,209.804909,150.310837,67.877455,-71.698446,-58.309377,94.25665,245.184207,285.52498,255.723797,177.721202,-29.143246,-81.025913,5.817653,95.289691,76.878067,29.624973,42.546909,106.272549,115.285343,85.226473,82.233549,102.244998,63.139105,16.978664,-62.754496,-77.589646,-74.155404,-55.926888,15.10215,67.491857,94.555022,165.97404,175.635056,129.671074,85.636735,-43.833861,-86.317424,-37.660172,57.344106,73.074405,20.577455,-34.081745,-87.402603,-69.402214,-61.161306,-144.734646,-157.751853,-53.66913,3.13102,-46.311867,-133.36689,-216.299331,-173.356894,-48.214518,-35.79292,-57.330322,-92.411146,-97.910286,-56.160989,-12.712934,75.144764,147.313492,171.606263,135.381086,68.398026,-71.443208,-129.795024,-216.930309,-227.17684,-204.167472,-177.951579,-159.647423,-131.509804,-157.664235,-287.348998,-329.692891,-292.391236,-179.03746,-122.774623,-65.724341,-94.965544,-214.509479,-251.332609,-206.481115,-124.853027,63.426896,142.457001,115.256116,5.999522,-31.895971,-108.258218,-158.355193,-226.24476,-209.018813,-173.080158,-153.516385,-181.449547,-215.922391,-223.273529,-272.737591,-282.629236,-187.334545,-86.27992,-98.795477,-175.993319,-195.45609,-199.809373,-186.412522,-145.216575,-163.235082,-168.251276,-122.458113,-101.983323,-112.524686,-133.260981,-176.624696,-193.574614,-192.330523,-122.903707,-94.967933,-104.825459,-128.185957,-170.050397,-166.944823,-80.16859,16.870418,35.825557,28.004005,11.554094,-36.279263,-68.855673,-108.330196,-94.88557,-35.083904,-11.597986,-38.258544,-119.308768,-107.852917,-21.989301,-9.778803,29.501522,172.613241,235.56269,239.728066,179.358223,62.338148,52.250918,86.055654,88.349944,52.89263,75.105044,116.204325,175.040101,148.484935,-41.61337,-108.811208,17.494089,192.872502,185.670383,51.869492,-13.897482,-118.561918,-182.039046,-236.876147,-186.33764,-51.857104,19.07491,25.975679,-99.974032,-201.10757,-232.101028,-136.478653,30.717124,11.426447,8.994339,57.42327,69.40417,55.998878,37.334244,45.458525,107.177104,232.468949,207.740873,177.751677,125.153872,81.792416,-47.355812,-111.306421,-179.286209,-174.839162,-170.974405,-171.376036,-144.691221,-24.292565,10.328461,-26.183753,-42.587231,7.958012,91.623412,128.364122,174.836615,165.561265,114.510956,126.826547,217.652527,254.204828,290.754915,419.205169,427.576321,287.361674,226.873307,227.030057,231.791508,159.808757,131.347661,141.517561,106.982112,72.366019,29.522626,24.936419,52.47996,130.007383,185.447573,262.143496,251.033694,152.333097,102.119022,67.513508,78.153889,99.716958,150.000161,198.253495,249.452341,208.635023,49.236387,11.044039,94.779272,239.783581,298.609758,349.440719,330.875693,241.764408,191.721704,138.559519,139.277132:-142.031161,-170.604038,-143.161266,-66.661011,-60.086865,-159.986086,-233.081584,-272.913153,-153.820111,-45.485878,166.599647,200.118827,109.188711,32.342809,-92.216085,-126.27045,-135.097817,-68.337745,-32.567247,-29.90346,-60.063258,-135.206126,-160.128504,-139.53296,-81.411068,-50.35004,11.869189,20.496536,-30.43145,-89.675311,-171.132055,-140.167466,-19.507499,114.259946,224.793594,382.921996,356.499099,190.064254,140.566696,200.397861,315.041466,329.325539,269.021224,220.443398,122.415752,55.244046,-87.251733,-122.105073,-146.513824,-177.519648,-175.938337,-128.737784,-109.627688,-144.27113,-194.014598,-256.784532,-205.080328,-154.838209,-73.548255,-58.90591,-26.750585,15.419005,130.614931,178.865761,203.438567,192.390607,202.238206,208.037513,188.194595,114.210689,86.478447,105.499265,119.12174,114.364232,131.141063,134.281924,92.266907,56.560656,38.099908,72.645668,137.113847,125.201346,122.219526,144.799987,149.241103,98.210065,50.61174,18.2692,103.970675,154.133509,178.332276,133.256685,19.308436,-2.510589,16.813846,35.613415,94.064439,234.78767,305.124498,318.188876,265.291714,160.52004,147.725849,188.429691,220.602665,242.440154,303.19843,307.385192,221.691109,149.770567,38.79421,32.201965,91.545009,159.256255,170.690559,131.69247,89.489486,-18.202723,-65.615453,-87.851973,12.358308,103.402548,262.211519,272.894661,157.623242,82.390363,55.685817,114.938691,215.386504,228.791113,226.077702,161.491846,99.838478,18.811797,30.690259,129.424576,215.335997,231.220228,238.95435,238.482265,183.765099,118.754908,27.733032,52.009688,136.581173,104.740578,77.363116,60.112282,55.081405,14.889685,-16.525302,-14.202078,130.91279,208.263807,255.615186,226.12274,129.815612,73.086254,18.125145,56.168179,168.455288,204.494104,210.956033,170.795702,110.625197,10.74217,6.47489,82.823115,143.857965,139.182885,127.89643,128.870098,82.658597,33.330824,-27.004859,-21.578717,-30.067975,-75.682195,-76.251611,-76.60039,-96.431743,-146.619082,-146.02245,-55.997952,99.174957,187.116235,309.98161,296.548823,175.119248,135.992464,144.822138,167.803022,182.203601,146.372012,121.94725,35.793508,-6.633354,-22.572463,-22.330638,-75.868385,-125.616521,-93.944287,70.765236,126.681749,70.786237,-6.62687,-109.832549,-111.572446,-109.460362,-159.525312,-157.740247,-59.083771,-3.284778,8.077652,-28.070381,-78.185702,-16.155401,65.305162,219.503839,223.845275,84.528443,-8.508727,-117.836793,-124.927336,-118.2563,-90.671412,-82.632261,-192.87586,-283.398599,-351.933849,-326.572084,-260.876874,-216.6235,-190.94996,-151.91593,-148.455033,-152.030293,-175.20457,-248.33757,-220.436616,-16.122441,99.103645,82.973296,-16.34558,-70.243629,-156.032674,-176.656602,-149.990309,-100.112686,-94.618657,-117.328974,-133.670888,-132.465051,-121.878024,-131.809309,-138.604788,-125.598048,-107.064777,-96.650104,-67.834925,-46.476191,-28.271617,-36.990986,-49.567747,-54.546765,-33.291221,55.448319,78.383797,53.471097,25.656037,-50.579957,-83.951929,-111.028422,-155.807473,-197.275679,-262.891779,-276.11263,-297.245438,-283.875022,-155.561954,-148.225545,-224.203047,-297.013658,-266.349318,-203.455775,-202.70635,-228.539525,-216.640187,-110.019196,-47.331211,-80.927446,-199.851279,-220.450308,-138.195228,-83.017409,-10.278652,93.591542,151.560743,161.25762,107.047956,34.485358,43.449609,53.026654,29.642087,-52.982955,-42.567288,16.590154,84.806363,49.199542,-111.958748,-176.408211,-172.825098,-77.486609,-37.738262,1.674768,5.267249,-19.618475,-81.576785,-276.359391,-318.87856,-231.894255,-155.217334,-161.356543,-205.894151,-233.86699,-290.776694,-292.043666,-188.944833,-54.26634,3.601733,92.904062,82.593973,-39.979993,-86.68285,-91.824135,-67.395954,-1.898111,12.315518,3.825263,-0.78439,-5.448311,-77.644582,-145.206209,-250.475064,-269.726182,-247.600709,-138.582077,-81.373899,-76.516989,-150.96897,-333.230419,-353.409624,-214.530834,-56.516246,-18.798634,34.418032,64.39703,49.256467,-0.166416,-26.76244,126.82774,209.262663,265.20292,247.500034,174.767875,134.841925,103.867389,113.810966,105.648638,120.589176,158.183238,166.99638,130.097304,34.072664,-19.112385,-80.631718,-41.885792,-21.294004,-19.298768,-21.254382,-25.185321,-49.014781,-93.753908,-68.323752,50.825937,157.017573,197.266258,224.080067,189.206455,69.083316,49.439826,145.024496,245.94228,266.270861,299.820336,307.238618,261.217203,223.615079,180.541278,167.917499:-24.883683,-89.876375,-93.577766,-85.200748,-80.646378,-80.076209,-52.172473,103.683556,206.296359,218.172761,250.502719,252.652149,133.755169,19.033584,-146.20498,-149.438824,-95.411721,6.310786,60.174017,16.825405,-79.035899,-251.441594,-264.669589,-174.539624,-121.317858,-97.843795,-39.379324,-40.810836,-111.186441,-158.318927,-200.65565,-173.802699,-39.402883,149.201626,218.979556,240.79721,210.216196,121.706864,102.970517,190.26874,322.935017,373.496592,385.573165,313.956433,91.081883,-5.160972,-115.648524,-133.860329,-159.557099,-215.985279,-241.113103,-242.885697,-236.940488,-281.121351,-304.977059,-278.064226,-203.14395,-150.206856,-68.528439,-89.765632,-177.987096,-166.617849,-37.917586,31.407239,150.621403,248.074753,249.116764,103.60363,-9.668249,-163.381151,-160.1899,-48.188554,33.551905,46.795928,16.596403,-28.805749,-123.712237,-158.947451,-182.90115,-159.379209,-65.938858,66.226021,117.977451,94.592622,26.804319,-95.933238,-97.911003,24.56215,142.712572,167.615646,161.921152,133.868412,35.734945,-27.375795,-98.824126,-74.599249,58.233941,245.547176,323.786242,337.93648,281.281886,128.086223,89.091328,159.942176,222.119705,228.505144,269.360821,270.001474,128.797392,32.223073,17.308751,82.211569,121.84618,59.565903,28.297505,-47.502767,-79.601031,-107.808939,-114.057949,-105.045414,30.811432,142.656294,246.818264,187.814893,-20.43754,-71.278358,33.192444,117.592855,158.781605,131.598407,126.846317,64.051749,-4.495191,-144.423184,-150.171919,26.805763,187.371577,197.077023,160.916372,143.273886,88.715953,32.677767,-62.402765,-44.476214,55.199212,99.572838,115.586882,84.803294,13.570265,-132.543856,-140.770722,4.533563,180.10896,226.961144,226.925282,180.026237,37.833144,-35.510372,-113.652354,-90.077624,26.223722,126.165122,153.072122,91.633271,-6.260669,-160.538064,-125.849453,83.60247,143.766237,117.133424,107.187167,123.547632,78.912342,10.827797,-50.116046,-8.964265,80.834464,91.757897,78.979401,-0.884016,-47.124705,-61.559844,-22.119088,122.323604,262.355841,298.566422,281.784012,226.551076,123.744581,120.70499,195.36041,233.348537,250.539071,253.757571,241.815227,119.768608,36.383584,-59.831147,-66.441639,-31.772212,31.365205,52.79079,69.872971,83.240684,88.667024,49.406907,-42.514326,-50.420699,-1.382574,88.165298,114.288017,72.897869,35.493629,11.795495,23.381186,76.952878,196.464187,270.519749,323.096899,273.777731,117.461672,48.873314,-21.852159,-17.707056,0.931726,6.826412,12.414731,-59.678519,-138.453215,-227.121316,-206.139301,-103.553252,-12.286504,18.372382,27.898719,13.697736,-25.54418,-62.115301,-102.180054,-44.779753,180.059905,276.340484,238.162482,122.190418,88.913393,18.591225,-25.293969,-77.187691,-94.892042,-79.879974,12.311332,47.254807,0.196953,-78.717107,-241.861828,-258.018109,-101.698578,113.977717,139.52984,1.357943,-88.090192,-163.457842,-147.76648,-79.744382,-56.401604,-45.945047,11.450792,43.255681,63.121371,36.204701,-64.889383,-109.438334,-139.24105,-105.562698,-104.140982,-193.055843,-245.573502,-268.669404,-243.722212,-163.741792,-144.902935,-151.258784,-121.758785,-88.87994,-50.234381,-78.881399,-146.585159,-109.978297,39.460553,69.262568,42.456068,-26.173616,-57.62887,-98.066091,-84.894555,35.915452,201.369989,274.520933,303.846755,242.877462,81.373379,22.650806,4.492138,40.647583,92.51063,94.496313,107.249072,104.25153,49.594364,-119.764297,-163.834192,-122.972125,-16.244559,54.566257,113.619052,61.820484,-58.456113,-82.182131,-105.767708,-107.33883,-56.32303,25.658215,38.391667,-49.029748,-115.425667,-187.257221,-182.858251,-84.146546,99.963302,188.170303,235.36562,166.406607,-9.545783,-46.612888,-25.843563,6.204323,67.582538,96.93526,101.353698,59.979561,6.19361,-129.354942,-184.311544,-219.550778,-203.316139,-198.553683,-197.030716,-203.950979,-230.523205,-247.793831,-264.357473,-243.788726,-138.888572,-29.544446,-10.51051,-25.768784,-45.99143,-102.456866,-114.272943,-58.486079,77.04883,155.631364,258.631664,256.192909,135.42793,41.764765,-67.706119,-41.564639,77.87466,96.091348,55.465401,-24.917546,-48.88559,-138.162677,-184.637219,-152.030544,-35.811505,-10.975115,-30.289667,-43.968674,-79.956898,-120.431994,-144.127303,-81.509586,94.615619,173.968998,186.573137,175.385183,132.576779,5.286138,-20.961487,49.073319,161.645414,219.769143,299.702048,283.884924,157.108892,99.991639,123.806993,183.644538:-175.842093,-134.33907,-115.869627,-42.203589,-6.780635,-26.09721,-65.518262,-56.964872,103.383437,173.190589,216.452354,202.041536,131.792555,91.227004,-11.050616,-88.464059,-214.469889,-141.621983,-67.624608,-49.265095,-102.369057,-195.229997,-217.367352,-236.772638,-213.490639,-162.210607,-7.95664,30.732614,-20.490415,-76.879133,-185.572471,-203.646642,-102.281456,137.173688,263.072838,388.031678,367.88049,293.392251,298.937905,400.462331,441.010634,383.23142,204.861094,147.317914,86.338598,29.399886,-116.420747,-146.214797,-156.878551,-211.726205,-223.157872,-191.879911,-184.466339,-271.853466,-347.608694,-391.005525,-276.81887,-224.947187,-164.197499,-121.578128,38.986406,121.859993,198.285339,193.487074,179.83731,255.291505,297.580168,277.503596,221.392915,110.342343,75.008469,65.091314,157.524132,224.883539,283.318639,241.40554,82.935894,23.194348,22.257787,78.87651,189.506229,138.500957,93.686178,118.264306,175.203118,187.880881,102.672263,-50.310068,64.197006,159.082984,201.630998,133.329373,20.127785,46.088994,164.577763,210.104447,253.446373,277.449683,319.671579,432.604382,469.358958,466.592825,442.113191,410.935309,386.283138,373.18759,371.733766,365.121484,278.787572,197.145946,40.995349,27.798112,143.060847,268.536129,290.561337,223.569802,156.13698,9.382048,-66.637419,-144.545596,-24.645575,94.244017,302.744069,325.672431,168.222521,56.464552,30.661755,129.866012,317.468162,395.976524,417.171567,331.711384,216.408192,3.921603,-12.255917,152.644438,274.77671,270.120277,221.149905,184.125653,117.872348,112.62999,126.063972,116.236451,81.506667,123.552082,143.181491,63.294958,-16.570882,-127.770791,-127.091739,-41.20427,14.839012,46.65329,187.077916,245.763208,216.346577,151.758574,89.126276,114.864064,136.35668,108.822822,120.616556,107.100237,80.473621,51.755266,28.079373,-8.823626,106.591668,168.585512,139.215648,88.538882,77.354227,93.031326,47.308257,2.429122,-64.639035,-62.131849,-34.724599,-40.150731,-81.851092,-137.315311,-127.365432,-35.461947,101.093348,172.766453,278.307107,276.252336,203.622413,177.079376,157.488903,173.25744,253.262359,247.467665,192.555696,76.700884,53.886124,37.267787,-5.573777,-145.876693,-173.831097,-112.159711,74.662741,110.11746,-3.976495,-70.511696,-83.75437,-58.038123,-57.934247,-122.244115,-126.953572,-54.74218,-14.456986,-41.556811,-108.544491,-181.852906,-78.081497,-16.399095,29.855262,15.796622,-44.129867,-64.50844,-45.72157,-13.946184,29.771123,-2.927197,-44.846534,-193.195546,-258.166881,-232.804917,-178.521961,-105.287943,-76.468452,-77.736414,-62.309159,-23.729739,70.001076,82.204049,23.072926,6.927719,76.408062,114.965369,83.069664,13.021836,11.760842,32.790224,19.467583,-16.110252,72.982543,141.7904,201.194935,193.994163,157.113993,102.822065,-67.885394,-104.375695,-17.324641,32.133679,0.878607,-21.962594,30.298788,114.08568,83.032354,8.951417,66.017249,111.054572,169.642562,192.408861,203.815375,153.471859,-30.689864,-92.277071,-87.066854,-48.78106,-48.545865,-94.299362,-138.085251,-219.06819,-213.458132,-84.23499,-131.359616,-277.083709,-486.638278,-486.007445,-410.054432,-371.024453,-258.595102,-188.206793,-98.658419,-62.932722,-60.615674,-137.997923,-184.440587,-182.675053,-139.022487,-18.608312,50.856363,53.120863,54.344021,54.785378,35.310883,-0.213182,-102.202605,-103.494489,-20.897175,-43.991451,-79.698976,-115.98102,-119.237056,-117.581941,-111.920437,-71.828082,-52.632656,-64.005511,-63.121355,-51.643369,-56.210779,-90.012363,-215.770103,-262.479523,-260.45855,-214.546963,-203.207866,-243.340866,-288.647435,-351.9536,-340.157965,-208.291513,-35.434923,28.365473,79.054668,53.358346,-12.040241,-9.279368,11.963576,6.008032,-2.223723,31.84267,52.563731,51.275751,30.934173,-30.601609,-91.307828,-254.367714,-316.582489,-277.485378,-111.313893,-57.147885,-145.245315,-256.481234,-422.368366,-414.101571,-260.687631,-154.16733,-132.651454,-82.961878,-57.878712,-54.118082,-86.631868,-161.931464,-121.422728,-63.790308,81.65691,136.496936,111.977917,49.229243,-65.703248,-83.30628,-19.788668,59.055423,66.968972,7.247143,-33.276112,-66.76037,-81.059361,-143.359278,-190.229918,-199.819693,-189.701116,-150.580269,-25.993603,-7.246042,-59.193976,-50.958083,24.956863,54.392561,86.939386,158.135381,135.936509,13.912926,-6.151812,62.647987,66.675385,42.97888,74.882124,109.347817,100.463009,53.910586,-35.614405,-44.446605:-62.060053,-56.977663,-102.672333,-78.483976,-15.67283,-17.456726,-79.435208,-66.586294,143.441287,235.726845,306.180947,272.504593,92.858925,-9.003941,-142.655697,-166.463259,-124.541476,20.848644,71.581185,-1.852197,-104.822413,-272.713173,-290.012718,-220.811156,-88.602146,-5.592777,80.677461,54.836608,-58.589792,-125.065667,-225.847212,-228.82063,-113.347937,141.471528,257.770136,322.980928,279.822134,170.42474,161.496289,259.948291,384.691251,421.969976,372.292644,283.614859,68.298383,-34.468033,-185.904232,-217.377597,-184.869372,-94.559899,-81.403077,-144.30094,-195.097566,-303.782632,-347.721555,-339.688733,-198.799941,-112.006678,-13.215531,-25.113996,-84.974513,-84.368587,10.204679,104.351642,308.71888,370.926304,342.524167,228.02718,157.60589,-13.670556,-87.468414,-77.47673,67.129066,123.905346,181.401287,175.44499,70.726899,-11.131049,-91.622836,-47.280218,113.778731,209.886607,224.042775,169.828443,102.473117,-52.482393,-94.814981,-21.512964,133.088531,165.500008,137.663724,108.874285,57.242078,35.766917,57.55317,106.894145,215.268982,354.788566,429.912634,430.303546,343.824827,175.887353,151.545315,223.855925,343.758354,395.661745,464.3016,451.273659,309.849253,206.014968,64.650783,74.746803,195.28984,273.585974,263.400585,140.662564,52.36014,-97.252496,-142.598615,-166.942223,-86.791354,19.388028,252.237523,267.168129,82.224559,8.399329,85.355801,182.361858,316.270765,351.703247,317.126428,138.247542,47.672832,-17.729374,10.536678,92.34129,148.601846,214.458704,329.028855,285.42001,71.938943,-2.219833,-37.603423,-18.694553,50.266279,74.207713,43.361343,-59.886357,-99.630035,-162.285413,-185.044583,-128.967119,52.517497,135.391676,183.627901,146.345179,27.101184,-32.947674,-83.145663,-49.839459,25.31109,41.812894,62.092193,65.963319,18.304452,-116.626031,-151.975592,-80.701852,78.115586,140.759165,216.892145,220.625018,124.243387,34.179275,-68.964578,-32.841198,77.563678,93.302484,86.540111,20.991467,-30.837857,-93.509852,-87.859239,54.270741,299.393239,384.971972,417.447764,368.603516,231.184542,184.314092,158.402626,178.385008,277.480469,324.924028,274.546339,96.634761,35.733995,-5.959694,-22.824172,-56.618049,26.899752,111.296656,191.18061,153.129335,25.038377,-30.039992,-107.751127,-106.34127,-10.486181,55.229845,53.210971,23.05447,5.982642,-37.141201,-59.101204,-39.172165,119.890418,227.831739,321.075877,276.120763,128.899731,67.818184,12.171617,33.037642,112.946356,129.775433,100.560921,-43.123986,-130.825063,-222.792717,-209.305286,-123.306342,-67.002026,-45.60869,-6.170314,5.752725,12.463514,-6.744273,-52.722772,-20.765305,133.793511,190.00627,163.395248,83.777298,49.816973,-12.517331,-32.141218,-17.796993,51.931437,93.804921,151.568091,160.410999,135.676664,85.184376,-38.349873,-48.535763,31.044009,71.443884,55.209098,-7.890298,-30.018343,-30.62743,-13.574089,26.080911,46.314811,81.856635,213.265196,265.016489,237.090307,134.554801,-125.821782,-173.468224,-63.550182,31.97577,11.993048,-138.370911,-226.450219,-291.778698,-249.568381,-120.132722,-114.903914,-159.106885,-220.442093,-224.035282,-247.080677,-276.918039,-281.521449,-230.604834,-82.605822,38.572563,63.380782,15.963294,-45.934988,-159.902982,-156.23586,8.054413,180.903281,216.17647,173.706288,107.200054,0.149348,-27.583728,-66.486715,-59.999444,8.018984,64.492327,66.065315,6.16376,-29.613433,-86.074955,-118.011577,-141.404793,-46.94234,12.211686,27.865103,-16.002908,-125.901686,-193.556643,-300.590819,-286.678326,-147.043546,3.091663,35.709529,-48.332567,-126.11556,-228.294249,-237.655439,-139.935159,93.047413,201.653527,242.274138,171.851954,53.972657,49.487334,57.912451,47.583428,49.507073,91.951304,105.685199,67.608234,13.005315,-122.674794,-190.602285,-292.0384,-304.046045,-268.103332,-149.236551,-118.715834,-202.429667,-282.837787,-362.650206,-337.980582,-214.644464,-95.07519,-74.683958,-134.333562,-169.299528,-198.748588,-226.368808,-275.971508,-164.377058,-58.723717,91.077437,78.592921,-84.029691,-159.822639,-169.287408,-113.10655,-0.841816,61.238552,63.694504,-25.078416,-76.755319,-135.003338,-162.08781,-198.799456,-202.87547,-199.808984,-153.413914,-121.450532,-128.185688,-175.233611,-209.246153,-143.457902,45.930243,141.950724,170.699862,177.953759,119.019531,-88.747939,-150.149461,-51.255111,148.950671,212.87189,281.631876,286.329991,182.712481,96.108797,34.911321,77.920805:-145.549987,-118.896673,-125.542954,-46.916561,16.353649,55.552452,42.469498,77.24106,178.56249,225.365027,315.037153,336.555863,294.871416,251.098112,128.125671,46.539545,-104.723201,-121.938652,-71.763019,-24.374712,-69.230215,-169.666858,-167.690193,-98.952239,-79.348112,-69.680985,30.428058,90.569294,125.21987,82.394147,-66.998487,-103.517694,-7.838827,174.193435,249.282056,338.203654,338.14812,294.786227,304.260854,419.412188,463.2446,394.707454,184.235292,111.359061,92.734053,123.831621,149.95627,116.031561,-37.842463,-173.025815,-183.803869,-181.389558,-210.284894,-299.759987,-345.871908,-397.050493,-344.600381,-301.381036,-216.948397,-167.043971,-36.815423,19.400066,37.337056,30.581251,93.654686,207.289276,247.735415,213.826771,134.145856,-30.238548,-76.470991,-69.537435,7.292164,18.880738,-0.796209,-8.984065,-41.83475,-76.799217,-116.341969,-86.263646,9.587698,26.074539,39.028433,127.242058,156.170634,65.548546,-39.138084,-173.815876,-97.338512,-65.494346,-132.290389,-188.86603,-214.159695,-159.96193,18.189209,103.096836,197.616678,178.140118,172.086873,213.294386,234.672145,238.383131,218.76613,181.345952,160.95178,130.183783,72.96844,64.056452,24.04425,-2.764302,15.998358,50.264517,86.236884,61.984096,60.522392,80.853423,65.459889,-52.992328,-135.995194,-201.815066,-33.256044,93.148832,293.760706,333.276027,269.814706,194.138813,157.10915,249.894821,476.676923,520.70625,492.073666,376.300873,305.636767,206.901791,179.509195,187.567479,224.554351,200.448576,92.526471,59.421051,105.666842,157.333736,197.682628,170.724838,75.241818,25.611151,21.516713,15.702222,17.835341,1.42278,-34.986467,-83.415344,-26.918098,16.668568,110.01538,157.820801,234.145804,256.193818,258.810131,237.81685,129.817227,9.599255,4.719026,23.897224,12.863508,2.275135,-5.778479,-31.091888,58.253721,126.862691,169.09128,131.069656,12.319619,-46.61266,-77.783143,-20.813725,78.161973,-6.347648,-52.685528,-83.805137,-91.796826,-106.72537,-110.780029,-117.299083,-58.374322,3.85237,80.642874,69.290701,35.414978,54.006398,137.554287,179.336754,260.227998,260.571009,232.3277,192.87021,178.358191,143.482207,110.409197,-4.523353,-85.277712,-78.074755,8.217286,44.072303,36.442248,12.929582,-22.346007,-31.133657,-65.883064,-136.658032,-148.367109,-87.188119,-53.882715,-87.825012,-124.865817,-113.031028,-41.90068,-17.048311,34.034457,58.755658,83.807007,80.920821,52.264444,44.406921,67.981799,114.526635,131.22489,48.222087,-53.017654,-174.858735,-147.612437,-45.449957,-60.239601,-76.288967,30.754,134.915959,274.909391,277.776243,196.334072,159.971481,115.271903,59.293733,51.82401,70.825349,83.561025,104.848523,101.960591,115.384697,225.127659,292.845352,368.020728,362.205564,277.867016,189.864683,-47.709495,-118.552366,-48.54384,100.66449,122.493368,101.317559,109.758485,156.310355,148.738407,117.920369,131.543953,120.417987,115.052523,151.102531,220.624567,201.190332,58.890105,-6.110798,-30.262703,-19.736254,-45.290925,-125.624102,-157.49437,-203.081363,-224.838038,-234.798022,-281.173874,-356.912647,-520.423699,-563.637237,-522.424534,-452.450132,-312.86224,-244.922897,-76.401372,22.680901,5.921815,-72.997447,-83.806204,-34.816698,2.40594,71.314175,89.255756,65.833156,-3.512469,-28.524461,-49.555715,-70.510125,-165.952112,-199.037081,-152.184722,-57.326547,-50.282467,-109.17103,-123.146638,-88.698121,-86.248874,-97.747355,-48.182526,-30.871551,-23.107691,-28.2728,-63.041905,-94.808575,-164.494986,-181.215466,-170.942218,-100.627884,-57.521707,-86.964699,-157.223768,-271.558196,-304.946269,-309.256173,-163.492106,-53.966544,118.131528,134.056772,49.83246,7.4313,-13.137945,-9.873023,-36.45576,-89.918112,-87.741905,-33.994479,-16.801013,-13.724809,-16.06077,-29.139651,-56.767548,-68.5326,-81.959898,-86.948935,-79.678209,-73.893388,-111.702584,-136.892244,-133.999418,-49.467472,23.930772,132.846756,128.227598,9.782197,-74.720644,-204.595246,-228.731648,-207.867734,-103.79913,-54.533781,-66.094252,-117.686834,-221.387565,-236.291432,-171.024711,-113.219287,-101.866187,-75.577704,-67.685399,-89.838868,-130.123486,-248.708073,-303.226515,-287.675512,-225.916204,-202.733824,-179.236318,-177.825624,-202.851364,-216.903376,-223.384187,-217.468766,-208.46458,-204.563315,-216.40338,-244.956012,-267.686991,-305.669989,-269.582122,-218.894308,-107.051797,-91.496239,-182.371712,-266.64262,-391.89035,-388.975203:-25.126382,-75.242532,-102.853598,-69.939482,-32.078537,-25.013653,-61.514637,-53.90624,139.374772,224.431555,284.580775,284.061331,242.402306,190.809328,62.229675,24.382467,-1.257195,7.753708,31.243426,-14.519907,-102.547234,-262.301872,-293.354013,-238.295663,-122.180121,-100.057329,-85.396953,-57.01407,40.379988,65.820712,-13.991623,-62.454306,-21.491188,190.696492,329.858322,495.618622,463.261367,278.19,230.707326,342.344246,457.344361,406.63456,199.710653,134.619209,124.258119,118.620224,17.435255,-43.598044,-118.667447,-136.33869,-126.649008,-97.616689,-79.516834,-81.612022,-131.721765,-235.50119,-251.034845,-254.110367,-193.529569,-104.542666,108.608862,181.275145,194.865719,151.93882,74.487313,154.641179,249.741284,349.026538,326.468176,278.224539,265.006895,189.487829,125.610771,152.050262,262.201874,264.629325,104.307153,5.743863,-16.457135,62.003427,165.486223,123.47453,138.084767,245.479782,254.469465,114.6106,34.633406,12.213349,92.642679,114.849971,80.432197,34.012705,5.138273,51.254302,169.343924,200.497448,186.701307,203.248366,280.47667,429.50139,432.320976,371.359027,354.848592,317.155051,194.541796,132.41661,93.737283,105.229966,111.288042,73.037877,-60.329082,-95.690715,-47.101645,48.627264,91.026072,147.613448,142.170304,48.3801,-14.561778,-50.205563,65.678555,140.634949,248.220536,237.809199,42.199478,-62.029669,-11.562315,119.1886,272.145403,236.493116,235.918234,247.460288,199.333349,0.635568,-69.700282,1.752505,87.310231,46.999784,-42.350925,-56.399264,-35.953494,12.847807,148.739065,177.031641,123.101154,94.127894,88.95733,18.775872,-10.5562,-19.646971,-38.097308,-55.696128,44.996996,109.813249,215.165705,264.008169,384.646908,417.057729,328.989325,255.366922,186.947737,237.955068,270.354463,218.042131,159.015803,111.837862,102.965306,96.745286,212.860888,273.069117,279.685259,251.773433,204.97272,179.459883,121.661893,109.720719,123.722115,130.239423,116.218783,37.561229,-8.670464,-71.162031,-92.430546,-91.29892,49.410886,163.238673,298.26232,250.691695,33.57561,-22.002931,60.869738,138.856757,232.295873,253.090322,252.210718,227.593118,202.018325,102.569063,37.561043,-63.759666,-177.994381,-222.008189,-151.924785,-66.875635,34.839397,35.678589,-3.027071,-15.283484,-21.467724,-42.645839,-55.363064,-80.658753,-112.92846,-235.50543,-285.159845,-258.014336,-166.898163,-129.723049,-56.131694,-35.538286,-25.297072,-13.59189,-8.057431,-41.166234,-121.076118,-75.062717,-30.288819,-66.039976,-147.441847,-276.69129,-283.72419,-233.695613,-195.287896,-172.628141,-81.159881,-19.323357,75.344019,71.237831,-2.634463,-11.070687,-3.796243,-64.510601,-78.359444,-69.662884,-76.395753,-105.802678,-103.688084,1.761427,188.665426,237.083506,195.91271,151.815877,66.785756,-13.587437,-235.028375,-284.341842,-178.415061,-74.917758,-82.774685,-138.829478,-144.92574,-71.69058,-12.448859,33.752971,-87.422158,-137.467876,-40.907769,80.215221,256.000746,232.682994,-20.349745,-130.165996,-123.983457,-39.818136,-47.804085,-154.552424,-239.130383,-404.925679,-432.823565,-343.25384,-330.636537,-411.429957,-540.825088,-520.826892,-397.185351,-374.540556,-408.035646,-387.869755,-239.411439,-158.456872,-169.375013,-164.853684,-123.846683,-80.031255,-100.504363,-84.878753,2.534758,4.392209,-57.974273,-86.885222,-90.118601,-71.281892,-95.544215,-141.159025,-190.490759,-135.780062,-93.018388,-71.795473,-102.897007,-170.897047,-185.439984,-189.586072,-215.686346,-228.796916,-176.862323,-113.580753,-29.227726,-43.739995,-96.26365,-77.527482,-42.280757,-106.022783,-107.581729,-92.778596,-140.004637,-282.223481,-318.506399,-315.162561,-289.92808,-279.966292,-211.163088,-153.426181,-78.744911,-75.375569,-106.838348,-119.203996,-130.638632,-134.199059,-110.707517,-51.37591,-51.429359,-125.739753,-176.810812,-234.901128,-263.185842,-286.848345,-271.489589,-224.456699,-175.98684,-200.746407,-245.622961,-224.615078,-154.571378,-127.625271,-94.914657,31.361088,82.335245,68.623175,12.544505,-94.961695,-86.36995,-38.06112,44.309792,55.033742,60.121829,37.13587,-122.017851,-202.643688,-234.7901,-141.055525,-88.048791,-51.058995,-56.438202,-71.505787,-93.780386,-147.889539,-162.815929,-168.296288,-188.086393,-196.021716,-194.260331,-183.387479,-130.429713,-94.006919,-82.163865,-88.696108,-37.721459,62.29158,49.378775,-49.70139,-82.635205,-82.449933,-78.89246,-70.317661,46.928175,118.804489,96.958501,9.532354,-124.51697,-135.756419:-123.165355,-135.77964,-139.193483,-31.719012,36.948054,100.016235,112.535598,166.96864,185.50762,176.279946,174.233989,166.765497,163.668321,169.606518,60.338484,-53.957975,-221.216345,-188.053223,-121.04237,-22.309268,-15.212625,-62.2229,-108.273995,-168.7499,-63.863855,20.085743,127.606302,135.245588,53.419038,-29.922388,-201.764972,-232.799183,-130.669758,78.402727,185.144208,338.265543,353.094122,260.521208,209.700924,264.528303,388.443193,381.60584,254.87313,176.242217,16.0976,-53.791732,-93.236496,-63.740971,-42.884593,-124.503365,-160.113608,-185.842715,-186.626397,-256.810362,-346.656327,-462.948084,-383.292849,-319.602137,-176.916109,-114.938429,-16.03438,45.855551,123.121455,117.55921,107.914126,157.361002,174.6971,117.009452,57.559739,-38.330982,-82.803151,-143.881697,-84.861193,-15.957355,119.246379,125.907551,-14.514583,-112.334621,-194.926765,-120.693538,147.837324,215.128056,171.047385,79.836787,53.704926,23.489258,11.0592,25.788989,39.58253,20.168788,-29.034688,-62.24318,-111.275723,-106.157411,-67.399514,-13.455359,159.035232,221.694979,210.056746,196.439702,209.769434,233.619147,206.879604,168.21535,268.052882,311.231682,294.173382,251.930291,176.453277,145.794883,132.48611,162.569849,162.35716,62.967772,47.491345,28.718308,-9.604021,-94.250723,-122.247945,-150.445107,-122.366468,-67.568047,120.067564,191.088211,175.548592,132.252742,139.834428,214.70645,374.389009,421.232749,423.493219,314.020243,190.677601,4.641417,9.96446,149.308779,249.096853,266.182142,272.969121,252.593833,194.423012,184.947597,160.757417,124.235451,62.464145,35.887422,4.116367,-84.081577,-107.569081,-133.500101,-175.008207,-222.679741,-65.188311,22.156598,127.380699,172.852452,232.558957,213.104637,85.314549,24.700056,-10.56206,12.535224,14.597218,-48.531259,-98.945905,-139.168645,-122.466183,-41.624125,76.6302,132.138178,206.167146,198.6509,97.461972,38.837487,-19.215202,-4.594488,32.738965,14.309948,12.449452,-0.492368,-25.919332,-49.878704,-36.500842,28.868435,133.420812,175.008089,214.605421,206.004707,124.350999,103.347075,169.096415,207.640251,245.251778,206.512679,141.053069,4.416831,-19.111837,10.527752,18.811897,-26.649397,-25.377556,36.32449,164.023313,157.786944,16.412894,-50.074819,-120.692617,-133.179166,-92.19524,-12.821989,8.806465,29.901119,37.055327,-18.296597,-63.310836,-38.982615,50.51362,84.0225,164.876889,179.94006,149.830009,134.309668,87.93695,66.335551,65.574315,45.712117,34.65752,24.487979,-14.417008,-122.655326,-132.748244,-59.588789,19.576095,41.321016,81.294191,100.593027,113.117847,111.523709,88.409373,88.363808,157.832678,180.699366,145.841182,90.059939,109.318591,161.089526,136.782551,71.49723,159.37438,233.955214,291.811718,265.145096,164.899421,74.784556,-147.468354,-180.144888,-2.373811,193.676778,201.765299,81.339835,36.502494,71.986564,97.083974,105.344129,142.367416,157.683741,157.032277,151.751675,121.818405,78.453841,-24.469917,-28.584267,42.168896,41.335662,6.810367,-74.536834,-110.693905,-178.842292,-205.598434,-207.520737,-261.668274,-351.208313,-484.119483,-477.41194,-403.805189,-366.299556,-271.393698,-205.149764,-65.540409,17.156299,22.969744,-56.573814,-103.854529,-101.512691,-73.534244,-50.754219,-67.167383,-57.892424,-11.404836,-11.40196,-50.131402,-79.61516,-170.703514,-194.238323,-142.217645,-63.1332,-57.551432,-136.840998,-177.746584,-145.718034,-113.008353,-106.942019,-71.009607,-46.114889,-42.072498,-56.209702,-102.905745,-131.850806,-167.344053,-175.922964,-214.454726,-165.724872,-96.24825,-62.651162,-119.974148,-267.272242,-329.813017,-350.681248,-133.377896,-0.392694,74.397265,17.164609,-49.586104,-23.569274,12.47592,8.480382,7.015487,-7.588979,-17.263443,-37.798211,-51.790363,-84.46815,-113.684564,-190.065025,-231.529802,-216.40286,-150.091804,-155.413931,-256.222385,-289.611918,-244.244278,-190.661625,-147.852396,-189.514493,-177.990078,-142.466388,-152.636289,-220.114905,-277.300674,-325.253822,-197.029553,-138.905026,-109.523289,-110.144537,-109.814379,-123.486671,-166.007196,-152.592443,-66.003686,-23.123349,-11.131332,14.768728,31.732129,8.224981,-61.279849,-210.59015,-225.538093,-189.382475,-108.829676,-96.321023,-118.757135,-129.380811,-121.706962,-101.469522,-37.298913,61.512641,107.074681,66.094336,5.932552,-28.656656,-34.114508,-95.092205,-110.140716,-73.610428,41.846221,65.574502,19.558417,1.049654,-7.03101,-20.314793:right
-284.020282,-289.71176,-324.784807,-328.502125,-296.742405,-265.981835,-277.613239,-338.843843,-424.391021,-467.99965,-564.665357,-607.857265,-545.878389,-406.751139,-111.557226,-49.138095,-96.637543,-253.082902,-323.548203,-323.463505,-251.528675,-106.51733,-96.385394,-206.015535,-278.342305,-279.434609,-243.356068,-198.929624,-107.583568,-74.051839,19.153197,86.657245,187.706425,111.106968,30.630462,-42.196345,-13.183093,108.733852,160.133722,145.533376,-20.706414,-126.037373,-245.077744,-229.28913,-149.403952,-110.531537,-14.722378,17.582382,9.553999,-31.951942,-59.456523,-117.793679,-135.923502,-132.744388,-113.984997,-63.200624,-77.906556,-112.762718,-57.063004,56.517052,272.699672,309.709849,251.638216,211.623811,214.554469,216.669447,182.14161,154.932905,177.437795,204.836695,194.614247,157.507394,175.348472,217.791185,281.510726,280.424817,267.158948,292.315114,377.791829,392.498595,358.353983,236.447669,164.137216,168.430157,245.914514,404.253867,452.552686,478.209576,437.819519,411.232522,374.613154,365.292193,332.348646,306.705423,241.508288,212.196331,205.165624,211.200081,198.882325,185.173526,194.014749,249.286372,275.526494,274.001856,282.929725,286.124421,191.320306,132.376215,178.320888,268.819553,368.429919,335.087201,161.720111,-20.405067,-79.433872,-119.935054,-94.697098,41.094879,77.548132,-29.145885,-134.789906,-148.737712,-192.690829,-228.995042,-264.112142,-236.587946,-117.224845,-43.314647,87.381216,84.273592,70.610482,159.578059,230.365256,306.317724,319.872113,323.720458,257.703924,209.896671,145.032095,140.512005,197.547827,246.459727,270.900413,235.150255,196.275506,208.372041,204.427186,199.454139,192.98613,146.558012,119.21434,59.895785,-89.54545,-181.571121,-279.126828,-264.498967,-165.934289,-113.403918,-69.692717,-97.578882,-168.497965,-143.960677,-101.956368,-13.941478,17.454458,87.313812,124.487782,84.496958,-140.252159,-262.594123,-363.088765,-305.814071,-99.849076,-27.1375,-3.111149,-39.792171,-141.895154,-214.792137,-232.389948,-222.761844,-201.502552,-110.103794,-46.108526,11.182779,-65.185611,-113.743176,-131.234421,-103.630357,-77.691374,-86.584866,-104.008718,-101.28131,-42.648759,-37.275076,-82.358203,-116.315179,-69.123221,103.799858,174.439826,115.516977,-139.594783,-246.17508,-330.328338,-309.989837,-191.861848,-120.032283,-36.681591,-47.295443,-120.094092,-216.494742,-248.946771,-178.618404,-89.25197,88.448375,135.26197,97.494103,26.564994,6.295874,-50.39497,-70.068111,10.722519,107.249164,250.563068,247.068877,174.973734,158.988254,173.073434,229.744325,254.859581,276.93366,273.240974,178.751292,-6.330941,-93.391616,-185.720059,-164.404848,-11.597674,62.338157,104.124544,85.585417,0.136599,-106.277626,-130.635636,-139.106318,-144.093954,-107.475083,-60.6394,-33.725949,-120.936962,-161.23365,-205.176322,-213.497706,-177.089791,-109.150301,105.295139,202.002378,241.740301,112.022123,64.481799,86.390985,140.15576,235.933428,235.207138,117.251848,-49.77748,-119.472578,-190.198484,-178.166074,-87.636959,-37.583178,0.638785,-16.687709,-93.516003,-239.463863,-306.337009,-263.494575,-159.775065,16.946614,17.641443,-132.576988,-209.352638,-181.859763,-107.638079,-82.460153,-15.351951,14.829096,-18.525051,-61.129589,-64.120293,-62.839653,-106.112659,-165.928796,-175.821977,-192.114893,-170.609299,-38.468023,61.827431,61.894176,4.870899,-25.007717,-35.0436,-3.573529,97.098096,125.675805,74.274091,-63.375982,-122.274299,-167.336032,-142.812666,-4.626139,62.886897,53.072938,-120.900774,-211.772067,-295.956234,-269.180446,-110.013714,-18.630831,47.006347,19.539266,26.744179,87.708924,54.392928,-78.514849,-124.427319,-135.147586,-105.306607,-58.383675,-138.955519,-214.776432,-319.9888,-306.497839,-174.518514,-116.388219,-126.914998,-166.153483,-161.248748,-97.861042,-89.11076,-65.893732,-23.638503,58.870722,53.346959,-14.448208,-76.21713,-120.197145,-206.146251,-209.799616,-111.199986,-38.683156,100.997738,164.655413,175.340531,-33.347105,-117.335613,-123.0097,-103.252546,-16.891007,80.932825,220.414152,174.5398,142.720043,141.844527,160.779378,178.900867,186.261629,226.501979,237.449701,201.055788,110.687813,70.376943,25.59688,1.341084,-83.918369,-138.986814,-209.203932,-141.344682,-106.54278,-162.947548,-227.005329,-303.110298,-300.529761,-251.69585,-223.688886,-131.339941,47.83557,130.313376,211.676243,212.887769,183.176124,173.546117,173.262065,153.195283,118.040158,24.513699,5.595362,48.784572,82.51491,114.271023,103.056672:-278.92495,-360.380577,-382.130977,-390.2091,-364.605461,-268.035098,-247.669814,-320.106859,-473.239044,-567.375433,-700.972076,-694.63923,-548.470709,-442.246067,-271.638314,-237.230305,-232.141418,-273.738669,-288.563262,-193.792452,-114.164088,-49.539149,-68.62255,-137.119313,-204.785965,-259.625854,-347.869293,-305.118785,-85.153316,-9.634941,19.240925,40.759151,131.654538,121.438485,99.876596,91.979865,75.462459,23.373883,20.391227,78.389006,45.680342,-51.311596,-220.962596,-233.134781,-183.547823,-142.547078,-34.307293,-1.227184,-40.737948,-183.936331,-233.930022,-211.689765,-183.049307,-162.91514,-152.567784,-114.581656,-88.184126,-101.362712,-111.104043,-64.445476,109.852954,187.937015,205.44162,160.649387,140.576536,164.72628,136.965159,88.628769,112.115874,181.499747,157.927371,17.489565,-29.403041,7.469193,132.000403,185.714799,240.812676,247.776729,263.93473,296.792857,349.552661,241.549163,162.722042,107.149264,150.767052,286.458462,313.771303,259.563043,176.134554,142.857947,153.47227,211.376932,337.817465,365.176428,343.774759,320.730226,265.756352,176.273387,145.615071,168.764842,212.263665,303.117292,323.575399,316.249294,275.264366,226.7599,126.874625,135.238342,306.191433,404.08257,409.487052,301.949396,42.944648,-78.845262,-101.533989,-125.120728,-129.628549,-128.771022,-127.002666,-136.81025,-147.268903,-149.685101,-144.416132,-152.985009,-205.263824,-215.819819,-165.527679,-112.673379,-21.457505,-16.496973,8.045254,178.392937,260.936932,346.608043,373.915346,360.936993,220.625192,150.821364,112.537671,143.652872,290.176038,397.164205,505.303714,446.420158,268.81417,257.587579,281.014458,254.748986,222.792544,218.194013,227.268669,166.474552,9.534805,-81.283408,-203.992476,-212.67494,-195.306725,-186.664498,-165.936725,-167.516706,-181.372056,-214.146612,-253.9807,-293.06076,-246.120766,-74.056103,-23.362445,-59.125308,-191.650717,-302.921138,-458.574424,-408.498413,-176.289969,-99.081126,-56.069515,-73.212793,-170.238519,-232.566116,-219.794271,-152.322324,-110.89769,-28.987242,-10.491416,-43.549983,-118.627237,-132.085394,-78.757436,-48.880994,-24.755619,-4.247437,46.777006,61.829252,102.697199,59.053415,-9.1999,-45.898067,37.166809,273.014858,312.009407,146.170387,-93.988141,-156.732995,-170.573406,-165.056942,-166.362094,-149.874502,-142.898102,-178.7374,-234.60569,-270.9173,-306.693923,-274.208122,-167.567303,60.049215,81.21333,-56.680135,-89.21727,-26.759031,48.773187,18.108905,-19.110033,42.980096,207.263709,231.77207,154.301881,24.307926,-1.982489,48.797261,99.541347,203.744311,225.359739,139.637747,-10.688581,-68.021463,-119.529132,-89.855361,70.732493,135.588135,142.092829,125.421335,79.955715,-71.399356,-136.932408,-111.556229,-40.680048,69.953713,70.244036,10.427582,-27.294982,-68.966721,-212.373743,-255.317293,-178.459232,-61.629837,211.486243,294.091173,263.374365,118.81458,87.624251,134.964041,173.302744,240.276777,272.870409,262.175832,83.775578,-21.489866,-101.426657,-84.91708,-31.894396,8.994418,56.485942,35.48278,-15.972917,-90.216603,-151.739802,-186.641933,-131.916863,21.669286,51.835892,-44.710778,-193.337708,-226.050097,-182.373045,-116.978964,44.653112,90.972397,41.222036,-14.099764,-83.67357,-106.601611,-90.922357,-31.084433,-23.471985,-56.346581,-53.243872,45.454316,79.748474,42.388235,10.078318,19.65329,-2.152774,-13.802367,28.994343,59.011097,67.677746,-11.891627,-76.360656,-153.441531,-126.113616,-20.573639,-10.607466,-102.518869,-240.208604,-295.689469,-338.88888,-312.973867,-146.370952,-39.795873,70.266243,69.979243,70.621342,47.605891,16.064513,-14.625007,-16.245654,4.968913,31.082979,65.414314,-28.140864,-128.703321,-229.147963,-179.099239,-20.830507,23.78125,42.546323,33.605599,-27.664028,-75.295061,-50.568937,48.098048,91.412141,157.261747,162.411535,111.286848,41.921293,-27.793354,-208.285533,-230.933145,-61.445467,61.000609,184.863257,186.347086,134.845659,-32.931646,-108.29898,-110.981173,-74.316442,4.363593,57.427888,149.505816,125.281907,83.137586,62.238662,91.380563,131.124709,140.502426,198.302007,231.987829,206.760973,38.660537,-34.297237,-57.919106,-47.371436,-88.500375,-136.215102,-234.1695,-312.468478,-335.976833,-315.298676,-303.201617,-315.433603,-300.543039,-227.928768,-204.952249,-165.605515,-13.62368,90.062142,221.860557,222.550404,160.101296,133.846476,114.497037,52.638953,-12.324417,-66.430692,-28.281347,47.20517,58.706854,98.10503,126.709959:-373.610156,-484.54524,-523.713698,-476.878269,-395.883938,-257.280939,-256.65189,-376.47336,-529.372745,-591.443968,-620.612868,-589.98682,-450.854388,-360.431749,-270.44122,-276.031909,-329.40889,-396.073942,-390.129463,-314.409357,-284.353459,-241.033926,-228.091519,-262.816059,-359.581174,-393.969306,-340.33919,-261.556748,-89.360122,-18.495356,32.839,23.385655,26.556157,16.422925,-17.277197,-103.680255,-130.344751,-113.506097,-91.954396,-73.613338,-97.778071,-143.222758,-217.167651,-194.505033,-54.984551,11.027315,47.796359,22.288919,-97.308481,-246.942321,-268.904627,-191.944232,-139.424148,-71.316853,-55.848857,-48.965491,-94.850413,-111.461445,-25.311211,53.397309,162.243689,177.405262,166.940717,162.101613,153.838839,94.693187,62.764188,84.921131,124.627184,129.513328,72.303615,-41.8196,11.835493,63.618658,110.046393,125.617972,191.834785,229.152291,241.788002,206.501823,127.500307,105.230285,105.709094,83.800134,88.318597,225.160604,297.17372,269.049289,102.702686,28.933514,14.158478,87.471663,281.371306,350.35925,378.866407,342.0491,204.782427,76.799827,64.178727,128.922694,164.235788,210.454414,237.757339,304.99779,293.531515,240.571652,136.265751,130.575393,234.651211,312.756722,368.550028,297.660456,29.477542,-172.472065,-215.910443,-201.409419,-164.880344,-119.476513,-132.918403,-200.286221,-232.561499,-253.236076,-294.338173,-291.270996,-263.006111,-241.650035,-187.704588,-163.927834,-148.784635,-156.394752,-114.814275,81.273187,180.672094,308.862228,337.720708,295.839561,162.06031,112.842023,101.360804,133.214263,273.768141,376.935447,516.88335,502.491878,374.533392,289.025102,260.935802,222.218018,226.183154,252.344701,245.127885,173.36982,61.176724,-2.192061,-107.076718,-133.798208,-149.153149,-147.455423,-131.696649,-126.027056,-174.223481,-277.989628,-287.211508,-199.181701,-159.207711,-124.194098,-98.412345,-71.46023,-204.847391,-315.097648,-418.219166,-360.598493,-166.903881,-101.887645,-56.01316,-59.055242,-79.897276,-126.307538,-151.077796,-126.042438,-67.377456,77.616851,120.093416,78.675537,-50.764383,-87.910457,-53.745807,0.764335,138.04337,207.778611,273.804303,244.489679,116.132236,16.540831,16.759124,111.218795,177.207904,297.567193,318.609282,208.010684,-15.0542,-102.123473,-150.354752,-114.112533,11.320931,60.931681,62.470037,27.549316,-27.750073,-96.258816,-148.670751,-144.239374,-45.110895,186.17539,214.165393,109.511892,42.404605,40.643146,35.729882,36.165706,136.791994,232.786113,324.876625,289.404455,175.770185,115.738778,104.710854,72.443337,71.056274,159.023887,212.30312,228.870107,93.905013,-14.768772,-153.703811,-126.40268,49.771533,127.136598,173.761516,148.94666,49.091729,-36.266468,-47.654287,-12.200619,18.986394,68.48774,69.671952,6.924376,-89.472816,-115.527102,-57.640208,3.699118,80.425078,100.94339,174.129301,209.863454,172.192617,32.519299,22.829662,150.3253,190.300618,136.400769,105.913267,103.869855,59.309769,-0.219279,-73.933499,-48.025517,74.664589,129.075906,140.494774,90.242813,-66.193996,-218.047104,-246.469677,-146.743688,-51.023922,102.151075,120.912306,13.953182,-140.343782,-162.136994,-99.012892,-51.253955,44.552596,89.103249,112.480386,80.280962,-49.954908,-120.561073,-78.376934,-15.779363,-60.376128,-160.224618,-158.60342,-105.131875,-84.532708,-87.972345,-81.203758,-73.58537,-55.973291,-32.037293,41.505661,57.008132,-21.795528,-166.064508,-213.154858,-228.900067,-200.300408,-125.843666,-127.556316,-208.776597,-307.355114,-342.932395,-281.031646,-181.413196,13.439759,71.518868,116.126407,113.063642,58.660772,-60.508703,-113.175852,-73.238635,26.591393,183.498784,163.154154,28.559556,-50.644916,-79.308393,-95.141304,-62.413829,46.301938,91.003689,105.543993,81.39748,10.716223,-20.438012,14.446402,132.186816,173.575651,188.140599,157.888686,76.727813,33.349342,-13.526444,-116.575959,-114.615562,8.862997,96.274758,196.997994,188.854229,120.017583,-15.845791,-96.872172,-105.985455,-28.764638,89.729909,90.097091,42.949088,9.578423,-7.082454,-29.45378,-18.028838,65.858784,116.111836,153.767577,144.144441,97.168078,-12.77541,-60.113949,-68.380718,-59.037602,-92.080032,-137.489073,-250.712095,-335.091009,-370.145288,-396.743,-372.654311,-289.468043,-246.963675,-183.8674,-174.196211,-178.443541,-83.290605,0.496731,81.955978,61.566837,-6.719111,-29.52332,-58.585832,-185.378063,-277.37946,-296.930636,-211.625233,-51.562904,-24.259243,-27.510222,-25.853075:-350.437824,-477.45893,-538.007797,-462.018331,-371.472886,-286.014337,-319.453989,-459.71406,-518.888567,-519.192569,-524.115818,-520.840886,-483.661909,-434.706556,-259.743645,-178.199756,-141.193964,-242.966057,-299.352972,-315.738752,-267.326251,-141.279875,-120.174741,-194.976419,-284.053452,-312.35979,-349.043947,-348.169678,-261.567855,-190.837294,-83.705984,-37.73441,88.99572,93.939891,10.573508,-154.644651,-181.625129,-139.268887,-98.102794,-52.663834,-116.163456,-178.383833,-258.251823,-245.738633,-130.113297,-40.330842,109.723372,130.17379,69.76125,-70.201797,-129.852889,-136.447574,-98.331676,-21.618576,-5.903867,-2.67735,10.694068,-9.748959,-47.704751,-2.857891,175.238124,242.621762,289.145067,293.852048,283.329762,176.527851,105.483058,70.273962,116.30613,195.971597,173.286561,58.392758,70.872848,110.848291,149.523454,166.015482,233.344907,275.329456,308.603639,282.947286,224.913214,168.884312,118.177832,71.785658,117.619401,284.282615,339.313784,313.290858,173.297231,95.704125,57.112123,117.978425,260.53621,296.235311,291.207044,275.857136,263.40196,191.499735,144.818919,134.161894,182.216843,304.001518,328.829156,325.970502,312.607089,263.862263,147.330135,157.690338,326.280358,414.801888,435.551097,372.801008,201.01847,10.952284,-58.261022,-83.613209,-56.956914,6.620759,12.707404,-85.356365,-236.804398,-280.569859,-277.505007,-265.160644,-283.700347,-275.803323,-157.48591,-74.196088,36.369802,35.378262,58.352623,240.526419,343.308908,477.035294,509.87518,472.247882,328.56573,266.035635,232.537151,246.074964,312.110308,378.13701,471.707747,433.325018,254.286068,172.056575,174.72541,211.299987,238.396592,289.186127,285.300225,164.260169,13.598096,-36.139916,-91.374658,-91.203702,-54.997153,-22.704098,36.15499,25.148027,-68.414598,-123.392929,-110.452367,-54.95544,-22.584325,110.469992,182.988465,172.085418,-3.033258,-116.704361,-292.110821,-286.193219,-86.946576,39.28214,157.992125,115.918105,-88.298853,-253.789724,-262.239013,-153.040409,-82.685088,48.318263,99.072634,73.301706,-111.063717,-177.968749,-150.630095,-81.479446,61.900408,124.549525,154.851452,82.959936,-99.655501,-150.299049,-138.762787,-81.293988,-38.106773,54.845277,81.243188,16.649063,-159.550787,-228.459718,-269.978493,-250.944256,-156.238767,-85.143985,16.092422,-3.570905,-139.98632,-219.002375,-215.771603,-138.671777,-76.803876,42.036116,85.208741,135.007698,139.157235,119.356099,60.327484,34.480424,59.449452,147.995021,356.018453,381.220293,281.746752,170.57739,146.215999,159.772354,182.468293,255.663829,294.004165,277.483705,114.667714,5.72602,-187.156287,-217.251992,-82.18558,34.825379,172.698117,156.206482,22.395098,-132.033896,-179.380396,-167.047716,-122.982783,-20.634817,-8.846989,-110.412817,-177.401265,-176.75301,-218.564129,-240.322566,-142.779983,-33.046432,168.320972,229.927905,214.392611,-8.896864,-88.532871,6.188635,106.569883,171.793077,116.877048,-80.576965,-193.903215,-184.883592,-134.086148,-131.025677,-101.862021,-27.997846,134.112097,137.140802,-1.827652,-187.083769,-248.076062,-184.635081,-74.650711,125.060755,135.682538,-10.985061,-80.273642,-77.679545,-129.220769,-157.995197,-121.819073,-78.002144,-30.85256,-28.997924,-59.24264,-150.90578,-185.298689,-183.717716,-168.479734,-118.91174,-85.956032,-52.939412,-77.163419,-104.338728,-175.246652,-197.396702,-154.400195,-75.643488,107.795095,138.358537,50.608431,-61.885126,-82.689335,-60.957413,-37.827871,20.321665,38.516279,-27.628247,-193.827706,-265.761891,-292.833339,-237.968286,-61.231143,26.468911,96.086161,61.532774,-49.209411,-128.04185,-139.423232,-100.064974,-82.368355,-97.741682,-109.054171,-101.404895,-184.167792,-295.954072,-425.541995,-353.494969,-126.495695,-93.380846,-151.275157,-153.056365,-71.925989,-16.273035,4.294816,24.635205,13.769957,47.693302,92.679871,109.860179,-31.196267,-136.185531,-240.045069,-200.292228,-12.955307,95.632103,257.647801,286.37991,201.849618,-34.553701,-116.10089,-74.664358,8.730893,159.301432,202.237689,206.705383,107.537828,50.117291,31.929533,61.443676,72.6049,70.255539,120.581602,147.330714,142.347427,60.137033,11.134882,-61.534824,-82.432903,-97.582628,-106.038375,-178.50476,-303.881716,-359.142533,-410.440324,-397.325887,-322.521819,-279.508032,-193.865952,-159.842382,-110.873592,-66.249958,-55.377223,-52.299521,-45.840213,6.060356,37.732854,37.02366,-73.57306,-159.408616,-291.093203,-290.814356,-181.544255,-120.706064,-66.542797,-59.866909:-417.370026,-567.266576,-613.574459,-491.660334,-360.618516,-222.259364,-260.831028,-430.136626,-573.374568,-622.457036,-590.936674,-524.535117,-416.356328,-374.462976,-306.086005,-280.475493,-251.129508,-316.361891,-339.860792,-266.93344,-215.159467,-184.396773,-214.068613,-349.432231,-486.137168,-515.473784,-457.121789,-379.839076,-165.223627,-61.00295,-1.178588,-37.574369,-96.746555,-170.084947,-222.499939,-231.408752,-173.171619,-47.266153,-47.855958,-187.032786,-253.186439,-222.804527,-140.507432,-105.035186,4.125559,85.686086,209.51129,205.521259,54.794903,-104.212705,-117.559601,-41.022371,13.656791,119.153174,144.84939,96.9193,22.397493,28.77853,118.042848,160.911369,228.834208,280.206078,375.305774,379.633758,288.807255,118.298392,51.016415,98.378156,191.412189,262.140998,194.340959,10.080711,-16.138077,19.290571,99.593675,138.351276,232.950462,287.982864,339.731653,305.457701,144.433076,10.957677,7.407157,90.31636,128.46683,199.746867,252.986951,320.260802,182.552799,59.87343,-65.802582,-23.438645,178.516642,278.617651,348.074612,303.143156,172.427541,136.261892,162.476442,235.243148,264.516795,335.645996,379.39135,435.201092,354.316901,262.270165,129.134542,148.971023,343.354324,446.697968,466.20966,367.991765,98.845079,-61.483307,-76.975864,-41.205477,-8.299168,56.935492,58.285638,-40.413413,-221.337679,-298.755826,-326.897174,-298.681812,-249.078489,-223.743765,-142.969783,-100.859339,-96.641516,-155.308974,-131.46051,44.904062,160.128894,360.096477,412.765362,397.428016,266.42133,186.137327,129.57029,183.995304,354.713303,417.073305,455.713406,434.628348,318.293047,159.991647,113.235615,139.897088,197.768913,307.788258,310.087891,177.99832,25.93128,-31.403491,-115.562656,-126.268878,-51.295334,15.108994,47.172723,-17.149226,-174.582455,-199.933725,-164.609586,-88.912916,-59.128365,35.012492,81.85812,61.22384,-96.251817,-196.05336,-312.838878,-282.139417,-70.434762,47.932217,123.892188,61.764012,-129.01176,-254.117014,-265.20969,-183.677127,-128.4447,-13.653587,48.307585,67.603265,-44.484917,-90.008868,-121.001327,-109.045729,-3.62589,85.385951,168.826885,112.677421,-99.530051,-237.825687,-217.890766,-76.016142,-11.18401,137.868555,205.693184,136.882394,-151.207004,-247.620546,-199.340166,-109.966138,32.553022,80.667572,110.269452,79.239093,-44.364001,-192.998767,-227.842703,-121.499271,12.599511,260.478287,289.685331,217.458973,154.551977,104.264724,-5.322652,-0.782606,191.589318,328.321164,435.682649,371.079378,160.91293,63.20011,78.42831,150.248097,190.015563,304.389056,342.392444,260.322442,52.239084,-41.908399,-129.410906,-101.415112,44.123708,109.807575,140.09724,113.646339,10.398287,-133.479217,-167.60608,-112.671995,-55.408675,47.365411,58.383323,-38.373618,-123.540504,-114.154739,-57.65346,-40.76622,40.192713,131.754062,278.108328,267.707341,118.082257,-18.317261,-34.710073,60.895446,161.796482,314.500221,288.099974,96.790607,-29.135408,-54.693185,-46.070596,-22.982108,52.176116,135.999378,308.589047,299.308091,76.294473,-153.116286,-188.148256,-44.090234,89.334654,263.185825,238.356014,72.814121,-10.393861,-20.717027,9.440559,53.766927,153.329898,174.498967,127.291446,77.03964,-40.226169,-136.878538,-134.689256,-57.889481,-36.483161,-36.917429,-32.523939,-22.080595,-102.126737,-163.503622,-189.10775,-148.36463,-31.97119,39.135501,158.226544,161.114788,40.597981,-63.871424,-74.086458,-92.383662,-102.720943,-47.838761,-8.872791,-91.10368,-319.85103,-359.908604,-190.270027,-54.903388,131.545378,180.16843,196.161778,153.269621,-27.796384,-235.75106,-269.787538,-145.5064,-43.307095,108.057134,140.316176,104.758002,-87.124386,-207.242952,-308.655065,-260.192785,-73.637479,4.38339,39.484797,19.377396,-11.20499,-75.512861,-111.736963,-111.743912,-67.049448,82.144201,143.861973,146.751802,-4.423909,-107.402625,-202.813988,-150.425417,95.138481,227.32427,327.806202,271.181532,50.007209,-148.36967,-180.179515,-114.730762,-57.780857,44.965397,67.637214,20.548002,-49.251494,-68.82343,-79.70567,-75.429188,-60.982029,-37.831107,33.121748,54.377676,17.6764,-106.80898,-165.104666,-170.777081,-121.549406,-38.753,-46.397354,-160.181471,-333.516132,-396.757929,-365.137673,-296.537505,-193.030152,-157.48007,-100.812065,-88.59088,-91.115862,-133.574579,-135.543864,-36.6026,26.038398,86.693749,90.932485,46.74034,-117.460462,-216.002576,-287.165687,-231.506702,-37.413729,40.581131,73.915503,47.093102:-250.174334,-239.62318,-244.495991,-253.438044,-237.681879,-195.809555,-199.607503,-234.784226,-236.468947,-255.04474,-356.660334,-385.775483,-316.472707,-255.215719,-151.906731,-94.867489,-7.877037,-144.205236,-269.381104,-373.612089,-309.327148,-93.260213,-47.800936,-200.376011,-384.836498,-397.760068,-357.232073,-338.030006,-254.901452,-177.762492,-6.277127,73.77355,191.402851,90.61562,-31.387532,-148.322516,-98.557342,32.139418,43.536771,-12.052619,-95.488249,-156.859942,-239.622191,-211.400048,-74.081901,-9.096846,40.04023,15.905882,-47.580227,-65.360604,-66.242814,-96.128104,-130.158301,-141.694981,-89.147994,28.04403,10.712101,-41.53508,-100.345717,-44.595466,185.997474,275.021165,287.646606,244.560375,227.66985,234.697881,195.370963,139.276871,153.427827,235.780161,276.869207,287.433718,229.860687,200.177684,161.745616,176.579178,273.263803,317.131629,326.155256,296.329084,198.931353,30.789999,-38.435308,29.457923,147.002351,349.915982,384.009421,332.382899,250.592188,200.7349,90.11699,70.747168,149.413677,202.978639,164.027097,78.955927,-25.025806,15.179943,59.126881,140.036255,168.476344,229.971054,260.702966,286.137689,285.986151,268.092267,190.868241,181.675708,322.111576,444.690458,592.086042,559.599819,329.633868,70.970105,-13.136601,-60.727202,-17.340644,166.659577,230.286273,184.913089,44.212722,-25.165911,-154.806763,-197.998476,-184.563021,-128.030431,21.152966,93.835352,186.288233,106.192133,55.9649,130.587556,222.820015,307.637579,278.99652,193.387851,185.630908,187.292263,153.746137,132.778608,132.571725,172.761929,254.540473,233.497936,78.55279,-49.513916,-51.209894,71.410465,133.520717,145.059116,103.542376,-13.885471,-120.544577,-171.555969,-202.918359,-144.76179,53.279543,123.12677,67.765656,-28.634352,-89.980511,32.112554,87.408289,183.623471,237.919333,362.575805,415.626282,350.872203,7.271854,-149.546009,-176.496668,-70.403726,122.245954,164.749138,162.3041,120.540299,-14.901348,-217.725948,-307.805443,-323.35791,-262.10885,-118.635551,-53.042395,-1.788439,-93.824982,-143.105106,-159.024755,-126.359025,-89.835207,-110.223477,-144.113703,-138.411267,-129.953275,-177.736485,-214.296097,-234.224136,-204.069336,-61.292429,37.062877,103.39184,-81.116424,-193.24741,-318.80232,-298.635034,-113.243333,-5.528312,76.047341,28.6712,-111.750023,-202.00016,-218.756998,-127.429372,-43.332649,82.017655,114.61444,150.220063,154.361827,112.31071,-42.325102,-78.272791,42.57211,149.72836,249.467052,210.498802,74.157283,9.477002,16.329324,82.769722,112.416398,154.936115,165.128742,88.890785,-62.761328,-130.595791,-230.690823,-253.452679,-232.049522,-179.277029,-33.359473,-8.733721,-134.479907,-269.931628,-267.171744,-174.218932,-128.087801,-84.559746,-99.129965,-198.904716,-260.754943,-264.271909,-277.560103,-272.663506,-181.692162,-102.817699,41.884343,71.092333,36.795435,-22.45528,-16.449285,64.311372,99.585669,113.42582,94.703041,9.961556,-98.948953,-137.139417,-145.940923,-118.099824,-68.651888,-46.133271,57.910745,109.772051,69.97947,-140.041796,-200.603763,-66.349975,63.127475,180.739794,142.604977,-52.560681,-221.675657,-222.475841,-107.978774,-59.871639,1.385603,45.404376,73.888875,29.793042,-10.164402,12.282084,-33.442071,-131.277687,-107.601673,31.307433,67.724703,10.070803,-52.995467,-38.699284,-10.341241,-16.141735,23.81553,87.95428,216.545693,234.215915,155.578345,16.45183,-28.65868,-0.673676,70.904954,226.874612,245.235721,116.817043,-85.606494,-177.634332,-269.266381,-235.03716,-25.68945,105.972432,252.93286,222.215357,21.815093,-173.078169,-225.110557,-211.021787,-170.909888,-141.111807,-152.815849,-137.474538,-144.155753,-215.77493,-355.154532,-340.457959,-200.777765,-147.805312,-148.854813,-172.584733,-143.36705,-122.140392,-157.626236,-207.856531,-179.748865,-32.591119,22.144213,11.672648,-77.364918,-146.418526,-256.596124,-239.707122,-63.688425,49.220359,233.895037,292.334375,283.145866,30.159736,-92.992162,-108.38088,-50.573045,66.231099,136.775257,231.50158,179.515169,136.352422,119.278742,142.613157,181.728608,200.932293,275.701107,297.096774,220.887052,43.989499,-29.216715,-92.31492,-95.075283,-47.787041,-7.338092,16.935119,-47.258178,-83.749758,-158.9475,-203.205838,-276.005825,-279.647311,-188.387411,-103.595401,83.092605,149.723185,122.747651,53.785314,42.708111,72.07565,111.634494,246.367453,278.709634,172.232383,-122.605047,-186.118694,-83.948382,3.33805,66.125675,46.555861:-337.587024,-431.975631,-447.017772,-356.052904,-281.808147,-210.645471,-235.459523,-358.969585,-476.831731,-530.066459,-594.086508,-559.597367,-318.236924,-161.182802,31.026668,30.747432,-85.258151,-189.469363,-225.373822,-270.152012,-253.785119,-157.065315,-128.75455,-203.455943,-388.239015,-455.970009,-453.376153,-394.673761,-218.76679,-112.293408,59.868565,84.159828,20.098102,-119.52222,-192.130478,-225.097513,-164.037408,13.670973,62.418865,-5.295343,-187.578674,-258.274712,-253.551302,-184.271868,5.520058,100.117972,185.359853,160.902456,52.54498,-62.823062,-96.33814,-49.414781,31.641794,209.539864,242.788446,163.868986,22.446975,-28.424862,-6.961911,77.142939,289.488665,366.295395,419.577004,414.604612,371.941601,244.063196,175.130717,173.646339,240.75888,338.094976,309.292034,169.966566,104.525873,88.554957,75.953663,102.53593,228.3676,311.12596,424.244486,408.090673,185.616669,-97.948877,-144.601848,-14.600951,86.96832,255.134572,318.73641,353.430983,175.836338,32.704244,-146.57911,-123.793275,86.50641,205.703526,316.023989,290.903187,138.330276,-37.266043,-52.008821,83.33875,171.685663,354.839392,431.024283,450.254408,335.344607,249.335495,140.280212,182.018031,413.77806,529.877629,598.069784,522.676738,231.858383,-8.273401,-50.873658,16.166285,98.276231,257.12644,298.750708,225.388652,-54.322163,-192.419478,-253.504538,-199.92045,-155.052409,-148.541884,11.133564,108.551914,66.069279,-165.556788,-183.332741,59.094401,218.315941,427.551655,460.758161,370.732666,168.365921,90.945854,70.334198,119.984105,272.695707,360.479741,467.761885,443.056839,263.593657,68.073802,27.841311,105.794029,194.086922,335.700117,336.935708,211.775718,51.55045,-34.705792,-150.687225,-134.377156,18.956955,111.898902,193.753022,143.495241,-51.591189,-128.088368,-80.048525,74.718309,132.983908,253.954495,326.889776,364.885834,105.348671,-87.955903,-245.363497,-135.837638,203.372224,298.914194,277.428997,199.10072,-11.915994,-203.722068,-256.022597,-242.429213,-173.449741,39.864635,126.495944,134.482447,-58.062175,-164.016567,-212.566006,-142.50217,19.997374,70.134413,112.033322,82.365573,-125.542167,-378.636003,-406.349305,-244.310821,-134.38139,58.304671,124.610515,33.674457,-318.171684,-453.407391,-451.933667,-334.413275,-46.262339,49.046587,67.029982,21.135644,-111.308028,-249.336991,-263.9922,-138.475049,-30.201617,184.841117,251.26589,248.919259,129.449693,44.253639,-105.317476,-108.606189,77.01018,210.608258,346.94738,308.358661,123.030372,-3.038086,-17.224264,33.044172,93.686045,282.624523,357.391729,290.119549,13.441136,-125.942082,-321.65439,-334.382027,-148.363728,-11.347069,145.008921,132.166089,-51.606424,-316.805722,-374.698285,-237.067564,-119.540885,17.416593,15.88442,-125.161009,-275.858534,-289.786652,-238.929407,-184.777795,1.685974,112.534124,243.728678,222.575202,43.899515,-149.177855,-185.282718,-78.950623,25.023441,172.41229,165.107097,18.226945,-102.633003,-132.909246,-164.980332,-156.996111,-36.883995,78.455817,289.647632,306.746474,119.263229,-118.62879,-163.387069,-65.043969,56.505955,317.669565,371.010823,233.342603,-8.704349,-92.71971,-145.728199,-122.803225,-25.776935,36.989991,133.058786,144.073243,68.111031,-115.414438,-185.112997,-163.972858,-81.123637,126.341923,187.824372,114.445467,-78.923666,-137.993207,-151.874665,-125.335103,-42.053597,19.344976,163.475121,200.220204,116.901152,-73.576035,-131.993064,-72.313815,18.430755,133.637577,113.50931,-58.142255,-305.938385,-401.98043,-395.680308,-276.77794,53.863004,184.910649,243.420017,172.859877,-71.418784,-316.591645,-367.971777,-256.786576,-145.365623,4.054898,4.21,-98.086212,-274.51185,-399.052321,-536.593425,-471.430612,-207.720577,-113.604126,-88.492833,-113.888187,-129.449906,-210.685668,-266.508886,-206.090787,-94.105126,114.966329,154.146117,87.809205,-55.472939,-139.731376,-265.487835,-257.680331,-60.838085,96.849982,348.414616,377.284231,192.852401,-166.243602,-280.244067,-221.264047,-93.998716,144.532517,187.098205,103.580525,-47.474112,-107.16594,-124.73029,-79.564538,39.945771,107.470553,246.015893,269.902702,136.077042,-102.965934,-156.353625,-79.324095,-9.374037,94.686884,118.891908,56.787135,-120.717951,-202.2645,-267.586161,-244.856626,-141.947264,-87.029173,16.937205,63.879615,82.405679,-19.510426,-49.038871,26.858574,101.283049,239.871638,287.890573,305.814363,137.336752,-9.790324,-203.996765,-194.851812,-49.673419,42.448908,183.416483,197.898743:-111.093997,-75.048597,-94.572258,-82.361628,-44.788732,0.095046,-10.715859,-48.719552,-21.590445,-32.898263,-174.089013,-227.770575,-149.557705,-49.995265,97.625339,126.68771,144.6599,17.245725,-109.884061,-310.094885,-333.627119,-272.245922,-238.794069,-223.795658,-266.336895,-314.440516,-394.943696,-382.966879,-263.078932,-184.646021,-26.789937,42.467458,80.109688,-80.861058,-171.694882,-186.423188,-109.990011,57.880636,93.041029,68.334357,-6.59263,-62.288915,-141.14341,-129.856275,-85.092479,-88.406616,-115.472506,-114.150412,-92.916812,-115.500456,-148.776456,-185.877422,-164.249424,-57.779943,-8.360779,1.236518,-56.825798,-93.867629,-146.174651,-112.282661,61.654262,134.634569,171.715187,167.51387,186.842627,161.458817,118.872903,49.612155,49.300563,140.553785,194.537588,180.685964,126.395361,154.749311,233.661876,235.778501,179.596415,154.776695,124.191821,89.382364,-42.199552,-160.822049,-174.06582,-91.692199,-22.900312,128.54873,214.297818,331.298368,319.351896,282.588206,174.283373,112.281461,-7.495798,-41.984862,-29.472524,-5.579374,24.297612,-7.4182,-30.073831,0.85391,70.360006,265.479138,339.943526,336.690277,198.336617,136.863506,121.197884,174.339758,292.772998,344.913966,480.06677,521.689599,431.784181,177.901977,71.466424,20.976201,78.318108,299.641158,391.005756,357.07186,163.79156,107.442544,86.005963,74.855378,51.131696,83.406014,212.50402,253.641918,236.547645,146.148054,104.086501,77.020953,90.809465,109.94749,116.09852,154.512385,92.799485,-0.944887,-148.380334,-147.745413,-78.799111,-59.095486,-74.591632,-119.237808,-265.707386,-335.940518,-319.230948,-231.732949,-184.769871,-100.314453,-66.373122,-32.51916,-64.624278,-114.517452,-186.659276,-165.583193,8.075774,113.72225,162.510522,110.65485,92.382697,201.987746,241.106464,299.756868,320.827511,352.773259,388.713569,419.037696,184.342743,24.703489,-54.173772,46.452517,261.938397,297.086152,248.605488,200.394209,104.156338,-33.308005,-123.732235,-236.238195,-229.876189,-114.915713,-34.010202,46.442942,-55.556028,-125.173472,-174.072068,-146.635629,-64.398636,-34.793154,-42.0364,-78.098928,-150.704725,-186.373855,-185.798834,-145.449467,-118.226421,-25.414409,50.114408,184.633387,233.334507,216.336077,106.170525,55.610568,26.916485,27.968136,33.504519,26.364043,12.497321,71.083445,106.434697,176.957973,217.353232,246.791973,211.480077,131.307853,174.603709,167.706696,-26.466003,-122.68001,-100.240232,-12.613859,91.064048,53.408965,-70.805956,-96.605475,-92.043728,-59.826792,-26.379316,65.367296,93.450401,11.745838,-172.736173,-247.514301,-337.744992,-353.042165,-336.258823,-311.329037,-236.499327,-198.507057,-176.479473,-211.130494,-223.799231,-262.479108,-273.654501,-242.90871,-241.761315,-281.01186,-212.402421,-159.343693,-175.827725,-227.009289,-226.770818,-158.762004,4.170257,75.468477,169.64274,106.381828,39.452677,-15.193831,5.710858,89.959537,124.826482,118.685916,69.783862,42.860673,-31.519703,-51.013539,-43.674463,-32.289708,35.595696,71.827946,39.89089,-73.409475,-104.374469,-69.801656,-12.440636,132.33164,168.400246,65.858551,-58.660284,-42.624827,61.179366,89.679373,87.73245,82.385532,73.49768,77.146936,125.989114,99.816807,36.212436,-28.666379,10.714241,168.089911,224.476059,203.425933,159.319644,157.124588,107.889722,73.324721,39.7227,42.966959,85.61554,111.400173,126.758071,62.362934,7.62196,-49.693481,-25.466661,85.40195,121.835703,64.101694,-92.890835,-167.268247,-254.232892,-241.492014,-98.501211,7.285634,166.862098,160.979244,5.096865,-103.928257,-112.707425,-132.821405,-151.393427,-129.46501,-94.407431,-45.653861,-50.991739,-93.568493,-226.557224,-254.754188,-190.716513,-147.768423,-117.991737,-117.316892,-80.381561,-81.251656,-138.442868,-208.762367,-153.755772,10.900577,38.819439,13.948305,-39.689041,-105.14017,-246.59205,-271.146881,-173.763711,-43.873084,251.823365,321.189027,232.922102,3.719347,-90.944186,-112.97952,-56.142814,52.57342,77.145813,85.722662,137.760835,175.826793,188.612445,157.507365,88.34521,96.703676,211.841129,259.752167,253.71501,116.886823,25.879086,-60.973059,-46.816107,34.334522,71.81702,103.964783,71.19207,20.091168,-100.056872,-135.755168,-160.639634,-150.697928,-42.315946,38.386793,169.621105,215.201097,196.985641,149.777498,146.222962,201.4315,257.347022,329.101925,274.166973,210.42415,31.108578,-52.823681,-94.092212,-50.943984,40.446174,50.59803:-82.191496,-134.913194,-183.91818,-206.38821,-155.096464,-3.631038,39.586872,-15.556117,-136.252499,-194.849064,-315.475253,-351.345016,-309.27194,-236.015583,-99.730756,-76.46243,-78.354147,-129.053668,-179.236306,-223.670985,-211.387128,-171.086695,-145.480179,-103.891814,-113.807759,-142.442982,-224.123222,-247.10811,-209.983786,-155.078595,-35.394828,11.446815,111.87082,95.389764,14.040633,-84.927093,-63.064437,40.554167,85.340223,77.177951,-64.315081,-157.736965,-260.865973,-240.678582,-184.697978,-187.119014,-187.833322,-161.426752,-85.143966,-69.655563,-103.071199,-217.087492,-258.902704,-222.12673,-163.793457,-88.552023,-36.473617,1.436393,49.981079,57.005074,83.781755,109.520759,107.980625,75.714551,65.252278,115.082888,121.089623,127.706592,158.644303,270.639607,308.745764,283.111693,259.473856,268.787552,225.402046,175.964949,104.219294,112.010266,165.537599,146.75605,18.715434,-42.754273,-13.675593,125.227245,196.060397,282.327416,321.629549,423.030369,442.127312,416.927846,368.598919,344.00053,258.214008,198.788698,107.367181,98.507157,146.940003,138.467755,85.00417,13.866504,34.436139,169.916545,260.301327,363.477745,337.212175,316.40298,255.479755,214.838471,179.405578,213.427934,327.601312,348.769156,272.132195,81.522426,-21.630336,-128.042648,-104.071707,68.323389,143.023524,150.579536,116.473718,84.206371,-77.049771,-154.621564,-167.880305,-119.099163,-37.043321,-1.90928,95.184473,71.200431,29.687646,58.59727,113.437206,183.706469,193.26134,171.178489,123.067597,98.110354,48.916721,30.924711,29.395963,52.457116,70.253296,32.277624,-95.254055,-195.524759,-177.99124,-6.255427,34.041083,-91.952926,-147.177793,-97.884359,-101.9721,-176.524998,-279.844108,-230.099568,-11.668457,58.184452,20.579382,-58.674888,-155.568144,-13.388371,92.651313,212.391665,229.095049,249.256292,245.264707,116.629302,-178.670114,-304.822015,-302.000707,-187.994899,1.851926,17.521681,-64.059243,-125.992741,-199.257489,-264.581141,-339.506738,-465.771775,-469.443745,-351.435226,-256.174357,-110.713837,-45.144873,-32.476018,-96.470847,-153.368174,-199.174772,-173.298124,-120.104979,-128.072133,-133.310697,-78.46385,-60.285415,-47.154836,-43.246026,19.500044,78.825153,126.317125,59.366447,8.640884,-48.599222,-13.82052,85.392757,74.450964,-1.041157,0.037867,44.865711,39.925551,36.458973,91.315727,124.826848,146.36845,152.688489,161.931848,111.348719,59.852969,-52.831801,-86.351367,-18.336563,79.081205,213.596712,205.499378,133.74564,76.025116,59.026759,70.822753,91.39462,130.447676,125.334496,10.398713,-137.643067,-202.055859,-324.497715,-349.155377,-301.13461,-266.04048,-237.245381,-238.119168,-224.596194,-167.537805,-153.20174,-181.505743,-188.587788,-146.326297,-125.481875,-107.903115,-59.336351,-52.814158,-142.635588,-204.905682,-246.818066,-202.103761,15.812734,152.721571,309.713542,228.412021,160.024656,119.041876,156.42573,269.216863,303.384796,278.079101,162.117129,80.534331,-73.481252,-106.863434,-56.967086,13.174383,127.651075,106.415069,-64.987329,-156.627425,-134.432218,-17.432284,32.276807,68.355235,68.001995,18.227579,-22.036073,-3.412431,75.268361,116.082196,178.792544,196.887569,152.726369,96.386393,64.291459,109.095142,76.837931,-71.758888,-101.221522,22.646646,110.583538,172.157482,135.246924,112.24708,38.428309,-4.777415,-33.225025,-9.472274,46.757038,57.472643,30.45955,-102.959145,-187.518773,-231.895642,-162.062732,27.125254,81.871168,94.660027,-19.83382,-122.428662,-267.011429,-253.468464,-111.123425,-35.61872,54.027691,54.510197,-20.084525,-87.249073,-88.706399,-85.22099,-107.208288,-160.802086,-159.417169,-115.821201,-138.289155,-197.793961,-334.228275,-349.518371,-254.860914,-193.019554,-135.299543,-139.25845,-137.127743,-155.574721,-196.153681,-231.475767,-191.929905,-69.144895,-37.00582,-44.972492,-71.138245,-107.253611,-205.477101,-214.340915,-121.866869,-40.212412,125.485159,168.999306,140.718988,-41.030548,-137.461705,-151.518096,-100.747471,-22.906938,33.413507,212.078618,262.737504,207.172075,145.837516,184.588567,240.242362,228.846157,247.892197,291.755509,327.862343,170.722413,55.082553,-70.487933,-64.117078,-15.692169,-19.465144,-66.666824,-29.82904,-10.521106,-83.333726,-140.441894,-166.205562,-133.195865,-70.071869,-53.994674,39.755618,191.118917,229.104239,255.454394,244.026648,156.600391,150.065014,310.43083,436.373962,389.161453,176.427417,102.220427,68.276467,78.864708,98.83213,99.135905:-262.661201,-260.794345,-231.59974,-113.111651,-69.714015,-67.376456,-95.007883,-172.036819,-217.563694,-243.004233,-308.463403,-308.343596,-175.069812,-68.166948,72.008025,85.174628,62.462781,-81.921147,-205.781877,-360.196227,-332.686516,-165.578298,-118.337458,-185.046058,-306.956471,-340.021485,-367.45171,-368.779944,-303.327368,-214.543357,0.501492,53.466892,10.87813,-146.282127,-227.331877,-204.084489,-88.621351,124.061109,149.41188,46.821396,-117.499844,-185.653074,-239.435668,-196.448151,-57.845666,-27.047947,-42.855592,-55.140896,-74.139884,-148.632273,-181.48859,-137.786144,-72.350257,60.011387,92.212129,67.421822,-39.020498,-96.500557,-86.970085,-9.590155,163.916937,236.433594,310.663117,280.657503,180.001783,161.940431,173.695935,221.337582,230.09732,189.604817,161.47489,135.605281,138.682511,127.030216,132.987884,170.808804,255.129929,281.157417,260.024598,196.978591,50.795357,-35.506535,-62.111401,-47.640591,-20.874996,58.511144,142.355992,299.485106,187.483053,52.503235,-139.885848,-137.757002,-2.953186,49.32892,16.294507,-15.861288,50.810615,125.272942,97.143791,49.532169,81.493726,197.502798,226.176293,191.066423,139.430608,111.052222,117.283404,189.325171,372.693102,433.992465,501.009349,502.279659,414.673986,251.994302,162.262276,108.817297,189.312848,393.541702,419.550247,283.896672,81.899488,9.523458,-33.814319,-9.699003,32.839173,46.125245,128.715257,182.287686,181.187248,49.757969,9.562131,48.552575,105.943493,225.019349,256.440463,208.468622,112.730152,81.838985,3.54004,-38.025706,-2.931124,74.916592,162.571675,116.705802,-24.427176,-15.097365,26.461766,76.074401,78.067707,90.501431,92.625395,32.07929,-51.302491,-69.54186,-55.671828,-30.95924,76.165965,156.286753,219.227013,156.685333,8.670804,-2.351678,29.444974,193.42262,290.122212,405.496472,424.126875,351.145562,123.629757,24.398974,40.809926,138.502214,344.721635,423.349994,430.935932,341.836195,141.381289,-24.98483,-109.005085,-153.855243,-97.442336,36.121895,68.638003,68.734422,-30.780115,-107.961996,-151.750166,-90.452317,23.790715,22.184141,-59.724011,-115.198145,-218.264341,-315.961016,-363.763235,-347.135852,-264.197271,-63.715536,18.708164,86.902525,16.044244,-34.918926,-93.144085,-74.079606,-9.601932,-19.067069,-51.130131,-24.108077,63.800748,1.875885,-83.422156,-107.615118,-21.09404,146.877109,180.142663,197.993149,156.399209,80.718523,-90.217179,-84.861702,102.698522,173.38265,167.521051,120.48349,-30.185528,-99.868058,-65.302572,37.241648,88.835228,198.12578,211.336483,89.995217,-66.198002,-134.414986,-294.94123,-348.617053,-284.992407,-183.668986,-24.708565,-31.430381,-157.182389,-246.388625,-263.899014,-252.870188,-218.785355,-114.944459,-71.903522,-44.153282,-89.623535,-142.018462,-259.913233,-265.252135,-130.47189,-56.857583,-3.893215,-1.250874,18.027105,2.560059,-42.220215,-114.578582,-101.977334,-12.21143,16.277085,-22.88421,-122.607091,-160.651106,-137.12528,-83.195573,-28.423126,-10.062013,128.324642,187.877994,84.698018,-165.771174,-203.034834,-98.731355,-41.947474,52.983478,93.050809,31.767271,-118.157135,-137.979138,-107.289106,-97.127985,-46.597559,1.93496,45.216173,30.278558,20.729679,9.561304,-42.729214,-146.108212,-126.94919,38.475452,120.340981,182.775306,92.798847,7.857173,-103.025028,-95.786439,-49.422172,-29.618401,55.810921,115.681203,197.627815,141.403028,67.739084,16.782112,70.577496,151.700203,113.804554,-68.175369,-182.484885,-182.226159,-114.417854,-62.80533,70.064947,155.348023,276.164376,248.99682,7.833154,-229.325267,-272.571959,-249.562467,-206.41769,-80.91135,-29.091839,-16.419175,-119.0824,-202.696398,-317.549752,-311.341185,-223.314541,-181.210953,-140.766344,-139.395555,-151.248252,-183.355807,-217.473985,-286.096099,-274.131217,-76.187374,52.972989,118.523058,-49.496504,-140.997831,-258.100088,-263.708386,-107.590621,48.195887,311.435496,328.759161,140.471492,-155.354934,-244.773895,-201.074212,-133.960274,-32.676086,30.540702,153.86128,119.139319,42.275005,-68.679584,-47.243319,66.447687,107.667083,180.697002,204.281937,151.827808,34.681519,-0.644378,29.217332,89.429662,240.789465,285.222253,243.179637,49.294405,-75.276678,-201.580189,-153.985332,35.368201,103.546547,145.167334,140.27438,143.505333,131.741905,115.851193,118.818098,136.667648,217.389078,281.040887,372.947626,311.931794,193.107511,-103.037131,-157.861434,-44.659963,16.771805,16.921391,-5.812035:right
55.23135,137.755395,135.112396,105.74456,111.84967,112.012452,72.807018,18.2861,94.720705,132.142296,129.258005,117.355722,157.184864,187.851056,169.551434,116.560671,24.193864,98.626103,179.127866,269.729026,252.242462,137.849313,79.302108,103.10459,304.836699,365.311845,272.938686,172.3072,90.961202,116.410951,142.931142,152.893049,260.152726,341.840589,318.031701,210.273863,167.002554,105.129213,54.901376,-76.585449,-90.323985,-40.145241,85.092227,131.906492,165.686982,133.861751,-21.985242,-82.759217,-55.034817,67.269761,120.479401,152.594138,119.063003,-14.069282,-83.284204,-158.30094,-134.741871,-107.923214,-91.345227,-104.597074,-113.590903,-114.536678,-185.743613,-243.29366,-256.936111,-91.98169,-15.553038,25.612108,18.059686,-22.333084,-67.604364,-145.015559,-67.296013,24.540489,158.506353,154.588282,50.970914,-12.106856,-101.478521,-99.972618,-10.368254,124.022383,207.210496,339.148186,344.477696,206.532469,104.605579,2.986852,89.690199,164.846001,308.173976,361.133671,452.252513,473.714419,400.864044,367.406684,432.737971,508.555994,506.533273,414.486392,342.799067,256.377417,271.849506,390.614474,474.503433,490.015851,525.0185,533.692693,499.512166,456.398563,358.290649,336.030427,330.907806,347.504707,394.002164,483.848683,465.609162,360.252459,327.575179,332.35146,432.699453,505.220138,626.966528,653.082666,661.014219,654.14024,569.33018,499.462673,386.361252,327.439592,322.715691,340.235323,349.801791,333.631857,290.309746,201.47561,158.050832,142.75166,217.399071,294.26017,331.666303,259.153863,45.367873,-11.644663,50.178805,193.046945,250.717519,335.921592,351.058239,224.383176,121.421142,121.11793,265.437423,283.237097,277.066723,254.28977,102.027352,-8.409133,-161.174605,-152.624052,-23.87695,39.381053,34.632416,-14.112417,-50.463196,-114.812877,-125.710843,-83.391374,-34.601047,-1.30157,126.706737,172.932821,137.558347,85.773601,34.024513,61.037346,144.963099,175.937681,190.000242,233.779178,263.344096,252.607927,198.311792,171.978472,304.013314,353.772405,370.99848,365.489867,334.667484,284.336886,176.732525,173.782508,224.151697,196.270544,171.946112,159.321512,152.281182,102.772042,62.193282,-18.39352,-15.212955,24.553385,98.78084,101.460449,66.542492,45.549986,34.408589,80.377578,204.369932,152.474228,103.417021,39.269729,-7.944764,-121.571245,-155.408831,-97.070501,98.533057,172.322553,168.728413,103.629267,-23.615333,-52.535368,-61.310092,-37.114259,45.459172,85.221091,101.355739,131.243564,128.553277,49.695914,-12.108376,-20.497035,105.367404,139.941356,176.077671,215.817068,274.98581,238.36212,82.787831,50.797366,160.451888,291.98628,313.489668,284.195857,224.308405,28.812052,-53.126331,-56.415255,109.438535,208.954346,359.155453,385.321015,316.364783,229.919661,70.422207,36.555236,32.997406,91.999629,138.305656,167.403497,136.525969,44.919336,-17.060943,-180.301162,-243.646479,-197.01551,-66.553952,-62.892556,-220.230169,-330.584037,-450.279175,-406.423472,-188.850861,-13.757663,36.534049,11.589739,-52.376091,-168.879044,-195.657568,-154.127175,3.974732,80.155057,143.996025,116.075274,-33.61382,-123.370181,-280.314448,-320.481118,-293.452975,-189.617072,-130.160653,-92.483657,-140.939616,-312.152876,-392.936705,-443.167831,-348.204647,-284.69802,-198.897629,-205.124931,-227.799672,-200.787521,-213.042983,-277.444583,-292.711308,-113.177354,-66.513563,-160.59075,-245.185979,-342.1022,-350.859271,-302.347085,-126.642304,-24.523005,54.755952,21.662233,-35.995394,-4.910063,99.485874,100.254101,-0.784985,-6.266248,54.439273,144.349546,119.956095,-44.344757,-131.003634,-199.216356,-84.601795,6.478657,113.957649,101.784914,21.43841,-28.665209,-187.840035,-269.574424,-318.809284,-234.485846,-184.897521,-158.595981,-176.844471,-209.063781,-220.049612,-206.222751,-127.228799,-92.918919,-56.349154,-61.767398,-140.104779,-203.032416,-349.801288,-409.806146,-445.540711,-405.724696,-362.875213,-232.846347,-174.099575,-154.354728,-196.466468,-257.920574,-189.617345,-159.188725,-185.635615,-220.667246,-206.641381,-164.554672,-168.69365,-203.219459,-193.591852,-150.447141,-137.056711,-61.603618,-23.595534,-66.148693,-131.077033,-185.135492,-71.159727,11.515224,138.928768,159.030914,127.174835,100.423702,50.130851,62.219831,189.222542,255.509009,238.716205,151.385189,95.590875,14.974428,-18.974343,-129.329177,-144.898017,-69.615666,97.422646,119.02542,107.63413,114.813033,64.33364,-0.569571:10.810083,69.073909,80.97603,63.151275,51.603195,47.929338,44.16283,75.914358,165.507384,177.305174,82.983749,41.384744,78.75098,97.037917,8.707432,-51.197444,-35.210862,103.077611,145.70361,145.376513,132.994211,138.495794,151.460373,195.945448,258.697913,270.295233,216.759972,172.678869,133.06946,142.293832,157.656711,154.047022,186.856294,224.404686,203.459467,159.122855,151.172901,57.866765,-31.598697,-92.965488,110.739092,206.038262,206.980934,167.823117,184.962013,209.145507,131.228023,32.691921,-114.109009,-43.106269,16.670247,32.925358,-7.388245,-127.784148,-182.604504,-212.981628,-134.92363,-85.564316,-53.361981,-73.233003,-125.739161,-158.972858,-243.640794,-271.307511,-260.189663,-179.190726,-122.135846,-26.322598,-15.138517,-76.079041,-120.571106,-164.519683,-84.305722,21.496222,186.956753,148.441292,-43.417393,-86.228026,-69.004126,-54.473907,7.03034,236.096922,355.648531,385.37078,317.9775,166.807593,98.736731,42.599973,102.086442,124.957964,153.897604,200.310803,344.952454,367.917821,292.433419,282.768324,360.440201,348.14264,284.74417,146.803306,118.559695,158.890547,194.874421,238.281339,269.963305,293.11533,327.385195,326.671706,294.038444,258.647772,181.623906,177.467909,237.596657,285.098641,312.752357,383.134117,390.652628,296.950032,251.711609,312.13981,412.723262,436.715837,500.25998,528.686006,504.036857,443.193567,286.905791,239.325603,253.156799,293.136352,287.233633,283.368285,291.348319,246.739794,198.623876,149.445176,141.594299,141.22978,184.246243,212.116274,219.114244,193.138781,112.015647,83.597641,63.963651,61.8868,83.200461,140.078727,127.504639,23.653876,-1.57323,105.581651,235.054772,257.246709,282.157829,270.157311,137.588077,45.968386,-76.01319,-86.15442,-13.074949,83.619096,115.919178,124.83801,87.676402,-7.095166,-30.15416,-42.010227,-3.626195,38.804819,104.194901,107.012427,64.822012,33.428371,14.701376,40.898231,86.702711,101.291648,110.027255,129.791743,136.871086,82.439862,28.252167,27.402594,201.556666,268.657945,260.766346,228.272482,226.450326,225.281589,182.662923,192.451173,273.154978,317.319943,296.506447,139.965945,54.164122,-14.366464,-5.991904,24.054365,37.983661,60.223835,76.157462,33.485437,-72.212951,-97.093266,-74.822934,-24.740859,98.600358,164.43744,183.784501,153.292166,84.157408,-79.731006,-117.796955,-25.855378,171.126153,224.115286,185.500343,124.876149,-14.988094,-89.178812,-194.899125,-186.096195,-32.977194,117.289933,140.793809,99.610469,51.924953,-59.090641,-106.198267,-122.419694,-34.965203,18.725959,146.145587,211.266346,233.994734,172.975803,48.785209,54.706102,173.618076,279.941296,292.70473,229.862696,173.102265,44.127534,-3.982904,6.132723,133.354584,205.967249,279.683703,274.732777,211.732727,146.546872,3.497396,-18.469583,64.105455,194.43515,214.293698,149.597444,108.839988,46.200186,11.994908,-2.239812,60.737839,52.780662,-55.417623,-104.122662,-150.420987,-182.589284,-216.870405,-156.542062,15.393853,118.132915,168.789249,163.894121,91.437955,-60.431958,-102.779233,-81.035853,104.830814,201.599788,244.22551,192.658354,62.250208,9.425766,-70.530548,-90.6436,-94.599163,-63.808736,-50.26853,-100.945888,-162.624339,-292.935897,-338.175198,-357.023332,-278.403939,-206.117783,-82.155508,-79.85833,-178.676419,-227.493209,-261.239309,-259.879047,-199.816999,-24.463393,40.633313,-31.676815,-134.942324,-300.224075,-331.946048,-237.588106,29.260628,140.645426,168.370858,107.896526,54.52858,87.078151,131.152182,106.995143,51.265381,142.041637,209.883114,189.231187,86.716826,-107.064139,-130.754138,-75.604095,-43.027565,-38.943579,7.516168,38.493231,17.309743,-56.612154,-233.104118,-257.339467,-150.874604,-58.667613,-69.748073,-140.577067,-158.472712,-160.673432,-171.408823,-165.710177,-36.212044,28.350395,81.238231,78.056534,-5.746981,-98.485482,-312.207565,-388.642567,-432.018669,-306.129481,-223.131324,-140.34978,-133.716718,-165.3136,-195.74813,-212.935316,-154.682516,-132.766081,-140.715931,-151.275828,-170.554728,-206.6294,-277.876791,-253.968572,-148.157485,-106.68505,-66.502487,89.425534,145.168846,78.713001,-6.739699,-75.595824,-43.759728,-32.878768,47.348625,113.926818,152.357612,100.91429,-8.955657,-1.839701,126.798412,198.729981,186.511013,128.896803,99.988624,44.468853,11.020293,-46.996582,-39.307352,-27.853769,-26.872673,-22.937584,48.718714,84.869973,19.738671,-39.866903:32.558167,92.090277,93.844253,26.752644,-7.581931,-82.697065,-106.972149,-7.604911,95.421577,70.012205,-4.769594,-4.840301,3.130865,-29.460879,-117.283168,-135.154257,-128.351761,-89.794593,-67.400344,-60.654757,-62.81232,-34.369553,-27.36192,-19.413501,94.710065,164.491618,196.356819,165.459189,109.751323,98.686306,94.600095,91.244368,61.57097,74.981704,102.570381,107.494199,74.089695,-38.904831,-86.849972,-43.577449,151.00571,231.743828,260.012094,216.722828,138.004673,124.128869,86.503348,49.925484,13.63324,79.416264,103.173402,57.751458,1.847391,-114.51524,-148.863689,-147.14434,-123.019378,-125.248288,-185.689246,-216.886275,-194.591956,-183.66768,-233.380028,-238.341509,-121.664527,-24.019822,-48.931498,-112.804245,-94.569128,-57.013042,-80.859786,-109.777754,-1.212962,69.491088,92.498159,34.511225,-46.742608,-37.504464,-35.66517,-54.053554,10.37861,245.74814,341.128459,327.415862,236.094862,40.065723,-26.700743,-62.850924,15.812186,59.198189,81.099066,75.109689,88.881108,104.203328,148.068111,187.252747,295.727196,370.910385,337.706826,144.11514,66.776572,52.225943,96.018416,202.964285,210.146482,186.336167,157.322917,140.385415,86.79882,65.64725,51.911707,66.779683,169.710922,318.603207,363.093672,337.369743,276.588064,141.681035,113.049529,157.127667,253.72742,309.976839,361.650841,340.135214,286.919469,258.783784,137.010679,70.631151,76.010168,218.613277,251.103333,181.809009,109.667034,-7.743773,-12.357728,49.137497,30.789107,22.625726,103.963985,155.62778,158.20351,107.217831,30.61741,48.021234,126.751046,151.303179,141.339549,56.063091,-1.511863,-63.600806,-67.428612,4.873244,191.22382,278.778663,292.332585,216.416232,74.020532,39.379511,-7.841398,-19.800121,0.773362,72.089497,123.929954,186.291002,162.599517,14.24113,-69.072376,-119.756867,-4.533844,60.804472,129.352743,132.699038,87.164668,43.353393,-24.202769,-28.45212,-4.945171,6.617325,-4.618468,-8.085306,21.880128,72.495223,68.082665,58.259509,122.92538,167.367063,194.394602,190.875315,228.919657,242.4976,218.531618,221.717612,284.499994,328.789943,305.806975,142.619959,51.972973,-19.154277,-6.341943,26.223772,54.479558,84.738045,123.148096,109.796807,73.050428,67.218519,76.618784,87.844097,107.46071,200.79416,264.625303,271.387419,207.731536,54.021877,-9.653695,-33.992618,187.317201,325.423155,376.517699,283.271071,83.133212,13.291767,-77.07493,-83.697603,-47.630101,24.039816,67.512154,77.617283,42.680356,-47.916666,-93.798379,-127.622734,-2.145089,78.132385,150.025401,143.506158,78.985059,36.431662,31.612472,79.926428,173.075738,174.409052,158.556255,157.596175,150.914373,-0.735924,-107.948693,-104.582173,129.516811,223.420437,331.984075,362.130266,364.385308,316.64346,150.419463,78.865374,47.722625,188.407151,266.105064,298.3504,246.636715,48.100295,-34.336548,-3.161763,102.926903,115.248857,107.276384,96.349868,53.787495,17.394949,-57.478018,-48.049707,75.374553,197.407332,232.252261,188.094448,112.00665,-50.407208,-97.081961,-39.610047,179.186866,256.603077,225.28628,165.325002,77.048879,29.337293,-90.206606,-126.882105,-131.6968,-96.615411,-87.512686,-106.996489,-120.012821,-161.94264,-186.462443,-198.432058,-154.957037,-105.563325,-0.653254,11.287868,-33.088015,-52.44795,-64.956093,-77.459962,-126.284723,-62.609739,7.022793,2.634753,-89.507419,-220.580335,-186.744371,-6.115557,109.809133,130.126713,151.180841,163.915541,183.445082,175.275898,145.00079,158.882247,239.176442,308.151203,325.685302,238.338189,129.012449,-55.683304,-65.537495,24.886427,76.850361,70.754108,16.389228,0.547647,31.184756,28.3905,-48.511018,-76.413565,-83.814532,-75.360304,-71.017558,-72.527819,-85.793827,-147.69705,-170.697409,-120.229064,-52.407494,-44.183161,21.171851,63.647885,4.2046,-104.87541,-326.152128,-378.547756,-363.387193,-309.30984,-291.728212,-242.330649,-201.996171,-188.657129,-223.171922,-241.370633,-195.702059,-174.879746,-161.944456,-187.683626,-276.753149,-317.200187,-291.005497,-212.307485,-103.669776,-98.255313,-58.203022,82.103243,119.216528,39.32305,-41.468618,-150.053755,-170.779639,-140.703983,-17.636806,28.232701,37.188461,7.108044,-57.859526,-51.655872,44.718954,124.309284,139.992179,123.396206,87.230076,-33.346196,-76.901826,-40.156184,-8.972904,-33.290362,-59.013217,-29.299929,103.528294,142.479816,43.035008,-24.69995:-49.498372,92.999981,129.574983,119.586134,96.140186,1.124728,-46.268909,6.609363,143.183533,173.518074,173.091635,160.174184,127.081552,108.096576,42.940316,-8.211366,-70.359519,26.72983,82.051435,59.527068,13.942166,-29.134126,-28.635501,7.247885,134.772585,219.107627,278.657665,226.619545,104.46996,89.310761,107.432617,121.159895,150.456774,183.225262,184.316419,144.370227,123.139105,31.707735,-47.76024,-114.527037,52.496522,154.355582,222.746785,200.31211,159.081831,132.064894,-8.226552,-74.057276,-21.55142,180.540183,216.899808,124.414499,77.356957,27.460524,-10.552341,-56.843992,-41.339681,-48.947629,-78.588972,-84.044999,-101.583547,-137.757094,-236.652975,-241.052881,-96.853206,35.716017,37.545495,3.600243,21.526099,117.410707,119.156384,-12.958923,25.971274,159.594026,356.000659,333.657792,169.602862,88.505991,-43.561106,-64.690991,38.0717,279.949574,399.081723,442.637351,355.015588,148.721581,85.505634,64.904661,126.640778,159.253536,241.017772,292.164104,391.143346,419.940315,418.185292,420.773428,465.582257,483.088167,468.716149,379.062706,328.181647,265.600881,262.137322,331.73384,381.115406,370.904605,343.512409,324.065879,266.75085,244.785437,233.027873,247.111872,296.45133,381.309963,447.055866,491.762587,424.662815,226.538968,172.913429,195.231341,262.314224,308.422351,460.71317,519.518034,496.330713,427.982681,290.769586,273.780378,341.229311,372.892118,344.117993,232.063723,175.694111,84.429397,45.277258,4.75761,2.840917,24.04506,159.847668,225.020728,205.364453,138.719318,19.897662,3.877139,44.553073,75.329055,84.049602,102.468758,94.609856,8.138016,-37.32919,17.92425,163.621812,201.796497,257.414896,284.230425,243.830732,150.919825,-58.648572,-88.134652,40.500531,205.394467,242.623547,177.630861,86.805838,-77.594254,-126.044292,-146.395969,-36.813924,56.395256,233.177274,249.604714,120.750305,54.028626,12.55949,14.428333,56.459602,209.325063,283.628596,314.911363,289.597248,215.747881,181.915157,165.391564,216.916843,265.735889,355.39232,364.786893,341.735924,314.06347,217.472137,201.820223,315.908788,416.362904,399.249498,246.554541,149.822293,41.194419,33.38166,32.458637,60.1972,95.07892,133.807741,119.010175,61.781592,39.883707,45.852724,79.001198,149.941384,205.258762,237.704541,235.157981,173.984807,-14.108069,-76.813514,-28.469204,118.506772,169.835576,212.471681,200.495585,117.567157,62.630364,7.529956,33.818612,113.73895,112.903005,107.391972,137.411212,145.091475,36.336979,-54.680254,-101.510439,-5.619353,15.406393,38.61426,60.318949,35.804289,-23.664551,-109.850177,-91.899659,9.890832,61.747186,65.410008,51.522156,13.263373,-126.121978,-175.307665,-141.084489,-50.177118,6.090193,203.566849,301.320544,346.806774,270.679351,24.27683,-40.475618,68.186475,231.745642,234.316979,122.848009,72.789655,-2.591502,-55.232425,-109.977805,-59.627916,-41.509981,-45.516972,-66.11138,-170.22604,-247.587736,-312.731816,-255.818009,-85.949089,11.246105,42.531804,11.558104,-61.767766,-252.353039,-322.076694,-270.079144,40.052339,178.117628,182.961842,86.722055,-45.011947,-74.073978,-193.509971,-251.855633,-233.191563,-143.249242,-114.930269,-97.950333,-115.921496,-192.798136,-229.90999,-264.544166,-223.073591,-161.958933,-31.26929,-19.234045,-103.19819,-157.911295,-225.340224,-218.006047,-118.295439,-10.575708,-9.930974,-132.746013,-205.09542,-250.723921,-229.417537,-148.303864,-32.770286,38.732313,161.624542,166.768478,99.016069,89.974797,125.931181,124.173047,99.155124,195.675495,270.312711,300.556375,231.701298,2.813975,-103.911303,-201.273336,-88.873838,20.957404,177.922721,183.37889,75.113914,-10.936642,-137.993507,-152.522457,-121.478899,-67.31817,-49.680052,-63.199055,-88.768324,-150.116074,-179.056934,-183.072754,-105.369174,-85.934397,-120.824112,-160.633957,-265.229807,-336.787843,-510.821244,-559.906774,-524.16346,-446.537213,-395.797214,-239.230538,-171.844063,-170.873989,-225.305561,-291.698494,-261.713178,-250.004669,-278.661613,-312.057902,-322.017998,-287.789763,-256.310824,-277.191926,-294.712317,-187.961008,-90.407229,70.739334,77.491838,-36.436019,-92.040048,-104.513992,-73.797449,-55.58861,17.641605,35.486127,5.114571,5.393108,59.326845,95.881226,201.591068,279.023496,272.728049,183.326582,134.138208,57.661257,22.959864,-18.64203,-40.645744,-34.180599,61.365893,117.973454,171.675911,165.731774,90.286749,42.443534:-32.392904,185.303012,250.305968,185.633273,98.635793,-43.434283,-70.935672,14.604304,158.405216,190.731942,186.931913,164.630078,58.264115,-10.774734,-69.895575,-58.691033,3.129333,135.104543,176.738824,89.874104,-3.663571,-162.027135,-203.136314,-145.152808,40.825775,111.849441,138.875012,122.143103,100.324807,90.107771,58.147879,48.811415,34.369061,46.920796,80.990821,126.125703,114.754124,21.847499,-28.324623,-13.713966,104.271689,154.849733,168.851003,136.457116,63.122647,8.419498,-140.263736,-165.514163,-30.299892,153.106249,171.385145,77.223114,18.315331,-87.131877,-137.611906,-179.252323,-118.902304,-84.451255,-71.053184,-98.134738,-169.107131,-187.20768,-195.126466,-190.425126,-136.566166,-19.587592,19.864758,-5.226037,-35.082382,-77.223453,-98.216993,-118.113801,-25.750152,73.350229,210.528926,186.592884,35.708813,-39.01705,-121.858859,-93.983324,73.57129,206.999353,238.643131,229.596762,162.514874,-54.504873,-111.146193,-15.264867,108.370221,124.167279,95.738556,73.49305,70.838488,80.786457,99.501697,130.64569,239.635844,317.168441,306.802468,173.776786,98.833193,36.462002,51.739718,109.604352,120.757936,118.535288,117.701664,89.019027,-26.30925,-54.917102,14.07852,81.688469,211.20872,318.378106,351.689333,316.874397,229.71368,5.588241,-41.963917,27.556755,124.179496,191.264599,316.763888,317.894269,261.687568,234.150485,134.870527,69.577731,28.802725,165.291872,208.71952,102.357709,-0.030861,-132.355074,-138.883957,-86.04516,-61.139484,-53.998651,4.068353,22.04429,-58.2268,-125.567604,-160.958634,-127.557027,-42.197883,44.054227,59.376648,-5.48308,-59.52786,-155.511943,-189.396775,-163.886877,14.995962,106.272195,145.808788,92.33356,-33.964029,-79.940681,-128.510981,-120.027966,-10.471526,171.267592,217.994516,124.343978,18.267396,-162.945782,-202.071389,-159.42686,-43.416037,-0.058242,11.245564,-14.259491,-78.92689,-110.878508,-137.330623,-107.09355,18.558419,73.799098,37.656056,-40.076231,-22.181985,18.310464,-8.601044,-9.745313,159.276749,237.943306,256.061177,215.69719,157.463599,133.519838,67.620703,61.800638,146.324029,273.345888,286.123079,147.891287,56.308269,-56.541233,-87.476656,-78.69412,42.911634,96.561124,74.401383,22.594995,-14.86839,1.922973,11.823981,12.671811,88.273277,206.134883,224.746183,145.90977,71.303777,-79.663981,-133.72748,-112.784139,112.487192,230.19536,293.179595,238.125657,99.94364,60.666464,65.845233,102.438334,177.102169,188.532963,167.42315,61.865418,0.216511,-85.313112,-110.111711,-112.151546,-50.653664,-4.361487,95.652368,117.435778,21.54218,-73.383739,-147.076493,-88.836913,67.195469,127.108022,124.69082,84.217211,58.176032,-22.114152,-69.851157,-34.612261,175.640505,264.810078,314.942325,306.396849,310.651165,286.109252,140.225063,90.668281,168.878389,315.120609,331.425632,232.260502,160.979582,45.037815,12.761222,25.61721,74.316712,96.735639,123.61972,118.327877,51.889432,-14.554011,-123.139855,-93.745901,126.789676,290.354756,294.881335,186.435553,121.438603,42.344961,15.550246,35.197163,223.524781,325.803304,353.866885,265.83517,62.099219,-1.944519,-53.297635,-44.927179,-33.029177,-13.664726,21.6967,35.903276,-0.083164,-99.634489,-141.653603,-151.784932,-56.744666,11.873602,122.570879,138.065352,63.994028,-19.34354,-113.201391,-63.343162,89.703765,159.530521,182.149882,127.665088,42.072089,-88.902239,-94.255614,-4.022686,166.009923,245.735092,310.038333,280.102037,157.94343,110.64785,90.00604,105.131833,161.9923,284.693524,334.535786,260.02403,150.093772,-73.276098,-149.709962,-148.148777,27.810927,109.099299,122.519422,57.459388,-77.832054,-120.968302,-154.110717,-132.154375,-45.585394,12.458045,12.548582,-65.538473,-127.110228,-235.149601,-253.292517,-160.400365,-3.963964,38.35094,19.82269,-34.347437,-165.305066,-227.453778,-357.686442,-414.35556,-465.453557,-369.492507,-279.667018,-150.841635,-120.630108,-106.845253,-140.629294,-262.013957,-269.534109,-186.286071,-58.4085,-84.655365,-165.970503,-176.319674,-187.57836,-174.456467,-69.493886,78.259207,133.62244,150.716979,139.168456,144.220836,146.013162,81.058484,-35.99439,-34.107574,99.821795,140.149075,78.730067,25.682789,0.963741,48.584836,176.268138,233.412442,241.83459,200.966715,140.808205,-30.078775,-100.307582,-81.93594,61.670231,110.929538,135.346578,113.590284,46.94479,19.70101,16.469535,38.820759:79.486179,139.450237,162.917865,216.425229,221.061106,161.815646,127.257032,134.284855,154.503179,151.480487,160.280925,144.542301,68.439919,40.722771,21.211106,23.243979,29.269141,33.511531,40.901185,34.413702,9.48843,-93.188837,-153.187177,-162.470121,14.806894,93.414501,95.768176,48.245039,-17.97898,-21.688809,39.863614,110.655355,223.151749,149.80376,113.819448,182.011234,227.824799,128.546109,-10.351162,-185.390075,-69.323302,-1.753821,31.5116,41.442086,68.571722,29.872557,-130.243972,-158.153885,4.9474,235.359224,259.716608,124.025455,51.540454,-2.981792,-19.200997,-44.878672,-82.277444,-130.491948,-219.017126,-234.006698,-222.614914,-218.763472,-205.232111,-170.977085,-58.639933,50.442515,76.41543,45.59819,26.078992,8.563989,-14.085659,-16.201567,80.639764,132.279432,171.083936,132.4413,13.704262,-38.279945,-129.081406,-132.208724,-10.760402,201.093333,304.120645,359.244276,290.726763,94.511942,10.798132,-99.452278,-27.298859,94.998685,300.029901,311.473081,284.680966,299.705177,312.007863,309.019196,369.081257,427.402094,397.969289,222.514802,128.208818,52.591671,69.972737,176.843973,339.683528,401.539002,423.081773,377.127669,241.344868,206.973389,205.896974,192.774387,130.995187,142.487418,184.427805,247.10703,239.935883,190.700545,182.020811,225.569313,299.355124,345.589233,470.277438,517.432381,531.848042,505.136789,396.026348,351.851152,317.712545,265.780882,236.827903,159.522295,121.668817,76.10461,43.25557,-18.742143,-14.409956,2.952393,93.562887,154.218422,172.332398,116.753144,-30.739658,-76.136709,-57.794434,50.054743,130.682464,235.201945,186.5453,-54.595411,-133.185055,-58.086717,77.372049,97.095804,121.632424,119.367151,17.009188,-64.297227,-185.036211,-187.730318,-46.433789,132.111593,142.638023,-15.798029,-120.518483,-254.75494,-271.650142,-200.720687,-71.370559,-9.939815,87.626402,85.40958,-14.887117,-50.276623,-78.793981,-95.144371,-57.848426,83.840732,153.071427,229.264767,228.242138,189.71128,179.21447,194.80626,207.201578,215.267336,266.004471,287.797143,250.482465,174.949958,-2.531506,-23.825687,123.385614,246.4876,235.38863,163.269548,131.193537,36.231853,-35.16643,-122.105806,-23.791086,58.177306,143.337119,133.288028,67.2979,40.413244,59.180435,99.509888,180.482102,197.544307,179.643292,125.032172,89.899969,-16.23875,-76.179575,-84.86795,39.520594,76.616272,96.397611,111.51698,137.634507,130.707504,90.688711,72.270578,74.759673,182.46621,247.834167,240.034234,163.682755,23.808339,3.325496,53.18089,113.607388,114.096463,95.383497,70.464485,-56.591986,-118.446635,-106.242333,-31.874624,136.281476,187.2245,162.379517,71.193537,30.570505,-52.029077,-102.228857,-119.809257,68.601367,195.836011,361.207643,380.608763,363.984856,336.186157,180.52441,88.739225,64.088678,161.357541,176.733267,132.709539,102.902427,48.485601,-3.326719,-120.731115,-87.281868,-17.282089,78.825908,50.839529,-164.109823,-295.819293,-419.042158,-360.686297,-97.416381,85.831586,109.188723,23.632486,-53.907828,-133.608217,-118.803902,-28.918793,101.770107,162.202799,189.824045,129.382459,-36.337775,-99.921397,-232.786448,-278.909137,-234.930339,-169.355183,-170.91921,-189.747093,-185.401953,-165.865091,-184.333402,-264.935705,-246.171842,-198.206907,-170.590928,-212.149994,-268.635553,-235.603291,-128.192964,-95.090431,-56.591113,-27.004348,-29.510181,-137.28503,-225.777326,-331.770508,-330.795805,-255.691989,-132.478359,-58.688087,88.365497,133.989801,158.146136,158.667208,145.355934,127.84735,95.717265,134.047674,194.366283,267.423999,225.346825,39.84066,-42.751915,-90.018013,10.46253,85.621976,231.952309,256.383813,149.999306,56.616887,-104.07711,-143.868187,-110.187005,5.573369,46.627511,-25.054853,-124.792922,-223.951049,-203.045238,-180.497372,-161.854206,-116.395379,-46.093876,-57.680419,-161.422308,-248.043099,-427.122938,-466.526018,-424.437066,-344.410741,-297.592914,-154.72811,-95.871226,-129.236632,-195.248762,-241.919809,-153.421053,-128.065244,-162.697726,-181.536036,-147.016789,-122.006127,-171.917544,-223.248239,-254.668847,-151.3932,-54.920665,70.142764,46.43988,-62.123743,-82.93788,-44.868498,-14.219389,-4.991801,76.370998,129.872653,151.708858,116.708799,34.50851,41.619192,206.201185,313.448718,286.612818,176.923582,127.792603,43.584801,1.382721,-27.808154,53.152739,80.767008,62.068139,54.458481,86.20956,100.678634,83.684335,53.034004:114.925606,305.96944,354.011333,289.537846,212.04813,65.123129,14.306042,31.506399,156.172781,204.681699,240.123544,218.015126,119.177739,66.779992,-32.772431,-49.585533,64.569321,204.651306,197.589137,29.006054,-79.73577,-266.966816,-322.322513,-251.105635,10.726738,130.227517,199.335378,150.294001,16.674763,-32.475135,-30.075128,34.78636,189.269547,259.234663,244.578876,138.915591,85.193914,-15.451203,-66.496434,-52.883518,126.001048,190.114798,175.953367,118.710856,-5.354622,-58.105331,-155.224893,-157.319752,4.425841,198.462777,227.28279,138.084905,65.105133,-72.376003,-133.296095,-167.82817,-98.929714,-72.26483,-55.508,-81.427659,-207.261504,-264.150659,-266.575547,-202.231327,-5.356592,127.68569,125.345914,5.667571,-49.75372,-97.131486,-111.431257,-64.172457,69.358103,114.793672,178.113066,188.28211,75.27044,-20.093659,-120.771243,-96.800876,39.516105,186.803263,248.286146,266.607092,185.17395,-69.449805,-142.760245,-59.866999,123.784655,183.563358,249.866801,259.715085,218.54273,167.040036,83.043863,91.72614,201.22411,307.913783,302.797232,146.995555,41.875315,-100.670131,-116.308255,-17.375218,184.9224,265.641387,280.129726,205.630382,-7.26902,-81.151096,-54.801361,25.50987,152.216606,226.149107,274.429772,297.060096,225.431404,-12.217868,-87.050056,-15.237974,184.99832,269.838452,348.109612,328.076352,267.417388,247.256978,188.018755,167.619896,199.551784,262.592774,259.433684,131.014937,23.727089,-151.487038,-180.461871,-157.56561,-99.950052,-41.494212,80.230383,79.703354,-22.229174,-72.87811,-146.429316,-152.652967,-54.339904,121.522229,168.165608,67.176166,-43.593021,-239.923655,-295.692999,-241.012605,-32.126077,55.904008,133.318425,123.569352,7.848488,-109.563373,-311.473711,-284.391161,-12.379413,174.728854,165.006811,-23.970885,-150.521513,-340.352913,-383.06886,-332.637855,-124.592344,1.826732,158.080539,117.304716,-115.225095,-192.885692,-198.171574,-163.460617,-49.512401,78.991117,113.413018,121.975988,98.893361,-4.129019,-33.958165,57.876652,183.401792,202.907124,186.487237,172.369375,121.730931,59.161389,-72.167342,-57.140233,187.472,390.879344,365.01576,132.875378,3.922391,-150.844208,-169.12632,-126.169305,13.00052,97.575103,157.305652,111.758808,-25.186098,-79.790012,-119.545928,-85.046565,78.270956,252.179037,291.667324,200.9359,72.942813,-203.338972,-261.744329,-143.032019,106.601014,217.223443,310.244723,272.560951,150.887414,111.85369,61.935363,55.970248,116.168142,243.806654,285.267521,228.424379,140.82623,-72.891038,-144.789017,-91.687494,65.44346,88.322125,54.651768,45.279841,38.55221,-9.736183,-163.345091,-165.147795,25.100806,167.713697,172.693771,119.185103,61.182112,-121.616564,-188.310533,-111.784881,133.62228,249.517877,408.800433,429.311701,367.888782,303.633914,118.784071,41.895044,54.560637,249.152909,323.253831,265.875617,162.379849,-41.663475,-97.563206,-64.414633,38.000147,67.903314,87.319869,62.277229,-87.207378,-188.123045,-284.104516,-220.853597,42.276049,191.584694,195.186575,119.95106,36.027025,-135.615808,-157.817581,-35.215332,188.632109,273.808704,306.602496,243.113145,72.941895,7.831645,-138.051558,-186.838416,-83.607288,104.574644,130.095732,46.713418,-18.541846,-150.618,-201.616118,-193.414132,-55.649109,26.375685,79.828648,27.868132,-96.859387,-145.811573,-230.471677,-212.335892,-12.918741,123.216093,82.190011,-141.850894,-236.616973,-275.738399,-241.542609,-146.970298,-13.49894,98.234939,292.086391,286.774378,94.896297,-2.46802,-30.762458,42.136915,224.630123,331.559234,356.792677,312.628427,223.254998,-54.473025,-176.466739,-209.17482,6.729197,137.802122,287.357687,255.917386,30.477435,-87.317233,-223.117107,-233.423896,-123.070753,38.601438,60.034773,-53.389354,-147.736346,-295.369106,-328.132875,-268.176579,-108.139429,-52.256863,-35.650836,-73.534209,-220.266911,-316.031222,-477.364707,-498.441128,-392.071595,-188.461974,-104.041373,-49.484048,-66.816642,-169.158692,-239.580452,-255.781786,-109.697755,-54.926648,-1.062979,7.299485,-34.490942,-87.805322,-204.011649,-212.812526,-107.403204,53.845675,140.29935,209.608037,153.416338,-11.579406,-37.735436,19.96531,80.954765,126.375639,238.100174,245.593502,110.515531,15.091911,-77.378089,-44.410544,126.402886,277.445676,306.283604,234.780734,155.133067,-16.25836,-95.788417,-153.28114,-51.723316,2.157001,87.055648,120.877852,112.695671,51.432865,-97.173037,-113.739102:272.446022,281.863309,273.075102,277.08732,267.322365,199.79021,160.68912,119.339565,121.317523,117.900616,91.809805,63.758304,-9.269614,-44.62198,-134.541341,-172.868624,-190.128742,-166.7596,-146.20817,-126.012074,-168.522105,-379.480607,-470.906984,-455.621061,-313.072831,-272.173644,-285.566468,-301.387707,-254.073046,-228.448852,-256.105471,-263.282961,-211.56945,-152.23213,-118.683157,-24.193143,22.048169,39.145247,-10.826912,-153.171196,-166.909284,-121.197702,-65.03809,-71.12764,-82.189473,-93.520573,-156.62501,-166.609328,-53.645912,123.815634,173.04894,177.980586,157.209347,76.796113,26.906053,-15.576153,-12.059378,-17.136884,-44.55556,-66.843856,-82.605226,-57.547775,8.636358,27.253592,48.827695,64.552954,61.804583,17.573691,-0.2066,33.426381,65.57394,106.496289,151.472665,177.890254,145.206028,80.546644,-6.866042,-12.36181,-66.182805,-109.538743,-103.913001,43.783277,151.271494,247.642033,187.961928,-11.477437,-81.260507,-87.875832,40.492823,108.812387,157.638494,139.35151,149.858508,187.53259,182.298603,143.319668,133.981762,174.028829,190.855585,214.7618,189.452092,50.757207,-12.323455,19.270879,209.505715,286.978888,309.795948,256.620416,130.094801,79.437595,-49.89498,-124.656331,-195.356083,-110.985888,-46.910047,-20.021527,-67.335715,-127.813689,-87.056778,100.079475,240.875754,261.539764,290.01896,311.61901,327.126486,338.386563,360.302314,329.013503,208.21837,189.956227,242.012259,322.279488,289.212444,162.417036,133.229995,151.178576,158.18556,133.127755,103.683515,104.174414,41.935476,-23.006221,-150.368764,-181.868553,-127.402931,35.197949,131.721824,238.044744,200.052606,-0.801884,-75.295461,-29.942342,104.45525,110.807461,51.448625,44.907141,52.698449,22.098521,-98.565514,-135.310642,-83.528913,37.036021,60.220908,-45.763726,-134.045313,-203.070795,-178.632321,-129.383358,-142.072712,-136.371474,-81.787904,-81.972697,-126.008538,-136.351582,-149.448089,-136.804002,-51.84853,0.407444,9.958012,32.112191,38.993563,37.485576,47.577429,105.705907,88.994903,63.85216,106.899822,138.328217,73.974835,-5.886677,-104.018344,-89.260587,3.929364,27.889614,4.85499,-11.296711,-1.851152,-49.864574,-97.554976,-118.00551,-77.546878,-44.11304,90.036639,152.399862,181.053808,156.727874,104.298534,124.651872,263.58046,307.266825,269.877787,172.848753,125.19128,8.737134,-47.886283,-73.920326,-52.297459,-46.546322,43.88071,119.132037,198.720173,160.142854,-18.099849,-65.022081,0.544682,81.257555,96.159852,81.864846,49.349844,-29.694011,-57.52253,-41.732954,12.798812,7.474566,-40.41929,-55.560462,-67.669737,-66.378769,-20.981743,27.98677,93.713839,71.597775,78.154986,123.239516,116.54178,-5.042739,-81.389058,-72.815576,134.947909,224.282324,309.500594,317.575993,294.88071,260.251939,142.995408,90.924778,59.701374,47.549762,28.709784,-2.808895,-18.209369,-53.952587,-65.521224,-58.052575,-47.853682,-49.498793,-68.222087,-84.507676,-118.204907,-140.428405,-173.572685,-156.912341,-45.164532,90.574051,143.373064,119.559219,33.238305,-88.298141,-62.948848,86.586328,185.105707,178.004395,88.972021,26.397109,-89.432947,-128.318765,-229.89821,-301.646088,-363.036504,-249.370087,-198.726369,-216.975694,-253.981377,-284.604429,-282.486592,-269.682392,-227.911505,-205.610061,-181.939987,-180.706442,-223.292557,-265.42756,-300.846715,-259.576984,-128.263163,-101.359683,-106.820707,-118.338552,-141.767367,-211.419733,-233.061539,-177.816183,-25.425554,35.415881,104.237936,115.969039,100.239425,92.873625,107.999338,118.943537,110.964084,92.831104,114.024611,158.497057,140.357564,47.001895,-9.407488,-74.075086,37.279657,129.786507,231.569255,215.497302,139.126621,112.142922,18.938356,-41.711962,-48.20471,83.186663,148.218335,155.226785,88.003943,-30.321023,-34.741247,35.035247,88.98274,90.502862,113.20956,132.665544,70.85762,-11.473384,-115.836153,-118.638921,-97.398309,-13.074217,47.771938,102.345763,102.455462,136.276294,138.862916,30.430682,-78.529451,-79.374517,-12.57665,11.662285,15.491078,22.091295,30.827642,7.496703,-62.838487,-46.067006,2.67694,73.404767,74.461076,28.496764,-12.579375,-62.50611,-9.152236,18.468025,13.327599,-7.356053,6.687882,50.736763,92.860877,79.649612,80.514835,103.864069,108.5152,109.818747,86.924439,-14.067987,-53.241567,-60.288834,-84.170189,-98.424993,-32.884133,11.704778,10.775897,-18.565599,-70.182359,-73.997286:98.161071,226.570989,225.886303,145.468141,111.396441,90.015492,91.504504,103.951889,89.987634,92.975178,125.535442,122.162736,103.197741,94.857821,19.899144,-33.329753,-129.448733,-175.677063,-140.561216,-46.485223,-43.927944,-72.178974,-79.230566,-104.188685,-86.1235,-60.674501,-97.220201,-148.537829,-128.259422,-66.100685,-28.098439,-33.984716,35.844491,117.259332,138.836706,139.452907,101.02738,-5.28892,-46.551694,-137.908718,-208.720035,-175.058158,-20.648116,21.729196,24.398173,17.163331,-26.149025,-54.944399,-64.244212,1.718833,54.287257,116.42753,87.785035,-66.874772,-126.163114,-106.382075,-47.040166,-46.055388,-53.5205,-62.559779,-90.338317,-92.28186,-96.214825,-109.480497,-110.956073,-48.833503,-15.937772,20.751692,21.668428,-16.831327,-35.670163,-0.570795,82.558229,111.233877,96.900126,44.18691,-67.118845,-97.940892,-134.842945,-140.370012,-73.04551,111.721797,215.756832,319.176743,304.030433,174.569125,87.036182,3.477941,76.187131,114.767427,185.842025,238.806983,346.525643,366.784983,343.817626,347.736991,380.233817,351.224452,345.191865,325.991159,272.519741,132.34522,97.257416,124.337042,208.263489,257.424605,361.454603,387.342847,327.998439,253.374627,101.553713,72.169575,98.762306,136.762893,181.116483,292.865491,308.945104,258.430799,227.544055,234.30252,348.627762,407.638942,469.622,481.192091,527.281086,559.631125,520.274858,443.972646,335.503427,337.254865,339.26247,264.873867,209.099398,152.871102,129.254849,53.25144,25.535472,40.10274,92.023052,106.681526,115.057356,109.906066,-10.074726,-97.530755,-76.297236,166.688991,245.514879,255.626745,219.772909,78.316439,1.120615,-2.342113,72.103312,60.992465,22.840663,8.224886,-60.195832,-103.702581,-138.238797,-115.136131,-50.633085,-25.5805,-30.542296,-118.172801,-180.357996,-215.524097,-203.153481,-208.111101,-188.536177,-154.17018,-64.345427,-43.318249,-95.873668,-136.774418,-176.636818,-179.837897,-173.107242,-92.788529,-30.865675,11.882355,-14.835851,-78.956319,-68.738718,94.137963,215.28073,205.55429,204.589475,234.208518,229.818824,175.206136,30.838691,-16.348895,-23.367753,-2.778615,-14.217709,-38.293885,-8.715949,58.198527,38.369272,-50.087578,-50.486155,-10.986196,52.902324,62.027423,81.606195,80.248852,38.697469,39.707241,94.844228,102.228323,98.209412,68.636871,24.546613,-121.62386,-203.053619,-232.970909,-61.507702,23.371086,95.225635,86.755956,68.497368,74.396258,30.565837,-17.451562,-40.363127,57.815389,118.29491,164.698988,125.187403,-14.251889,-58.085317,10.211054,158.221902,184.268689,126.312831,66.127194,-25.397502,-25.603433,66.884797,131.307911,196.524807,224.976272,258.481612,276.247722,232.333359,85.100046,18.742748,-5.674033,145.966081,239.283604,358.010974,371.899954,324.277575,262.299239,67.144477,-10.640831,-29.461727,10.529021,39.205997,109.17633,125.03788,117.618549,81.452672,-52.316929,-105.747064,-80.668502,-20.104146,-28.893903,-135.932093,-197.976013,-230.563113,-182.806199,-43.045419,107.858143,176.732,138.798134,53.600145,-33.599005,-29.292537,-4.720875,-3.331147,-16.95405,5.211786,43.808231,38.170362,-46.978375,-278.786839,-338.844123,-311.985048,-246.232913,-217.247967,-171.140062,-175.922527,-280.658395,-362.336075,-437.982377,-353.863359,-288.732752,-172.983572,-150.418537,-147.461983,-155.373486,-245.036583,-292.338362,-223.350708,-18.682453,34.00487,-58.533494,-147.359585,-244.734303,-265.752322,-277.236029,-167.92563,-89.415816,8.45452,14.04286,-24.063994,-39.464607,6.413274,52.080112,82.336874,74.775389,115.502379,214.582412,192.822495,-20.333586,-130.823215,-150.109296,28.150471,108.569353,183.503815,154.862029,-7.614368,-89.611022,-206.090796,-245.355928,-234.523337,-111.603534,-48.653593,24.310957,22.221759,-25.334125,-46.852739,-53.154995,-22.178256,-0.431882,63.196119,89.878497,105.422306,84.829609,-22.21508,-56.973035,-38.954045,-41.161349,-30.104039,54.970142,87.489481,73.716935,32.765664,-59.464631,-20.199753,30.045189,70.631372,74.497749,124.384846,135.740909,41.526456,-12.117191,-15.101799,36.365198,52.428584,66.644184,55.29119,-38.334824,-88.222165,-75.113993,5.739156,18.814561,9.353678,-2.924133,-4.978546,19.721757,61.658771,71.734881,111.650238,136.59009,121.916492,48.74986,-5.191368,-120.846602,-172.55417,-229.668488,-164.650945,-107.707361,-55.201045,-64.370095,-52.705949,-20.834718,-8.15839,-44.533916:204.736808,313.715632,274.462104,184.653069,201.763034,248.338608,192.708523,-4.514899,-6.368588,74.836858,192.803106,172.245252,39.271386,-14.305128,-53.583721,-51.781661,-33.718585,-7.269234,14.046565,-22.90591,-119.512362,-357.811587,-409.1148,-309.681716,-130.359942,-64.888488,-9.75275,-20.914451,-77.642607,-103.245583,-129.195326,-121.626558,-63.288725,25.598056,47.88168,5.803978,-8.56745,10.962956,-26.956444,-179.020567,-109.45611,-3.78002,110.662108,92.301087,-18.784128,-90.075082,-189.978462,-162.178734,30.13732,164.873506,180.057496,125.100048,64.198515,-55.326251,-93.044624,-71.122514,16.492538,22.458755,-29.590114,-65.126189,-170.79001,-225.77807,-231.412375,-171.596956,32.75305,176.870629,145.811315,-4.755768,-38.199032,-35.424924,-29.124404,4.015651,51.110549,86.161037,148.159933,120.752519,0.916881,-24.112319,-12.399622,5.423217,48.495407,76.541849,105.149065,133.138689,100.037656,2.65013,-33.348671,-41.645038,40.999807,74.661733,121.892617,158.147933,223.602191,229.084019,166.572531,133.731928,175.232148,269.819584,288.591568,198.689702,98.493262,-59.554261,-86.279485,-41.455526,125.392619,196.122309,155.220016,66.222011,-62.695685,-72.187269,-56.265624,-58.622121,-57.063655,29.754684,78.446802,47.702274,-23.043481,-130.122352,-134.743115,-46.142997,116.059453,190.333309,262.500456,262.232839,247.920778,236.717219,197.81249,203.820286,276.212573,309.860528,319.886805,298.555504,239.606633,80.381011,12.314667,-59.670911,-9.739957,71.87414,253.894334,269.900199,97.348481,-13.154991,-64.591328,2.990219,171.498489,240.488151,238.797355,133.489403,24.355839,-202.65036,-258.271334,-180.219434,-14.024804,35.326728,65.586572,60.275293,16.438858,-32.449732,-137.488789,-129.45324,3.254623,55.190433,36.272626,-31.457447,-79.857102,-219.90954,-269.168681,-219.357903,-58.59203,14.792718,41.940515,-27.738792,-145.906951,-122.811162,-39.547061,-29.18308,18.850091,99.537322,122.326443,163.047202,171.580922,138.889914,132.704863,197.793938,247.645754,232.324023,163.634972,128.855549,58.578633,16.813183,-49.443167,-45.043514,56.973954,190.204551,230.528997,220.318996,174.331598,52.922287,-10.970267,-109.42034,-49.133135,43.737094,222.616658,256.58597,217.429937,175.782356,99.58965,92.677769,168.781784,230.891084,224.6981,189.10699,158.400332,45.923694,-14.321862,-89.83837,-79.283832,-7.591197,215.764466,283.794136,253.292796,194.331522,85.730663,64.784924,97.568025,145.611649,169.233674,129.801181,54.486905,-44.384847,-43.592711,-19.848783,43.470153,73.183735,65.856908,44.049583,-11.324116,-57.665955,-156.687493,-148.230029,6.747735,95.174726,73.782731,-44.425798,-115.503658,-232.520336,-257.266371,-166.040506,32.927205,91.925699,125.785787,133.406597,166.390443,184.088624,134.100219,67.584364,2.084085,80.377975,108.873621,53.831192,-4.4417,-98.142298,-125.596637,-127.817213,-119.948548,-138.794847,-132.897596,-106.018936,-122.984672,-179.182664,-233.428365,-169.719466,18.0894,65.010806,54.41132,-8.531852,-63.655241,-151.668409,-170.391262,-138.964782,78.915401,213.554899,261.889696,161.896875,-28.419699,-64.759394,-139.33459,-203.988751,-261.605209,-162.399383,-124.598164,-170.926891,-206.382914,-192.469507,-176.090604,-210.025602,-232.562648,-201.390157,-124.764569,-124.903476,-187.747051,-208.797116,-207.352434,-181.854031,-105.907943,-97.808232,-111.156384,-160.665179,-187.227246,-213.484543,-229.811172,-220.318554,-61.536281,22.03906,84.735441,76.035838,70.11678,92.822213,139.039363,146.316327,147.539563,130.28664,129.625441,130.992482,104.797209,-14.006121,-78.269553,-118.660067,-13.442542,68.58978,190.555797,180.29078,35.809318,-35.068801,-122.318373,-141.206398,-83.265689,82.29978,150.675799,113.499338,21.242934,-112.826843,-117.333121,-78.928789,-61.211009,-56.62035,-41.016623,-29.837209,-74.629201,-147.900304,-220.864579,-200.248212,-224.694926,-237.139065,-166.851077,-17.747982,4.713871,-16.23737,-47.249509,-98.415775,-54.873189,-36.809024,-50.800138,-62.735729,-96.426837,-130.501301,-188.467473,-177.406502,-71.282476,78.357326,148.490449,187.471436,141.554312,-21.779594,-92.201164,-72.580018,77.601435,111.171208,81.105538,48.655698,-10.313314,-32.541952,-40.383501,-19.238142,64.696327,160.723368,194.470213,184.440953,130.646828,-42.064971,-116.011602,-123.659787,-59.752997,-66.51257,-72.459247,-27.735989,93.758205,109.631984,15.712727,-30.62728:right
31.983683,163.413362,245.76886,328.215741,293.898798,110.42378,-7.602241,-186.134282,-150.973707,-70.278234,130.331524,228.542828,362.662646,370.4633,264.075486,184.134952,46.523413,-12.82465,4.00761,97.522286,128.432076,54.723711,-25.2395,-66.787952,-44.989709,-85.625635,-87.647698,-14.884298,76.413593,44.924212,-113.962034,-188.115597,-183.097611,-9.676317,77.237602,152.514696,150.44278,166.573295,169.777373,110.361961,71.020473,99.45973,238.906494,301.436207,349.895124,353.284623,353.347931,349.944536,310.7654,266.263695,268.131482,241.327556,183.122632,22.705969,-65.45894,-212.239629,-203.457274,-145.198878,-46.752853,-34.844462,-50.442089,-71.028042,-175.619429,-243.622752,-265.0399,-92.371182,16.802659,133.815673,107.531044,-32.397838,-106.830785,-230.233201,-237.457765,-203.454003,-150.963994,-124.599841,-64.867045,-69.642636,-148.064107,-180.113228,-212.872701,-232.406203,-222.666431,-171.060577,-146.324919,-159.973536,-191.47289,-180.937195,-84.628482,-28.585562,140.654077,216.424859,169.292672,42.612274,-223.640378,-281.417526,-215.971862,-90.339065,-44.701913,-20.779081,-52.625986,-139.687789,-155.474184,-89.481853,42.416057,91.7216,125.357168,122.094651,111.23481,81.555487,-42.589421,-85.107809,-91.178277,-71.343556,-17.067003,191.882174,276.68896,307.50039,271.915171,207.482445,193.112137,183.112462,177.269756,181.442038,175.971813,163.936836,55.6042,-32.445432,-93.586489,65.150913,151.272843,162.38114,94.689171,13.547209,35.82647,72.378656,-19.172818,-58.867898,-15.773576,33.967183,42.737293,-35.760473,-277.012895,-331.197592,-211.425945,-89.264366,-73.786645,-32.122455,-5.888349,-21.657942,-83.189336,-223.229445,-195.298265,-131.456586,-34.495645,-34.717223,-146.7829,-224.124565,-308.86282,-311.290259,-293.896539,-227.239336,-164.65223,-64.824439,-46.79148,-80.197465,-149.040152,-265.222704,-173.601574,-123.511069,-169.342502,-238.870624,-308.008694,-286.422501,-242.554365,-250.11611,-268.160493,-167.919645,-70.571401,37.368235,10.36842,-81.151372,-106.041794,-126.063917,-135.938068,-123.513788,-44.863086,-28.159479,-123.625722,-188.770745,-245.093967,-239.896774,-231.673552,-273.696362,-279.096938,-215.092715,-179.201774,-214.575044,-305.231128,-491.223376,-469.470444,-403.654574,-291.876104,-258.766629,-199.32957,-197.086861,-336.441683,-418.979733,-400.730458,-211.610607,-115.626239,12.53975,18.351301,-109.429978,-198.856874,-233.66175,-120.298962,-104.237729,-131.593295,-131.927723,-155.998178,-203.296331,-316.777268,-331.828826,-227.837539,-107.375631,-104.281325,-220.20675,-281.06088,-306.454003,-301.454484,-331.322439,-370.409586,-358.661182,-232.529748,-158.651336,-144.217263,-195.618529,-214.089224,-155.747525,-86.783795,-132.309136,-134.105789,-128.093913,-159.818186,-258.424711,-296.240513,-310.193342,-217.396159,-158.762316,-102.174183,-94.101853,-77.084839,-95.979429,-234.368069,-322.897346,-457.085878,-514.804965,-508.270806,-438.350432,-399.691824,-387.5091,-422.688349,-491.755507,-460.276198,-395.086809,-161.531901,-56.500741,-45.923703,-99.596113,-150.255485,-148.218766,-121.428049,18.142567,115.972528,185.416355,152.946764,103.106793,89.624092,30.408895,5.089887,24.572748,101.230726,138.257856,143.902667,102.794021,-10.097193,-33.687445,20.005959,112.335103,170.095262,257.161293,256.531457,223.886408,198.154313,78.127838,-25.062748,-11.692229,88.042971,112.588666,69.852117,28.702955,-74.099098,-114.686696,-70.394956,77.720629,145.993789,234.72373,233.773977,80.931239,-53.072408,-204.058829,-95.119323,-42.545839,-18.639729,-8.956081,-16.877113,-68.902798,-179.906781,-179.385328,-118.477241,-88.241672,-37.123648,101.986744,99.268728,-117.972655,-269.624867,-420.334064,-252.024519,-132.100993,-4.457059,11.001798,-15.00927,-67.398073,-187.232953,-210.178045,-203.609818,-177.616413,-144.563986,-112.265661,-132.480401,-149.631694,-131.878493,-72.032856,43.22864,102.356711,169.208127,178.902388,183.65293,182.838322,166.410257,176.755698,273.253503,312.210678,286.408786,235.083577,217.583748,134.626412,53.961867,-87.102376,-62.633546,-3.743553,145.174552,215.01324,288.814058,293.047013,247.868482,210.938242,207.459053,319.777331,394.949327,517.783917,514.993146,329.307684,189.830566,8.503057,46.936496,108.639238,238.494763,276.890863,250.876917,198.18594,58.670951,-0.343506,-70.223526,-112.60973,-96.296663,20.631488,62.461571,37.836541,28.757131,137.458153,253.496987,249.571854,164.995106,116.149048,49.916672,40.980855,18.863113,-14.062668:76.346161,196.713649,218.544666,214.688011,200.332512,91.097987,-0.360143,-76.570276,10.012068,44.297911,59.505466,87.667386,230.489996,272.904632,185.603519,109.568073,36.033567,91.467925,137.711683,149.573501,118.078135,40.360501,-19.701849,-125.970463,-144.324482,-135.195618,-70.044737,-48.444928,-85.86822,-113.864581,-154.283912,-171.226471,-145.963926,-6.813867,74.508145,182.713938,200.531877,169.761172,140.583689,144.779356,225.212431,258.040026,292.050909,302.89285,363.097801,393.652236,343.743853,286.368501,249.500748,343.926884,387.228362,328.825205,232.3316,60.275683,27.22701,59.035313,109.690844,110.434742,104.328543,115.314763,144.575867,142.757504,61.534665,-3.733408,-51.83302,77.849097,157.72287,226.151966,210.756066,88.627177,1.187699,-106.536057,-75.506722,-9.667178,151.174028,176.905251,65.883582,-16.451425,-115.091363,-122.03053,-91.716252,-73.396945,-54.425598,-2.635338,7.454353,-40.247865,-71.891831,-17.135845,66.297931,78.846648,172.592694,215.549952,116.645729,-4.899563,-211.335737,-232.284172,-96.276412,66.061625,109.737135,117.436166,76.197855,-36.056154,-60.09167,35.971808,220.767039,284.438492,324.174933,306.978155,276.857223,269.838835,160.896848,68.285471,-29.816174,15.821738,75.190236,236.295313,302.371108,330.068827,300.024609,239.952978,229.251043,245.692512,308.711949,314.714596,248.040895,211.585102,131.71367,83.342917,70.516231,200.710682,266.595958,270.988348,216.158544,92.833442,55.351649,114.48533,205.287129,173.320025,80.499272,93.722658,148.791322,106.416154,-130.313878,-225.18575,-213.64833,-117.624436,-88.485675,-51.192766,-38.619486,-23.491675,-23.166076,-52.629595,-95.129115,-66.025996,52.495463,60.555862,-65.825667,-161.08849,-309.39855,-307.578092,-168.308986,-67.122755,-57.609089,-41.390439,-4.902667,46.900537,23.716419,-15.420813,31.697266,51.093029,23.673103,-16.061109,-91.186763,-132.18598,-196.628472,-178.537081,-46.932266,95.745901,151.99219,163.167653,121.686169,69.941269,56.240239,-37.730195,-73.768422,-2.352274,179.902084,194.818404,39.637492,-69.432065,-235.290936,-271.398343,-232.142333,-109.497793,-77.325835,-162.180033,-246.638417,-387.638831,-450.850898,-569.520803,-552.330967,-476.316391,-300.736915,-255.164156,-250.184182,-268.023595,-371.817867,-434.605477,-423.61392,-217.981809,-93.708489,66.183283,54.829953,-158.473623,-290.821228,-393.624573,-257.859019,-176.622205,-116.829878,-138.00657,-208.642454,-228.968148,-243.417278,-240.485015,-167.753544,-73.870044,-75.945424,-141.554001,-170.141879,-268.589779,-341.427016,-418.346543,-365.987353,-313.752517,-217.786608,-190.009018,-172.83532,-189.431771,-218.849022,-198.182735,-149.91324,-108.787455,-42.033204,61.438467,21.951312,-163.515451,-248.631573,-365.644801,-311.996366,-219.232197,-70.853647,-54.019184,-122.354734,-197.792749,-375.500575,-424.154973,-408.307012,-401.032826,-408.984604,-432.625592,-457.688248,-503.671199,-508.70644,-474.372217,-408.147904,-357.198164,-178.937488,-89.88625,-71.277551,-129.920393,-214.867614,-203.296245,-97.699052,43.451247,109.250748,136.46,92.466057,-16.743918,-64.125626,-94.093778,-33.855763,-9.087045,21.682241,33.151278,41.274352,23.539321,-92.300655,-147.692968,-126.162615,-14.249968,21.769578,57.94187,81.7651,126.856345,111.76322,9.718407,-64.682881,-52.366739,84.946912,134.82566,72.564549,6.542345,-101.954741,-122.862174,-41.933385,108.384181,148.927132,140.200344,119.999506,48.498123,-26.03348,-163.513159,-114.774509,-56.816186,10.795929,36.963851,75.086117,43.593689,-106.043863,-161.269895,-131.274672,4.399225,48.216515,34.612018,-10.00866,-143.696264,-217.239555,-240.165151,-138.179464,-133.900314,-176.723684,-173.131201,-142.613786,-147.183282,-179.213807,-178.695973,-146.991762,-139.930115,-136.962828,-115.37544,-109.214659,-138.444328,-169.464351,-143.092148,52.385731,127.199962,152.660437,138.134674,128.134192,151.286323,254.945744,310.516893,366.086936,357.669935,334.325154,249.599199,192.487252,79.645483,39.042661,0.086475,16.486819,63.659464,246.209087,335.158496,380.226515,341.157377,254.12726,238.875192,266.270564,309.050402,326.994761,331.42718,313.827658,217.581066,135.606801,10.122265,21.94127,57.634541,176.529846,237.99699,231.93532,145.612324,-74.411033,-129.299452,-100.009551,-27.766284,16.747693,104.819787,112.736163,51.617708,34.404674,95.564525,184.804288,202.278558,173.268763,124.909658,-10.399478,-73.695428,-161.680088,-157.147408:85.94606,74.135328,60.801404,40.688055,52.482541,52.310554,2.854431,-84.279772,-64.570453,-50.995559,-26.880085,-3.538626,42.443099,34.310835,-38.185837,-58.873408,-9.043759,71.756149,73.481197,8.031383,-24.872145,-86.784951,-107.836474,-68.007644,-71.014865,-93.158513,-54.403156,-32.969873,-87.265003,-135.714093,-189.186235,-181.022336,-88.344851,75.843627,138.914516,141.892588,111.962525,98.957348,130.587426,259.640453,363.693922,382.903326,393.969238,406.408932,454.84704,453.743616,340.140406,279.234314,297.123173,374.092634,349.526235,202.219808,139.571582,79.708766,72.864743,96.082134,107.760533,102.032236,132.1633,167.263301,186.59615,143.658892,27.52089,8.659734,55.154556,129.66256,169.652902,215.5901,186.921092,40.170377,-31.537514,-95.173091,-9.586482,78.193502,215.501522,229.002281,142.527718,43.761874,-195.068123,-255.222812,-173.348133,-18.871678,42.295179,122.503753,128.355945,61.655496,13.818949,3.621076,109.17591,158.737799,194.280593,186.026875,148.60523,112.029038,10.759353,-9.722543,35.066324,139.236684,211.636731,280.013629,239.513821,91.866024,44.170392,53.827338,134.747699,202.383155,385.908737,429.197817,300.190532,198.78311,127.077264,139.572061,134.147643,125.953579,156.667294,256.437698,295.807325,291.241644,257.043341,221.67757,253.76302,283.945113,338.213114,332.11891,239.646385,175.988152,75.663005,71.801846,177.859712,325.224502,387.302103,418.603706,358.423978,147.35068,70.467303,93.913836,185.232447,202.162897,240.837128,255.786893,166.697456,45.741854,-192.10465,-211.455257,-64.438413,25.980036,22.859415,35.062494,69.428859,97.323259,50.626478,-71.510915,-79.980009,-38.54401,75.98758,110.333013,57.537546,-3.88978,-63.81425,-45.249205,36.529792,100.09982,128.167672,152.546215,137.539105,99.764156,92.436874,79.956596,84.581475,106.061195,132.924762,113.189421,23.091013,-34.553849,-108.912043,-78.698942,90.402856,230.17487,268.88312,262.16401,201.008085,22.536704,-28.713469,14.937648,122.748792,181.365321,268.493326,224.066189,-44.6377,-174.992979,-248.858825,-187.212106,-43.054678,4.033909,33.089856,35.67894,-45.88349,-299.185846,-391.532749,-444.893707,-411.986278,-387.156542,-323.448221,-294.78329,-288.727257,-317.863184,-415.416944,-446.538562,-388.287568,-215.806681,-131.274751,-78.060819,-125.501034,-298.834995,-367.910561,-368.052155,-245.874227,-186.600807,-130.541555,-124.831185,-143.026786,-181.55496,-249.97137,-240.760591,-156.201642,-35.352114,9.858199,3.341612,-33.237049,-114.725141,-160.948862,-256.019731,-343.511288,-376.189014,-365.789788,-316.798703,-226.377008,-225.840326,-276.097635,-278.241717,-197.049601,-50.744938,14.041178,60.967178,39.395774,-96.39386,-201.972385,-329.703621,-239.608574,-188.606079,-153.822756,-139.044452,-114.262795,-140.232091,-281.43519,-353.736883,-381.562074,-295.115788,-275.518824,-337.962314,-373.902665,-375.819502,-380.59584,-421.750146,-363.998447,-304.535003,-242.913228,-242.307511,-219.104648,-196.862433,-193.466451,-203.071825,-171.434219,-35.905901,55.903069,140.903268,98.707748,-83.03127,-176.594574,-273.867057,-220.339704,-167.059846,-62.976966,-36.215532,-71.329273,-118.576112,-222.461894,-255.001089,-215.727663,-88.528711,-43.661858,-35.229186,-51.276397,-79.648155,-99.488072,-151.325099,-150.672962,-127.560853,-68.547087,-50.121063,-64.984049,-96.430655,-151.792329,-141.770981,-35.943266,72.401386,102.159474,143.823451,152.248983,95.232015,40.864835,-10.71729,42.292373,73.72693,145.787623,201.789116,255.509832,195.991983,-1.272894,-55.09271,-31.61455,34.825938,41.217945,-5.63455,-44.206327,-132.494122,-162.452283,-121.992929,-62.398743,-85.250186,-128.623571,-103.905897,-52.810883,-78.070897,-156.947093,-147.992437,-52.097509,21.254623,36.894996,14.090128,-13.293947,-70.542727,-89.340793,-33.103497,94.69612,130.494813,159.473089,173.625535,200.926732,221.717422,264.46206,250.97587,184.745997,207.850675,229.669185,212.609105,188.478547,119.407216,59.898119,-29.142673,29.58075,102.908872,232.385587,250.654425,221.886268,186.606931,82.126567,60.101819,117.784592,204.360178,240.077697,230.144269,168.811937,-30.714923,-124.363945,-170.623617,-74.835911,-27.956948,28.07128,45.807706,47.152096,7.613828,-125.753321,-165.298974,-142.08038,-75.363671,-34.828404,4.978472,-43.901853,-256.680457,-330.194035,-257.961899,-62.786574,-5.948445,-17.730596,-59.33558,-146.075798,-188.553058,-217.720281,-176.62348:41.997768,214.420152,281.097077,227.658527,129.9561,-40.824377,-107.519758,-204.405511,-155.67598,-88.224136,62.046673,132.945222,260.955504,284.230119,185.200983,114.340268,35.333433,10.976529,30.113598,83.564863,79.53763,15.158525,-21.939573,-48.969036,-35.493084,-21.716282,50.263002,61.887682,-58.022987,-138.965076,-246.591026,-281.166408,-245.419086,-59.981233,34.458968,145.779452,157.133335,103.852725,65.74302,128.251382,317.226288,358.366455,359.734464,371.418458,417.545545,421.932477,369.4697,338.704057,318.93706,344.569261,347.794071,244.106283,151.963481,9.000566,-36.556348,-124.921629,-173.756405,-148.800877,5.571212,87.090842,143.516984,106.441016,-63.596548,-136.157563,-97.779682,88.289298,166.738529,189.073235,116.406777,-70.653091,-137.717279,-192.826941,-114.892497,-44.153618,79.133092,99.414415,24.099077,-41.859643,-160.812443,-203.791614,-217.200378,-119.749915,-56.621026,-10.261037,-45.969605,-143.249354,-155.505868,-102.975056,-27.241162,24.481051,158.621456,202.927527,161.260373,73.529673,-136.374589,-182.584579,-104.422528,51.94168,129.365438,190.490479,142.814116,10.867468,-5.859873,54.376182,136.006556,198.546863,347.524058,364.66076,244.608911,162.113212,45.48233,17.720572,6.777818,78.544091,151.55814,265.408864,283.610624,277.696635,273.316872,282.073724,263.031865,255.348737,281.476647,285.062652,236.450831,202.106624,114.665618,62.674766,32.644792,188.966479,279.040193,301.684811,241.546597,102.992292,49.906321,52.554547,152.137892,166.375168,156.955556,155.435867,108.279096,46.477182,-138.31891,-207.164149,-184.998984,-47.389456,32.898216,184.496356,219.132235,148.251147,63.597753,-66.859525,-43.55443,20.207101,178.903908,215.52739,121.755693,18.243047,-161.800124,-179.693942,-55.975305,60.356764,93.423311,176.345087,198.880954,98.619091,-6.511642,-135.420207,-78.477265,-27.572587,30.478418,10.309018,-98.647829,-139.430589,-156.587376,-149.817299,-98.395411,50.185405,133.299887,179.319873,128.679127,-32.073296,-112.209755,-188.801929,-79.802981,11.270535,129.103802,114.61739,-12.091183,-90.134542,-249.386355,-282.641054,-180.811126,-85.250632,-85.685351,-62.605541,-43.960994,-118.949605,-218.710467,-418.512026,-458.197831,-416.647608,-301.24118,-257.427711,-215.212331,-241.016663,-414.202825,-477.695777,-393.51157,-220.386925,-156.856186,-95.420705,-96.066427,-149.238599,-210.736683,-320.401855,-268.428769,-200.622571,-98.28006,-84.727859,-102.220973,-129.198469,-230.895252,-270.596228,-238.584773,-111.231824,-63.240254,-88.742004,-150.847272,-301.867953,-373.18431,-434.335479,-399.002948,-375.496847,-299.258905,-250.563033,-202.396218,-220.129444,-281.226634,-282.304757,-212.590998,-125.434325,-96.317892,-82.517466,-100.301546,-225.790328,-319.92689,-395.489739,-269.442809,-205.519013,-132.427981,-89.97012,-31.358701,-84.138057,-366.55615,-492.481695,-499.057278,-352.012062,-314.871146,-328.616685,-360.429676,-432.017436,-454.86705,-477.373217,-462.27748,-402.854908,-189.183276,-100.017569,-97.544009,-160.387418,-253.425909,-247.367785,-148.238663,3.203218,63.046814,58.567767,27.675555,12.673382,-13.511838,-166.073307,-218.859664,-154.731011,-4.32319,14.597729,-12.180791,-32.432956,-133.395587,-183.083824,-136.635371,27.434052,84.69065,78.126528,44.238232,38.057894,45.587421,11.684623,-60.398414,-73.270261,47.089161,119.7654,74.440904,-6.832923,-92.899284,-104.676293,-130.45019,-11.529984,109.93656,267.087614,255.578917,87.882295,-17.178733,-96.293948,-8.959811,28.392401,66.651273,93.656302,131.415179,91.51155,-79.853163,-131.854735,-83.152088,45.957815,97.493004,90.323837,17.480506,-182.111041,-258.171894,-280.671142,-179.031854,-118.772992,-25.341069,-4.874625,-39.307287,-106.613267,-276.398099,-305.828277,-189.070765,-29.234412,13.150418,-0.722017,-41.900826,-102.810389,-104.012997,-26.669132,102.784333,135.403117,163.768072,185.252103,188.133303,166.378191,151.021452,157.431153,142.255389,140.070016,187.235822,311.707486,317.509238,120.960192,-36.378401,-206.207553,-137.476293,-87.62466,33.467856,97.363525,132.628849,99.986364,-6.863705,-54.009322,-37.86992,120.968427,197.115669,265.610132,250.837271,118.263695,16.437037,-100.292075,35.34108,135.175843,200.123375,163.496561,102.527575,91.961534,2.917477,-81.820523,-222.485179,-194.95891,-125.774381,-71.869877,-124.645735,-215.374022,-206.488464,-172.258242,-97.158955,-21.232257,83.326867,72.179194,8.812573,-8.80542,-40.154407,-48.283803:144.378778,206.85488,194.641893,99.985668,33.029324,-115.445399,-186.351224,-251.629562,-235.453705,-205.589573,-55.42822,31.257775,83.864922,38.578483,-66.454633,-81.221669,-64.529022,-22.881081,10.430188,68.896888,71.534469,-35.268127,-124.595726,-177.431802,-81.645411,-63.228606,-82.700371,-107.076787,-200.375601,-255.319202,-320.077842,-317.03663,-249.662617,-102.513152,-19.658305,35.231591,4.94841,-51.711681,-29.79264,175.243887,386.826368,416.786122,436.011509,460.541225,479.292705,441.14568,327.106472,297.946874,281.118631,251.955826,236.855169,172.715642,116.980049,-0.030837,-46.338193,-108.392591,-121.716726,-84.768849,73.150978,144.564183,135.087674,38.98428,-163.166658,-161.382094,8.288415,98.345255,115.320076,114.551613,61.809104,-110.773995,-172.649694,-185.98754,-146.501137,-96.770741,63.349269,96.91437,-23.480135,-136.959428,-306.263822,-311.475769,-205.165518,-61.038611,0.943309,-3.792627,-59.540486,-140.713436,-139.771411,-76.189543,-21.991096,18.346529,140.941193,173.113736,113.025372,32.82792,-105.624652,-117.794728,-66.674393,100.068422,215.176433,265.71265,161.350963,-65.325815,-79.167331,49.044116,160.868529,213.740765,328.755512,353.438373,273.307045,159.32871,-74.777292,-90.935967,53.550503,163.411682,207.790038,293.756805,297.144994,188.267441,115.676326,82.17368,220.590122,301.710546,365.935125,337.229431,220.783866,151.169982,16.114251,-19.026745,20.521144,197.477784,287.512725,310.847928,249.015836,99.77067,49.72437,60.287273,150.734601,196.609303,283.811978,282.989466,143.213194,42.888108,-117.218485,-147.546693,-87.920275,49.820994,119.198562,216.486437,227.273934,109.823176,3.3764,-94.659728,24.913831,112.062272,254.816911,279.420529,199.525308,114.005001,-66.022816,-109.814406,-30.034684,140.540887,213.271604,287.509828,267.425817,114.59228,28.471252,-2.619949,98.260845,144.953753,176.419354,135.548181,0.929843,-47.630472,-76.537047,-56.816623,20.598029,131.915015,192.778633,212.000094,142.803914,-37.550627,-82.148548,-53.541385,64.059504,127.185421,178.28314,143.948393,17.301091,-44.1273,-136.434172,-120.993888,82.890129,262.19399,269.621653,174.862404,110.020884,-29.443632,-107.625005,-240.833814,-237.353831,-162.003827,2.620225,13.079642,-90.570178,-166.78402,-326.664188,-358.276223,-263.487548,-89.732638,-0.608562,99.9207,59.247929,-146.948241,-228.41859,-228.66149,-82.747784,-6.425828,80.355143,80.672063,17.110589,-45.216927,-182.003824,-198.982827,-63.411367,166.611758,236.497447,221.411944,168.187899,-7.479852,-128.503432,-293.910295,-249.560084,-187.678027,-79.431682,-52.408095,-67.24608,-106.016821,-167.736353,-144.613368,-9.349614,90.847257,114.085008,112.975836,73.40924,-71.710536,-140.903901,-173.068228,-82.408591,-25.023151,89.207464,137.408288,162.082462,116.137599,-92.785574,-209.812154,-293.263658,-126.391312,-34.748767,-10.888554,-61.762036,-203.013239,-280.180567,-348.191185,-263.730806,-192.867284,-36.850636,6.734155,-47.481834,-110.595911,-197.06248,-190.82024,-72.122449,94.697819,149.953624,154.240813,123.687887,-9.726845,-124.2842,-270.947203,-125.415246,-2.292039,129.40044,96.200029,-41.500787,-79.945356,-130.418215,-163.482299,-160.928957,-8.101239,70.663798,83.474189,39.537994,-32.740215,-59.077683,-93.405479,-91.939436,-51.75633,100.788293,123.629679,-13.85229,-94.740523,-158.260027,-147.627128,-42.776341,149.324465,223.739219,215.986801,166.877642,85.895104,38.531019,-60.233528,-27.262101,46.586936,178.277288,199.206549,160.440084,106.502878,-42.326197,-99.439949,-110.447812,-46.714768,-5.935074,59.626918,44.484963,-147.57183,-264.870552,-312.389295,-157.883898,-69.982135,39.185602,31.178563,-83.317363,-160.686025,-279.763403,-271.611418,-102.43785,67.695995,96.445092,13.851104,-60.08106,-150.643324,-160.065499,-106.800876,57.144552,152.231874,237.589792,214.037321,133.531865,101.20118,44.698212,25.923974,3.989817,20.54777,63.424415,174.341277,179.801504,-44.015813,-208.349534,-300.883358,-125.153769,-63.137749,-25.170948,-9.926722,9.972599,-22.013116,-127.303822,-141.790936,-75.333592,3.057218,45.011667,136.903907,136.719109,-47.581412,-166.76228,-195.866027,-13.814752,57.96759,86.663333,55.184429,-5.263923,-21.641343,-93.543427,-153.756368,-261.897081,-244.843907,-178.75989,-98.90954,-140.305909,-366.227242,-470.842193,-445.977678,-155.195142,0.564996,123.418122,69.810224,-100.362718,-156.868235,-154.942037,-104.638319:117.189394,259.258058,309.206716,300.006741,223.44449,-14.593991,-137.602854,-295.017414,-233.280826,-133.802243,107.010221,215.814071,351.302702,357.787546,243.48353,164.202881,73.090414,100.638427,126.424021,112.273611,78.564434,-31.928253,-97.114976,-101.476787,25.115571,47.615118,46.787552,64.703308,80.886044,51.539819,-39.271815,-76.77504,-88.746816,54.693762,152.088237,250.791888,255.116561,218.36381,174.124579,82.135557,81.459987,120.188744,209.351163,230.887803,227.941472,224.664489,234.715569,238.659203,237.755326,241.028529,225.941362,115.486249,38.642987,-115.481593,-190.748349,-300.686345,-306.028472,-273.460711,-186.62964,-157.062205,-133.187329,-131.176136,-179.282621,-209.804618,-180.742821,-81.816005,-24.60307,63.189842,49.038379,-104.423014,-199.340407,-309.948842,-298.578047,-274.87319,-176.437325,-117.278215,-106.99142,-149.492893,-223.375432,-243.153916,-273.084799,-263.189297,-222.859269,-178.754348,-215.422719,-314.76488,-332.798273,-295.962126,-177.57679,-78.290224,170.8744,230.591023,95.778248,-7.044504,-87.718988,-98.274362,-139.472741,-76.075088,23.459551,155.423768,109.589259,-71.706713,-108.005491,-37.461012,53.954068,86.243287,136.286874,131.04513,48.133738,-13.550571,-152.253599,-198.579777,-198.850842,-106.471781,-19.188331,182.656973,249.414866,262.435903,219.939624,161.471638,228.995281,257.910067,241.998468,220.193103,153.718256,81.171716,-120.362039,-181.243758,-107.949191,69.205712,124.396853,162.872749,155.714365,91.192882,49.013983,9.787881,14.683942,26.295365,104.763065,144.923214,96.098897,4.95885,-177.339357,-212.92442,-159.140836,-50.820111,5.549282,134.114099,187.987712,161.814561,67.81653,-97.483295,-33.958836,43.238197,177.238132,205.146535,134.630127,50.693236,-136.166537,-197.530416,-183.991428,-41.523018,35.503056,120.197352,124.288344,60.65826,-20.218963,-219.730238,-254.542152,-177.909211,-18.468582,-48.952769,-304.913303,-402.112563,-424.365692,-416.95967,-432.79126,-323.860788,-206.603305,-17.348341,-7.176279,-133.928698,-222.280935,-313.265455,-189.864284,-74.531137,109.927751,127.785096,-12.868591,-123.593259,-223.291378,-177.541841,-61.227459,-92.192379,-100.637409,-19.705095,13.745087,-51.124142,-144.34208,-318.807783,-345.698407,-313.606306,-170.589017,-89.544413,-74.38619,-165.343878,-387.347872,-403.058013,-190.049605,4.245488,47.337059,117.356928,126.334654,33.764592,-38.536801,-97.764022,14.919518,71.901746,65.295794,34.807116,-3.313512,-50.541885,-226.336499,-272.093808,-191.90853,-70.400091,-18.529997,52.318835,36.054095,-111.156148,-197.224716,-264.71154,-164.631232,-93.430651,8.628909,5.979121,-100.55241,-143.764516,-119.846731,-81.348499,-11.91017,96.300111,135.099873,100.773933,59.415839,-37.409804,-92.838521,-143.320083,-85.348215,-27.80988,79.409123,100.947336,71.721298,14.174094,-195.914843,-289.377591,-289.049786,-166.245493,-147.782534,-185.079363,-203.649133,-268.514786,-319.577612,-353.592473,-312.979559,-282.595379,-116.649044,-13.166974,8.203345,-75.516429,-223.084681,-234.149022,-154.970014,0.707407,86.475385,158.155226,128.71311,43.503848,3.838595,-58.834433,-34.436331,7.218356,116.82724,164.886938,177.024265,135.918983,45.59032,27.109138,47.606769,191.297258,319.916641,480.989291,433.747639,227.18273,162.392707,139.529904,117.567365,114.620583,223.866868,278.419502,209.278013,113.312972,-45.284297,-78.820435,-58.55554,26.400257,88.706564,199.609821,218.149147,131.233356,29.237353,-85.915258,30.174349,78.955655,108.541588,124.045074,134.951362,104.549777,0.750475,-21.657519,56.68208,173.318681,193.751634,166.327707,133.947669,-24.980087,-156.320705,-318.56869,-193.97648,-76.774323,134.136445,190.564317,116.737073,-14.202075,-270.423766,-302.149699,-177.275546,-39.573262,-5.521943,-16.778073,-56.432933,-120.515007,-142.334702,-167.990414,-34.158096,86.52856,241.427723,228.834588,123.830704,85.856676,20.263417,-13.224991,23.429943,141.860125,159.237971,102.231599,69.133151,12.799529,-60.934981,-256.368045,-255.018093,-188.284701,-59.832951,-4.821418,86.040306,83.089038,-57.665748,-132.664515,-124.259482,55.285256,158.945817,278.904892,269.427256,162.836379,80.927369,-57.760617,-13.609589,55.460854,191.45941,242.048418,281.413342,256.764379,87.673146,-43.366485,-248.335636,-240.172491,-179.942269,-97.13049,-123.010449,-242.971713,-268.866567,-208.462068,-84.268163,-10.05905,116.96012,124.359167,6.174895,-63.027198,-120.265939,-114.5644:51.290147,226.338388,269.21885,222.675568,150.472525,-66.411247,-191.026865,-337.729101,-231.119929,-109.685623,134.440155,209.21166,239.200713,204.605038,54.160905,-10.432723,21.716157,169.24978,204.700634,144.998408,86.284059,4.438435,-18.104129,-27.816933,-2.557807,34.750012,174.560895,211.715874,113.269873,10.927538,-215.349487,-297.138391,-241.473986,41.958207,159.915309,204.999147,152.743507,25.749126,-16.211697,9.968345,151.963268,236.022412,389.650281,420.193064,308.857318,202.519018,97.466222,126.883619,214.345187,255.584594,265.994684,196.523917,113.936538,-92.975682,-196.088214,-270.432186,-158.610066,-99.324588,26.339141,97.601879,107.914527,22.145015,-166.28521,-194.555305,-61.103144,181.247145,259.863928,213.207613,96.284495,-157.0307,-232.492673,-245.813816,-133.561979,-63.097898,39.259729,42.681173,-47.798618,-137.373962,-367.372916,-420.852486,-255.971796,19.384159,79.815964,0.893282,-94.150951,-280.034964,-339.152646,-304.933166,-93.742026,33.10176,221.729419,232.370665,66.186634,-55.848092,-222.78064,-242.95278,-167.609202,41.331875,154.631505,214.318107,124.109477,-136.453168,-197.374035,-96.888266,103.605992,194.156235,331.769855,350.294348,232.16541,105.211657,-132.486595,-161.72454,-54.945915,66.088888,127.374656,240.804997,256.237384,163.765703,83.304536,6.08272,147.891161,267.301025,426.80993,413.190232,219.276978,81.465451,-132.650577,-157.082809,-42.260399,163.800308,261.944697,349.880097,305.455103,111.356048,23.483606,-42.559158,66.349043,180.062132,411.846646,435.222808,205.694084,33.387794,-216.943045,-266.418807,-190.110883,79.635598,213.442141,330.482466,303.565898,116.780364,-8.802525,-173.688334,-73.376591,63.114719,336.292969,398.736799,287.144236,139.58501,-137.636379,-178.600653,-39.695866,193.095009,276.374425,318.64762,289.163484,160.376304,68.732104,-87.650662,-74.201424,5.282672,154.188162,133.559703,-76.176068,-178.568965,-290.966404,-310.011193,-252.536827,-33.866748,81.562329,113.087359,15.452479,-227.193262,-308.632972,-328.94442,-134.753099,11.990336,227.118036,233.275244,71.099032,-53.336442,-278.230188,-304.438473,-130.152611,100.210648,177.281902,242.913463,204.726237,-3.744571,-127.63036,-317.828854,-318.766184,-232.676276,-9.996616,54.31648,-13.421151,-140.841531,-418.567394,-456.084654,-261.523035,0.7215,94.974108,202.823504,193.041653,16.807188,-106.612503,-229.103899,-125.578086,-28.224492,133.777667,143.946253,34.758931,-46.725809,-213.324537,-245.964829,-102.95716,155.531174,229.676602,199.510545,130.920313,-57.392123,-170.075398,-305.081087,-199.891947,-96.882533,77.996572,99.414737,-27.294329,-124.95039,-235.419545,-222.647871,-86.63621,139.89848,231.075726,212.611339,120.921671,-79.109223,-151.995847,-167.426185,-22.052048,66.177183,212.286275,240.840462,167.28275,76.881467,-159.552488,-250.131065,-231.465099,-59.374991,-5.674487,-25.123584,-76.611641,-236.005876,-334.408572,-422.547145,-281.128772,-159.482202,90.524249,154.159592,37.199717,-101.066465,-289.155576,-290.032778,-159.065114,82.30878,201.049407,260.182946,192.661781,-34.98258,-156.730903,-279.021129,-163.889824,-54.642108,140.155797,168.568936,62.822274,-24.522227,-168.58155,-197.860414,-115.668053,116.361437,230.214641,300.237469,247.956674,85.433895,-1.529381,-128.949537,-43.51241,72.802116,288.724961,316.631598,153.099843,1.205948,-242.977501,-274.182169,-181.893702,36.849614,166.867089,275.3563,211.666708,-29.963088,-142.32205,-219.07523,-99.311322,-16.821284,119.306446,134.444333,0.54124,-108.99144,-254.711005,-264.78916,-190.825947,-18.281067,89.727151,197.034651,143.210449,-134.238037,-291.117149,-452.302685,-276.411019,-96.622329,192.617935,209.13704,1.875388,-148.903149,-358.778807,-358.178975,-150.163387,105.176955,170.112536,116.124825,35.315911,-113.095938,-194.530045,-292.085829,-51.942239,128.104494,309.265556,284.039232,98.873483,-8.795554,-149.015154,-162.470119,-86.54311,46.749635,105.728127,138.032107,90.499505,-146.596788,-313.212911,-512.705152,-392.089563,-292.575094,-132.362917,-63.873547,-13.302476,-74.064144,-259.229111,-288.89497,-174.058328,20.259915,116.139541,238.678665,225.118636,28.550178,-101.305782,-200.532766,15.516205,178.293484,384.034618,378.234673,204.629981,73.875671,-184.202991,-258.479697,-256.183766,-160.734847,-106.477355,-76.876395,-132.948303,-317.594473,-395.219164,-396.819744,-127.788455,30.402103,206.012074,221.420607,175.994471,113.089786,-85.728388,-153.945077:-17.267024,55.363717,78.461535,26.46949,-36.51728,-148.951844,-202.415707,-332.855486,-354.035862,-262.232374,46.424075,190.279086,360.922797,356.198902,178.119588,85.00795,1.136826,-16.710264,-10.891293,-14.164885,-28.64344,-22.102709,-4.353914,37.520868,103.295416,136.072214,212.967257,254.993246,276.791753,240.62185,142.622885,103.38303,39.413665,98.902331,182.884561,277.877292,262.623692,174.032586,105.375574,-33.673397,-93.2317,-92.872103,-14.914962,32.001954,27.507944,-2.167232,-46.634123,-75.836386,-143.73591,-131.909285,-108.177359,-146.146968,-206.239979,-328.950275,-383.520921,-437.924768,-388.89486,-351.703295,-282.201454,-247.229229,-166.351708,-146.742856,-229.142575,-280.193728,-236.685939,-113.627529,-70.251496,-45.027188,-73.848735,-168.705931,-222.547618,-319.177537,-314.225231,-287.435024,-260.960787,-255.533298,-226.909557,-210.942441,-235.939071,-284.88599,-381.39068,-404.648666,-403.67566,-393.291934,-373.549668,-328.798618,-319.0577,-287.388927,-139.184066,-30.020291,125.243939,128.806112,47.360767,24.705446,-1.62E-4,-47.541992,-122.989451,-28.363378,42.481825,63.140086,-2.52851,-159.532379,-202.803712,-190.645561,-158.295377,-174.341244,-197.562297,-180.851729,-155.776585,-185.438068,-363.639452,-471.926791,-543.369885,-414.092202,-308.924156,-30.539194,97.81712,147.377353,68.428061,-77.333021,-71.500776,-45.778069,-35.349071,-55.351753,-87.755926,-88.731587,-156.503999,-234.716074,-306.578974,-138.457307,-21.14499,126.97641,152.127354,150.291315,120.916862,23.195015,-9.579455,1.553566,-29.893468,-80.205623,-177.493911,-208.376941,-248.097372,-242.964223,-139.844054,-18.11883,5.216309,34.004934,79.192293,160.925653,124.034075,-73.4996,-142.707129,-89.259001,76.292635,106.360642,19.402174,-29.14396,-93.74988,-136.371584,-153.926463,-39.730221,14.452209,75.964341,86.896107,29.464651,-52.568898,-223.44706,-245.236316,-209.550041,-159.603554,-200.38942,-385.600949,-454.072041,-483.919854,-486.116565,-512.400228,-480.907839,-400.841831,-174.635898,-104.758129,-137.259388,-203.85466,-301.892863,-263.784523,-187.563673,-1.090919,43.749377,-13.471297,-65.860926,-134.118956,-157.073718,-203.436759,-176.966772,-98.280596,76.008593,105.337041,30.382993,-53.546521,-234.644759,-259.483128,-198.86412,-101.004626,-109.86298,-179.288328,-214.237415,-318.568013,-360.65929,-251.870322,-19.520933,32.187906,56.811035,68.076594,60.129302,49.056012,80.3561,109.490109,75.811533,-14.663302,-20.644574,-2.213001,-42.011474,-209.29066,-252.747039,-165.363431,-36.141326,-18.44563,-51.484427,-63.743325,-66.930822,-86.752634,-126.664172,-78.51401,-43.677753,-10.724361,-27.625253,-118.450546,-165.78337,-218.701548,-211.955985,-154.514143,-67.524658,-0.153218,78.695175,52.274728,-41.427948,-69.61145,-96.935203,-75.483543,-32.076648,104.496506,169.91921,177.326874,104.150944,-90.721982,-157.601666,-182.318717,-121.893204,-74.100859,9.899875,6.904697,-115.873629,-200.2812,-287.590341,-255.519596,-209.241781,-79.19173,-37.075445,-63.798658,-114.352752,-194.545115,-193.196223,-107.073085,18.032882,93.546265,216.730501,221.379165,129.462997,51.83248,-67.731804,1.483293,50.403149,102.20413,139.855651,198.21903,162.674953,26.826819,14.906581,156.894717,313.341855,352.029479,351.619942,324.854488,255.497912,201.499244,50.185604,-31.850454,6.848646,199.32886,265.518258,212.376979,141.986984,40.066906,-1.146583,-54.296747,79.478841,209.351844,356.273095,329.27796,184.037386,94.769951,-40.995609,7.611252,79.861015,217.235557,243.0139,195.465851,145.461915,43.478121,31.265827,114.071773,184.985128,197.498355,212.030648,206.831739,110.487994,5.237486,-173.084836,-43.32357,113.837185,404.564831,468.356765,341.836291,201.201644,-0.561288,-28.612216,17.455864,116.929903,159.924879,225.432731,231.302164,137.029568,41.254569,-97.525821,35.035349,161.824893,338.033947,351.719525,280.953742,235.714338,141.70825,101.462551,87.170502,107.577237,131.707571,222.574432,244.612604,155.389449,64.559633,-94.3688,-105.606775,-62.893699,38.78496,70.065792,47.571954,2.636694,-107.597616,-145.713236,-107.906644,48.040554,135.505345,261.99596,278.962645,223.483056,167.039307,80.760132,161.630056,257.200106,425.411395,442.042496,319.315972,232.961126,79.221813,-11.921558,-211.534916,-268.778363,-208.615149,-64.131804,-57.891521,-148.237785,-188.434939,-193.546526,-110.337225,-63.489742,-14.514618,-18.476459,-41.82984,-49.623207,-109.779011,-157.201891:-87.097174,28.743533,65.251705,52.587047,12.219363,-97.871889,-166.89351,-282.451757,-266.993393,-208.863223,-24.580736,73.103319,247.293549,303.556171,224.937221,106.666284,-60.913813,-46.897671,-27.027227,-45.668861,-62.802019,-59.209352,-53.062034,-34.046114,23.793507,58.256153,153.154011,204.726138,226.256679,191.132184,85.548351,43.806254,23.319197,62.279878,100.610623,158.549972,161.593089,154.317395,135.139717,45.978393,-30.388957,-44.225165,-20.509203,13.086208,122.89933,171.39472,178.715616,151.399179,95.01168,80.212369,90.100416,52.775883,-25.589994,-248.1058,-345.800344,-435.269597,-400.553276,-365.088929,-317.802237,-332.495768,-389.051026,-399.083006,-421.291526,-429.584894,-361.370403,-225.184843,-165.377167,-66.597062,-38.613473,-74.058535,-149.653904,-347.993838,-424.768821,-404.055416,-338.49065,-313.185905,-232.563818,-188.201851,-212.700673,-271.841355,-362.36694,-404.847422,-413.06205,-386.513819,-353.48414,-287.718169,-267.651976,-232.467645,-126.783877,-27.689825,197.06651,255.154426,159.166455,45.110424,-117.716766,-137.839545,-132.851339,-107.775494,-85.128683,-91.319045,-124.074448,-147.485817,-125.705075,-76.400517,-75.033183,-95.792991,-148.191126,-173.618811,-203.685469,-211.817018,-278.267263,-326.870354,-397.389885,-395.170252,-310.325454,18.644381,157.649643,219.835432,172.993184,47.434152,-10.65906,1.446298,33.1451,17.883008,-11.142643,-2.798123,-90.588521,-199.056931,-317.33723,-191.718664,-87.899467,11.183302,-21.474836,-66.287749,-36.429305,-28.202277,-135.350597,-184.382815,-223.693801,-205.96421,-166.672546,-187.12111,-308.616929,-354.831483,-304.209936,-190.73921,-166.799161,-147.19485,-110.406687,-4.81604,-2.864823,-122.086714,-231.54932,-233.113763,-116.57299,-65.606849,-140.341365,-229.312086,-350.883403,-373.085408,-356.214821,-287.885796,-244.410598,-157.524134,-127.584016,-150.798855,-221.898679,-382.252481,-381.720983,-326.303744,-235.530004,-246.068915,-363.9611,-429.251938,-517.044249,-543.127292,-589.210702,-524.620534,-396.318068,-110.85634,-56.958627,-132.322376,-202.783081,-289.203504,-248.8135,-193.534105,-74.879475,-59.878444,-164.556967,-240.331228,-324.533197,-320.217056,-276.219796,-253.820073,-224.979271,-154.905819,-148.519507,-182.054837,-221.91047,-323.117621,-299.379037,-274.881642,-301.448377,-300.336333,-246.545484,-254.589414,-374.938433,-421.233733,-362.871755,-247.535259,-197.982024,-77.341751,-37.350529,-62.334848,-104.737377,-105.548629,4.37018,28.295222,25.077573,13.588373,-70.128483,-129.03647,-216.561556,-236.687065,-217.702666,-144.139518,-124.505011,-193.971258,-256.42696,-340.717961,-369.821281,-392.628359,-284.176748,-188.544055,-38.215571,-26.627406,-106.406221,-161.270295,-180.828443,-127.737742,-37.248174,-86.735319,-123.152104,-164.344843,-178.783696,-194.72114,-193.592466,-202.033766,-220.826875,-196.148446,-42.659729,30.714513,33.274797,-11.98618,-110.600078,-164.599639,-236.140443,-246.468716,-245.751219,-225.676051,-219.265295,-240.800523,-261.385938,-325.661502,-376.439698,-333.922467,-81.866848,26.888112,12.399107,-51.4147,-123.407032,-128.995867,-103.255495,5.659632,95.775675,250.201951,280.566561,235.247205,167.789492,32.620079,-2.669928,25.090822,131.321345,155.80856,96.754792,53.470787,33.591827,70.419804,178.806514,219.501355,243.449376,307.108254,305.870983,231.413037,186.699535,98.473842,-32.364643,-72.340579,48.666729,178.606982,343.981487,322.708704,126.817009,50.040841,82.847587,221.42857,290.696054,372.598009,356.173976,215.268522,114.090059,-40.524236,-28.36573,17.746714,111.468756,142.557534,170.909813,162.352085,74.260074,20.834273,-31.544719,-41.442874,-28.11694,52.690169,78.244624,-28.131971,-140.777269,-256.301302,-108.012749,16.3984,249.264852,309.250732,266.476032,185.542516,0.776931,-54.251964,-57.059438,-18.218283,17.57404,105.527561,131.782399,153.791056,129.667326,49.543283,172.039402,282.679833,386.967736,370.666122,318.800892,308.794916,261.773418,222.596378,187.358115,194.481678,202.157986,213.791828,200.725163,119.313322,54.658239,-58.901013,-39.671404,19.041506,147.114939,188.497288,267.624132,316.948609,344.880427,301.310558,195.793534,248.431146,343.22889,481.299576,460.600133,317.720686,246.556394,176.955791,237.869283,287.500226,361.571305,377.408123,361.346591,324.662044,185.067992,92.104639,-106.735111,-244.08829,-234.897065,-66.139201,16.719084,28.867698,1.474937,76.3261,249.679277,265.001141,129.039535,44.381654,-43.719871,-53.548366,-67.67003,-78.426094:89.653005,197.800875,222.475604,234.930185,199.380393,36.07349,-67.139054,-247.125909,-259.636946,-167.221313,128.214973,256.536821,389.037389,391.064237,265.098182,193.474534,141.536288,138.011529,160.823708,181.402241,143.425355,62.056239,35.690615,-18.93959,-4.543802,38.467939,139.911096,177.736286,193.521414,166.364147,54.892148,9.196055,35.916203,150.526119,211.953876,289.013708,278.584778,168.791756,95.671378,10.547236,106.461966,203.704501,329.30844,299.252271,105.399362,21.453326,-23.848982,4.47578,93.480766,127.478959,127.440014,91.009086,14.907844,-207.07059,-271.97133,-227.743682,-119.309067,-95.421412,-28.910426,28.855523,75.517918,34.65708,-97.376053,-127.988144,-44.965185,145.201264,205.045717,120.930477,-3.463184,-237.879308,-294.681653,-260.982357,-155.505568,-134.183036,-113.647129,-88.174495,-68.442405,-106.890145,-256.28953,-313.423436,-291.088778,-167.189476,-119.199908,-126.752489,-187.395715,-338.647729,-389.599593,-376.901339,-197.119226,-76.446179,146.439849,205.675558,119.817412,3.407801,-195.57394,-235.04639,-186.24427,-37.770057,45.453853,83.280224,7.467644,-158.056718,-193.141286,-205.147608,-150.864632,-103.534724,-33.708728,-19.825301,-34.121551,-83.000214,-282.653048,-364.085193,-330.92956,-194.033288,-122.377968,19.445508,55.351719,55.293636,27.010742,-67.198041,-52.255211,27.273611,170.834184,171.750583,65.664971,-10.537975,-172.048406,-223.280091,-197.932237,-54.073412,9.368452,45.935314,37.667271,17.391379,-5.220994,-49.574871,-6.047495,31.458426,84.378252,99.628857,37.218921,-60.482468,-291.16105,-348.321581,-271.995522,-110.682535,-58.093899,12.535526,49.498625,73.55248,20.226476,-180.341476,-180.624346,-49.063892,225.707898,265.417236,146.019306,28.817945,-204.549969,-250.763773,-126.068648,54.046349,97.537555,155.217737,167.775412,81.909113,3.576418,-140.105654,-236.477112,-231.071437,-173.337312,-197.805865,-355.21973,-415.406928,-415.222694,-395.045009,-407.550941,-380.278862,-300.834114,-130.338744,-116.916855,-248.138495,-348.497111,-470.962682,-368.163721,-273.483707,-120.020046,-75.946314,-99.080034,-157.838116,-228.356398,-215.366249,-142.746171,-73.620543,-43.184539,14.107101,23.32305,-53.534628,-147.851741,-323.915504,-294.472843,-224.53839,-93.048663,-71.329643,-149.588532,-212.85965,-310.275797,-335.519972,-293.943674,-136.113568,-46.352148,104.540136,130.752953,13.117316,-95.200847,-200.96308,-101.722938,-44.790127,2.960475,-8.162423,-68.890979,-109.52754,-230.975854,-283.487026,-280.791173,-172.606755,-85.179884,42.452058,21.49523,-114.716235,-174.269875,-222.664579,-148.575362,-100.728386,-42.716621,-49.48481,-172.170759,-248.644883,-310.828914,-280.184799,-137.247338,-32.003612,-16.623814,-2.645907,-1.809093,-97.319771,-189.945412,-276.514651,-131.368943,-44.540068,74.541706,119.260378,111.232678,28.962493,-194.863995,-252.050274,-194.649913,-95.024035,-53.978174,-0.221364,-19.264057,-145.455681,-209.144282,-262.43519,-263.234441,-228.532546,-54.650921,13.91974,-34.68604,-109.982628,-235.065868,-276.560015,-240.310916,-8.659931,112.769729,201.391334,164.283508,34.595005,-25.745281,-66.216607,6.89792,45.116193,97.925153,119.172305,107.030161,55.767558,-55.132673,-58.243495,34.962502,164.896305,245.625069,360.329995,344.89131,203.919667,125.878375,15.141687,15.130171,75.828199,261.066118,304.111696,161.788315,29.058228,-139.704501,-149.211115,-106.973672,-36.963809,29.338903,126.258821,114.016073,20.84677,-44.495925,-114.799422,28.596149,106.597604,179.387284,200.59436,188.909457,136.64498,8.681671,-17.799166,37.352437,159.727217,214.792974,259.086073,233.354164,109.970488,28.373206,-141.855538,-85.871766,60.144377,295.254707,288.203052,109.852286,25.522887,-64.899754,-84.76596,-60.288061,91.981317,172.667419,202.871966,152.168484,40.356173,-6.832277,-99.914204,-74.367495,6.463204,202.512587,258.254809,236.158695,181.826718,31.249432,-38.158432,-54.889844,53.425303,115.019499,229.240624,258.179482,120.566872,-41.981591,-245.968147,-109.383578,-24.265528,16.483882,-8.000621,-58.060548,-68.784759,-124.422191,-164.080724,-126.922363,78.930692,196.457064,343.740342,346.491739,241.098712,156.276854,27.511586,123.791456,218.921568,334.045156,351.479066,335.028447,285.301188,91.996034,-4.329817,-63.158559,-10.562096,4.203932,-50.82014,-116.162324,-232.701145,-247.078579,-168.871287,-42.456473,4.78065,108.00491,167.31972,222.650424,196.222243,66.926337,10.915529:right
74.473199,102.020309,119.021219,105.02343,74.194611,39.358173,72.421306,167.509063,183.545583,180.499774,155.592094,132.943958,100.499205,88.891475,54.58607,26.043767,-20.798684,62.211373,125.1119,107.125288,34.116958,-54.770991,-35.955276,58.376776,159.875459,210.703862,245.816208,216.291038,121.584237,88.143331,98.489604,133.007419,189.464036,182.332016,139.17974,7.064255,-54.404131,-118.843897,-102.651576,-24.967266,2.243387,-9.048184,-82.292693,-129.054231,-206.280982,-226.075538,-130.434407,-7.681995,211.086918,248.793826,227.203297,161.129582,106.046291,-8.391272,-13.91044,89.005409,182.772906,181.547213,100.556218,53.076517,-27.633424,-52.235686,-26.321243,12.118848,98.472183,168.352915,154.797582,54.535537,14.214011,-13.943813,-7.442752,-5.922608,-29.353781,-39.228975,-105.949945,-166.896091,-305.781563,-369.109506,-381.035092,-311.866763,-126.583444,-5.037277,7.939402,-39.597066,-74.833473,-122.824142,-119.413706,-69.279336,2.786062,55.010147,114.685892,98.232686,0.513261,-65.014195,-105.957116,-58.864846,37.248127,27.142068,-13.673302,-129.760717,-189.177876,-241.534908,-199.118721,-34.61265,21.973335,0.265519,-16.07118,11.43852,50.299359,23.400842,-36.032859,-10.610387,110.914756,166.458465,149.54643,61.221256,-9.660204,-170.384625,-203.873973,-205.037375,-242.476926,-224.67141,-122.363337,-93.75247,-82.897594,-58.19002,67.044276,123.593836,152.912396,168.268604,168.36913,109.20784,69.365488,43.512033,64.278446,76.806446,-13.599565,-67.974402,-162.465086,-188.343337,-194.218708,-210.437502,-303.952239,-349.269846,-349.578058,-237.811813,-190.989009,-186.235642,-235.953973,-383.056253,-419.363042,-370.04479,-270.870248,-248.199016,-284.305925,-309.572419,-323.796029,-327.88375,-347.239335,-350.943771,-325.669539,-269.237648,-252.778005,-292.991856,-335.936147,-366.745403,-330.953602,-223.640636,-184.131904,-171.708991,-106.580221,-55.632496,62.697898,109.234004,95.900225,36.388026,-22.049365,100.712747,139.723148,98.750324,78.427055,97.580397,108.621695,85.441941,80.117221,111.706095,141.255627,102.552491,-6.70264,-38.953383,-63.346703,-69.272205,-59.479778,-12.453518,-0.798618,-9.538279,-27.065386,-69.321108,-57.08372,81.784948,214.801435,215.648034,142.661355,126.321058,114.2841,83.32058,13.382565,-10.034025,-34.626103,24.1994,67.722728,99.78607,86.788643,74.56285,106.764698,207.020948,238.027918,252.424636,307.708269,285.453464,101.507466,37.065709,102.123529,147.818653,122.078331,100.894235,98.892806,35.762922,-19.359658,-82.263824,-55.122773,85.621093,183.068431,174.94515,119.210935,101.894523,12.461945,-71.2616,-188.25871,-198.6969,-177.901317,-140.769105,-123.248194,-89.04973,-90.33517,-135.850453,-150.712932,-155.669482,-119.888685,-83.119367,-64.859088,-89.014668,-141.787604,-153.475249,-102.030599,-52.288093,14.196111,1.088328,-27.341544,-25.451466,4.206179,40.501695,63.760191,129.332689,122.873789,84.672168,-3.214012,-15.263331,4.516438,-5.198426,-50.847563,-55.663703,-33.237645,-35.95348,-72.452575,-162.448246,-168.875024,-90.143347,-43.214469,-14.774478,20.620457,66.380754,65.027476,8.661254,-67.82382,-67.572878,-13.918449,17.704337,4.446474,-138.39577,-225.227182,-331.096714,-346.32468,-368.498899,-367.188871,-312.102914,-266.355469,-246.333353,-190.801203,-175.838322,-214.589884,-251.511277,-244.226071,-202.080365,-192.027017,-208.446145,-168.470616,-55.768696,-37.358456,-94.083169,-109.046138,-53.527152,-53.529857,-84.293779,-101.033949,-76.651329,-54.063803,-63.85928,6.764949,88.903729,161.30351,102.589656,85.263011,47.298985,-2.042512,-88.927422,-77.963422,-2.186582,-7.338253,-13.181488,8.921837,13.000044,-36.397507,-83.255952,-121.756697,-82.221218,42.542779,113.28912,137.406633,171.730781,170.867663,203.131191,242.936998,261.240782,267.598665,289.918654,245.007051,179.504249,65.440896,13.753449,-79.709764,-92.512919,-72.231888,-59.861195,-23.623342,115.744524,155.597933,103.385951,81.27958,181.405426,300.561539,298.914376,159.001743,51.024577,-65.085528,-42.061032,58.209307,83.379067,86.247753,141.403777,176.710594,174.011104,122.937255,-0.3625,0.410232,137.821783,251.605848,288.264966,312.478377,270.163704,91.939859,21.796668,76.004237,162.584657,251.24223,165.025471,96.058963,69.187128,107.668543,189.526451,243.97457,336.211563,299.836614,267.505017,245.240957,247.531308,190.820244,122.747169,66.658856,105.356932:67.021025,113.562675,92.237933,17.62727,-4.256969,8.704718,43.1788,101.686704,85.512659,51.218047,-33.196707,-54.117866,-19.520027,15.527701,39.558348,23.700064,-15.735664,-28.211017,-22.055081,-35.940424,-80.4051,-152.62424,-130.449723,-11.265669,121.578844,177.256506,161.212912,83.4388,-61.848673,-82.40437,-38.06976,10.665169,117.060043,110.605535,25.618575,-189.425366,-230.145985,-137.491206,-68.067062,-21.905265,24.94444,80.502325,77.692654,-3.729822,-137.65446,-132.42967,-17.467363,63.954077,201.137175,208.10101,167.961589,46.690991,-28.135654,-124.57571,-103.955449,23.013595,113.663035,113.895667,23.557839,-38.316478,-121.881696,-124.515002,-78.785336,-51.151747,17.816199,38.483045,9.770289,-39.419624,-38.103719,-76.148751,-139.459404,-222.565832,-124.162584,-74.841572,-139.060044,-225.641781,-377.231854,-410.105702,-341.642148,-266.493407,-140.109647,-34.355233,-4.212602,-85.105942,-164.414772,-224.380351,-182.461479,-29.965855,121.608061,177.029406,178.238103,117.337449,-34.939248,-92.275276,-136.728935,-121.450184,-48.720011,-25.066674,-63.306965,-164.534366,-192.858916,-220.271936,-217.169442,-121.741393,15.082219,15.144613,-106.333829,-128.76763,-68.7835,-62.7442,-84.104312,-56.900151,66.061319,110.815561,64.818709,-97.727573,-186.198285,-323.017149,-328.896981,-224.737733,-131.168588,-101.391042,-116.063112,-165.755619,-222.253801,-178.457022,22.606943,112.482341,168.821567,140.034648,119.369733,60.223995,30.066808,9.596648,25.370453,76.761577,89.388696,55.237905,-110.298524,-198.653382,-241.077319,-197.703044,-137.596098,-159.008502,-230.239958,-248.070512,-256.679901,-308.082962,-366.557226,-530.170908,-553.124763,-355.643593,-117.777813,-102.561932,-198.379909,-222.206563,-202.141229,-214.517594,-298.794565,-329.960818,-318.622358,-264.287628,-260.263898,-283.135301,-283.19017,-263.267018,-234.409067,-83.907495,58.515853,77.091773,74.912186,73.80462,33.926709,12.042542,52.714552,89.982301,102.74533,145.510732,205.58053,235.117441,157.545272,-29.112902,-46.818159,41.367452,115.422651,143.339604,162.077869,136.089392,43.570736,16.270729,38.989799,62.353988,76.572895,60.085396,65.854076,88.461002,62.208614,-57.082344,-78.897937,63.627181,260.371673,273.086216,180.23024,152.414814,118.607608,72.940818,-53.787125,-113.322649,-120.974472,51.570124,101.714709,46.089317,7.647178,59.021431,136.29229,238.304533,229.024996,235.441,269.886889,237.494147,93.615517,71.099408,163.062874,198.252924,169.620052,141.991454,135.226698,55.468325,-21.426601,-119.896976,-88.873211,72.924205,182.860003,182.641794,125.722275,88.638813,-51.988613,-147.5308,-264.390384,-262.843685,-155.474102,-23.410196,-6.367756,-38.055644,-59.851882,-120.479513,-150.556688,-175.453113,-172.868749,-160.120995,-127.834579,-131.691308,-190.824872,-207.429745,-130.591552,-56.318423,50.874044,43.311958,20.048115,-12.775457,-25.515939,-13.463833,18.792094,73.397882,96.901784,103.151864,102.06171,89.316006,12.725244,-36.332262,-103.609907,-103.033278,-46.676753,-65.378116,-104.885352,-142.049498,-137.648259,-104.465562,-69.780387,13.473262,80.880589,101.01313,62.740661,10.738062,-61.785316,-52.02746,67.763619,138.99023,195.141532,81.225333,-25.827677,-205.777476,-245.589769,-252.673306,-234.872283,-172.151974,-97.435161,-75.339484,-89.093485,-101.279334,-111.314619,-125.049466,-162.002986,-172.110833,-170.668479,-90.239909,-21.069369,44.284663,-0.684905,-120.718322,-114.665637,26.366623,178.296784,223.996258,212.966764,158.229655,39.121782,18.621804,99.955184,182.029563,320.724791,306.285057,235.268948,59.403318,-24.135593,-125.689063,-105.606246,-4.443076,14.734423,16.967866,69.864845,77.562294,-58.702952,-140.086084,-113.314549,-29.731827,103.235942,170.295593,187.022335,190.234146,177.763214,170.635871,187.888299,188.079656,121.448786,97.095471,119.587118,145.22901,84.158668,0.111275,-112.903972,-123.263043,-115.022401,-60.104448,-25.892036,-10.253477,-12.853457,1.847146,17.330603,99.946156,204.357672,214.810766,151.363966,93.380788,-72.719007,-140.863615,-89.084343,18.576062,207.418347,250.64943,216.718669,101.208149,63.069088,48.014703,65.780733,144.660118,259.000967,319.08797,329.540799,247.216134,12.225029,-55.443217,-0.63785,66.20429,186.161336,239.850255,192.535284,80.795695,97.390511,190.453228,201.851026,164.381419,131.298624,109.171604,46.921887,33.787708,10.566162,-27.027536,-75.005021,-51.208571:46.711586,170.378281,202.684556,130.194705,52.718461,-19.529503,22.02328,101.968009,23.604961,-34.023197,-107.738858,-118.222608,-102.840811,-94.532815,-73.779719,-51.600093,26.288102,53.434529,14.462357,-81.073601,-103.417767,-97.997685,-74.503064,1.793706,93.101571,118.69367,76.718179,17.398721,-126.415826,-177.996384,-135.726826,-36.199997,158.821414,183.247228,147.196539,24.267922,-38.531683,-76.350498,-51.144533,23.652673,142.488913,193.759469,142.83354,51.635333,-80.480054,-70.230697,113.846057,242.571003,396.761995,378.802598,327.191756,173.131844,89.043912,-26.318326,-18.791898,112.784596,178.911497,127.794862,-48.579493,-104.399335,-134.207742,-125.342743,-22.933619,66.680025,188.865785,131.640612,65.372011,-33.462233,-65.450669,-151.11593,-181.554429,-113.581068,16.647769,8.385991,-146.319632,-218.639272,-297.775952,-320.98486,-293.900824,-243.746208,-148.107402,-106.449574,-114.887275,-172.454835,-209.224612,-222.511411,-154.561964,57.542304,141.773451,116.788719,-26.746516,-114.468861,-216.274715,-209.517607,-107.12946,-52.38119,-26.587699,-70.457672,-89.766368,-148.991006,-201.626729,-289.179874,-300.587701,-245.600726,-82.080695,-40.215537,-147.874235,-217.669946,-250.521304,-230.884328,-140.464809,-88.215243,-17.704413,23.850701,23.0511,-32.12564,-97.05863,-285.003955,-353.321841,-361.755178,-240.105089,-186.013967,-203.914982,-247.870662,-304.728043,-285.646075,-95.288782,18.981856,109.828033,97.453486,86.362887,29.679937,-6.41499,-47.761917,-40.646021,25.392081,88.077322,84.577954,-44.986234,-138.166297,-219.410968,-183.776473,-79.752452,-79.197967,-169.07306,-226.714718,-235.864968,-275.753359,-350.533109,-547.184482,-552.2781,-332.32418,-184.806082,-193.646364,-267.312063,-306.063492,-373.766696,-377.622776,-286.641351,-230.809459,-204.836881,-197.237535,-203.72742,-306.212249,-349.78257,-272.080842,-151.543682,87.116196,162.199826,168.127004,172.19704,154.718672,90.567772,81.243667,101.372754,103.398195,131.387988,227.008132,243.892752,137.860832,62.46321,14.753719,30.532901,63.19867,161.704603,230.081325,288.518267,244.507347,52.826744,-26.209684,-50.118275,-14.80303,84.066915,124.219963,95.778275,10.911512,-29.801205,-124.368922,-147.436686,-2.023809,252.687079,260.418388,80.558519,16.76748,6.057709,20.651017,66.87191,77.201941,73.268559,120.926767,115.723713,38.894735,35.293161,138.012904,196.884949,247.019035,290.508633,323.578979,302.07346,253.230692,189.931042,179.539066,201.429615,243.344931,315.196563,242.821016,175.690932,57.052332,3.779895,-57.576825,-36.923939,117.046569,259.008348,232.793197,34.707808,-44.289501,-159.58964,-235.097497,-303.031345,-257.46795,-80.67398,6.117031,-45.982011,-195.733311,-229.647562,-266.959341,-291.808179,-277.366729,-156.066017,-113.346988,-129.088068,-161.096194,-217.528802,-214.872614,-98.896787,-19.673273,108.313691,138.481139,98.294476,-1.247777,-23.875254,5.943272,37.567522,57.786285,32.558063,33.53254,87.079543,101.436828,-8.389759,-84.451053,-112.596981,-86.959253,-39.591784,-21.772313,-38.743339,-81.579905,-94.817696,-107.649562,-74.531068,85.101945,211.222889,207.803159,43.11528,-57.29503,-114.797,-52.086318,160.97289,236.352598,255.508716,133.451201,38.732326,-102.104153,-131.17172,-140.690353,-122.865206,-48.251231,22.852048,39.087816,33.482022,25.276036,34.181379,35.352404,-28.012019,-56.545346,19.815955,156.896861,175.221878,99.145205,21.158305,-76.660488,-39.010282,108.966622,159.574306,155.917679,137.821117,120.295871,46.738837,20.247745,112.180761,207.608946,332.440508,297.602865,235.271378,110.675735,43.011563,-71.625437,-54.451498,94.786707,178.755167,165.952738,77.659482,32.716006,-52.352209,-85.757569,-55.780719,-1.427432,69.270406,90.809644,128.559378,199.639025,167.360555,70.343915,85.619369,184.306917,204.057509,177.302836,95.002659,46.550769,-61.032663,-94.531581,-49.122192,-0.542641,30.76903,18.316012,3.165567,-79.461406,-123.90629,-114.279365,-52.261901,59.153526,92.883194,108.252644,103.167775,67.778926,-24.353853,-47.252629,2.041246,55.289576,137.896323,104.596855,50.422837,0.765502,14.846412,20.088209,10.736348,53.993682,227.838254,320.581542,308.369456,190.526428,-35.386391,-73.417703,-64.522798,-47.805095,68.263002,149.56614,119.697209,73.549776,82.423368,88.496446,96.46497,157.923173,171.606936,137.921769,0.548112,-71.081976,-181.192832,-214.677554,-127.896891,-18.531544:75.579206,122.57407,128.380851,25.127549,-59.452491,-130.389827,-83.365502,66.064602,130.43856,139.677696,132.677109,104.040392,29.830419,11.058186,35.554536,59.200195,85.173718,111.649588,110.258395,27.484219,-40.887628,-134.948786,-124.427554,7.130806,165.642691,194.771887,88.749449,-7.539283,-119.322944,-112.070657,-21.709449,43.26534,176.786254,234.951825,199.403811,57.304717,1.487478,-24.328526,15.318261,152.724905,213.077726,185.49357,60.86615,-5.45722,-119.617351,-156.772827,-111.775672,-19.486222,173.070608,228.323194,211.121294,115.994538,39.488543,-62.365487,-30.935593,131.972808,217.631532,196.50814,74.131927,18.657503,-59.263966,-75.366705,5.501383,80.586021,211.085093,270.685313,247.196706,123.457134,69.21092,26.155687,33.122348,93.073997,105.953073,46.568833,-124.992484,-181.905815,-226.250001,-225.18283,-160.476691,-120.040687,-113.707627,-136.269833,-125.167434,-82.753026,-97.185597,-221.125234,-245.333702,-92.475903,125.356513,162.997597,58.697799,-27.425337,-149.190522,-180.834813,-135.249633,-69.566018,9.535534,8.78033,-16.467881,-120.497105,-195.671145,-320.788634,-308.506509,-117.65325,33.416905,25.930895,-65.728957,-87.419183,-98.720414,-126.936701,-104.730462,-19.712999,122.63901,148.621208,153.353208,125.293994,46.441518,-207.527225,-277.755273,-242.788216,-199.937114,-186.138146,-171.471802,-190.672947,-243.850067,-219.818897,-16.781537,90.007423,173.217059,150.561339,125.225057,91.97463,90.367482,94.06519,104.916874,105.543319,29.132954,-21.727693,-138.355177,-189.341684,-233.943734,-234.590104,-245.218437,-279.88166,-371.666577,-334.26397,-290.066306,-286.995183,-359.14491,-580.893095,-626.740134,-477.614798,-280.878685,-260.317328,-322.878329,-356.066957,-383.552714,-389.816474,-406.891515,-406.493391,-362.729086,-280.655371,-258.063823,-291.429375,-318.270931,-300.1228,-241.596061,-90.967088,-59.188888,-75.764826,-35.179702,23.434432,118.519318,145.558624,180.635894,176.284201,152.017475,190.374137,196.765747,154.970181,131.377543,87.574338,73.013866,74.076477,117.863068,172.415337,252.385729,222.543731,80.471825,22.835195,-22.251072,-21.156656,-19.228838,-23.292332,-31.081854,-48.908096,-48.775163,-92.688931,-123.158701,-13.874281,178.782827,182.951765,64.291054,30.200105,75.285512,97.442945,44.413066,-2.70717,-36.105118,17.031468,36.980599,52.277271,58.412268,82.990474,116.152448,217.311839,278.670966,283.39655,252.124936,218.06388,112.655682,67.850523,109.272058,170.652283,202.909709,110.787565,53.668393,-40.997367,-76.54259,-97.491989,-54.284157,107.995336,200.380975,165.235477,-30.128829,-118.685594,-238.059632,-285.79099,-286.774101,-229.975256,-104.26569,-88.213574,-133.324398,-220.682966,-236.536353,-282.472332,-310.287292,-286.9818,-181.095104,-138.397075,-136.944258,-175.604768,-245.703468,-235.211828,-124.614998,-63.482023,11.10236,36.220289,27.184012,-11.649986,-14.221227,58.357407,115.110002,151.708898,82.582341,43.29654,-11.260368,-20.207878,-57.311479,-92.35029,-114.576444,-104.372857,-98.893405,-83.041466,-66.431112,-35.17314,-33.605747,-53.687591,-50.838366,12.727134,95.154909,114.430325,68.168762,6.587909,-116.58696,-144.721415,-84.135093,-6.782949,101.732342,32.997839,-46.14311,-189.149389,-234.302603,-299.729993,-305.383633,-221.797167,-130.911783,-109.180036,-61.781458,-41.485494,-92.128348,-154.456929,-197.232097,-151.189668,-41.801784,33.850211,69.46876,76.941047,28.057188,-93.334326,-97.064423,29.909997,144.145298,167.12097,182.647218,172.24438,91.944923,47.821998,79.927947,156.793793,280.278308,265.347637,210.894293,87.946399,42.16209,-22.251841,-19.493096,58.079666,98.099479,83.382721,33.512419,8.555258,-85.111751,-143.295198,-148.345644,-74.358054,97.94858,166.175597,178.520698,180.507804,153.317159,111.517392,137.543091,216.472413,221.218638,198.586478,100.540818,34.116265,-56.567182,-86.139517,-168.503198,-207.327204,-217.991108,-113.523134,-53.79386,-13.232569,-37.400462,-80.720016,-37.421629,166.07617,255.538697,215.608114,83.940367,21.011436,-102.544517,-130.684632,-48.997267,20.042015,115.752398,168.694822,173.840229,150.482401,117.078192,20.275512,14.517506,168.554735,374.262251,409.154829,305.58944,220.329076,87.572862,49.735249,69.798011,129.973495,244.345218,161.14384,70.037834,21.6577,88.10502,240.882198,286.54577,340.366008,325.031435,286.897828,178.027123,125.859191,41.547609,18.431427,95.061503,164.603168:119.330862,166.369411,149.337865,47.258608,-14.127443,-102.094243,-104.297748,-20.544205,125.482631,149.049844,-0.703028,-102.349358,-140.124416,-86.652769,4.272312,23.790644,81.582452,124.743182,102.50769,11.553943,-44.429716,-155.236177,-154.647338,13.06053,174.538958,179.908271,74.983424,16.224705,-71.077146,-104.72314,-77.292758,5.583418,199.212155,242.993786,211.101369,93.304603,24.801314,-7.408289,51.164304,193.084044,242.729101,238.539464,176.300586,106.533072,-83.329294,-137.948522,-39.402966,76.242274,249.64225,200.944302,124.497748,-4.630146,-43.562592,-77.405133,-73.532977,6.531924,150.343157,158.158599,-24.594313,-130.389462,-191.082622,-152.56035,-17.203512,48.056671,157.625582,211.934036,181.415458,46.034283,-16.292047,-55.573521,-22.933339,71.989201,96.835862,76.468448,-22.729996,-102.632456,-290.111927,-353.807102,-324.601829,-255.013576,-152.516036,-182.344476,-221.112898,-274.163446,-292.311731,-316.937206,-297.029481,-145.474735,34.952168,67.548062,-22.988207,-119.869695,-246.471882,-218.503005,-73.330577,-26.18742,18.300606,62.017831,50.981739,-90.860374,-193.047963,-340.076201,-345.302344,-232.056589,-92.046267,-52.847502,-58.4164,-87.134151,-175.801563,-205.232543,-108.910342,-24.743786,51.345603,86.000951,99.927688,33.179243,-52.658918,-200.024919,-208.706512,-147.570956,-122.806179,-145.417215,-227.180961,-253.860526,-279.222383,-254.710442,-43.364323,85.120683,233.765326,282.910285,273.507516,197.422322,158.79047,111.645133,111.02602,167.130643,202.834284,168.208564,39.434971,-5.123215,-51.45713,-70.462744,-91.071857,-91.324558,-99.724346,-139.956352,-158.657268,-183.168594,-228.462287,-447.593955,-535.090654,-429.137689,-168.020426,-122.425212,-201.677568,-277.432083,-420.321049,-434.119358,-308.219925,-237.617577,-178.992237,-133.928372,-116.473036,-155.178586,-204.836162,-211.595886,-122.57722,87.799772,114.099816,118.466233,236.651079,273.799195,159.785993,84.574546,119.297021,199.312745,292.699829,296.204955,293.380711,249.742353,199.773767,90.407103,57.614648,65.847783,167.951306,228.35709,244.137527,187.198171,72.799938,52.424842,40.218575,32.721784,61.626512,117.56714,110.623528,29.439539,-41.829541,-203.133754,-216.996444,-4.367492,238.980058,258.809492,154.736691,108.626552,99.627988,102.623519,104.308382,118.815362,160.585156,202.501624,213.659941,159.751193,97.963984,27.481793,74.763575,292.7712,424.305307,417.029221,292.403937,213.218777,105.423057,94.444744,163.877825,202.938417,239.52031,248.637581,198.862007,30.080733,-28.49348,-49.332943,-14.920626,93.598991,173.550253,166.868047,32.370289,-62.967422,-286.062497,-384.551074,-384.535616,-285.071145,-59.949911,15.628498,-19.769,-147.247317,-213.732361,-318.820525,-315.90993,-140.749038,30.07156,17.016823,-120.80504,-176.300728,-212.083742,-188.338574,-75.941446,-15.754784,96.514495,189.955088,198.789127,119.969025,68.175668,76.495827,129.699493,154.981188,89.476769,81.240614,58.943506,12.665198,-97.488229,-115.2114,-72.534049,-47.489489,-5.423831,17.213937,23.123065,17.665948,-28.779391,-160.570483,-176.371292,-68.065774,91.740039,129.208285,63.312563,-27.743177,-214.106348,-231.369059,4.073383,178.533753,288.680101,89.89569,4.369223,-84.787305,-151.68986,-293.010441,-280.470336,-122.189474,-22.286469,-3.860976,0.690881,-18.67613,-99.6416,-142.348052,-153.403864,-115.137663,-39.401711,-7.108167,16.278417,44.672082,20.258672,-36.420608,-22.834911,49.234975,125.152867,168.995745,204.82764,173.884217,65.825084,38.410354,107.372891,182.084248,308.455699,265.632217,194.328836,88.894399,36.086219,-99.10936,-108.879131,41.510414,179.920998,176.349464,31.637715,-69.103596,-224.723646,-243.303029,-149.639772,-84.627609,28.852496,141.655403,174.733103,151.004514,89.22227,-18.77481,-11.191133,72.659977,115.863182,110.038854,49.90112,-6.535525,-151.500233,-205.073398,-229.599688,-211.584518,-127.727748,-0.826371,23.635696,-39.160403,-91.868712,-132.155692,-89.247501,65.859701,148.517755,138.022148,79.627567,43.810169,-79.174982,-139.742139,-101.699922,-2.452705,178.48333,166.319642,112.174937,41.057704,9.696619,-104.796695,-124.41705,28.042712,246.605755,297.343327,233.514164,138.448924,-60.439596,-108.037206,-72.863273,-20.10361,80.791919,70.806335,32.969778,7.777583,17.958099,29.157868,56.580278,176.48703,243.735382,233.581208,144.800942,66.116192,-103.086531,-138.175319,-66.624055,-0.46308:319.648105,343.605932,340.15422,281.02404,212.538897,79.313371,87.00485,219.383169,289.052621,284.628476,184.388072,109.910585,39.887924,52.979075,102.628437,125.421164,165.349042,170.501811,171.612322,153.747658,105.974246,-26.162672,-58.010054,15.513656,192.177678,233.027371,155.059509,109.306243,119.388258,138.353005,175.794977,211.515569,264.709081,271.803853,267.093716,231.653519,194.889014,104.488646,100.920974,204.554359,214.932514,157.741203,26.750611,-26.274648,-119.652216,-157.029044,-118.127353,-22.375526,211.219266,297.776819,250.111,106.791504,81.933185,105.068425,111.719344,111.770236,157.875005,200.747909,180.025754,92.526889,-46.261554,-42.364616,42.529819,96.980014,253.492622,359.863848,328.149844,166.95524,89.7156,-8.490393,2.101492,145.781024,196.798275,141.25715,-1.092848,-66.88779,-232.607018,-297.896632,-233.077677,-139.148119,-54.758964,-73.279243,-79.488005,-127.518527,-182.377018,-260.477985,-228.051536,-76.102044,27.978427,56.484341,24.851098,-35.922872,-128.324739,-143.281048,-122.993762,-80.058551,38.502252,128.963199,120.991279,-39.23521,-137.456217,-212.978978,-172.928206,-15.800725,73.278769,68.392725,23.28756,15.492096,26.556804,15.465717,-10.232076,17.412281,127.291137,195.552382,185.065852,50.136413,-50.986512,-207.078016,-218.079277,-171.290846,-199.015795,-224.618847,-219.01945,-186.009434,-142.131984,-146.770185,-92.778957,-10.418409,147.318536,196.796544,186.915581,133.844157,113.313712,119.20149,132.610144,79.466987,-36.38606,-37.433458,-13.603031,-46.510955,-141.74181,-186.024816,-316.762145,-383.532159,-364.449515,-203.088473,-167.820469,-234.236664,-326.111373,-543.955547,-594.144775,-520.237574,-386.283416,-345.460476,-309.284703,-306.110284,-381.848749,-453.705621,-509.764967,-475.598785,-401.561515,-407.262297,-444.359864,-519.87247,-521.614444,-448.593301,-380.603153,-262.799888,-282.069732,-302.695646,-290.097458,-248.167068,-82.930496,-3.470093,41.077107,29.390876,61.094545,144.992114,150.662022,94.933086,68.866142,19.906746,-15.445974,-42.925481,36.007269,87.851441,126.741646,100.183811,-9.674983,-76.354827,-162.319518,-156.471105,-73.514565,-0.345868,-17.997785,-129.212918,-170.250144,-183.131526,-151.31852,25.250308,221.225974,240.35258,145.231142,116.557389,128.482239,111.815652,43.971629,20.346886,-25.116318,-31.616614,3.394811,80.616776,72.811232,15.99549,46.949359,226.323756,343.879087,365.283114,367.839851,351.27859,273.452786,217.868491,117.479098,91.365979,110.240028,121.378559,88.079967,-52.969148,-144.62593,-225.418929,-157.816492,55.460719,106.016626,77.026913,10.552956,-17.731014,-108.716406,-157.884229,-161.86008,-120.499546,-70.30761,-129.325554,-169.680523,-175.00149,-138.629618,-103.269065,-136.330064,-214.002306,-150.971788,-91.571629,-69.760624,-94.016413,-113.05129,-117.26463,-107.429876,-67.590372,49.165115,131.77476,143.17259,124.506128,124.460295,160.835171,187.611603,239.640357,209.951883,170.449106,122.089144,107.700144,42.409248,0.299593,-28.253674,1.850563,80.127535,28.504171,-30.14045,-65.025044,-52.395623,-62.588358,-61.925027,-3.097114,62.490492,69.155089,0.320531,-45.579623,-88.394204,-109.661121,-149.496205,-130.38286,-49.049455,-62.214625,-102.856146,-180.73826,-227.686585,-342.567925,-372.075095,-343.156761,-255.418008,-200.518351,-125.851258,-134.599095,-225.149237,-259.303609,-178.85397,-86.517349,13.892393,-43.407394,-96.727025,-155.382699,-145.935717,-82.41591,-36.171268,23.581991,15.251128,21.841862,44.464908,25.792336,-117.111185,-204.125726,-175.824677,-52.64695,111.85818,46.423928,2.388062,-23.504719,-30.903637,-74.302225,-67.132879,-7.418033,-7.092834,-0.279531,17.360874,-5.715638,-133.930317,-201.856128,-191.841382,-101.75157,69.067842,117.247122,132.408557,164.238413,167.53728,154.942062,147.805881,144.666845,206.46469,243.947541,208.81292,141.731014,-2.273609,-65.460896,-140.386094,-136.850856,-76.834415,-18.193628,11.15956,87.268605,110.870169,76.54841,48.294817,81.59749,196.430207,207.115611,79.833786,-1.273391,-41.526542,-0.365873,112.73643,149.931854,180.935985,186.081617,157.458892,62.219607,19.916312,-32.418868,-10.320926,194.274422,427.556415,468.652664,405.927969,345.164915,214.477299,159.898851,164.711719,223.306887,314.135739,292.078505,244.119738,126.572611,111.679645,204.099496,264.394598,345.708657,406.957388,429.868408,399.441233,344.521181,187.704899,100.411775,26.165041,68.226065:370.110882,372.199732,310.753448,146.589844,58.97367,-20.128932,42.074409,272.964717,414.585826,427.273094,316.855374,206.507301,36.6781,21.265177,84.414845,132.469078,234.551924,291.471423,259.932666,101.452306,20.287891,-76.472656,-80.578481,5.614716,187.714882,265.898528,237.789523,139.028053,-52.87473,-101.418704,-60.559402,27.928773,242.66134,359.60742,346.839488,173.72272,53.272384,-41.23285,36.792823,278.728843,341.974057,305.971266,168.670785,83.495838,-63.54253,-99.629159,-39.735556,50.420789,250.926754,297.317926,251.285015,135.411884,78.669639,-5.989542,5.951834,144.016166,261.322855,246.396784,91.411233,18.31212,-44.089796,-53.268897,-9.437668,70.479356,287.544502,350.958003,294.427588,144.220472,77.936112,-15.804692,-6.518065,127.2532,184.758234,129.731193,-25.559302,-87.112373,-208.189825,-268.674221,-287.10154,-225.581224,-73.819354,-25.816402,-46.39314,-165.020712,-252.484949,-388.595512,-384.34729,-183.117264,32.201168,53.410695,-22.018376,-70.394939,-148.624282,-172.577774,-114.193482,-38.243505,59.782313,39.434792,-1.32744,-161.697207,-264.221689,-381.198352,-348.023292,-157.829214,8.419868,47.071708,10.29989,-49.405437,-196.10019,-242.648143,-160.649151,-52.593148,123.994692,156.44682,134.018092,5.151424,-117.461982,-327.623496,-323.065602,-159.066352,-69.837507,-84.140824,-185.905144,-235.694963,-258.999956,-231.04116,-123.374342,-50.429772,144.783188,275.624818,240.63669,68.575419,16.253497,33.477537,79.595456,151.266626,167.887508,184.183831,154.977437,77.731457,-123.597814,-197.357498,-272.565966,-288.17507,-234.97285,-147.826907,-162.859102,-294.261437,-391.081973,-586.531111,-610.383978,-447.438556,-269.368815,-249.724726,-308.959489,-364.893611,-491.759686,-524.944764,-476.179603,-425.109328,-336.422929,-270.560326,-283.092574,-402.209117,-448.995067,-421.084056,-348.126003,-175.861685,-87.882895,-68.780987,-13.530733,27.471275,35.751823,-3.012418,-0.414371,64.847265,189.35754,186.252477,151.02872,105.271634,94.232104,49.982349,29.278899,23.191249,100.147901,152.775632,151.973859,88.897288,-47.551869,-88.411001,-120.871638,-122.567336,-90.327551,-26.988531,-32.507716,-171.323067,-253.311449,-312.391987,-272.876479,-57.296233,174.017689,215.269741,114.912034,42.611559,-5.245162,-5.829385,21.391236,61.222947,118.960689,125.784169,143.413014,151.197912,103.749636,26.541457,72.462931,261.765901,378.213806,399.093658,331.159545,245.199544,87.680328,53.024022,94.087199,146.087695,202.151579,170.800622,124.639956,-19.65071,-95.313039,-181.045335,-153.22023,44.759491,204.1068,192.750193,7.773849,-119.056128,-344.750739,-387.238826,-244.97163,-126.925836,-9.865962,-62.24448,-119.53021,-205.85195,-209.738751,-204.558702,-220.04798,-204.178057,-51.176093,13.694439,-0.54321,-47.293123,-130.678045,-143.045752,-26.237458,80.30864,250.287034,337.239264,336.584521,233.162827,176.372893,152.137261,179.518566,224.744729,206.651558,195.585872,154.793335,109.490217,-37.336651,-116.225122,-166.951863,-108.998115,89.167133,138.324583,93.190086,20.798197,-2.710657,-71.053885,-81.772569,-5.606699,138.404582,175.291207,57.002443,-55.005889,-212.190331,-240.866024,-169.111099,-80.12361,34.308545,-18.466304,-84.092442,-254.347091,-336.779435,-404.339467,-366.183559,-221.372581,-104.808289,-61.358429,-49.010918,-111.898949,-304.678002,-351.172196,-225.041967,-114.160094,-37.929864,-88.283129,-92.23772,-93.754464,-121.264927,-161.334141,-110.093692,94.102791,201.248408,222.623665,246.196059,209.592924,18.55369,-54.941397,18.344373,108.524932,202.020393,181.158337,119.346928,-25.166484,-58.498706,-59.34569,-31.511958,54.908671,111.156792,124.118858,81.998425,11.276829,-203.477255,-300.995096,-312.06529,-201.330508,96.060308,217.334597,201.619884,125.712488,81.308099,11.757559,15.654595,109.920185,210.011,205.540134,52.668223,-48.170989,-165.737864,-194.049523,-268.119199,-279.413856,-157.064512,-3.100039,15.476297,-41.762573,-92.087064,-159.226625,-131.060673,75.034078,281.559157,306.513587,170.378532,50.727035,-121.530891,-125.784031,18.951156,112.340645,246.529498,328.014109,309.704138,151.898263,76.922941,16.124921,31.438903,143.755563,302.992897,380.051695,409.254267,339.135607,127.404445,48.603549,54.424691,123.60192,243.515895,201.595046,131.526865,42.454932,55.144596,114.881195,154.988322,318.723719,491.856609,511.451494,371.803219,255.032294,64.041853,19.595761,76.383006,150.613772:421.825023,514.001024,515.039268,437.671111,388.863986,311.536102,306.395823,395.623749,465.755669,430.23,254.182933,172.699875,79.18147,48.709163,48.334689,91.445007,179.970294,224.391801,224.467034,132.075298,58.771133,-28.727143,-11.440355,107.569815,206.457017,217.767205,184.138522,171.73814,210.652461,251.013768,319.497507,351.187236,448.318883,529.387271,523.042318,459.881113,419.776416,333.908555,318.086918,332.90865,316.379583,293.599371,235.321291,193.074837,98.034012,66.10171,62.591364,106.461095,268.530309,353.331024,330.468262,228.938222,177.092296,73.979565,34.483788,-3.571109,-10.157119,16.959935,97.722721,119.041223,116.431443,93.16121,39.256335,42.761097,148.153189,317.746309,370.245584,339.243446,268.198345,132.9658,109.682756,121.848768,127.88149,124.221931,65.439252,9.332233,-82.145194,-99.320827,-72.01948,-42.436487,4.134568,52.295623,69.120993,5.620132,-80.743409,-229.846289,-215.220247,-12.738597,163.808699,207.239393,209.083067,175.635231,141.35246,163.594018,237.650035,248.776531,199.445443,226.838024,272.606077,268.772082,202.639582,86.669112,89.277019,152.445057,157.97155,159.359183,213.158125,238.902293,214.467303,185.268509,199.99616,238.796797,275.426996,219.357063,192.830093,163.431236,133.322144,62.717484,48.473571,-8.357639,-133.852879,-147.687495,-75.200734,-46.071766,-32.582105,-22.21648,60.079328,123.277827,230.621507,269.227948,237.022031,124.685933,108.094997,149.983448,154.795642,90.934198,38.064154,33.097428,-65.694138,-168.608966,-286.857524,-271.85647,-241.849416,-272.538176,-343.6912,-265.418262,-209.406372,-218.253114,-287.612909,-458.937376,-498.750526,-432.271496,-276.345382,-211.928052,-216.69341,-268.178442,-306.004128,-282.33423,-243.260292,-242.450752,-217.504586,-185.922949,-243.586427,-444.806755,-489.380818,-458.933259,-445.924626,-478.360142,-519.082982,-508.760403,-410.252012,-324.620285,-162.112063,-145.16619,-235.789368,-262.265591,-196.298565,-165.830777,-182.013406,-155.159584,-114.146161,-99.328968,-126.622044,-147.674078,-126.716261,-110.89995,-73.708231,-78.453453,-178.618238,-248.222087,-330.174533,-323.918092,-215.39927,-107.437365,-95.116506,-102.183222,-107.366741,-121.382783,-111.584799,5.322933,135.789591,138.755785,54.246627,11.772552,0.178996,27.076715,75.681881,63.418161,-3.227631,36.344222,78.673088,103.049182,90.789179,92.088218,133.641291,263.247353,309.950086,314.326798,349.144291,352.169872,272.20311,202.618469,67.340993,29.085251,21.790145,-0.194203,-13.482086,14.286376,6.223751,-142.010482,-205.519238,-119.811928,70.963599,106.262639,61.421356,28.900212,-44.728165,-102.409835,-170.355799,-160.600246,-127.732335,-80.20199,-21.644127,94.108173,96.203948,-20.007839,-91.282409,-160.793759,-106.185709,-53.682829,22.939159,30.251428,-22.994928,-48.592762,27.812041,93.908599,152.139815,225.744963,260.320867,251.190325,231.262243,206.685657,205.190213,231.527201,293.509779,298.077749,194.061251,112.968452,-4.817343,-25.937678,-19.110219,-2.004027,31.265677,22.65695,5.720784,-11.220435,-12.980323,-65.223126,-99.336255,-82.805402,-66.591517,-113.659624,-227.467303,-238.46321,-199.73641,-198.666239,-191.696879,-160.85731,-157.3662,-286.169043,-337.103639,-293.538377,-234.239609,-223.0782,-280.098619,-357.820909,-233.257889,-147.04244,-112.669997,-154.825651,-249.334767,-291.167169,-268.448494,-185.321684,-66.867656,-109.832451,-143.745725,-154.183443,-124.93101,-85.357732,-91.229143,-93.991102,-72.273497,-61.227205,-53.194667,-79.95056,-201.829176,-251.912617,-218.660433,-151.626115,-65.272301,-24.204066,3.490399,-11.518697,-55.182088,-82.463882,-44.308644,68.843633,127.302937,124.518004,87.553117,65.71276,-8.12981,-61.607003,-97.699563,-56.06853,49.430903,65.402406,39.767811,-19.152181,-23.033747,-11.355845,-9.6289,46.151499,158.791532,189.265618,151.615256,106.014541,-0.270029,-56.013564,-95.629259,-80.438127,-73.303545,-31.084508,43.423375,204.443612,235.287477,162.784781,102.133379,69.511171,100.535296,99.006049,74.757575,80.518158,124.949012,138.049673,130.081667,116.191915,100.424939,116.728111,110.263141,-2.923051,-84.675859,-161.338985,-133.971231,23.988093,205.849435,269.556331,325.765485,301.694596,141.072309,62.76503,82.508126,157.786913,246.532332,236.693972,224.190234,196.700905,194.112135,190.901443,194.347773,270.007661,357.23397,370.768249,325.915011,263.426324,97.641581,29.184366,38.222774,120.314191:313.024645,317.835902,338.764684,392.23862,386.95191,300.399847,273.411669,337.117731,423.383975,405.568849,240.034919,150.445478,81.357058,104.072848,164.480376,158.789151,105.115224,120.555182,149.767122,156.309142,117.749391,36.367047,49.535225,186.593294,276.723822,270.531773,265.989127,292.190486,327.146796,320.167122,289.249262,276.325738,293.404952,365.105295,385.826758,335.971805,269.773906,174.903942,188.662524,266.53181,292.410052,284.535626,158.263951,40.362312,-106.738556,-92.304968,30.264377,112.588045,282.277308,355.886665,321.033945,150.920753,77.482232,46.834402,88.321649,207.586575,235.201138,206.944658,142.425764,138.663449,157.457079,145.28196,109.870026,133.00085,294.266863,397.366238,359.695961,234.049803,203.070332,172.271199,157.618386,164.681015,168.784204,123.846719,-40.162776,-94.431861,-96.829248,-92.265626,-77.845032,-29.655627,100.027891,126.712982,120.258483,107.566889,59.198521,-111.098554,-147.447611,-53.877615,63.194769,106.082444,176.565552,178.813225,66.900737,-3.076394,10.700725,83.322819,189.73308,170.953634,125.744844,35.504518,23.380317,14.275754,-2.440401,21.727698,110.853168,138.096068,142.174377,139.239715,156.590669,157.208042,115.112512,104.630214,180.750917,258.711025,216.410052,49.416567,8.472882,10.495656,7.213998,-77.333716,-215.537882,-231.028934,-119.747765,-46.408392,33.513369,29.322741,-7.793865,-3.685994,72.344937,158.533156,172.774621,165.482312,145.069086,50.018318,6.418315,-40.13047,-99.662619,-126.468533,-168.682425,-181.835307,-209.106183,-244.99711,-359.448544,-413.305698,-454.934039,-372.401371,-318.101359,-308.523264,-362.523368,-476.145281,-487.261364,-464.298856,-428.255322,-384.934394,-302.516331,-267.526085,-219.657372,-246.659331,-346.565851,-355.975374,-273.925279,-222.098135,-247.208283,-316.158471,-350.497637,-488.395901,-551.092195,-510.679066,-384.788395,-363.168756,-376.856384,-340.768616,-138.875269,-70.150558,-130.387975,-178.997139,-154.086036,-80.267951,-68.355075,-61.557898,-59.035567,-97.368872,-122.090612,-135.730701,-129.381147,-113.430272,-83.818151,-90.141063,-112.471436,-117.001117,-151.430558,-180.699434,-168.877575,-27.649291,19.778762,-6.472154,-39.075552,-69.700562,-63.394848,8.849452,120.459313,158.988813,156.600222,120.295444,9.597594,-38.645206,-58.115003,-43.693971,-10.19935,27.984899,22.094337,-43.988913,-63.262658,-12.913532,44.240034,148.375607,199.240009,233.086485,284.03889,248.981868,62.171337,-14.58994,-14.451884,23.856349,60.060921,44.47576,26.31379,-4.026768,-33.026161,-124.309436,-118.95281,37.013962,158.633611,163.708628,136.266663,128.432955,65.095386,-7.751078,-123.305536,-142.385451,-176.700566,-151.195906,-88.919064,5.730889,-15.992084,-137.950556,-181.907403,-232.380912,-241.45779,-199.750745,-109.434071,-101.401262,-119.332556,-122.20171,-58.281431,-4.221907,45.208203,44.321891,17.91382,-25.668352,3.089381,101.146227,142.289484,204.959936,200.429956,167.56485,64.087016,14.016096,-45.122581,-66.038604,-99.095619,-108.001777,-108.449556,-66.986185,-67.873254,-136.270779,-164.85247,-160.947051,-126.098817,-52.498155,-28.976477,-21.992944,-38.180221,-54.710721,-60.954064,-62.874376,-82.700077,-88.919814,-90.288583,-126.192858,-168.666768,-223.811163,-214.151629,-203.543376,-223.657797,-257.523057,-243.683205,-232.135163,-231.571643,-243.203465,-268.719169,-268.090806,-189.649127,-130.553858,-126.120896,-232.333009,-250.34316,-187.419962,-137.210371,-96.529004,-111.956414,-156.955688,-168.403827,-173.283405,-197.141299,-207.595364,-252.032141,-278.992403,-225.469218,-142.331482,-25.526159,-24.573521,-13.159585,39.932073,31.566688,-53.791436,-61.647027,36.178484,64.599812,36.373124,-8.829947,-21.021961,-49.729118,-65.999718,-74.424982,-64.079869,-24.78681,43.205336,83.436308,163.986294,185.35303,153.043488,123.969539,163.574469,379.654646,458.287874,393.782696,306.537135,178.306006,142.895705,100.11978,80.006495,58.815462,116.927743,161.193643,235.896841,250.643237,208.551715,188.251417,213.276332,252.016895,245.931223,156.27626,110.256022,97.976475,108.411489,110.961206,105.083864,79.917459,113.141999,144.366239,103.980474,42.678787,-11.974087,21.337897,133.510186,227.451382,271.067411,321.701261,289.916504,83.648892,-6.862148,72.940487,196.082518,348.367475,302.208053,226.568861,112.171147,118.069445,185.309538,207.757292,237.787923,270.748601,285.334504,276.627288,253.544896,210.532596,187.812262,152.349131,142.113399:371.566424,431.917492,415.330179,326.242316,265.093769,174.954523,208.200069,404.506633,479.018079,424.571169,238.430031,187.684529,266.067423,316.48838,216.637768,123.511018,135.829865,280.555046,269.9523,141.876309,107.363238,64.904693,13.424728,-32.39468,107.240448,158.98694,75.090958,14.610015,81.392307,163.173036,200.618422,172.511832,202.452973,330.829454,365.160918,304.875722,225.832807,86.98992,80.667165,178.957734,259.054504,262.611317,194.326105,126.475418,-25.895661,-68.818069,-17.400549,53.960866,165.565317,224.429363,232.372328,143.885623,74.421137,9.079857,22.997244,36.490594,18.00212,36.312774,49.804649,35.46775,27.126538,10.292129,-43.106554,-18.494198,130.941996,205.075937,184.766884,174.946563,207.985576,177.167829,104.821003,40.744419,102.025276,121.226235,81.604654,38.331369,-45.520144,-89.113834,-157.837527,-162.702228,-120.568239,-51.422658,-34.060435,-95.177471,-166.781736,-296.019532,-297.266715,-136.074079,66.173315,124.579916,136.088195,107.851671,23.744301,-13.466052,25.219672,87.475374,143.67109,128.454813,131.227907,92.119992,33.839729,-67.263927,-58.103126,57.277707,121.276133,129.325789,130.976208,120.166738,64.55615,26.529141,21.824219,74.180301,175.851408,170.596724,144.569339,75.433746,27.370702,-78.644669,-95.812825,-34.55641,-68.212017,-134.675427,-189.450316,-154.346449,-77.065457,-70.820896,-22.383009,50.114864,176.658477,175.996867,148.255698,142.739491,187.185326,279.608454,280.170973,230.170296,249.956796,255.649683,155.257869,81.98069,-31.963539,-84.211645,-155.16856,-152.236619,-123.980882,-107.409379,-104.650724,-194.411924,-279.134355,-407.164439,-418.881088,-345.88953,-254.952044,-227.630323,-223.083115,-261.47411,-387.766966,-423.711033,-401.374927,-375.657662,-332.038464,-270.934364,-261.21268,-339.991103,-398.558116,-428.423413,-390.432703,-316.312322,-323.160784,-326.212678,-293.989772,-244.934953,-63.392109,7.33866,-0.002815,-27.857979,14.48393,91.614664,83.892805,33.272022,17.810362,-25.278262,-48.649353,-43.145636,47.379468,95.227618,33.204324,-70.643532,-217.690148,-236.095918,-240.691649,-238.231133,-158.807718,12.361839,40.084381,-81.88347,-160.408743,-226.407921,-189.181351,13.015567,139.482184,109.081361,-46.736352,-85.413112,-3.186625,40.431476,4.898716,-27.680333,-30.722926,26.490735,66.482835,109.122707,91.26359,53.666977,95.604351,257.866152,259.27982,216.309525,228.165684,279.556021,274.993111,201.5027,122.907361,139.602784,121.320327,28.66284,-12.013684,-118.443857,-187.420898,-268.808999,-256.033574,-157.219289,-57.904147,-26.294075,-4.065705,-26.171897,-146.593137,-224.979691,-292.896699,-252.399585,-122.064927,-100.964867,-140.180537,-199.675771,-194.868386,-186.318846,-191.638943,-157.265197,-104.483165,-98.147852,-88.916717,-98.426125,-164.650335,-162.36988,-30.797937,31.254616,87.174668,198.978581,255.451126,282.812607,283.274644,304.730569,299.445817,223.654721,176.888458,189.436819,148.159365,64.264557,-73.685589,-64.46557,71.347144,130.351352,140.249854,37.435751,-23.569827,-46.671477,-16.257896,-40.64724,-94.657855,-101.08967,23.318202,44.57949,-52.348157,-111.969771,-173.675756,-202.17821,-224.420105,-197.490849,-170.690724,-255.907577,-290.601276,-273.040869,-263.451787,-277.605627,-270.029548,-228.547612,-138.008816,-78.405247,-51.93985,-99.131734,-214.70038,-230.345061,-114.134649,-28.187181,-2.732199,-123.521078,-169.405716,-180.802773,-149.057871,-103.948387,-104.963355,-93.088286,-21.924476,19.519543,14.946416,-44.356487,-154.217318,-150.896592,-10.679501,71.143947,83.619189,21.872966,31.163324,38.529543,16.400082,1.68103,14.238013,0.102201,-40.193806,-35.670198,6.970083,14.7177,-63.349601,-134.254222,-202.598867,-175.469264,-18.4198,153.790862,180.446947,113.159557,45.816675,-41.065939,-9.205485,124.749371,133.265723,99.968706,45.884135,16.662402,-112.010395,-191.599235,-257.365897,-233.060109,-111.3867,18.4274,42.526922,21.815035,11.266386,13.459746,20.110403,46.591795,87.574532,118.777564,141.583845,113.264449,76.111574,73.845416,34.559673,24.633736,94.588513,174.119818,161.412351,28.100304,-56.918869,-140.795818,-95.970306,122.492152,277.789175,293.571499,222.57132,153.481778,0.862138,-35.00507,51.509333,120.320225,198.47279,210.904991,164.130041,31.725392,21.788701,121.090021,186.968489,289.085971,342.816813,356.946799,319.535018,262.573813,106.205642,28.926225,-13.737356,48.707764:forward
301.047564,232.687384,255.539879,343.816064,363.583601,308.327227,250.658677,134.857082,82.786523,91.921418,130.165433,152.511655,183.364234,192.48371,251.586689,275.529115,215.349227,168.198958,188.039435,189.971949,165.976982,192.747616,249.828813,309.054551,219.344937,159.530214,122.229971,160.17042,185.20319,114.216003,-60.301393,-105.062359,-100.387724,24.776066,94.344992,125.474842,108.241427,111.528532,116.567724,71.406382,42.917453,48.419358,0.666118,-48.517547,-72.813661,-43.063448,-31.933578,-88.272357,-225.541121,-242.932363,-205.689708,-31.204004,55.283966,18.31868,-84.373469,-233.170925,-221.053197,-165.191164,3.189712,67.553012,68.575326,36.976707,65.288345,121.193978,191.713227,254.780788,338.099107,537.363327,562.115982,381.629116,262.099679,191.19317,284.57129,314.664307,279.451543,240.881883,152.391439,97.944957,60.166093,87.010607,113.602124,74.444438,66.959837,126.54423,158.938269,189.710966,235.848511,365.428658,338.406657,294.109562,329.348401,395.699039,415.495942,356.352937,243.219849,202.240251,154.147648,201.389187,225.160632,195.641255,159.488545,125.05584,129.593121,100.37007,5.825875,-23.912513,24.994021,85.005373,164.079315,186.204986,217.384939,186.986067,52.838626,-25.46325,-35.224108,-31.987901,-38.188861,-60.244086,-49.324163,-15.782852,-66.443053,-93.992527,-47.3418,1.045662,50.785206,70.834368,120.161032,138.307881,237.845365,346.556755,338.321248,235.297997,170.014432,57.423137,10.432461,-118.263603,-240.10045,-250.761827,-187.761177,-138.187022,-46.495166,-39.645632,-134.070675,-190.679981,-255.945998,-305.541123,-306.142608,-155.497938,-24.719323,135.372355,121.874878,13.229551,-21.217901,1.881951,44.227909,62.269339,102.284466,111.802785,106.25342,80.350718,-7.385505,-4.086821,31.436852,84.540762,90.729003,49.823804,3.381872,-123.434942,-194.329134,-171.493053,-77.817554,-57.91199,-108.935625,-158.606637,-200.341962,-180.794582,-195.297112,-242.456552,-193.817847,13.26945,96.274066,116.628321,71.783497,-60.935205,-84.583861,-10.005892,185.44066,246.925879,255.85808,205.338812,42.212693,-48.678665,-164.450844,-79.272111,5.759911,140.459789,160.103673,122.18545,99.668241,14.053459,-161.678031,-222.149655,-193.541455,-134.010879,-57.968631,-69.087956,-131.204191,-145.977808,-140.807918,-111.962415,-66.473875,92.395959,137.484216,15.925311,-78.779239,-139.840794,-165.982894,-188.642982,-201.587659,-198.165621,-176.453404,-164.252699,-172.193082,-185.949962,-179.696304,-144.117734,-126.403782,-99.119588,-123.619891,-236.971276,-278.455577,-304.736098,-260.307461,-215.76562,-185.524588,-205.91581,-237.590024,-230.718117,-210.17432,-249.310115,-409.088444,-421.386475,-359.851105,-176.636391,-79.08154,-10.799691,-62.068686,-212.122791,-267.036681,-262.035686,-240.079405,-211.819255,-124.578918,-101.81684,-144.18108,-172.068399,-116.927656,32.84641,68.176586,30.759512,2.760692,-8.660938,-5.496745,-16.819121,-79.424924,-141.908022,-271.819666,-312.664792,-320.174449,-272.199547,-113.067482,-73.421248,-147.261304,-207.379625,-194.150611,-151.909522,-146.959981,-162.493362,-158.054427,-172.41218,-288.440945,-349.400643,-347.905848,-273.671105,-157.613279,-165.663872,-226.65244,-249.55835,-227.009828,-38.671135,67.005271,170.358409,174.974789,140.227578,105.010344,47.787321,145.744235,234.629331,355.696111,391.949352,436.239436,425.898372,345.006899,288.690051,159.402031,26.699968,-5.288628,92.618111,183.911735,239.743109,183.919431,32.493197,66.553215,150.434096,232.882792,208.463913,120.317944,79.805171,30.633503,23.91281,37.081615,27.212667,3.381215,-11.066559,-18.319511,-106.540682,-153.860197,-200.770652,-222.538812,-225.854548,-175.408814,-103.348036,51.891108,55.751373,-139.649776,-252.014513,-290.232259,-146.623741,-65.3096,62.360432,69.416198,-7.878056,-26.372878,-39.874601,-158.875033,-210.778565,-188.125603,-144.858237,-155.618808,-209.368166,-233.670284,-183.944398,-67.400251,8.617982,9.603095,-27.62062,-27.905231,27.230277,65.181748,55.656679,-25.057341,-17.271929,90.776424,156.659735,254.528488,263.940272,189.690702,122.158124,-2.771305,0.336416,44.465233,108.069384,107.717249,89.195319,85.808575,65.877948,72.506838,90.828675,58.75258,18.387039,39.903527,109.04969,190.654368,146.20989,-70.45773,-192.885025,-147.660541,35.18119,91.713504,112.412031,126.062215,124.728486,-48.773786,-103.87596,24.097133,139.170308,216.226505,162.902896,43.04143,14.146053:103.411294,281.132444,360.181831,353.055425,320.053337,278.744924,233.262132,100.951854,71.319912,93.120328,111.533849,100.782171,59.90378,46.825047,48.977097,28.893802,-16.065862,144.948576,243.057146,267.885387,226.614432,154.388434,120.699279,52.4263,-10.003104,-25.591134,52.382841,127.064897,141.443081,56.436978,-126.73245,-180.982902,-181.920062,-11.965792,96.281407,249.647759,271.754872,220.689517,166.166199,39.902676,10.55101,38.486757,86.788616,95.943862,74.584344,42.719171,-33.115213,-72.142474,-110.700355,-56.885015,-19.796478,85.395682,147.26352,156.343698,72.647983,-159.32802,-213.137249,-139.478894,51.242133,81.521306,4.350345,-27.774838,2.212696,30.415239,47.194871,113.648078,237.034465,529.647295,563.049532,366.402395,238.027477,115.500486,201.049853,252.666784,199.169999,137.674517,81.688295,57.399855,-21.682427,-55.339048,-67.023922,-20.326337,25.44253,174.649929,218.725934,174.090357,147.025716,147.584606,111.6973,95.85052,130.345991,156.629859,172.910498,166.836437,103.604447,46.728065,3.909791,71.16911,101.398843,137.670855,132.834411,49.305,1.116107,-38.986211,-24.514444,-4.411964,104.466795,188.064109,281.011081,261.940464,143.37555,86.212456,62.67013,106.935188,111.960722,42.078301,-7.680944,-9.790041,45.064719,130.647001,79.770862,37.643797,5.213078,5.078876,-53.943461,-103.500321,-109.316222,-42.499484,137.855483,232.68264,260.021791,258.669731,202.407123,97.095745,79.131814,-12.77157,-110.168407,-112.366724,-120.49038,-129.514066,-77.369451,-50.464093,-92.128142,-110.754417,-66.449321,-48.876019,-36.295695,73.261618,141.150169,211.162307,201.751525,89.631866,-7.302588,11.628117,113.699236,139.499056,84.553622,35.559682,-14.704548,-32.357803,-69.243243,-40.589893,-14.669281,35.431488,49.01304,6.966961,-42.268137,-123.949769,-103.981218,-83.415671,-75.469317,-72.630516,-55.587121,-54.148004,-45.951127,-32.32627,-97.019735,-225.246056,-195.995173,-2.238443,50.100781,-12.194649,-56.79327,-67.079133,-25.215782,24.546895,198.703763,272.800112,259.556039,183.428256,-18.799173,-111.961261,-157.889283,-54.577611,-16.588905,21.487677,31.019347,27.414638,15.014262,-71.492957,-232.55652,-273.731626,-208.410205,-149.503302,-93.921434,-92.775374,-124.463964,-172.983544,-278.052823,-206.564822,-116.470352,-20.368733,-49.342194,-172.581324,-213.3749,-234.038445,-230.592997,-210.730256,-157.934382,-166.086344,-237.876621,-249.97358,-237.095341,-245.656184,-246.250557,-167.221795,-113.399101,-46.023908,-80.786148,-202.995219,-222.246341,-219.727587,-183.717709,-153.881534,-147.361623,-163.637329,-211.895285,-241.321402,-232.705809,-205.618894,-232.613266,-308.474945,-284.585296,-86.489937,-7.015975,-47.534519,-108.25145,-150.749275,-133.923167,-127.29506,-102.014349,-89.161197,-101.797889,-106.208277,-69.865161,-56.386654,-42.768237,42.844564,92.617649,109.602292,81.709051,-1.070546,-39.759217,-44.211629,-28.546848,-62.988502,-158.717649,-188.58263,-187.091567,-123.507549,56.023162,57.752386,-139.002318,-195.171048,-129.315305,-17.608406,-6.139957,24.809482,45.586192,-49.165516,-265.200158,-304.411201,-181.748435,-93.465973,-32.916627,-51.409324,-112.739012,-153.444663,-159.18994,34.721604,130.569174,209.799759,219.780318,201.616979,163.841133,99.793413,215.904786,328.956226,501.554258,539.228529,523.459152,472.446882,326.481026,267.247376,222.891784,194.180808,191.316135,246.177459,257.109089,177.958806,114.383292,22.557253,148.180822,269.534671,352.568189,297.425778,125.075641,46.401721,-17.454996,-11.792978,27.627357,114.522413,150.622832,169.015413,143.731138,-0.598154,-95.407454,-201.436048,-118.728827,-52.708648,26.40475,60.625345,161.899335,175.372351,16.222399,-101.058013,-211.664127,-141.391059,-65.414249,73.971629,74.293805,-20.55753,-10.660229,99.632927,-8.590601,-86.896901,-61.378772,-7.880986,-29.281429,-97.193084,-174.537637,-146.140359,0.86841,111.286071,109.685565,55.405588,54.891673,141.560125,164.384343,41.409403,-37.837392,28.581672,244.045828,309.841029,287.509834,238.93067,166.601809,148.407381,150.097239,203.314342,211.726036,145.342906,107.32276,62.342474,27.833986,-41.501019,20.079906,63.840744,16.550293,-41.327403,-31.847375,43.526972,178.335764,180.327848,73.953055,-16.632157,-5.250648,65.980473,79.715185,82.836233,95.24141,121.773362,110.860547,100.281332,90.904159,93.100725,65.696944,33.14177,-4.013689,3.864239:50.887565,226.74904,345.798581,415.388991,366.283546,252.558453,207.005487,143.052517,124.169833,111.552807,43.035927,10.346803,-13.371482,-3.093905,38.666178,14.742593,-119.806881,-63.375323,57.463796,226.16384,189.908221,-1.215528,-47.439526,-41.858018,-60.727518,-49.314216,69.227241,118.194269,40.290156,-63.575848,-221.703851,-244.209644,-182.015243,-31.813932,46.561462,158.177876,171.862932,143.621817,116.997915,72.355484,133.092746,165.030003,149.435495,128.50124,53.664273,0.280577,-45.555242,-48.61445,-50.422078,9.052848,52.105939,113.546737,121.054978,112.569682,100.201477,2.147488,-65.451442,-4.840503,140.154373,111.062697,-76.856037,-120.631179,-56.87515,-4.684612,60.437095,135.247347,196.921915,306.814607,333.401989,350.066092,325.930016,178.932902,94.044916,98.789492,63.870047,25.982663,8.364801,16.94057,-22.949159,-63.536601,-72.197813,9.378519,44.683504,106.282729,110.710732,64.966628,46.323128,-6.987967,-72.863408,-72.886841,-15.290876,16.583418,46.600603,48.977204,53.199501,56.809595,54.205432,4.661293,-7.995522,63.765798,94.122111,14.028009,-51.234172,-129.52128,-144.566708,-101.569786,39.665842,81.178359,147.207844,209.189394,266.061078,235.135292,163.052189,79.092513,48.397066,38.918318,28.640425,-4.137924,12.433403,108.5761,129.297552,97.041506,63.550318,52.955717,-80.727952,-143.201867,-44.011361,62.920496,154.781071,126.076037,142.583161,180.251535,143.300575,40.38173,6.333914,-87.803176,-130.361767,-106.188459,-48.200101,-39.793311,-47.571669,-61.211254,-123.774009,-137.116276,-63.202059,-33.043487,-40.618436,-7.461134,30.333138,147.270031,183.040783,109.580346,31.855896,26.368613,70.467737,127.540211,163.506982,91.724172,-104.880187,-161.225094,-157.337158,-102.607714,-90.086192,-81.441381,-69.940443,-35.697922,-40.681343,-94.788839,-161.698122,-208.658467,-223.553759,-170.626001,-92.173218,-102.392824,-159.181114,-157.730922,-126.726238,-207.511067,-210.519228,-64.501268,-11.611391,-61.75931,-110.509756,-122.278795,-13.861659,64.43852,226.947766,283.104112,236.1867,138.574855,-19.013072,-37.824729,-35.674428,-48.555639,-52.996465,-26.48577,-11.056166,-58.534074,-106.544483,-159.546627,-181.824571,-201.545392,-180.581896,-136.41747,-106.562529,-113.959585,-135.954697,-187.436302,-306.96976,-274.889793,-207.967142,-68.340221,-49.133223,-162.289666,-244.115047,-302.902273,-224.110688,-192.264922,-193.063764,-196.727441,-202.151114,-211.704627,-210.146076,-203.250706,-150.241957,-13.04594,31.861083,-15.999434,-86.293442,-176.772867,-170.102279,-89.698948,22.738839,50.69635,17.972323,-16.153737,-75.847317,-80.85856,-51.509341,-66.647656,-140.552731,-131.861539,-104.074317,-7.551548,39.365535,15.421292,-41.09199,-127.911005,-98.224138,-47.731988,44.125422,58.268329,-0.927352,-47.491489,-121.7291,-142.717129,-103.498966,63.400051,155.438149,234.628062,205.47992,110.498116,98.773485,131.123697,86.401061,22.758435,-62.403085,-67.185753,-33.770592,7.221973,75.841123,63.563658,-35.28743,-92.692215,-69.741521,42.628771,86.046959,111.414556,117.009914,95.324461,37.266021,54.970127,172.987136,201.424963,145.033291,122.465579,148.79128,160.593218,158.515783,173.721207,205.587183,326.161539,376.999673,364.319208,319.803976,272.593353,340.596624,396.987322,502.694268,535.987773,533.262775,493.587023,359.696323,305.275861,261.822492,202.91867,179.709858,215.146624,213.714875,43.834357,-66.668681,-117.646613,41.633872,138.622354,293.823993,319.702924,197.680342,84.823773,-44.565272,-46.13632,-22.061266,-8.461004,2.696691,34.200395,36.679995,-10.640595,-52.229658,-109.607667,-112.881954,-104.138639,-22.801486,57.692114,160.008326,116.147904,-133.279408,-242.820524,-222.363711,-92.967545,-70.500424,-1.056874,34.582532,5.258738,-23.69375,3.539356,37.678657,11.451836,-36.918346,-28.03625,-23.192852,-34.769518,-54.26154,-78.95906,-77.719566,82.214715,159.926268,214.120624,201.567882,165.060467,132.261195,-18.629713,-77.336071,-24.953049,126.702349,190.880775,221.417329,172.069509,24.166766,-7.219598,43.23471,102.978211,117.330679,127.720685,113.114115,21.359968,-34.210536,-106.937199,-70.448234,-24.070382,24.15518,31.015242,31.114946,33.512041,110.878165,161.690169,134.867664,12.645925,12.404435,101.79722,118.534099,71.848068,55.697988,85.309417,151.895259,183.09117,212.459447,191.218554,92.707739,89.220252,158.459949,138.242249:185.331169,261.633896,300.73575,329.837149,326.195282,292.168783,260.030984,182.664439,142.801423,131.908345,112.909562,116.838315,120.281155,115.815344,118.012475,101.719892,69.510782,156.407553,188.294116,117.506049,76.14923,127.806351,183.917322,213.8974,152.70852,115.046673,72.891605,84.529886,75.634628,7.660947,-157.466352,-189.678997,-124.961206,-3.977558,41.265157,139.566487,191.266964,203.188694,161.442531,72.330478,48.053947,46.984317,34.082164,35.494402,29.686292,7.946371,-18.356535,-39.287605,-177.125028,-267.753487,-231.548155,-70.326428,-8.794956,-26.165835,-94.48875,-208.961647,-150.611253,-74.20572,42.210663,56.359426,38.148957,28.770272,23.277347,24.913304,37.931371,127.365758,230.466088,434.561359,437.09964,257.918351,180.835603,161.15825,210.399461,235.133256,243.964721,216.550705,113.393794,59.558231,5.294519,-3.144449,-23.15506,-11.386253,20.837225,101.127979,115.626143,90.703541,84.644473,84.088493,103.149936,154.466721,286.543965,317.476275,302.628131,286.910883,272.624766,262.409134,247.650004,268.44438,274.775961,253.438024,217.53435,89.035636,22.709291,-50.732515,-32.008331,-7.217698,7.293564,4.03619,38.795316,71.982439,94.855552,73.877906,29.377568,-15.006401,-44.829044,-53.297961,-40.794795,-53.182909,-59.410039,-10.563488,65.393757,91.182493,146.636248,182.672483,207.198949,198.39718,240.883574,291.641971,349.799233,318.951412,303.346495,268.382627,216.813488,63.026043,-13.404086,-152.226888,-234.443811,-240.157648,-202.687607,-173.437167,-125.764327,-131.345741,-222.744298,-271.155776,-306.044918,-295.712532,-257.533332,-146.4636,-106.950426,-29.408523,9.469104,0.419054,-84.305832,-103.974361,-61.975742,-8.705784,48.289709,25.007921,-21.595786,-33.674828,-96.73073,-125.621409,-105.612143,-57.771165,-49.505557,-84.952637,-127.862002,-234.415207,-275.016708,-261.48453,-233.155505,-219.546939,-204.815671,-230.305658,-329.187332,-357.226763,-341.441915,-297.123168,-251.475385,-125.613066,-95.078899,-106.450102,-105.846226,-101.225325,-67.529175,6.731071,206.773439,275.363426,284.715081,232.421367,93.820178,38.711769,-35.715018,-60.598493,-42.241118,35.20211,48.050494,-7.659701,-30.271708,-66.778962,-145.606609,-159.597297,-97.881798,-48.427754,6.059798,-2.936979,-81.755639,-139.649964,-221.064249,-183.713663,-125.168005,-7.101835,5.665345,-86.038313,-138.981856,-187.726469,-240.617842,-251.706034,-180.800956,-137.924186,-184.727335,-250.971043,-289.467013,-249.794282,-147.299123,-105.291913,-97.550123,-82.907529,-106.495692,-173.601596,-180.905366,-181.200549,-131.363697,-73.028029,-11.055229,-31.873506,-75.263506,-64.022937,-37.130265,-69.735635,-217.27262,-253.010995,-181.5627,2.211091,22.148244,-92.933786,-140.651409,-126.076069,-103.625293,-119.412139,-145.107771,-111.978146,18.443018,60.373939,39.732635,-5.841953,-61.709152,35.520809,97.131244,65.339696,-5.885672,-30.374801,35.111982,153.898026,132.925433,86.13404,1.419076,-16.875474,-21.837953,-0.410423,90.381945,101.884056,18.555143,-34.968116,-34.204081,27.785619,89.103275,182.86642,179.907675,80.847522,-13.831149,-10.843439,100.304716,150.347887,102.27744,48.031638,57.76352,94.167812,135.317468,225.476344,277.210181,326.010881,326.228199,320.73514,330.582832,339.087455,312.135267,328.765399,425.500192,468.648492,486.866038,453.318915,337.851019,285.420603,212.455021,144.121971,123.10785,149.558637,161.144554,79.444068,2.068571,-82.048562,47.266177,141.75937,197.290659,160.760232,70.484638,31.024249,-48.00647,-76.708213,-49.677335,32.553484,54.909044,80.937682,93.271005,82.68335,32.717293,-142.23901,-229.644555,-193.317904,-33.383086,25.536011,30.51922,-16.802677,-186.641466,-271.275239,-316.973073,-227.079467,-178.190798,-73.852722,-29.343493,-44.372134,-90.607006,-164.337163,-216.017403,-234.024526,-228.225363,-204.32074,-176.306,-189.838627,-226.156154,-222.084547,-128.925733,-18.654011,-19.927129,-56.798689,-29.594874,102.426809,141.769597,51.256416,-71.538325,-69.315655,2.782367,52.520644,126.443099,119.868339,39.090865,-8.983251,-71.287859,-31.289135,13.381835,50.271877,19.539661,-78.585185,-108.106063,-126.90646,-75.996273,-28.075612,-4.019555,-27.004663,-12.789264,35.574894,113.007933,96.281014,-46.382057,-131.704685,-105.966847,-12.921998,18.812083,57.569156,82.166738,111.358307,75.275059,69.234583,106.437947,133.829268,158.682684,156.303846,162.174125,158.107311:-13.761426,160.86079,266.33314,354.905005,334.997723,248.333406,199.569202,120.567593,131.089935,153.892106,169.976925,162.378914,107.12882,64.683933,-6.654917,-38.297432,-82.838501,3.624844,104.582925,253.456929,240.454874,133.347295,95.196126,42.49768,-13.249182,-27.142957,51.1006,115.578616,64.79844,-51.966885,-205.135332,-199.268873,-130.949886,-32.245803,41.300502,165.419024,175.952683,142.827691,120.218982,25.179068,7.435297,54.550392,132.314562,143.097619,117.05926,80.72437,-18.912345,-80.746924,-183.43416,-152.761651,-100.494208,-12.548627,-15.970515,-125.948155,-186.358575,-233.099648,-164.487233,-93.028909,60.50825,98.387378,89.44369,85.592004,64.916614,36.945442,66.821084,185.280151,222.455582,264.058299,248.242674,132.590236,89.577395,88.858511,130.376003,156.142915,182.463552,173.801746,124.00392,89.839027,28.593654,10.515812,29.699046,96.570622,115.486067,108.012336,91.301034,53.237118,29.896925,-21.353314,-16.946931,21.882428,178.555036,266.631764,309.938116,268.603908,246.362757,276.577722,279.66898,235.233259,260.401113,359.387739,348.686511,133.709325,5.827834,-104.615884,-32.540174,19.198159,66.779389,70.273769,110.94577,147.637045,143.033575,97.545791,54.344843,59.596478,47.772368,24.140282,8.591761,-36.587495,-35.241991,36.66939,93.919915,110.705597,210.418363,279.644024,304.411592,270.660194,242.192812,244.192716,246.793036,286.133767,326.234601,331.597654,262.49253,104.880967,53.035943,-54.859318,-110.732576,-85.403104,-1.77447,11.150051,-59.53831,-122.405135,-248.882704,-285.374633,-259.170919,-167.388426,-102.565776,19.273215,30.526088,-1.689817,-9.083873,-43.961542,-108.631002,-112.894262,-1.359649,86.854656,146.226551,95.861332,-55.732304,-122.626209,-168.940714,-73.16488,-7.12946,35.586622,-10.497145,-136.477806,-190.938229,-301.070026,-304.081491,-261.132377,-181.624232,-147.716125,-125.519486,-156.743201,-256.622042,-306.902662,-371.52949,-324.261607,-252.118959,-134.58899,-142.665286,-190.972516,-172.319044,-89.196968,-42.473635,-14.736474,156.705199,269.78594,317.202502,234.546082,55.368728,22.816347,14.517237,-48.457494,-69.959761,5.972609,78.404035,124.87612,55.421818,-154.371338,-176.451735,-113.292547,11.98293,29.945104,-22.9573,-41.20374,-50.679216,-101.388691,-242.047734,-224.796869,-152.717785,1.657333,21.511253,-94.809617,-189.395009,-286.802886,-194.447402,-133.443509,-56.394529,-46.921742,-124.230166,-187.171447,-242.986725,-232.274236,-162.890221,-7.765524,70.182397,105.765779,55.888457,-59.926758,-76.449875,-39.188505,3.167718,15.036908,63.594459,110.961334,180.610874,165.829259,55.617194,2.307363,-58.255819,-39.858683,21.064724,165.781473,167.909921,2.159395,-80.083042,-83.91154,23.636456,48.182827,48.83129,60.809861,99.185362,93.25187,-8.077126,-81.965077,-116.923439,76.172554,169.328045,176.753322,124.616203,102.457771,127.77901,116.486459,63.48664,49.703816,50.934372,60.242201,30.26488,1.616865,14.411922,36.41205,32.981296,-8.265863,-18.616117,39.417198,102.837864,154.263662,104.806533,-5.488656,31.859288,73.735695,182.016542,247.86665,258.769781,195.814892,113.834698,117.333377,130.966449,164.445144,199.679026,267.249318,284.444584,289.181648,271.031674,172.780433,169.548281,239.695545,399.42906,462.912974,511.055201,461.496045,218.167545,87.19128,-1.904705,84.098578,118.656946,175.237351,182.165962,53.318938,-63.106572,-216.389892,-94.7594,43.945531,245.728948,240.709737,83.605888,4.755343,-60.007862,-48.266199,12.88128,12.283309,1.970527,46.966038,65.680982,2.822941,-74.841483,-251.36644,-252.170154,-181.606926,-37.034234,15.875949,60.887402,38.595095,-119.012655,-224.011363,-321.223843,-224.285039,-140.961391,-7.959055,-14.348517,-143.434089,-194.854129,-211.983182,-152.93648,-111.342087,-50.740147,-39.526981,-35.071767,-32.684553,-81.883141,-141.413886,-172.358827,-46.602225,0.695709,47.018988,83.97343,185.4457,186.459319,19.161367,-98.086372,-71.781582,50.826249,103.079624,98.597016,44.799969,-58.265362,-80.953456,-51.597934,57.384619,112.489328,156.557456,123.395895,-24.728958,-105.713866,-193.136112,-84.018169,19.067403,157.300383,154.356585,36.418273,-9.122509,35.072926,76.063771,83.202845,53.507211,60.897866,91.031997,84.336742,61.32327,78.545417,114.471621,92.238078,109.272198,215.400983,242.637396,190.251951,177.325525,210.094097,179.738983:341.395481,353.860493,364.021246,337.938429,320.158264,288.17575,262.945548,147.650056,49.082545,71.796382,185.921121,224.870405,251.221097,248.533289,240.257614,223.928809,139.102269,119.9533,145.347591,130.957474,86.817749,57.339953,99.892162,209.139395,207.64722,177.803637,154.819883,169.597792,152.185285,88.428017,-44.999541,-72.33258,-53.115081,59.209811,118.379173,163.668991,165.073159,169.408037,161.576341,122.201962,68.763014,17.137498,-104.655262,-113.355919,-11.471282,25.199098,-16.960944,-84.536658,-239.780685,-304.013942,-299.43735,-257.50413,-230.682029,-199.73432,-204.023573,-223.076833,-173.600348,-92.556152,86.632584,121.088599,118.896734,131.937149,161.150207,144.41862,103.545232,234.386143,334.64328,402.645407,346.571496,198.081937,182.59934,268.132342,358.429914,381.752741,374.578697,361.477854,317.375693,258.531771,130.133005,122.615086,235.180233,284.450848,227.292702,153.865977,191.585942,282.488422,301.264051,291.578072,228.357064,228.665733,338.05633,408.004392,479.934467,464.959028,371.52209,325.677093,289.890567,329.710863,341.310831,286.984483,231.299236,91.864648,31.33092,6.433752,61.864271,75.167557,32.352433,0.34937,1.725279,24.279928,46.06328,46.081968,35.218575,-3.507672,-19.980625,-32.632827,-52.191359,-118.596884,-114.270983,-13.281755,9.887832,-20.473081,-22.512159,38.37013,202.673545,241.826302,219.318034,217.375142,292.314182,316.03799,279.749151,200.367799,176.53159,123.930731,70.846323,-82.585278,-175.719471,-180.736743,-180.198062,-180.571311,-185.322235,-220.284957,-338.624939,-377.162302,-388.644655,-418.248684,-420.292925,-299.088598,-228.555741,-203.682041,-209.845097,-191.353655,-159.046886,-106.494679,32.404216,74.161663,86.072759,83.967301,117.887119,139.557737,99.920484,-53.934119,-112.743,-75.886926,-17.732766,-37.841333,-119.681217,-220.419571,-173.276674,-138.86374,-82.804673,-81.471642,-197.783329,-286.001616,-342.866461,-296.647135,-237.2977,-293.271539,-292.223405,-180.920038,-116.631405,-53.575756,-43.781433,-54.096114,-47.737549,9.045612,207.041722,286.286877,272.050955,203.833059,106.102241,71.296984,-30.526162,-46.071596,-8.095496,69.127795,103.968537,179.601536,184.631899,53.368002,-88.338512,-83.332176,24.403001,64.628499,32.750915,-22.05904,-93.815736,-95.429928,-90.974567,-72.206003,-18.03867,129.267678,157.822659,96.670036,57.207044,-4.345725,-85.352913,-112.708595,-135.266861,-145.270224,-152.477462,-131.765782,-66.322673,-51.37478,-44.748294,32.152679,113.837572,169.363705,57.969159,-185.61475,-185.492673,-113.581366,-128.504167,-111.407046,-24.727875,39.577106,176.782631,194.436892,64.786226,-55.148444,-224.856384,-196.944861,-159.231623,-78.31668,-47.4756,-50.831934,-73.034892,-115.603735,-115.573919,-106.851225,-125.386936,-120.81585,17.094105,100.891661,101.51017,22.997001,-71.49008,86.199408,196.333952,270.148669,213.279784,42.431964,-4.432429,0.868526,24.274541,6.645849,-86.944172,-127.11978,-138.160656,-112.043279,-27.559741,-11.888476,-70.407353,-103.53129,-101.513246,-89.258319,-61.667602,-17.078995,-54.647627,-236.030093,-336.28603,-317.273897,-216.183859,-164.497169,-124.898238,-150.050601,-195.933939,-173.875498,-79.99529,45.937778,126.0011,208.232354,174.66059,68.744729,67.013598,113.643136,85.847028,86.237691,184.463859,252.380939,320.07613,305.797143,199.712091,129.959915,10.393989,-76.199142,-78.877199,53.521064,132.572673,120.737671,17.913596,-209.619508,-116.485999,58.375213,301.141794,267.132979,27.237347,-64.79558,-93.388939,-73.512792,-74.703828,-55.490892,-26.963403,-16.9363,-33.350997,-64.511591,-101.924707,-281.615566,-382.313396,-330.071729,-145.900812,-72.412062,-15.640013,-48.331891,-196.792743,-259.776901,-302.181009,-285.298902,-253.632612,-131.844741,-106.867733,-222.87779,-285.003182,-284.138686,-252.182043,-240.876607,-197.514971,-181.235343,-208.464578,-228.351814,-199.526886,-163.650786,-70.916954,-9.056214,-43.65917,-138.253515,-109.969767,76.434671,127.681714,15.219631,-111.055147,-111.59049,-63.004426,-11.024937,132.004515,148.944973,32.270708,-28.296975,-98.897724,-103.787645,-53.394905,28.011086,1.457016,-86.86738,-95.044654,-62.04929,-7.531253,25.167708,39.426057,26.178293,55.71223,92.085083,90.162622,42.604708,-73.267594,-176.331448,-193.088251,-95.354454,-17.269902,68.02842,84.709434,116.902162,39.800344,-16.041133,16.124532,98.814783,209.812815,194.626391,136.322729,142.275838:109.175432,207.455114,322.560556,452.923072,421.183366,282.087622,232.574349,174.96197,152.169017,150.614885,145.059451,155.410579,208.416068,222.417286,189.110264,150.792113,71.176917,44.540306,71.798159,142.358197,131.078154,59.071188,49.357827,64.707057,92.694825,102.339864,97.715556,101.698848,67.98721,0.717571,-147.67129,-183.435835,-130.458358,25.02617,78.748982,115.480487,120.953062,134.953587,124.222277,31.401983,-37.967321,-33.316463,29.402942,74.538974,100.631855,51.35508,-88.253271,-134.820988,-192.556984,-273.823907,-315.404757,-303.365164,-251.128145,-206.242083,-251.366302,-356.157247,-241.012276,-108.903682,75.340947,95.465287,114.589222,132.255059,121.059268,98.08234,69.403892,132.187221,214.10205,357.358011,341.946935,155.912371,76.418645,57.86592,141.680284,196.194503,286.062859,309.237447,316.24733,291.617389,155.58656,72.2753,20.595241,126.194492,162.073179,166.312488,175.675232,214.709708,197.486983,58.439974,37.329817,143.465498,402.563715,462.299302,440.683394,414.666835,389.300071,350.523048,253.316641,319.742002,374.181866,393.381397,352.839209,199.106165,115.662296,-6.378442,-34.544036,-14.489628,33.991531,54.921631,61.060306,33.431494,-33.937071,-42.51255,-7.632511,-13.359392,-36.620378,-81.815556,-91.110616,-75.144373,-62.783886,-22.444681,63.803976,104.627823,180.514658,236.990388,349.908258,358.76908,275.676103,234.52717,236.842582,273.148785,270.292974,251.32989,224.212242,74.724752,-46.325369,-283.880034,-302.548022,-229.586031,-97.964843,-77.072201,-102.572183,-133.471009,-206.375415,-241.282497,-279.777269,-230.431488,-184.060452,-125.795506,-130.126295,-158.529181,-162.364727,-167.694811,-138.681819,-95.013372,63.812888,172.203952,286.438842,244.716689,78.860081,12.127605,-55.984346,-40.979897,0.487107,88.089341,80.646166,-38.981117,-109.542875,-246.193451,-312.230679,-272.471296,-116.907579,-80.48387,-161.450753,-226.877424,-311.200092,-348.655465,-410.062971,-366.696022,-297.797457,-149.664798,-119.285551,-141.137181,-157.183224,-168.689797,-105.861787,-21.399946,214.440578,320.372229,372.294426,320.57602,183.451072,103.441205,-57.180547,-66.982539,-15.015913,117.922031,159.424924,112.909733,44.452897,-71.31153,-93.835708,-83.617665,-29.438292,19.969382,82.479335,55.577963,-96.737386,-179.366578,-257.057134,-184.001426,-82.833653,165.74647,217.548359,88.771702,-34.266973,-239.695407,-262.220377,-214.560371,-93.924896,-37.81531,-38.351341,-103.517777,-178.687405,-150.226609,-44.547815,52.712823,111.953868,208.827091,176.556574,-17.99514,-87.042591,-80.511049,32.832189,52.467752,16.481711,55.913639,253.45818,299.911516,181.473339,75.282918,-77.920123,-126.220981,-109.135032,38.659397,102.984262,27.041372,-61.306961,-127.836132,-53.737027,-0.014031,81.410628,114.515027,187.80608,202.853803,133.14008,52.19345,-70.919031,64.765246,185.364222,274.109114,222.402739,101.359813,69.017347,5.475422,-34.602314,-31.920003,-4.378012,26.488715,85.726637,90.653971,52.517371,7.411498,-96.426207,-92.32377,-46.11559,71.227991,106.814557,48.807304,-22.964726,-140.406107,-150.666859,-125.271701,-44.153388,18.508887,89.479809,53.846794,-71.176103,-99.182942,-53.085322,66.178135,143.444047,257.942959,251.593293,158.458065,110.44737,51.208921,109.525679,183.255864,341.701677,399.85865,417.111457,355.617978,120.317182,7.665186,-81.789105,-44.68557,-15.265086,67.203713,86.848738,-34.6339,-145.270786,-273.150197,-132.229815,4.106981,169.467781,152.432268,19.537404,-28.262112,-58.405381,-77.595769,-80.177942,12.897337,51.492831,60.785498,29.57861,-47.778324,-81.037354,-170.934225,-210.105081,-179.048627,-72.425863,-34.36003,-43.057721,-86.028726,-215.663155,-286.856329,-350.795033,-260.038012,-186.770618,-79.568568,-80.068031,-186.942217,-255.463465,-334.302482,-307.222145,-260.471457,-158.509951,-143.534059,-192.753446,-219.522785,-252.077826,-276.50055,-290.775786,-204.98532,-142.867848,55.570726,153.758671,178.056469,116.289358,-48.239476,-124.066217,-93.370579,25.881416,91.427642,171.286573,142.148571,-44.538401,-152.725029,-237.336569,-50.630419,80.597105,209.850269,168.442981,-25.51238,-113.885794,-218.415144,-146.070691,-56.0425,49.867033,61.486676,95.840279,107.5844,53.363265,-4.870583,-74.507406,-25.255153,12.167411,64.792402,68.476531,23.435592,1.564581,3.346292,34.667594,46.534553,100.417585,164.962072,263.795622,266.469178,229.958167,187.014527:324.019067,234.206459,207.210827,196.223784,217.91047,248.894433,213.724564,25.865775,-64.34496,-15.245076,123.320261,172.777323,194.658973,148.234077,32.54848,4.234659,-39.496892,-77.211152,-78.297742,-72.461991,-68.60316,-28.999092,12.051479,96.393163,105.208752,91.730764,133.754005,182.049589,205.576655,178.518752,133.219673,107.035109,3.448761,-59.79643,-36.941735,75.687665,136.266235,223.155187,231.834356,179.94395,123.525676,95.916546,-10.512605,-59.8944,-73.242347,-64.963705,-79.360407,-107.178434,-203.056919,-288.991554,-314.17574,-318.783358,-300.890379,-240.468414,-192.83778,-94.554332,-42.947545,0.809544,154.775643,215.648183,215.369807,175.18923,134.011894,150.247723,201.087404,234.425062,231.517757,242.725257,283.899871,351.168502,355.402745,357.536735,393.809723,419.32819,411.276362,360.84837,209.945153,147.418712,155.102359,209.734059,263.367793,258.515981,291.585642,394.307274,400.043176,313.462944,283.138514,290.760313,371.130712,466.425511,661.406572,672.634304,531.143665,461.913773,408.809941,394.025504,348.446004,301.498601,286.199527,302.790893,317.075897,289.899551,257.255398,167.225251,91.673868,87.88216,72.728653,35.122471,-46.893594,-61.935575,-34.285974,-32.523761,-122.740725,-221.619717,-232.315216,-211.887905,-206.949796,-205.337568,-193.618187,-176.05852,-163.481256,-128.577378,-35.477329,18.230231,159.444432,211.209486,201.269447,174.773978,220.544474,255.718463,172.886631,-23.801281,-44.393084,15.07491,39.356683,14.634861,-117.996752,-191.699337,-263.520429,-249.937474,-197.121535,-193.155473,-207.883007,-233.002772,-348.601639,-381.064404,-325.042017,-154.414358,-95.915005,-77.808532,-75.770854,-12.335097,60.819704,93.453923,163.172214,181.994666,174.761662,177.367107,232.588643,251.014386,199.900119,75.932611,15.002256,22.487686,79.739959,114.006959,85.173294,5.010629,-38.042895,-9.047796,76.387119,84.736002,-4.857467,-70.814406,-104.786731,-88.924949,-173.525461,-286.448955,-252.626005,-52.544024,28.203101,27.017748,-13.86372,-40.078344,13.498445,34.881169,49.194767,92.8039,235.63347,259.778459,173.669336,89.974392,-89.413008,-109.290554,-49.468884,104.469942,183.761199,318.67697,346.893657,288.146418,166.609935,112.399876,24.446218,18.250288,89.765773,118.527737,90.173874,45.010913,-12.9462,51.539925,133.015167,297.889548,306.122164,192.640851,150.567173,101.142866,-7.343668,-39.693524,0.382198,42.222924,54.867984,26.182047,53.974226,121.243095,182.6215,143.679255,172.171696,262.900831,231.241241,50.787297,-3.450293,-17.528028,-8.153107,15.555651,88.577878,128.416781,200.342734,207.822422,131.824247,73.671837,22.193914,23.439435,3.111525,-42.542518,-49.319401,-20.195042,6.3163,-16.215431,-112.9913,-132.767299,-102.049071,-53.64022,107.739171,169.773893,140.915544,77.73079,-2.256982,114.086378,214.555732,309.319477,268.2514,21.129691,-128.074366,-246.603292,-144.635289,-144.028901,-308.938586,-372.77668,-335.645526,-284.671231,-204.624065,-183.044104,-204.355298,-272.748643,-307.469676,-337.04106,-328.810238,-339.233447,-374.433867,-458.022525,-494.993339,-492.229555,-467.391292,-445.192371,-379.147921,-341.147681,-270.86193,-257.262,-250.283511,-153.197555,-72.955376,35.564068,18.072753,-97.992471,-119.66768,-60.645611,-23.082441,-16.982837,24.986162,37.809991,21.489902,25.049438,28.498804,-17.831813,-160.848688,-161.792232,-120.40172,-38.601871,19.241977,126.122849,98.517523,-114.68631,-151.702536,-59.748151,67.921538,44.688901,-53.035154,-78.337353,-101.53061,-141.578472,-243.853154,-166.359616,-96.67755,-97.052336,-156.799712,-194.437419,-144.126273,-109.126459,-206.355723,-202.147376,-102.587303,-67.822503,-62.1232,-83.351239,-163.080245,-211.574074,-274.446978,-233.388044,-200.7637,-195.56895,-216.064661,-278.742036,-316.445515,-375.632468,-372.43323,-335.263761,-228.156115,-176.335074,-129.770884,-146.526888,-174.333617,-155.730719,-104.650806,-136.331862,-169.010676,-177.769677,-137.46984,0.664368,57.982563,30.727362,-125.358589,-165.688059,-135.697532,-87.217426,25.874789,57.641166,37.708073,-2.587569,-121.111186,-209.958387,-202.853292,-146.704566,-162.667898,-272.538445,-281.811536,-126.775001,25.244373,31.167894,-32.206295,-41.097315,26.281018,48.912372,7.113615,-34.357048,-147.678887,-261.559819,-259.645106,-126.598543,-62.015325,-34.309639,-50.410962,-98.467257,-146.414011,-137.146744,-11.450581,63.713427,105.647547,81.302692,58.169185,65.211007:339.672178,337.912052,340.512832,274.490354,232.046282,151.270789,95.127088,-18.415528,-32.076688,8.143564,111.890545,144.172503,149.10309,144.005885,160.338283,155.649188,60.475378,12.583241,42.045566,67.811805,35.728654,7.699353,58.727759,149.433753,60.494663,26.478348,80.030964,120.850078,119.434998,85.069952,37.090913,18.069058,-29.715961,-29.888711,-13.701582,33.261774,64.435139,157.538147,195.835589,127.294584,-23.245593,-39.527581,-18.562054,-21.866931,-15.684022,2.138682,6.630356,-40.254709,-159.854737,-145.900505,-126.675947,-140.98906,-156.155454,-134.510671,-88.705958,-22.328384,-33.321513,-8.436478,93.629136,110.130484,87.648409,99.589823,175.968242,215.750627,263.313882,298.086154,347.549967,479.336745,478.784882,280.782157,196.202553,249.187522,421.735638,463.187357,367.116428,286.134846,196.772873,153.721506,84.285042,113.262375,229.875466,254.176265,223.926103,165.784389,176.57354,290.146732,350.12554,313.255203,225.851578,274.629241,460.521922,524.144536,543.766605,497.343577,332.015129,261.506612,241.291116,305.582143,302.072824,215.884476,172.652454,136.363265,133.53422,122.641231,123.422038,118.109591,65.566248,40.844297,11.855783,-0.252521,-27.39176,-44.949919,-49.168741,-40.301627,-52.192202,-59.130231,-62.492625,-135.156831,-177.467947,-184.650809,-149.46008,-127.644073,-54.459108,-20.034236,40.263152,75.786718,87.26239,47.896894,48.627004,222.036531,263.254172,165.345292,73.189273,-45.805977,-47.195552,-55.713266,-161.72385,-197.124043,-194.329386,-171.895197,-118.504858,-117.28891,-173.841301,-203.858176,-284.599814,-344.560039,-303.817148,-134.698256,-88.522702,-115.119788,-121.420058,-62.450654,-20.308881,-8.78966,36.92408,81.228601,174.796899,202.075326,206.80562,186.415912,158.122994,153.729983,122.959386,72.658917,78.315378,53.791806,14.623539,-43.521967,-58.411962,-55.174821,-56.387887,-70.633702,-124.721264,-154.535082,-152.48527,-140.094918,-224.759321,-286.038116,-227.604548,-25.388169,48.441779,74.008215,53.035783,-5.903996,-19.808566,22.089008,145.51443,192.97465,249.953429,244.474184,89.268188,-34.057269,-177.585465,-97.319038,-25.106512,101.161951,136.529515,153.144408,159.653905,134.223119,-6.489241,-90.659769,-161.320364,-119.446599,-42.105454,-80.721128,-192.181805,-197.431746,-135.325747,-69.859564,-46.305444,36.822366,88.734519,80.080705,21.267073,-77.238913,-103.741671,-103.939973,-110.450303,-123.507486,-160.437948,-169.537232,-139.339236,-123.40448,-157.059284,-141.86122,-70.963341,22.681802,-36.724723,-214.234339,-227.484853,-199.592907,-271.647233,-268.825852,-134.609528,-77.348291,-74.291856,-98.24853,-143.481387,-175.199367,-234.564288,-279.093184,-307.483661,-249.67747,-152.776554,-43.429131,-84.93295,-203.807823,-224.243093,-240.532186,-285.773234,-253.656234,-81.35993,-23.247891,-49.596384,-103.554624,-168.890883,-17.594993,95.000256,183.031841,134.793622,-55.058261,-130.465213,-169.094034,-150.697492,-162.387661,-265.324493,-330.649582,-343.606325,-274.288955,-108.00353,-91.275778,-210.217593,-305.062976,-302.175505,-218.356516,-193.116404,-282.234973,-341.311285,-384.00893,-425.429551,-446.799127,-461.787831,-446.0235,-341.335717,-285.907523,-269.509838,-292.235102,-243.524348,-41.14191,29.702863,26.32904,-3.254567,-10.833406,4.216143,5.86311,33.708937,90.150921,226.775818,270.583744,269.005658,244.397949,188.069287,135.296985,-5.362303,-64.131871,-41.130875,101.099474,167.171366,158.533041,107.143398,19.811386,50.055202,133.049807,279.120579,250.006203,34.683987,-51.845597,-81.012614,-67.455116,-64.065786,-94.40072,-129.031461,-162.971755,-159.981698,-189.269528,-211.7735,-250.117321,-266.507727,-241.175172,-119.920189,-35.245047,59.606205,7.490871,-217.981508,-297.097464,-256.672512,-71.875875,-6.824536,42.60583,38.681269,-22.436616,-52.692028,-93.522868,-183.595044,-206.650027,-129.822682,-58.464491,5.164247,-28.889078,-87.463456,-73.129946,-53.850589,-132.547338,-189.214689,-191.491849,-126.55143,-2.60009,43.108093,83.947588,39.240224,28.465029,13.417738,-8.30343,-12.616556,23.40621,89.328942,78.09751,-25.343191,-104.265635,-94.903011,-48.24588,-50.042205,-50.438744,-2.61954,121.715281,141.004004,118.88684,4.951473,-59.210901,-30.49704,53.535535,108.194762,34.696951,-190.764157,-317.104721,-281.976489,-53.321936,46.124153,66.938994,49.329066,42.805541,-64.389646,-100.56259,10.288736,94.008254,117.208634,73.55891,-1.615123,-20.573091:338.203008,270.273132,211.510213,220.75252,294.39984,383.422466,351.120326,179.135076,60.803009,73.179899,162.813091,190.860969,183.153867,168.510298,178.334322,182.534328,110.58914,0.393702,-29.176259,-10.467146,16.349649,31.43736,35.961041,77.208247,87.880946,86.726072,126.550888,165.769997,147.041944,63.010392,-58.703036,-45.125533,28.516523,103.621949,134.028139,126.512666,115.272393,128.803051,114.239488,11.251449,-25.547864,-3.512849,-11.610711,-50.529653,-88.759539,-73.290429,-40.5166,-65.09404,-234.904863,-371.158697,-380.88644,-347.220716,-324.641408,-291.669571,-279.446383,-239.319699,-143.309629,-64.91421,50.904304,61.44133,75.229137,100.650346,147.604242,150.535417,125.972106,163.610903,205.859032,251.638971,248.208745,222.282164,202.614493,159.50553,210.06625,254.482275,291.652552,300.710756,274.97252,221.240912,176.169259,200.625682,195.214874,202.492513,267.413561,417.187266,434.935915,327.72127,255.681863,189.096211,245.35098,310.073686,462.503392,519.447209,504.933581,428.502527,297.118565,293.330142,343.68787,379.462691,383.56722,325.425311,271.712995,220.792024,236.926821,224.60728,68.38309,-11.223385,-91.086672,-95.184301,-47.59753,-12.315149,10.049358,-4.929476,-20.620718,-10.62696,-33.639776,-133.804801,-153.414441,-68.4427,-6.500965,66.076917,70.717927,61.12815,88.149873,163.251463,346.633876,365.069262,245.184418,165.571589,116.025006,204.991663,201.433699,74.112961,15.732793,-36.457307,-59.334928,-136.731447,-191.161358,-202.969521,-221.642675,-230.604953,-276.770794,-304.788739,-288.58761,-264.753458,-262.503632,-244.507244,-216.424083,-162.005578,-157.03334,-181.818222,-192.809832,-186.79685,-77.045105,22.005878,176.021027,201.875505,203.266627,184.597823,133.402423,126.480967,122.770295,31.514686,-13.00203,13.59674,51.183074,54.837965,28.094567,-76.061181,-185.345495,-170.737785,-82.068176,-83.330054,-158.346588,-172.341125,-143.160684,-161.383634,-298.810412,-404.255565,-400.685575,-267.960799,-171.29665,-31.15793,6.144816,25.516479,-2.994248,17.584345,157.82813,224.992855,248.910174,226.356481,195.190188,171.02372,55.387873,-51.751176,-68.681054,-3.028367,74.431755,198.563882,202.617307,115.969026,23.328497,3.214017,-18.139762,-10.700689,80.545008,110.792086,2.094852,-97.470998,-178.073987,-51.343061,34.193755,153.105904,173.814781,118.019453,45.967739,-107.592256,-198.163198,-188.618,-32.650928,53.702058,79.337539,24.195328,-44.76335,-28.010552,-12.594832,13.819269,81.489385,200.550317,165.730514,-34.67152,-84.704416,-77.931829,-125.126798,-124.845852,-0.969183,92.585391,243.97987,261.753696,141.504283,40.81427,-84.628714,-53.811075,-34.073961,-73.172021,-107.005182,-118.839258,-99.554694,-115.166911,-159.240646,-122.849804,10.903027,68.087255,178.590606,209.085592,132.503313,48.368833,-46.132505,44.615399,105.917987,181.848765,186.26453,105.480521,56.10987,-5.779652,-59.230425,-62.242246,-29.550559,-25.18564,-30.980063,-12.42147,49.693187,43.451512,-84.378281,-177.476236,-168.339315,-145.174354,-164.058927,-212.088325,-228.973212,-307.98536,-380.9806,-373.442449,-307.624868,-266.719389,-191.650374,-164.593075,-135.547799,-136.058741,-124.052034,-17.926787,38.250815,54.11967,18.180905,-42.472392,-34.111355,10.642455,5.532055,4.622935,39.454792,84.186311,174.404165,156.91679,-3.192573,-66.130937,-110.51064,-176.752495,-181.619569,-72.232735,-31.787978,-92.654414,-146.961154,-185.440158,-127.45817,-61.711522,74.224242,82.825118,-27.656885,-94.789303,-182.233779,-199.849978,-164.246608,-73.705203,-74.686739,-169.075158,-191.213965,-142.595113,-116.793756,-152.574735,-204.218767,-177.813366,-89.844002,-53.401052,-3.972616,-24.863118,-162.415084,-212.071275,-205.838976,-181.631452,-175.488047,-119.344952,-97.183565,-188.306428,-270.461051,-332.847433,-247.263734,-205.531331,-187.977579,-196.12032,-173.986755,-139.892089,-114.189503,-148.847236,-245.443536,-234.744515,-192.219379,-77.3268,-17.740158,56.835468,58.581635,13.115197,-25.386729,-26.892923,-50.178101,-57.558731,9.176437,54.083596,80.479315,47.979922,-87.041981,-142.835968,-110.11316,-50.881475,-70.189083,-176.978401,-226.73622,-231.086381,-64.739131,14.655998,40.162578,22.290745,45.111519,77.661245,74.785036,23.070569,-92.340343,-88.705678,-51.840418,27.676753,54.699912,39.687933,0.162113,-107.046781,-179.890009,-153.526873,20.554276,108.497868,159.303957,134.611015,115.759003,124.865776:forward
232.915217,192.675678,139.773186,60.240461,65.922138,111.97643,136.339288,228.608446,258.11418,207.599835,45.939434,-32.604692,-75.578451,-10.76522,175.263431,200.632977,45.90908,-110.191945,-122.996713,-149.197644,-190.309538,-217.140403,-168.359378,-39.943351,-50.668688,-93.361499,-163.726591,-170.325938,-120.238612,-110.323518,-170.471182,-206.751422,-248.06496,-230.432677,-233.764611,-350.46491,-412.375402,-389.408016,-331.840634,-289.860422,-271.815975,-235.433208,-208.652081,-209.70812,-145.17457,-112.360059,-133.97636,-154.144305,-145.627828,-99.923658,-73.04614,-18.104131,3.358435,-4.083798,-10.726618,77.718207,157.723443,124.254786,-48.172007,-136.751097,-184.649464,-126.027437,56.497927,115.332867,74.108965,-40.341172,-41.720558,71.604096,132.03234,128.426773,87.788748,75.354357,122.590551,137.680197,121.909483,95.171188,47.958249,28.944618,15.130922,19.831905,21.321947,81.195076,113.825721,66.994313,24.897226,46.797197,98.735321,150.715945,80.255654,39.339769,-30.194445,-55.65128,-18.884596,30.655905,42.108857,-0.970457,2.835497,191.94079,272.349094,305.414532,287.927709,228.543323,194.96938,178.983984,210.622371,186.738052,-0.660034,-97.629199,-98.49135,-31.068923,35.532988,13.847378,-59.616031,-123.967461,-176.964488,-268.891492,-264.924658,-183.465009,-116.199998,66.482749,122.803159,93.499673,24.889138,-22.889142,-127.316798,-144.791885,-94.190767,-53.216651,-22.458563,-104.504382,-170.532532,-277.794183,-290.317713,-216.536589,-125.884751,84.172586,136.570905,124.777609,114.740096,108.363661,121.357626,134.73374,119.053143,119.894921,173.353113,140.182677,57.473634,-79.460342,-64.499904,65.180142,122.155679,161.445663,100.103662,72.643272,71.822941,73.347778,64.779359,70.903888,106.370988,108.162052,51.240783,58.398095,80.265078,27.987694,-26.628625,-66.336904,-38.451921,16.250842,-80.304903,-144.57482,-195.833651,-201.630464,-220.453349,-225.153073,-169.195316,-116.73922,-59.35817,-70.40319,-88.835467,-137.710611,-150.06599,-163.505966,-163.053835,-112.234466,-71.451165,-98.678725,-232.319266,-268.89215,-178.287404,-111.296672,-38.807628,6.011971,114.821221,103.555363,48.216687,-102.325977,-166.239791,-200.907932,-173.650316,-105.74424,-88.976932,-91.478882,-123.807785,-157.281714,-189.964701,-163.346358,-38.952841,18.923739,17.034182,-72.757748,-86.712287,-6.457925,48.87497,64.191052,23.636353,-26.23142,5.458491,1.180142,-91.595486,-143.616355,-206.305418,-240.763735,-264.879405,-223.730375,-180.661271,-327.878665,-411.384374,-416.733974,-323.612952,-109.447241,-53.262276,-36.016257,-102.457813,-157.131708,-311.811515,-407.86359,-509.821576,-479.564575,-301.177441,-190.749386,-38.134638,-27.442844,-62.46591,-174.605515,-212.103431,-152.205527,-66.069868,51.691107,-0.886031,-30.174479,-40.485656,-44.593887,-22.116418,7.045471,33.799103,26.547876,13.704378,19.833869,2.538435,-85.664988,-127.746464,-160.822514,-134.727291,-1.282514,15.414328,-59.417007,-211.221637,-237.027956,-174.661588,-96.34963,79.612898,126.984856,97.816036,8.447502,-58.527471,-256.460089,-324.919059,-282.700497,-212.789946,-134.566244,-154.408439,-143.234312,-106.433425,-147.619324,-287.364215,-289.366064,-129.398851,-46.138699,-0.757501,-47.501813,-85.393072,-194.844256,-241.549263,-248.411773,-211.277451,-146.08438,-149.896611,-147.397819,-122.200612,-117.344391,-97.92134,-79.495996,-71.389847,-91.289232,-146.8015,-125.760022,-113.407078,-165.37874,-189.037108,-187.308839,-191.472841,-212.334451,-191.972556,-167.779859,-124.798398,-109.426921,-139.907353,-203.251611,-284.571009,-261.849521,-226.40394,-254.973405,-259.062956,-267.55302,-274.820034,-274.144032,-254.232309,-164.347252,-158.025523,-209.253825,-293.870026,-274.571607,-113.820257,-39.059531,5.168151,12.955275,68.85608,45.985586,-34.686072,-215.760913,-251.051915,-186.250065,-121.466009,-25.822549,-51.618506,-78.909097,-115.086269,-147.857136,-223.406021,-228.390535,-140.18556,-69.665637,0.400739,-23.57442,-37.913798,-139.846319,-225.125013,-296.012758,-238.738329,-57.665366,-25.983645,-64.103295,-185.948237,-251.075834,-260.978966,-198.982053,-108.323961,-122.575403,-199.629082,-190.223693,-153.17614,-108.876793,-93.044054,-21.335119,7.315167,-24.963712,-100.05453,-104.081119,-109.403767,-140.912294,-157.848759,-110.825323,13.215457,48.825243,55.954265,33.713478,2.083084,-59.7993,-45.20655,36.730973,75.553825,169.861884,179.865402,96.975655,-145.973233,-226.716031,-242.886553,-217.705323,-162.695537,-121.45037:259.849066,213.42905,165.186159,92.206007,118.995996,258.836515,299.607485,268.328776,196.717564,161.97305,28.46813,-67.293691,-140.716423,-78.770014,97.200062,115.33059,-44.485103,-231.152891,-274.20938,-295.484661,-290.154441,-216.263815,-148.549462,-55.314353,-60.07565,-71.093957,-105.451256,-132.765444,-166.475252,-148.61339,-68.971113,-59.547824,-124.16726,-173.371561,-201.602348,-277.190945,-301.514247,-309.742132,-289.585665,-194.09435,-118.219504,-133.357785,-225.516745,-237.721731,-158.552484,-114.11082,-51.706743,-20.120558,29.390644,53.628483,62.3232,22.643486,-28.439601,-100.394492,-90.991055,30.250959,127.212266,109.895801,39.775995,39.03037,64.114867,50.892992,18.551426,32.370321,92.598389,86.478141,58.965181,82.051013,125.326574,103.154171,35.562952,-61.096689,-26.038117,11.469482,42.235101,29.467023,-20.849413,-33.772193,-16.796153,-10.364286,-11.667619,23.557976,40.669921,36.543341,33.967289,42.709337,49.512638,70.028195,35.646338,-12.638516,-107.774465,-127.951094,-82.97791,-31.777497,42.724646,30.160105,-46.308077,-3.062788,63.789469,185.99644,213.780431,167.705125,132.825184,135.401477,109.613112,59.0842,-60.422,-87.206534,-6.239008,52.880309,39.274118,-34.759279,-181.808425,-253.465516,-297.403266,-375.388876,-354.955982,-189.899328,-108.207997,-64.334926,-111.8797,-114.042242,-111.459869,-136.337761,-198.578708,-219.079766,-209.105153,-177.83552,-132.282531,-155.649833,-189.412012,-259.243436,-260.454939,-151.09535,-53.578768,113.241439,100.892239,44.377342,-53.284523,-71.184466,-64.176021,-61.454123,-26.274585,22.215991,94.095269,28.496245,-38.856559,-78.631666,-24.605797,103.750182,145.073282,195.971659,167.648236,136.027169,69.629118,41.402649,35.325787,59.035098,142.379564,181.884521,174.168431,77.259495,31.933163,-44.956034,-82.541393,-123.018822,-119.482858,-133.807254,-204.574191,-238.959401,-314.582576,-330.524173,-249.065648,-196.346543,-142.945743,-121.912468,-90.321284,-92.484252,-104.798106,-139.03319,-148.986188,-158.294623,-145.760716,-113.830428,-191.513454,-245.504179,-319.147437,-335.299164,-283.880947,-218.223444,-79.35567,-31.528215,16.024895,9.353574,-26.930208,-86.657625,-71.841682,-21.355907,-29.849712,-110.595937,-179.266593,-194.113468,-251.907911,-283.339536,-242.573203,-183.799485,-99.61866,-88.822518,-112.143952,-163.178333,-181.516126,-130.268783,-67.933946,33.755205,61.27245,67.307516,55.853293,49.983945,-24.60609,-77.765092,-154.422303,-178.626223,-135.920598,-71.359212,-43.754893,-194.274047,-254.242876,-241.613482,-189.442859,-96.672975,-63.774887,5.131657,-7.988584,-84.97635,-333.130026,-433.460672,-437.947832,-357.593117,-178.34643,-110.437046,-40.210788,-110.90391,-171.193696,-185.91697,-133.70946,-58.695499,-50.507086,6.458699,55.6707,24.538028,-79.805195,-89.238029,-20.312538,12.944671,53.473334,59.084262,-0.909295,-56.722171,-43.660174,-17.543637,-23.520766,-32.469235,-2.989245,126.396162,128.566837,59.703249,-103.038895,-143.949972,-46.717694,47.103157,138.425572,132.690272,125.319384,96.147248,35.726173,-130.149099,-182.991716,-132.996556,-56.586245,20.269225,-11.287777,-26.210139,-91.290215,-145.160643,-205.899193,-189.496431,-100.479146,-67.594773,-61.4936,-91.488515,-127.967332,-172.598264,-156.020867,-127.454248,-118.571679,-95.020476,-90.478358,-94.831998,-142.533104,-149.310359,-76.518616,-43.65042,-63.076036,-103.120699,-160.183667,-122.799692,-102.391172,-114.296385,-125.955149,-131.244988,-134.126782,-138.433017,-145.713531,-160.442038,-184.820025,-186.478791,-173.911715,-145.007389,-46.465375,-23.205437,-91.278864,-201.260381,-224.219776,-199.21977,-178.050944,-150.051636,-122.574914,-25.20502,67.505838,64.691528,-87.158242,-150.853012,-100.022671,-19.7103,133.734358,166.0994,135.592266,63.197234,23.418269,-8.330645,-0.194859,17.960972,42.798744,125.382464,143.94143,125.020965,50.878341,2.42477,-73.211836,-93.488606,-81.218372,-41.963917,17.883757,-38.254662,-90.017662,-156.566936,-159.932136,-159.043228,-154.050016,-97.187543,-51.26721,-65.454129,-179.221685,-243.707627,-279.44353,-258.106181,-200.063479,-185.166242,-216.291873,-238.334969,-224.091428,-168.201462,-137.121219,-54.70916,2.502295,50.307128,-31.99766,-71.151425,-114.606389,-132.83164,-170.842124,-174.15807,-78.190489,-3.362886,32.102805,-73.217353,-111.501973,-71.487942,-15.558835,66.771977,95.79146,134.409732,62.601997,-12.455407,-158.400158,-180.442944,-127.743193,-118.024489,-142.033987,-131.221974:222.461247,193.540577,143.038185,-12.064497,-24.699377,136.349899,218.787972,231.952723,129.095259,70.268804,-60.312904,-124.447253,-184.385465,-147.524957,18.859288,64.75002,-34.905887,-209.617674,-261.601274,-276.549606,-241.979005,-121.251043,-48.752812,49.3265,16.764151,-23.960833,-97.411884,-121.44012,-112.175972,-76.137396,-8.069151,-11.573955,-62.6943,-111.499691,-163.552671,-258.497564,-254.56993,-163.014708,-100.210675,-20.431429,-49.390999,-54.616722,2.245152,42.815667,126.337524,161.890343,170.991624,141.127877,120.472949,180.54832,174.35417,69.94776,13.829632,-44.337439,-42.719729,12.946642,80.604541,81.214948,-3.286242,-48.175337,-42.730287,3.808491,116.611423,149.690724,108.994571,26.063488,31.697763,120.74566,157.278194,105.966454,26.17044,-99.843366,-55.558229,8.165586,50.305849,23.674306,-10.282473,-8.469358,21.017267,44.794959,77.219851,76.479464,59.689628,10.240333,-1.819431,-10.532437,-25.602875,-39.258303,7.454836,9.583223,-69.8585,-117.946446,-163.906077,-155.117668,-85.543999,-53.068344,-46.630314,-32.02073,-0.989731,87.703397,118.335628,84.512749,59.188723,73.080878,70.926847,60.346722,27.145959,-3.611441,-33.054251,-13.04021,48.840102,50.451284,-43.232854,-164.85459,-201.131605,-223.504125,-219.762742,-186.634541,-156.324577,-109.987222,-139.341627,-176.318759,-253.176613,-273.933852,-276.321603,-256.235814,-135.836809,-67.642305,-68.977878,-169.569178,-177.994282,-126.04409,-98.69577,-48.049915,-7.159518,109.464263,199.286626,177.021346,5.332971,-61.493636,-49.567409,-14.546098,0.679697,-9.108142,12.250537,41.830336,29.291265,28.699054,55.122787,118.551503,157.576347,218.673668,205.802329,174.395011,84.274951,66.642582,124.592109,168.309987,235.636514,247.16114,198.365742,89.614689,28.158868,-80.613901,-109.41312,-122.832307,-123.342475,-98.86969,-62.914377,-92.610136,-207.605258,-221.354336,-163.706223,-142.059639,-127.14805,-131.968302,-167.178297,-159.416036,-142.972953,-116.696829,-106.609742,-100.245844,-89.34228,-54.896413,-80.98655,-127.178597,-305.297502,-392.891842,-395.029177,-316.786379,-138.348461,-74.319961,-11.798827,-7.532639,-27.694342,-84.417321,-105.837512,-105.086249,-77.415575,-34.282043,-95.304427,-144.250983,-197.703562,-183.641605,-121.728125,-115.047338,-124.199282,-118.295193,-108.270234,-98.073241,-93.857867,-62.417365,-25.766469,32.292797,35.703746,31.429447,79.148202,101.500386,72.441195,33.808745,-11.220546,-2.613109,66.345644,88.98566,-8.45941,-200.146293,-243.896751,-187.956243,-120.10686,26.675817,73.896119,62.175975,4.074382,-32.763245,-177.061163,-243.795294,-255.614088,-215.915495,-111.177409,-69.606777,-34.455827,-41.372443,-74.306157,-163.564621,-167.827827,-36.134468,55.509191,105.210769,-20.60535,-64.974175,-27.670878,30.588049,90.087622,71.442119,32.161076,16.044088,-25.999718,-18.095962,-16.735538,-53.875682,-64.56554,-14.131473,37.255808,130.643485,95.84272,11.523642,-178.512071,-215.469728,-111.06909,-11.252437,125.44353,131.633354,75.832018,55.026792,39.802544,-60.339817,-122.16216,-147.594362,-82.521657,78.406707,64.592326,-18.483886,-209.500896,-241.482584,-166.620175,-125.930759,-79.285724,-63.115503,-113.924439,-210.330954,-219.828504,-171.737588,-147.316371,-135.862208,-117.236231,-40.112666,-51.497522,-97.450725,-166.449692,-148.111699,-57.557687,-41.245607,-66.347801,-80.813811,-102.930569,-113.785714,-114.085723,-110.2715,-113.94742,-131.595963,-122.97928,-93.756451,-116.143318,-129.471189,-103.973471,-61.317424,-17.453806,-34.285686,-41.126622,-29.49868,-73.396566,-207.416134,-250.592792,-200.232621,-149.455064,-94.084597,-62.098981,10.917344,18.379533,9.559173,-14.527063,-23.395594,17.998695,80.609158,190.05504,180.371931,62.940187,-6.46324,-0.113735,58.656887,82.971536,111.14753,132.469224,145.159174,85.706335,48.122485,-40.930702,-70.68604,-66.572099,-71.0674,-124.499131,-142.799576,-166.21929,-203.603871,-218.499358,-216.389118,-197.003569,-154.170159,-128.678139,-97.020893,-162.849127,-206.845616,-258.975139,-274.289459,-307.390578,-312.372579,-267.12293,-241.534699,-261.063331,-320.047618,-329.06217,-297.044452,-263.578856,-169.332082,-116.426404,-65.419015,-107.111643,-139.445317,-163.490252,-143.502262,-98.414224,-86.3676,-39.484055,-6.882718,14.47219,-27.264368,-46.510297,-21.59166,17.469749,70.82605,67.689023,22.5989,-1.658612,-22.241735,-143.529314,-195.50966,-197.758294,-191.910632,-196.240816,-181.017496:189.212167,158.070719,115.022481,-7.171774,-34.380485,23.219803,90.259379,208.055245,158.581664,69.927586,-141.009852,-208.413136,-170.261276,-87.030518,66.612982,94.427241,33.788907,-94.071831,-169.834573,-290.222739,-280.765249,-111.620106,-6.37673,122.660791,74.250796,9.308876,-83.250357,-98.005278,-114.096524,-120.780938,-83.398879,-62.334802,-99.081907,-133.03462,-145.919325,-227.495213,-258.833786,-202.192321,-138.950844,-73.793315,-55.84877,-35.538988,-47.951912,-81.416935,-72.491162,-17.491583,79.20205,94.743501,85.479159,77.715934,67.924442,29.676518,23.942566,46.590349,76.693684,180.04104,226.604848,190.284039,26.623826,-46.502153,-79.118595,-64.947265,-14.658503,41.408839,134.301273,53.690066,-11.764786,-6.809372,68.401274,149.036553,111.443589,48.01803,111.987462,143.09409,119.984622,82.297319,52.843041,65.360735,67.89599,45.932684,23.329268,84.938788,101.448969,85.76158,95.839522,133.262603,125.810364,47.47748,-52.109833,-74.265899,-64.270722,-54.157238,-37.92036,-30.394137,-5.647273,10.590901,56.744245,142.524341,159.982259,111.582163,91.525084,84.619645,80.51306,86.661666,99.859584,91.512899,15.337632,-30.052234,-12.901405,45.757478,128.325504,118.547649,1.113113,-117.810901,-155.893174,-211.710749,-201.107473,-113.710768,-72.666236,-10.874099,5.814831,-15.264037,-95.776028,-131.210141,-156.93683,-154.344524,-133.739065,-126.658345,-111.350114,-49.194173,-37.223918,-102.586359,-129.983276,-64.015566,14.910766,169.183805,234.225898,207.137291,48.525125,-13.596539,48.890206,130.337703,215.497624,221.840596,208.728791,140.071261,104.634422,137.151414,177.978034,195.011481,211.147799,276.055689,230.339071,186.833619,116.552027,109.397924,179.612241,215.44377,239.807055,233.557157,157.105642,89.777359,87.207661,37.151711,-14.563069,-48.94843,-14.556576,51.122722,23.277908,-12.653231,-154.105443,-238.991703,-274.63505,-220.745459,-84.533965,-37.214531,-64.832836,-165.770552,-174.436232,-125.313825,-111.423838,-149.875667,-171.8396,-190.657274,-211.42227,-211.225288,-266.944476,-313.167106,-277.244524,-201.91599,-62.261233,-9.084014,85.652284,85.740282,15.732451,-126.831902,-131.481077,-50.3341,0.072312,66.78839,8.100984,-41.083184,-118.099856,-129.609157,-67.816459,-26.428392,37.522049,68.286425,82.36407,25.231289,-15.177191,-34.346589,9.361601,98.532588,108.949892,94.063747,113.738115,127.770538,89.886237,52.951763,-24.275203,-67.193694,-48.953552,9.036439,-17.057289,-201.169504,-243.839207,-178.963382,-99.826928,19.998848,14.000319,-60.670523,-37.050363,-48.772253,-290.037083,-442.84011,-525.942041,-456.854506,-284.110113,-226.680451,-200.644314,-228.331358,-231.754144,-214.25997,-191.845623,-119.982295,-72.229232,1.723337,-18.68954,-39.838655,-65.437555,-80.615524,-93.701102,-72.76643,11.330377,36.090946,-4.962078,-91.590245,-119.271254,-131.751494,-135.545595,-147.524891,-129.917432,-84.668443,-123.412234,-155.446284,-248.291064,-302.214769,-291.794091,-215.310489,-53.653472,-20.736609,-22.085438,-11.747133,-57.979213,-271.727048,-326.433806,-230.235084,-159.628052,-114.477244,-150.124979,-175.648119,-245.891725,-278.699221,-287.217026,-263.564016,-202.182306,-172.781067,-120.174972,-103.748825,-117.002312,-183.344764,-232.539637,-290.290575,-255.309791,-116.882486,-61.334443,-65.888071,-100.762966,-113.953641,-96.642999,-81.549286,-59.794363,-46.547665,-25.53094,-53.918154,-112.891197,-258.628751,-282.284808,-258.280014,-251.799011,-236.289336,-198.608088,-189.284093,-192.714154,-174.546667,-109.863904,-107.173012,-152.911937,-158.677942,-149.780077,-216.469313,-266.539138,-288.909028,-238.393636,-141.897136,-150.363068,-187.887599,-110.16823,-58.585104,-52.109599,-73.105031,-19.53926,41.669431,124.28569,132.210107,82.492531,19.6922,4.998493,-35.381673,-66.972005,-90.562301,-71.660239,-16.60521,35.686776,43.737386,-89.275848,-212.851166,-345.030286,-316.938815,-187.299028,-149.620613,-190.410248,-209.547063,-176.18181,-167.962983,-220.026676,-327.4824,-322.557813,-193.997219,-113.549577,-137.761004,-246.123763,-276.073845,-254.481365,-232.607558,-196.634705,-183.323366,-200.815743,-300.501606,-358.612756,-368.027722,-304.216748,-137.879445,-67.835027,-14.6774,-105.597908,-164.687346,-213.655873,-178.31544,-60.519345,-35.447946,-13.756612,26.468489,81.117027,-0.688651,-38.876854,-4.724882,30.129412,22.389854,5.620486,20.327814,-7.705745,-73.42319,-246.078858,-297.230569,-296.008722,-277.563262,-229.118367,-192.228987:202.601367,110.578706,26.568932,-131.31113,-158.428826,-58.385197,35.388579,151.007121,91.984631,33.085008,-75.818981,-120.093684,-150.342084,-117.564186,16.679383,61.308326,-17.950687,-196.267375,-263.540631,-340.654835,-322.868395,-148.183214,-45.208975,50.315695,2.238198,-47.532587,-145.766638,-169.438301,-153.695796,-128.66342,-69.203073,-59.907426,-127.344489,-229.231829,-262.371779,-256.375565,-226.321551,-138.435918,-77.397773,18.176609,36.49422,27.258874,-10.326933,-12.35912,44.119405,75.880815,142.590102,184.410909,237.069902,270.006829,269.644461,177.817921,104.532124,-6.255933,-1.936633,142.423017,263.472184,232.216528,-0.554661,-100.209702,-73.758039,-1.436794,99.723994,128.994204,134.790745,56.949707,12.491735,14.026936,59.461956,107.44748,96.885855,77.328718,64.555423,57.388634,11.093586,-28.747501,-46.533764,-5.29166,99.152599,108.090382,38.997474,16.579599,21.677788,30.264632,42.249922,44.332718,32.423708,19.853909,-25.353163,-75.662898,-168.444928,-182.039974,-134.150838,-79.765759,77.61006,137.313773,100.17843,-5.303421,-25.216876,-23.312109,-14.359771,7.62454,32.242607,100.763448,105.428211,80.143615,1.082502,-40.681763,-45.773348,8.084216,123.211438,135.410537,55.346713,-80.779076,-151.170976,-272.619449,-286.627415,-153.705862,-44.371396,47.36004,-97.206818,-173.265717,-205.663665,-181.617377,-136.093293,-130.102429,-126.505907,-122.679554,-120.898393,-106.592613,-113.625498,-145.001705,-123.618591,18.680767,105.046118,211.540856,166.894376,95.481608,-54.963603,-74.105859,11.76664,58.815164,112.625844,121.761122,37.596594,-113.287101,-149.979789,-61.539576,30.783633,158.185642,198.414818,247.426881,180.180251,120.411305,48.302506,66.57031,137.950132,148.201023,190.924409,233.754068,230.095967,79.33601,25.395219,38.358646,51.444413,21.197406,15.360181,40.801516,2.138202,-43.231312,-119.697643,-135.670172,-102.379092,-56.183776,48.166714,66.337016,-3.766663,-71.257905,-82.237169,-93.621291,-89.358394,-67.10841,-60.432092,-55.780987,-10.911017,-13.833168,-178.005405,-257.936722,-220.722468,-153.149913,-23.246201,46.767751,135.447299,65.456587,-9.248406,-105.182166,-83.092397,57.931687,114.080609,93.181766,-2.697301,-26.407769,-35.281289,-27.930419,-2.750313,-6.534675,1.188773,50.433137,149.178986,81.889347,10.16389,-32.791421,19.226885,159.714414,205.321236,246.021812,281.227661,272.805157,136.424454,68.321628,68.941304,107.292852,177.651704,188.356971,114.032224,-39.829249,-109.715196,-119.01199,-44.641281,151.430271,223.751358,221.627793,60.776289,-23.952684,-172.549354,-238.122437,-309.069909,-277.480682,-97.528954,-34.342235,-86.762771,-177.612247,-183.055897,-164.887579,-138.429898,18.392747,139.225778,269.320016,124.068855,21.793646,-90.16739,-95.017426,-55.277674,-24.111751,36.446427,48.429402,46.937415,8.074001,-26.993721,-50.145294,-35.34876,-17.465063,-11.248692,24.742072,49.658493,29.436414,-105.442087,-182.268808,-204.821268,-137.975804,31.571883,76.89534,69.594357,-10.842764,-79.771945,-200.326741,-210.66237,-101.431125,-13.320818,59.330308,-72.560636,-160.111694,-281.671162,-291.713965,-229.940742,-194.899212,-109.404355,-51.102997,-5.828347,-136.728246,-215.175534,-255.258371,-225.912498,-135.938993,-76.756094,13.05296,-0.751276,-29.890778,-115.608837,-145.628514,-47.979044,61.122535,176.034678,138.680694,-20.586069,-85.390824,-102.660944,-174.925289,-186.149566,-126.40982,-89.448214,-45.726232,-41.792132,-62.044796,-134.724077,-145.999093,-74.653535,-20.912643,37.585172,9.848908,-130.043145,-212.804444,-224.44181,-230.267877,-221.791251,-161.643792,-115.775278,-49.441144,-48.304158,-71.504191,-119.437712,-94.042183,63.111464,133.500247,175.911603,165.741821,118.397231,28.483587,-14.601944,-37.816226,-32.052852,17.508157,76.060078,121.213771,-29.11286,-111.474398,-214.463126,-252.299736,-317.566161,-329.270212,-256.955399,-185.767324,-113.314074,-219.099898,-281.499883,-268.08548,-220.647091,-177.34982,-146.69402,-19.729868,1.316268,-72.619293,-293.143322,-341.503514,-244.645386,-180.377445,-151.494913,-172.374278,-217.975524,-258.496838,-294.705648,-351.771999,-329.386691,-161.679516,-62.806304,-13.578441,-168.923767,-247.624221,-295.570976,-245.014313,-65.429056,-5.607432,37.447829,43.804905,-17.43946,-112.599646,-120.126839,-49.847549,-4.874671,33.198373,36.538765,22.86613,-62.33302,-128.089346,-265.375495,-306.316836,-324.246514,-310.666073,-200.053624,-129.778999:11.682141,60.120612,50.207066,-67.588264,-124.334089,-142.305952,-117.623737,-33.172663,22.010301,14.864367,-78.513815,-151.137994,-204.614609,-146.570104,28.244873,67.273606,1.780379,-108.479189,-154.335344,-220.156371,-210.184551,-70.761859,25.205225,128.561257,35.272244,-38.212924,-123.698952,-117.250485,-49.510094,-32.987054,-69.435614,-101.266898,-122.656679,-89.041914,-106.576138,-228.672567,-268.898135,-226.996571,-183.365292,-142.707501,-141.540347,-132.949914,-111.827041,-105.585525,-107.506526,-128.315328,-148.340425,-95.069072,52.736931,66.488173,49.59168,22.892902,8.270042,15.443979,61.742681,203.540611,237.429763,161.19849,-142.435254,-267.936953,-271.996363,-190.556454,-60.206484,-46.051482,-76.633173,-105.110437,-112.433243,-83.282988,-44.542126,5.945077,8.352516,8.031757,29.809587,69.778022,150.765227,145.386427,49.965745,-19.083576,-131.013211,-140.061423,-64.978012,44.790851,87.090263,131.13848,136.461953,102.280868,75.41208,62.526396,111.239998,123.105186,33.309154,-17.951983,13.993593,45.710463,32.407451,32.309262,136.62411,284.004563,289.073429,115.373804,33.081378,58.3779,114.704127,182.8423,250.055404,280.895962,174.807126,47.614712,-32.487065,51.742256,220.134764,232.528263,139.283635,78.985713,53.662937,-61.48932,-94.531655,-24.489133,49.609139,181.933506,214.824181,206.015799,136.753514,61.270031,-96.61787,-133.87753,-49.259704,48.68794,120.735364,-14.003122,-75.914146,-95.717764,-53.537425,55.323276,93.29133,138.606726,182.153344,202.126013,163.97778,132.174619,174.127351,212.453793,221.965525,219.548329,234.834401,182.410292,118.792824,64.238559,121.06194,288.408916,315.134864,236.724246,148.269789,135.440828,140.111969,128.571603,77.594981,62.070341,105.436157,143.741979,116.863289,39.299294,33.800981,6.146412,-37.246695,-77.825957,-41.390574,44.795105,47.688521,16.55468,-143.724452,-240.570268,-299.956445,-257.188365,-145.780772,-103.439398,-72.447364,-111.22994,-129.702966,-100.756679,-54.977245,-2.710613,-18.091797,-53.888437,-41.477991,-48.617717,-115.842012,-149.727222,-150.321739,-121.661054,-42.583548,10.828164,131.716462,164.561951,96.428178,-115.804685,-157.455314,-107.125426,-80.423265,-39.013985,-23.294036,-37.451821,-121.61531,-184.005897,-229.916795,-178.553184,19.269181,105.795292,155.17076,107.402577,73.356386,46.987493,62.283665,62.697931,39.355164,56.462469,170.021639,183.130532,63.374676,-11.688205,-90.066042,-88.176449,7.284646,71.724578,68.059961,-109.224866,-175.507939,-170.445181,-108.472758,10.899394,27.462718,25.34706,48.540292,36.027412,-151.140627,-297.098392,-453.455635,-426.500087,-244.921819,-139.807757,-55.087186,-114.85583,-119.204516,-63.205915,-39.488198,-18.452571,-3.665651,42.952799,36.686866,9.050165,-34.0499,-38.291988,-3.582017,19.445688,34.698031,28.375899,36.532482,102.891357,91.67444,-49.423516,-105.264397,-130.036894,-127.680669,-110.588951,-92.862141,-91.683473,-135.70376,-184.965957,-257.178072,-244.17449,-113.600828,-40.654423,-3.696604,-66.257776,-128.799309,-318.313975,-386.607016,-326.838782,-227.088378,-87.86509,-59.629851,-54.617141,-141.646189,-228.065984,-277.508928,-218.667805,-63.549803,6.25228,68.960942,-10.488513,-64.131711,-149.15184,-176.903601,-164.633653,-127.439548,-100.502908,-134.616645,-107.278111,-12.535935,13.120323,72.091769,93.86004,88.411901,109.130729,165.897118,76.916019,2.573861,-114.618094,-143.835835,-139.017502,-130.780437,-171.705987,-182.778408,-145.024018,-91.187787,-90.151182,-94.615244,-116.916173,-184.059238,-169.258272,-72.125597,-68.791562,-117.861469,-246.301139,-270.608093,-221.734913,-180.536512,-99.780248,-70.034697,-69.822463,-70.40827,-70.204288,-32.724294,-0.090303,25.27504,9.451531,-26.715996,-34.175214,-48.15227,-101.707535,-127.006423,-155.307665,-136.765717,-35.97156,-11.310469,-55.224526,-196.081857,-255.874912,-283.20018,-258.024451,-176.37888,-126.103545,-70.345447,-99.68286,-132.488714,-236.841488,-280.976441,-266.989988,-204.047467,-61.767981,-75.689935,-128.922349,-195.599586,-191.312824,-142.821699,-110.259285,-65.159341,-73.889266,-152.382322,-232.180291,-242.499503,-216.283582,-193.697733,-166.832538,-169.887929,-194.793815,-196.827929,-166.493472,-102.284416,-88.829434,-64.570221,-46.646638,-4.346175,8.06705,-22.61732,-64.771445,-55.960965,28.433799,76.819296,101.676124,71.278708,-11.204516,-27.905648,-40.802705,-195.851188,-313.697376,-500.1833,-539.579463,-419.670264,-280.518855:121.406182,-14.60837,-95.832467,-181.863486,-164.648024,-38.453611,31.758116,73.026723,-3.974352,-44.273412,-135.59554,-178.177059,-174.478185,-120.363701,35.83987,86.173059,23.227185,-126.972669,-172.562263,-189.830138,-156.054846,-8.836374,86.356856,190.459559,48.817731,-61.040114,-199.49786,-203.194885,-138.740201,-103.290147,3.590337,57.504232,32.447249,-105.323081,-169.001458,-237.257969,-218.179813,-81.423649,7.755267,101.458458,49.060679,17.414235,-30.740859,-45.411527,-4.880205,41.762796,142.316383,203.176054,297.911052,256.381427,207.960597,168.946762,172.075009,144.020084,138.535476,217.5967,284.148468,255.679557,37.336794,-85.204311,-146.747866,-89.020989,99.921877,187.717793,194.326802,-18.433603,-96.388382,-50.539156,38.595403,168.702934,188.234553,165.92228,70.082021,37.621219,24.399045,23.547322,18.396242,-9.801105,-107.89581,-120.01495,-32.43142,46.405249,53.775511,50.193697,50.763121,66.403048,89.104473,115.105551,40.106193,-27.801497,-176.730293,-204.726272,-93.278504,-18.563122,51.961925,67.742508,72.321284,50.035729,24.702009,-68.74393,-95.408249,-46.231265,31.339576,232.744932,270.469961,215.708022,23.309386,-72.263124,-58.810559,44.052104,210.106114,232.227623,163.121214,-5.930466,-92.289306,-197.910026,-199.343949,-110.721619,-27.199101,114.698548,74.465506,9.583264,-130.747591,-179.279244,-186.801502,-150.838493,-35.222912,9.829771,-8.946545,-96.896269,-130.492121,-157.421241,-135.051179,-16.22664,62.629207,186.807653,168.039536,113.410062,9.237486,-12.561448,28.465127,87.249281,199.195599,205.380383,105.592335,-32.206212,-69.468602,2.809928,95.049436,259.962526,319.290698,378.545108,256.354698,146.181351,10.105203,12.933611,75.70414,105.797855,169.041977,182.774419,126.129485,49.05757,20.912256,-18.368932,-26.799822,-31.237502,-20.710064,36.883003,90.731945,76.58602,-93.430005,-201.893532,-252.560696,-184.224915,-2.041559,60.263501,83.524363,-15.910879,-85.474969,-99.768382,-21.038321,102.044739,83.358727,-24.359056,-54.310233,-52.827494,-120.835461,-167.679925,-205.077403,-188.974675,-31.85565,97.428868,240.630185,99.030084,-1.174988,-56.728959,-13.33103,81.709565,99.50909,75.497555,57.360168,39.438774,-100.992076,-173.299939,-132.029482,-25.074618,194.002167,247.052893,215.916424,124.862827,113.558183,170.642203,183.609902,123.131788,118.886753,249.138952,307.03447,248.993139,99.77536,73.918176,102.684379,106.219775,106.392913,132.068727,125.747585,-40.611342,-126.060873,-146.31364,-76.122628,85.477409,136.498202,158.126923,58.098217,-36.823964,-283.003353,-381.084935,-372.405725,-282.71709,-113.86154,-68.063359,-68.792808,-154.680478,-168.713311,-57.03983,22.286583,75.08703,73.141972,139.071889,190.166474,153.587694,20.239745,-10.212189,34.85434,75.001298,154.943967,178.947959,175.722642,109.32945,26.895243,-137.306035,-159.111134,-101.89681,-50.685581,47.483207,48.78762,10.184904,-117.449781,-195.883568,-294.202622,-272.757347,-96.112356,-12.122604,1.743847,-118.575062,-193.649312,-303.295497,-297.751378,-183.738982,-122.855612,-40.183909,-18.273893,-66.295011,-245.348653,-290.264696,-207.265303,-145.036897,-65.899038,-18.194286,72.208196,14.484986,-62.890735,-195.568321,-206.467224,-92.810199,-13.464216,23.584051,-45.790962,-45.835579,-15.877221,0.260791,104.015887,171.41248,216.920925,197.517752,134.828015,24.948885,-65.117463,-223.403826,-235.779361,-134.250787,-66.894689,3.10411,-39.762507,-88.465899,-178.930314,-189.269234,-140.184021,-97.670093,-12.095725,4.233303,-55.980968,-175.043641,-226.772819,-247.637735,-200.444498,-80.826346,-52.909362,-39.376697,-58.740088,-93.494096,-172.202614,-173.31597,-81.256186,-36.294391,18.043842,47.394138,67.802065,-14.808491,-67.530024,-120.081027,-114.328217,-62.273883,-11.153194,90.428579,35.301117,-45.211674,-233.412714,-321.168876,-394.252358,-364.190702,-224.887732,-156.609883,-131.590811,-227.937718,-270.12505,-302.631529,-303.082048,-291.644291,-250.661886,-73.150736,-23.935544,-90.515135,-241.066604,-255.447992,-167.797241,-120.923941,-97.882621,-109.579777,-141.267293,-220.444783,-281.398008,-365.047257,-359.278382,-251.481891,-163.15915,-40.614053,-110.703917,-173.323661,-218.835139,-184.947072,-65.004176,-11.257458,52.525376,48.346441,-47.568829,-121.56232,-102.772104,-23.853792,-11.447509,-19.749771,2.02951,56.506517,-35.047682,-136.626608,-328.637376,-369.669322,-351.187454,-322.166078,-213.011841,-139.141507:-0.549179,-36.648888,-73.747806,-158.017462,-168.931004,-107.445388,-63.397788,26.960124,120.456607,146.526526,65.133279,-29.681072,-102.313273,-52.450488,31.782403,28.28064,-4.046238,-25.85207,-47.016545,-116.438999,-143.578178,-119.9785,-58.991618,71.556446,-2.659624,-88.356993,-153.177179,-136.380001,-92.258471,-72.349784,-70.200006,-106.760475,-242.517905,-331.905474,-324.719234,-298.701595,-313.208701,-351.390945,-344.403229,-285.163752,-255.097805,-261.910294,-267.958345,-240.739457,-147.324391,-123.347664,-139.236957,-126.980709,-2.871223,107.982759,118.179616,74.914377,54.701592,56.563569,71.434742,121.486258,115.227374,43.277798,-193.555499,-289.976255,-327.341763,-276.895513,-171.188465,-175.060194,-267.908153,-287.368952,-276.372379,-287.980564,-292.318187,-264.67356,-251.928837,-265.439138,-244.551903,-177.373943,-56.670604,-79.597537,-207.422102,-237.685245,-235.651097,-232.8022,-190.570525,-35.111244,43.445078,104.60199,97.45257,38.758831,5.038499,9.564679,54.683069,38.107429,-80.564666,-125.166812,-60.152468,17.605482,85.882412,55.725571,-16.866536,24.939604,60.286489,22.648077,-40.962912,-71.200509,-8.912828,150.165808,219.790319,219.339499,149.644001,91.187044,34.040774,56.30677,121.379136,135.95168,134.454194,80.648597,37.868167,6.288153,38.273131,136.700777,189.266961,311.139722,337.090305,298.270301,189.359556,124.339318,7.501731,-14.495374,59.964088,132.458016,190.315858,97.862826,46.494423,-10.951772,-17.80235,-15.788744,-3.189826,80.038185,187.720633,219.204763,225.121695,211.866685,169.152559,148.173745,147.30696,153.08349,94.851536,-2.147565,-33.484308,-58.600731,-43.087356,48.881704,109.596132,200.08699,123.191294,37.72471,-66.338603,-82.602718,-110.449672,-110.680902,-52.919887,-22.28455,-0.256165,23.460305,22.584219,-30.569388,-56.689216,-61.916573,-41.914514,14.273837,32.393247,28.246287,-12.406123,-64.505979,-192.371638,-226.334973,-172.855144,-110.489209,-23.002559,28.108013,43.914407,36.640748,28.283562,17.052294,16.795696,50.965047,105.798193,125.82581,111.987754,73.480733,20.49095,27.880697,63.008688,67.121774,40.405432,-18.252095,-65.60267,-151.342065,-161.249116,-130.030626,-113.513143,-106.336847,-99.100224,-79.559298,-25.065593,-7.875632,-28.203132,-43.477662,21.007148,75.475248,93.509633,47.696839,46.382662,81.060385,105.422734,140.723019,148.66475,169.512934,152.869041,115.51111,-22.024818,-99.947252,-155.329162,-122.133042,11.773692,85.696037,132.881021,9.264121,-64.06459,-118.867506,-89.151742,12.070081,50.976384,98.682071,128.361528,113.653213,-55.796255,-174.425188,-251.757464,-184.539412,-5.947299,38.758374,42.257812,22.062076,12.032476,-2.019188,14.383914,82.343578,100.680278,103.140629,115.542968,133.876298,130.248962,88.601941,-1.644946,-18.291379,0.396873,21.953425,69.972225,129.280473,142.174699,90.49199,49.432272,-8.219343,-25.109516,-46.625005,-82.813463,-82.406731,-47.986787,-57.216503,-119.815467,-139.44741,-124.928593,-96.952329,-36.029595,-20.878208,-62.540586,-228.258113,-290.865622,-285.918231,-237.283908,-132.356436,-64.014612,-58.070588,-135.44834,-193.636622,-235.132466,-196.097377,-37.759291,40.656786,125.739716,99.497464,29.452951,-142.170934,-180.921097,-144.051667,-101.2821,-15.671518,47.146975,65.167654,71.803648,65.007947,54.829226,57.57826,115.461525,165.095101,223.129012,201.271286,177.201792,112.079237,69.226687,3.488971,6.076315,70.088444,143.595988,179.449636,191.715533,154.299533,58.916489,21.520266,-23.190546,-29.008658,10.874081,71.117358,34.568216,-144.582981,-200.330764,-209.08186,-202.274855,-189.265729,-116.975286,-44.956778,62.313847,61.777868,13.05718,-15.458492,-16.467241,41.317869,180.941076,197.413657,161.343466,75.649294,49.923145,-26.161844,-80.308351,-46.249503,109.935749,120.66031,13.604987,-48.394101,-87.510181,-60.894697,25.465725,68.737607,117.382936,102.584181,70.200011,-73.423051,-152.219799,-191.649584,-136.187053,31.517151,75.625774,43.144873,-46.783049,-70.862864,-30.757524,4.12048,54.317167,71.518917,58.739551,0.369102,-29.51539,-61.963861,-61.188105,-83.342441,-120.344374,-183.878632,-195.469735,-202.37947,-215.049865,-198.594537,-97.107212,-39.01322,45.850123,85.922883,133.967982,121.897473,107.770477,77.26354,75.22864,61.048976,37.102237,24.262624,82.895801,103.176092,-19.736127,-156.932425,-335.032685,-339.735922,-285.541728,-231.801643:53.460342,59.035943,55.776182,42.791254,51.675925,79.9132,104.647108,217.472924,271.540543,258.883084,195.395694,130.753308,54.310469,83.94912,140.161937,118.625778,18.46379,-58.550777,-80.778754,-138.165872,-164.685878,-168.889779,-143.803363,-33.506095,19.196165,-3.569359,-59.53848,-69.211884,-46.475069,-29.601182,-37.127095,-80.279858,-226.203414,-283.460886,-269.321223,-297.609725,-351.035032,-440.556929,-443.691529,-386.310347,-323.798259,-290.426779,-227.373603,-199.452431,-146.467897,-150.231529,-228.184713,-237.577785,-123.293553,30.430517,68.796715,46.170433,24.650492,21.389738,45.866138,150.070748,170.5386,107.932779,-79.613416,-138.367435,-108.142801,-68.89685,-49.623457,-38.670855,24.551635,31.586306,-13.125163,-126.180765,-142.715395,-92.108253,-61.684325,-29.034729,-8.305639,45.655634,176.91954,169.047742,50.35188,15.326411,9.727239,5.740011,29.40728,135.704794,162.741804,139.019848,140.299041,179.261882,185.619666,162.526746,84.914588,35.796622,-37.15377,-42.814988,39.727058,95.987502,135.908847,122.250409,101.118324,192.035625,257.617744,271.233338,228.505481,181.891966,198.837668,277.703925,322.791716,308.953714,166.171255,57.33959,-40.542241,-8.868452,49.398678,35.301757,-32.854074,-71.14027,-95.43738,-191.40875,-218.426016,-140.581475,-44.646371,165.759079,211.042016,189.328015,151.298074,109.845928,3.611379,-33.475152,-67.111221,-32.348865,131.824737,118.669453,14.269576,-175.440876,-213.981074,-179.984595,-120.07494,-3.548666,82.930267,134.438909,172.841981,139.494942,85.235173,98.275623,138.13708,136.090623,114.330265,82.104411,24.594857,-141.078448,-173.959099,-83.860676,-10.985829,73.73077,26.147705,-17.790689,-61.999106,-60.018446,-26.358383,-15.561811,-37.559216,-42.262773,9.4475,88.360268,96.083719,52.743124,37.830671,26.044687,32.76861,97.477083,100.93174,61.086,-63.083415,-133.405899,-180.473175,-142.566565,-50.161771,-25.965964,-30.109491,-58.007918,-54.248162,-16.476257,-7.938607,-58.660224,-86.023707,-40.463796,43.7834,52.702778,5.261353,-31.744998,-69.929039,-53.399105,63.603669,131.528418,163.635228,101.924183,78.857469,-5.862468,-76.427016,-143.806945,-115.270816,-30.642294,-13.045002,-6.688408,0.208218,-43.45253,-143.701095,-119.743805,36.372111,67.650135,-22.273351,-57.12,-30.645149,8.525317,14.568319,7.115417,-5.371035,-9.859269,0.189558,-20.241286,-136.173867,-204.109403,-276.569121,-288.62359,-257.092127,-199.58817,-116.686843,-173.67777,-231.899449,-306.291428,-277.476298,-115.05512,-23.711558,89.017379,36.750648,-25.219617,-195.594908,-300.438615,-396.002577,-349.093862,-154.66664,-65.657412,-0.211765,-55.61996,-96.830511,-153.203584,-126.204701,38.522034,96.535016,79.317328,48.094833,59.771625,64.106242,49.14609,74.765339,105.409787,97.307345,61.650214,39.19651,123.829275,140.199644,45.962698,-23.786349,-129.081221,-154.934461,-127.785994,-78.694567,-89.758577,-173.079419,-202.547217,-142.452027,-67.08431,61.33424,90.175813,92.016895,53.0634,-0.210971,-195.06116,-264.170079,-211.855907,-155.471625,-171.429726,-240.043322,-206.882078,-142.76712,-189.817527,-290.676632,-257.242588,-91.790695,-27.186673,35.592746,24.3662,-42.450543,-234.597912,-285.942166,-235.114878,-181.721014,-176.516728,-191.848177,-130.376443,-37.994085,-77.092404,-139.888082,-100.321435,-15.7903,-15.999793,-72.538451,-121.78076,-124.764534,-84.830176,-47.219668,-24.396265,-59.712789,-130.859317,-116.683359,-69.745592,15.651657,2.932406,-101.438794,-161.177209,-229.079259,-212.624297,-135.691215,-93.188248,-104.139737,-201.244323,-258.952779,-294.501305,-251.132987,-98.847349,-54.322267,-86.90876,-134.505956,-141.316696,-159.112457,-138.606406,19.357244,101.220333,141.331153,69.780992,6.364555,-134.275003,-176.211913,-182.101111,-148.780552,-44.137145,-8.537898,-19.442055,-79.792813,-130.770577,-193.163859,-179.779811,-82.949065,-13.807344,102.867769,94.374355,31.767096,-142.222418,-219.198906,-274.659725,-222.550557,-30.840838,11.858059,-34.78398,-170.780946,-236.489422,-265.468137,-210.228707,-69.792384,-39.844969,-46.997434,-34.828137,-40.926716,-90.753825,-103.62404,-122.700575,-141.710318,-170.125026,-183.789215,-167.655929,-110.328266,-92.530279,-62.57393,-48.462404,-32.438482,-30.88517,-23.683178,24.004814,42.078507,15.629298,-9.795338,7.330979,58.441766,173.786441,171.80186,116.778881,-30.249113,-101.093271,-188.701808,-202.968716,-172.991238,-115.356604:-9.27184,-83.593149,-105.7397,-84.912424,-48.31088,-28.299284,-47.452203,-2.110085,105.744605,112.443629,-9.221825,-102.566893,-157.686126,-111.898544,-2.78487,49.628969,83.741529,-1.860269,-27.253019,-20.538648,13.42632,162.44481,242.512388,295.36055,184.758107,112.725008,5.160419,-28.387344,-27.519751,6.493909,66.057042,72.263697,26.237825,-65.31343,-104.303199,-161.179604,-173.423147,-151.012118,-123.543351,-69.279725,-38.424032,-23.976731,-12.960041,-21.364725,-18.002057,3.973558,56.684483,81.704215,148.080002,183.39462,167.042564,118.55887,103.248915,89.189925,114.351472,221.156797,209.759779,119.132016,-138.641425,-234.868843,-265.410699,-202.265834,-40.309082,-10.229964,-79.976098,-191.981198,-206.334113,-125.025011,-60.938882,1.974429,-8.536639,-27.605034,8.310649,27.488172,3.298459,-45.912823,-166.688512,-218.328385,-277.612407,-259.768694,-122.268996,-5.711911,15.120124,46.794203,71.166363,71.849818,40.15382,-6.8382,6.490924,1.227157,-82.926068,-117.10819,-90.278312,-55.539561,24.136763,56.504154,68.552596,46.11902,14.601997,-60.779732,-66.03593,-5.406003,41.729396,110.169281,125.250747,138.502927,113.030286,66.741363,23.82402,37.163455,102.027092,158.645383,228.093636,107.951594,33.579376,-24.439508,-12.968766,61.540078,133.274855,279.564512,244.882158,180.291715,43.864991,-28.482843,-127.126679,-129.113168,-56.896187,-6.480555,32.40023,-37.938453,-73.016164,-63.031371,-21.476254,55.709719,71.018384,130.490613,260.260425,281.666242,179.140503,117.752378,108.595694,140.846797,175.013959,164.600137,129.866171,74.657271,9.559934,-88.826074,-51.911816,142.275604,217.925757,219.033412,80.405013,7.107181,-50.669493,-33.231821,24.811129,50.294617,105.265709,127.840944,140.495762,134.443524,97.42873,-26.857923,-58.805796,-25.558166,10.54399,72.317039,70.091528,60.569127,33.643654,-18.496074,-141.657117,-147.631399,-10.920073,83.504688,156.2222,129.415341,127.299544,117.03678,123.966383,173.964246,167.97632,54.774605,-15.218657,0.547935,61.674629,73.728599,28.065643,-25.246707,-94.715255,-64.88493,50.053609,77.783505,68.240219,32.117157,7.687774,-30.566528,-40.910012,-53.945332,-58.117861,-52.550965,-102.400945,-142.1172,-53.527992,54.98394,160.141324,145.851737,104.224557,132.853626,155.890042,139.552577,101.834352,20.665288,22.540633,163.567393,242.025857,192.789424,17.793236,-52.172286,-95.595624,-67.801036,76.903065,157.779154,179.039554,-27.797337,-162.085766,-276.59737,-204.934938,14.205026,66.761851,46.735479,-17.720324,-45.25978,-148.336091,-231.994784,-330.168532,-305.658586,-189.780158,-146.521314,-129.879482,-116.650731,-74.314517,3.575282,4.474627,14.457505,45.261787,88.620777,94.143706,101.274216,84.59857,32.256495,-95.787145,-104.013165,-0.14515,50.63676,85.954698,74.213263,55.398041,7.326155,-14.010915,-53.050359,-71.950061,-95.565692,-54.371607,-12.3927,-56.83684,-155.404663,-249.22684,-202.577209,-87.323897,-79.168454,-168.018479,-216.894177,-199.875889,-189.178254,-204.539532,-233.411903,-240.297484,-220.339344,-146.198764,-94.412956,-80.668805,-153.202036,-308.319249,-306.507964,-119.812444,-3.337224,104.912819,38.399201,-23.706693,-121.417185,-140.028104,-119.317791,-84.220076,-32.748995,-67.698475,-62.703323,19.323855,50.371819,111.740103,160.723221,244.851427,257.238554,176.726763,20.594859,-29.639451,-66.525183,-81.634883,-111.463404,-96.222048,5.038351,55.775689,28.963449,-54.888835,-69.01247,-33.262604,-36.450929,-110.66477,-120.213587,-76.83373,-111.178645,-177.329534,-309.789482,-323.22487,-223.533009,-154.601159,-100.354195,-117.930283,-88.547068,19.516714,26.134409,-65.049042,-84.467075,46.114438,143.6436,202.267083,79.86499,-5.743418,-146.735692,-165.940883,-95.773484,-44.175775,27.909044,29.731789,9.223463,-86.775658,-170.746174,-275.473792,-261.37916,-170.709683,-122.562702,-81.388735,-70.56237,-69.737942,-146.761088,-191.600817,-166.481795,-103.999738,21.883949,35.911907,-6.270918,-125.126477,-183.968678,-222.560102,-185.605959,-60.828303,-6.651936,7.697175,-67.225004,-101.276564,-134.508226,-136.75788,-128.056883,-124.810405,-184.432829,-263.253117,-244.236308,-149.80099,-107.727192,-45.466589,-43.520447,-47.128578,-17.180468,41.861472,61.58059,82.704751,126.994568,114.400207,-6.058359,-71.80908,-95.311334,-19.703939,-11.371792,-142.453346,-254.844534,-384.414038,-364.697892,-218.075975,-139.307772:forward
-164.798603,-255.229033,-280.452677,-169.692465,-47.692414,126.79997,150.885087,159.180197,142.446048,99.570808,35.721053,87.262999,313.834265,417.953254,560.324167,599.158013,613.289503,584.270329,567.523949,560.720842,572.509965,605.530737,604.91863,509.748315,357.687056,311.003575,282.888266,280.517953,281.123173,278.733736,233.353169,188.085389,108.671102,95.138144,92.667618,75.159589,64.835485,57.746544,75.435655,165.657389,226.398857,180.403431,-12.218745,-69.536819,-75.271328,-75.201713,-70.088255,-41.369075,7.052569,-54.065776,-91.530725,-72.206201,-29.847989,59.975599,106.983948,148.144104,73.964308,28.700949,-22.469788,-27.473176,8.06419,58.527184,162.94083,157.77506,35.468649,-101.669023,-153.627311,-120.480314,-29.375129,119.624719,116.227102,19.896859,-19.742437,-42.37947,-120.562367,-118.446619,4.450027,72.329768,141.887713,147.019791,82.813877,-72.414151,-122.579081,-65.118036,-6.794057,32.033274,24.568035,-38.459004,-131.542722,-134.120897,-61.139891,-16.28617,28.002137,3.553087,-117.187231,-178.937903,-255.19128,-296.020157,-321.602959,-308.206775,-240.453384,-57.975232,-5.231804,-43.656424,-128.794987,-144.903828,-125.551393,-85.392774,6.534134,27.825842,19.695643,-0.253753,-47.492539,-87.414472,-117.388708,-154.462809,-142.932113,-101.555929,-82.399212,-52.643831,-83.276623,-126.514128,-155.921359,-88.463679,121.682234,180.645128,146.419747,77.190733,-92.542939,-204.286193,-208.839839,-78.238434,17.376127,123.703587,146.044232,159.307636,62.185372,0.590001,2.28943,82.233764,215.330777,201.0164,115.770843,96.784151,72.75,19.004003,-8.314796,11.666044,55.692509,145.804979,181.977721,184.366013,114.837352,66.698963,-54.579841,-87.630659,-117.008137,-162.018624,-281.045157,-309.50774,-283.248857,-294.05198,-327.725879,-306.430039,-262.564516,-277.447446,-340.902331,-492.106557,-600.022753,-623.427816,-595.379593,-523.377199,-312.74227,-235.843671,-196.918603,-209.162871,-175.744249,-90.270689,-86.782499,-81.945788,-47.671377,2.340461,5.825984,23.057104,7.365194,-29.9079,-80.001657,-60.62498,-8.542023,-12.178824,-22.862746,-15.936064,-19.423504,-59.344718,-86.999315,-100.055901,-80.890184,-52.471184,-56.008521,-116.867635,-208.912805,-227.737007,-176.825309,-114.388177,1.755378,23.846105,25.546891,20.419522,-25.620026,-84.781972,-104.272864,-179.331696,-241.258189,-324.407865,-320.223536,-262.349315,-234.607502,-252.053579,-313.573939,-318.116231,-255.516625,-216.17084,-123.624339,-76.239575,-77.31175,-199.824286,-251.476469,-306.104244,-313.431309,-221.473223,-132.992076,-23.799461,-57.720693,-106.556954,-154.437286,-93.301277,125.132251,194.94095,229.457446,231.984719,210.155667,102.682761,52.492568,86.679207,153.420678,228.655242,215.859865,98.927389,-48.520604,-61.2639,83.975678,186.416513,245.025296,199.591487,124.321557,109.219424,68.500629,19.841193,-7.285955,15.123586,80.266109,182.838971,188.583908,146.782808,71.114839,17.064382,-102.425572,-130.002645,-83.99947,-22.30145,137.689715,206.129458,225.425692,52.989122,-26.830765,-13.2969,29.860529,53.886642,58.510621,101.637398,132.941518,128.139917,121.936966,131.268684,132.630252,126.132216,113.535101,88.980669,11.522048,-3.698479,1.238218,8.382798,40.98193,140.953862,152.368746,70.744309,91.428862,170.473853,282.166872,305.205837,322.102165,292.411456,199.334544,166.925881,115.789168,66.49047,34.20189,-22.59074,-38.526185,-41.188631,-20.645699,-13.830476,-68.255686,-57.502463,19.365797,34.246007,25.525337,44.028992,89.769794,67.098809,-24.382917,-44.453723,-23.922017,82.560136,142.097486,157.956869,134.902554,116.694527,79.556121,48.271739,-12.466796,-29.331982,-1.293207,41.990664,110.357851,105.639178,47.246324,-89.189202,-186.570187,-268.197685,-212.696126,-21.402855,47.486625,70.486081,11.550478,-26.967718,-97.106345,-100.478161,-36.821019,5.072884,78.879149,102.321362,70.90329,-93.917895,-167.863128,-148.126141,-91.307815,-44.548507,-38.00071,16.878895,9.24287,-61.185274,-212.465532,-212.239835,-87.48235,-39.389743,-8.78408,-10.7942,-79.538658,-168.636887,-198.319241,-247.64511,-253.742319,-171.621722,-96.729541,-3.316433,-19.441862,-45.449457,-99.38552,-117.628333,-151.289087,-170.047294,-176.87859,-153.521875,-123.222332,-235.13322,-291.682732,-225.781704,-120.166239,65.063995,121.31449,184.859388,128.640884,47.326523,-71.746879,-58.256267,9.083945,13.895068,-5.16363,-19.117513:-94.072535,-149.234102,-137.032793,-7.633729,69.364102,136.064171,147.32726,187.626772,163.708896,124.191551,95.626145,130.9945,283.913557,387.070397,524.065089,516.364325,422.911418,399.889555,434.112547,537.423251,596.900865,697.944024,692.180265,500.077345,275.069425,242.479769,276.248565,283.92675,265.926372,260.113184,252.738591,237.439351,158.880259,16.233387,-55.945458,-90.651189,-40.978766,70.489798,92.577943,76.38751,20.627906,-19.435549,-98.237525,-119.00677,-113.34349,-103.653163,-99.481027,-90.169297,-56.847803,-79.784575,-105.850683,-68.071042,-3.605555,77.637828,73.432139,26.384894,-25.979808,-45.990709,-81.006928,-89.077806,-18.450301,57.925768,155.630082,135.846295,51.295622,64.154314,67.7451,-0.347769,-8.17547,140.062701,235.785655,271.64775,119.183196,24.64592,-61.785391,-24.296057,151.09297,228.833266,222.88978,155.181629,55.421512,20.827541,-0.989523,20.816911,74.334195,150.759909,137.738065,20.854253,-102.609986,-118.791475,-55.214989,9.394154,130.104471,135.868049,41.43597,-12.582616,-93.204167,-203.706529,-265.930423,-311.203509,-269.689085,-77.623273,6.373143,6.719328,-103.329238,-141.540072,-114.06984,-35.490008,144.48551,185.716671,158.312617,120.454977,30.419991,-89.468453,-150.482181,-195.258244,-179.875302,-121.871728,-93.83435,-128.705643,-246.313412,-261.56741,-157.024516,-87.831804,-20.556449,12.033303,71.584088,28.891074,-164.832853,-260.170285,-236.518561,-69.800995,21.12481,127.040748,146.153367,114.083915,28.234739,-9.700523,-26.27479,12.088355,163.330085,239.491493,274.453662,227.324552,150.972812,127.708253,93.6482,46.765199,81.416462,228.003822,267.718257,198.251883,69.727662,8.368762,-60.524858,-59.918901,-75.98495,-106.427074,-179.402733,-209.310622,-239.191454,-298.257346,-341.635177,-347.356235,-316.515511,-310.19214,-351.499294,-450.413942,-469.29,-463.891552,-435.551447,-386.015156,-204.467727,-103.44359,-46.194325,-129.744977,-305.259335,-217.625348,-131.465888,-35.383316,-28.761725,-20.986458,7.462239,56.037101,-22.606753,-99.337069,-191.064998,-167.406228,-92.729838,-90.693568,-124.411455,-152.026722,-256.5091,-364.869528,-375.387139,-304.059925,-249.6015,-153.304014,-127.220512,-153.760884,-241.234386,-257.923386,-195.370637,-137.194025,-55.610274,-49.142374,-44.20801,-42.451259,-114.712382,-209.085168,-234.710508,-318.499383,-361.418876,-327.594498,-275.601145,-258.474509,-318.369324,-328.917802,-284.975175,-242.922166,-185.692151,-175.556139,-116.966614,-79.463599,-106.181313,-253.889567,-311.51753,-296.397259,-234.201515,-112.289829,-81.736345,-57.733064,-41.863229,-50.119574,-95.656908,-84.330098,35.293472,87.261728,87.897847,62.245379,54.79876,78.137023,80.943439,137.24636,193.522552,245.546957,227.634385,164.225371,54.729136,-3.286271,-29.63173,-3.538478,66.17243,99.697143,107.477685,70.804984,18.235663,20.527478,13.240203,32.562355,63.102732,125.602945,155.446572,130.057406,-8.062895,-53.458977,-94.829544,-105.222832,-49.371586,28.131367,185.964084,228.499154,231.933587,89.442889,-4.476381,-60.845366,-22.324697,28.782754,16.787578,-31.288136,-48.706521,-33.46109,37.319266,81.136575,127.998003,125.235801,75.725662,34.36349,-33.477257,-64.183179,-54.532552,53.928991,125.887494,202.441446,190.076743,70.884609,-39.039667,-25.058254,135.426907,221.137789,253.354658,220.679186,153.961286,115.504766,58.835798,15.406751,-16.107329,-1.118938,46.145626,103.867676,91.931103,-0.961791,-119.960158,-154.461657,-127.499791,-78.42086,40.638965,99.048191,133.695304,95.806261,-5.058625,-18.002822,23.956499,140.481744,180.622006,202.661329,203.48137,225.528228,178.826662,104.709904,-48.90449,-81.998917,-27.655781,36.520662,120.773751,106.542119,24.702769,-35.20395,-52.722847,-43.267939,-27.49845,18.426743,49.171996,77.201463,33.154229,-11.912789,-104.760348,-107.29013,5.49617,65.283558,88.892654,59.625325,-30.921412,-127.83799,-152.09908,-54.135674,32.426291,98.810114,102.9061,165.97208,130.799947,26.339504,-160.05913,-154.720498,-11.136989,55.99843,127.723503,120.741149,6.279328,-97.258237,-114.082808,-123.727782,-126.900832,-82.907987,-31.7525,19.377769,6.480989,-0.047589,-22.253139,-10.699494,43.889762,43.012611,-7.151546,-16.717882,4.749385,-61.182749,-114.059555,-83.39914,0.044338,135.440114,154.660303,146.863886,156.254293,162.758912,138.555766,109.743763,63.880387,65.31117,75.211016,55.076839:-91.543037,-159.004179,-167.111296,-76.170875,-12.865472,82.937733,135.496551,222.910908,198.36139,158.632609,135.017772,178.356637,323.29872,387.506971,428.172957,397.30025,320.107506,313.33244,347.642416,462.033249,515.89598,591.12634,601.452456,525.22339,323.161054,216.974526,122.732317,146.886449,248.240596,275.227129,205.403626,126.582693,6.325282,-65.745138,-99.60246,-86.021043,-51.698115,-57.989235,-88.419151,-78.264308,6.002501,11.378621,-64.41182,-91.759225,-81.293513,-89.521975,-185.209919,-214.430143,-159.973928,-105.161812,-74.185651,32.467431,53.979934,17.484984,6.005253,0.615677,16.196965,34.345773,39.936307,37.596872,115.795622,188.257048,247.899887,197.484967,42.635905,2.194967,15.431821,40.312007,75.083373,223.533065,276.807674,223.209403,34.845613,-75.012588,-178.388949,-107.545776,143.282913,205.409849,145.170009,96.837096,88.108635,56.968262,24.28399,102.435981,195.472085,241.720182,173.33712,36.12341,-14.58067,-34.071627,-10.272083,44.888349,131.071257,134.803557,90.866614,41.050376,-121.661508,-258.747842,-274.258367,-218.044754,-174.086447,-93.527642,-73.432794,-125.24543,-251.575355,-280.111416,-175.279793,-73.64437,93.888539,148.415075,176.148954,133.959391,10.845286,-67.28203,-95.029048,-129.079136,-139.705421,-130.678531,-102.822701,-103.109128,-242.645708,-302.692459,-285.095151,-219.876435,-100.454992,-64.458093,-36.785836,-63.203434,-183.624165,-280.647417,-293.204253,-209.104152,-115.45308,53.361287,79.880266,43.687966,34.459241,40.848267,33.903328,53.032832,211.595218,314.156534,366.755043,300.309338,173.224628,224.00439,263.117049,259.759495,253.658005,292.495777,300.701838,229.750715,106.234531,31.176001,-103.599243,-109.715507,-39.067801,-46.202174,-167.336968,-201.963146,-166.319346,-215.522303,-283.065101,-339.712394,-313.062295,-275.867593,-307.732545,-421.904065,-463.039067,-464.798821,-466.117811,-424.423187,-222.279554,-129.911121,-109.35497,-150.17263,-166.278151,-64.716592,1.376551,117.206251,146.164797,99.24753,48.656417,11.244308,3.353756,-42.495613,-143.892738,-134.630839,-42.047852,-24.273704,-59.674564,-89.383521,-156.080887,-229.470472,-253.842364,-230.982546,-190.745566,-140.029834,-148.584041,-193.483971,-237.629693,-257.341022,-201.766606,-106.039503,95.412878,137.065122,60.161867,-28.091208,-142.877718,-139.700933,-149.733254,-186.674583,-186.843415,-168.886408,-164.760546,-146.676854,-153.500513,-186.624272,-221.230904,-182.836859,-26.031054,35.736378,21.293556,-32.514124,-91.659076,-111.280518,-145.705657,-193.333623,-179.62242,-123.196194,-105.565755,-73.850735,11.347955,32.078924,-13.184992,-23.494195,49.44392,95.29795,90.550559,42.633697,-18.806938,16.882439,48.352125,132.549748,173.221225,227.414556,242.29488,201.862988,58.036915,-12.934732,-49.152333,-8.913003,82.887876,98.121716,69.838494,43.762065,4.640867,-17.296069,-21.879369,17.424927,74.096711,182.019,178.09561,49.841064,-99.040051,-149.934995,-199.07565,-189.631266,-102.273067,-30.238191,140.782353,200.463424,176.077527,13.197451,-47.837733,-19.588065,41.219643,103.131201,76.150655,-29.33065,-93.397009,-111.548987,-56.607638,28.552374,150.172547,136.697308,27.883497,-26.082324,-90.50229,-103.088679,-94.571274,-38.106974,-13.475742,-8.963922,-17.764922,-42.465201,-41.185638,-13.87809,96.511174,160.451188,238.10445,243.094587,185.169526,143.299733,122.77415,63.483151,-16.651787,-98.321199,-57.677958,46.280378,37.017706,-107.121655,-190.944504,-161.405613,-8.458837,72.279457,156.054453,180.645716,221.952476,197.267702,42.580885,-30.452479,19.675303,163.253722,205.457932,262.470381,279.306559,245.219343,125.872199,55.058903,-0.919382,28.272206,85.55759,93.674013,89.794083,52.464557,-56.296979,-48.192985,-16.708245,17.487768,21.828029,47.599443,79.790658,144.003667,65.587761,-26.996251,-102.839189,-36.025262,182.180096,248.053679,180.803977,95.101156,47.548632,73.252177,37.986589,8.203384,58.16705,162.178426,164.326403,93.957404,13.221227,-29.998784,-96.593059,-78.157072,68.109096,126.702332,91.9584,30.846892,-50.513407,-106.561637,-130.138224,-82.030441,-41.758753,-56.051783,-79.364597,-36.472439,49.598414,45.771115,28.356008,82.089145,210.616801,214.727211,136.796834,106.321648,74.539399,-13.647132,-46.4602,25.778907,101.225457,182.401173,180.493869,162.092414,148.733663,128.965713,62.322167,50.783212,78.708121,86.7904,82.242801,72.215716:-227.756456,-288.951821,-257.09927,-70.306018,11.07462,51.724594,50.661232,71.455807,55.098695,22.662564,4.674214,69.087837,295.638019,409.310597,551.477285,543.887853,444.515947,467.17281,517.754917,594.835785,616.999665,607.517967,564.640164,428.872352,269.511668,194.816628,129.226497,153.839532,200.340631,166.619739,58.094962,40.744994,78.01828,97.248936,80.600554,65.642768,87.403616,112.025152,98.594451,58.911955,30.604243,13.175034,-68.518363,-118.143193,-156.923109,-143.744394,-121.137456,-121.262502,-123.427993,-156.776754,-178.203834,-153.790277,-100.710937,55.098818,130.427909,196.193952,152.483145,103.726273,-3.28612,-21.54507,81.472827,166.676953,214.915978,160.293731,47.746482,8.771373,-10.99002,-20.383717,11.422957,109.475761,143.981284,127.504228,16.97528,-50.25722,-114.240518,-85.738489,-14.737744,-9.370612,28.139505,69.26441,67.262439,-32.554247,-53.558363,33.601347,100.253429,120.206034,70.007659,-59.047031,-139.64175,-151.554825,-132.377645,-96.81804,-21.295358,-33.556345,-157.210644,-213.452655,-256.412676,-282.797253,-304.903615,-301.314892,-262.305679,-150.712835,-107.6176,-127.565378,-239.19838,-277.947645,-255.963254,-187.821816,-3.92009,77.900529,156.775731,134.884965,19.768705,-93.832031,-137.448415,-150.486157,-136.150977,-157.996528,-175.074942,-171.115181,-222.335545,-262.673364,-245.622328,-178.422986,-58.960304,-41.212445,-37.42543,-54.913649,-183.15429,-325.472519,-338.606513,-206.009073,-87.341887,116.254229,159.986917,128.748504,64.181968,61.917855,106.821785,145.245364,229.328278,252.809424,245.249756,225.926358,202.76628,167.523117,124.022651,89.096943,125.920345,209.766364,220.190005,195.601373,147.988896,103.760235,-36.232294,-97.887943,-143.09384,-137.216012,-112.910772,-115.972306,-164.972847,-244.446142,-281.409668,-291.145853,-289.740273,-355.089751,-393.733653,-479.52902,-586.271992,-587.94767,-484.593749,-426.421135,-328.39234,-278.185497,-187.778333,-151.482658,-50.916203,40.704265,44.948263,64.186099,120.86932,233.360934,238.247527,159.656135,104.334858,103.393984,109.609904,124.72206,166.693716,161.621323,86.01297,27.153639,-81.438196,-112.117253,-116.135494,-117.50498,-90.196163,-2.161988,15.193215,-64.154125,-178.216491,-182.970996,-68.424233,13.102448,113.379601,133.274457,166.121686,163.700962,89.158654,-19.501687,-55.297684,-91.155234,-119.39065,-158.72844,-143.790594,-115.881836,-161.089503,-188.233239,-213.699912,-201.558664,-139.263807,-113.649467,-68.597512,-48.037327,-71.949205,-176.939118,-220.064945,-209.183549,-177.909697,-124.821305,-93.695347,-57.102029,-76.346271,-87.434998,-93.330952,-67.209499,38.776565,91.51839,145.925519,123.901646,34.699265,68.243199,114.570315,174.400443,198.835753,230.606496,210.842173,82.142643,-48.362359,-55.02097,31.28966,63.252963,43.872861,26.4348,39.049569,53.937629,48.447179,-13.940096,-50.329046,-6.737551,67.721489,146.958672,127.419353,45.498301,2.363719,-10.060837,-77.088218,-118.988362,-146.854348,-128.758478,-56.964388,-23.300128,4.061664,-30.516116,-73.649806,-134.172511,-125.438447,-76.226014,-62.261078,-56.337688,-65.724362,-78.14104,-71.477633,-33.069087,53.386627,60.069958,22.980505,16.093132,53.428892,70.22734,37.684669,-12.480619,0.18698,26.173751,17.144939,6.981401,97.029109,159.369377,227.721775,243.84143,253.277655,237.563575,210.454559,197.98163,117.805586,14.194675,-20.597937,-47.622547,-38.086707,6.717904,11.583463,-64.80767,-109.697645,-84.070423,-28.074767,-7.750228,54.319938,85.662695,109.504856,99.877828,61.167377,105.152487,166.731557,264.756212,271.07907,205.189606,168.8096,183.89094,196.607607,147.296108,34.05173,22.794012,71.054727,92.577024,73.744765,44.228829,31.97078,30.250491,-4.822621,-52.666642,-29.34797,70.015407,116.189326,160.164529,153.296056,128.85791,28.399877,-1.283893,74.700638,136.946851,164.018836,124.787705,31.585968,-33.357628,-57.667765,-35.771969,5.542764,79.088576,102.503769,106.500471,28.115109,-47.165532,-192.564768,-191.344303,-61.122352,-24.878847,-54.453053,-62.350493,-35.537045,-91.507189,-154.195055,-210.367257,-194.404241,-132.351035,-95.126529,-27.809,40.23859,73.188598,104.591182,108.895791,110.440307,113.411763,126.179645,104.951692,-32.94918,-155.759036,-151.623466,-16.64123,57.778251,136.9471,165.159751,203.463946,183.087636,163.355183,131.744855,130.478285,142.220106,134.962792,80.573284,48.150102:-160.588077,-191.706672,-182.7768,-99.332402,-43.355418,34.843296,46.387144,33.997151,43.228637,53.773446,91.713851,140.472005,300.508015,390.864875,473.769472,436.563094,340.65552,357.663996,376.878451,417.74739,446.549857,488.021933,473.883738,363.301718,229.166774,174.551328,112.419443,112.626769,109.001744,84.24467,43.415713,43.223535,30.768452,-73.123566,-118.92871,-48.992041,49.45272,159.580323,141.917993,53.844328,-4.571962,-14.540902,-10.781835,-2.802549,-27.302656,-52.356895,-92.605927,-120.6588,-164.564918,-170.240217,-155.547391,-31.548824,59.243496,152.360526,136.222443,83.673742,86.458576,80.826471,57.949983,64.107267,123.062462,169.088105,232.28573,214.788395,87.275094,-26.112228,-40.560925,26.706271,98.948491,204.656173,191.590775,93.001343,-13.054629,-74.518148,-125.103587,-99.698545,-18.01155,30.006162,123.121432,138.033772,76.491828,-37.249317,-75.504945,-45.178813,20.219235,146.219027,153.987236,29.821916,-131.345162,-162.636313,-100.201114,-36.143641,61.449863,63.039855,-36.464079,-113.216213,-261.685003,-373.029733,-385.172007,-280.57343,-195.893871,-55.071223,-28.372286,-107.114214,-262.316168,-318.635919,-336.84756,-298.405577,-127.434273,-5.938495,145.443158,123.284779,-0.660457,-93.477171,-131.8945,-160.356616,-147.615403,-109.588048,-106.626545,-158.930604,-257.88378,-308.644742,-332.204546,-281.389673,-127.021935,-67.560132,-18.980439,-39.287405,-199.951355,-422.155477,-453.718828,-273.693345,-144.294335,-12.052612,-20.000229,-84.515161,-70.548648,-58.691782,-55.834163,-14.726322,184.54486,295.404351,385.504291,338.014254,174.001838,81.22304,67.632088,108.516434,159.089988,276.99025,302.533,218.275918,82.511056,25.058296,-90.852757,-119.498311,-83.728186,-61.494486,-80.766198,-107.128285,-172.173043,-279.394167,-320.415372,-311.233748,-287.343722,-275.481069,-288.625325,-354.758705,-423.653827,-444.198336,-447.255376,-403.456306,-232.624625,-156.388986,-105.177791,-101.106923,-14.907268,104.778783,132.36225,143.080763,146.249007,186.734858,205.935979,159.902153,113.332899,113.847451,90.796765,86.633985,128.521275,150.23291,129.482918,68.27465,-98.843387,-189.181279,-185.770982,-122.71543,-93.489799,-42.666962,-25.716358,-73.988995,-190.414531,-218.522465,-131.669224,-31.415682,161.213301,211.632478,204.839395,169.91605,89.243663,37.540141,28.100497,9.468263,-11.173158,-33.806146,-29.012616,-53.516366,-111.817388,-131.569237,-116.839028,-66.398342,67.548885,110.334143,91.667007,43.752866,-38.369845,-143.32039,-198.532712,-161.114619,-84.55874,20.746532,28.390428,12.92591,48.975283,56.522727,17.401899,22.994646,99.410654,131.00623,156.924017,150.870985,120.067536,128.535034,154.080171,180.597996,173.341147,195.62857,212.998993,147.286132,30.260374,10.413018,61.810913,108.125291,168.53061,167.924421,111.048713,78.344537,53.604723,57.193045,59.874791,76.532844,93.90236,148.364197,160.545599,89.464167,10.648318,-9.510514,-76.745508,-101.531879,-47.106995,11.587551,61.322382,39.454928,-21.334614,-47.964711,-54.855658,-49.8124,-20.722718,81.813136,112.837119,70.47147,-46.849708,-120.556691,-146.910209,-42.051238,199.529058,217.423112,87.034133,42.463711,72.485075,31.89978,-38.059746,-104.755539,-70.463353,36.246972,61.58532,70.995557,129.41096,162.976348,214.894427,250.468575,312.056358,323.191871,278.675594,210.227805,70.1176,36.260468,46.015227,89.6452,111.020969,130.988617,116.278252,-14.385811,-145.708193,-149.941775,-64.119801,-13.571706,43.753908,80.398381,187.22787,195.941693,100.95088,38.203512,52.500721,150.423707,195.439412,212.639396,195.31138,131.270687,31.410318,-31.749567,-93.179441,-63.73131,9.62112,28.350169,49.377329,41.271607,-19.378522,-88.385137,-93.353008,-12.186711,60.339948,169.634537,168.410892,111.386494,61.59728,12.197936,-67.465996,-35.072233,102.943006,139.31044,117.015619,82.423673,49.305902,32.178045,-9.124179,-44.297821,-5.116563,77.457051,86.860175,44.827567,-36.730437,-75.64202,-92.388196,-60.706632,-12.670075,-19.070684,-54.112696,-65.587031,-66.378093,-118.499071,-156.944097,-183.205372,-186.072137,-167.932055,-120.23589,11.478352,72.389116,66.727999,72.379475,105.729267,138.163797,129.488546,129.09572,123.096734,35.984414,-85.359626,-91.271094,10.349539,49.000199,73.09373,97.92633,131.752325,54.123415,12.890333,42.760283,92.592025,131.737138,120.375377,83.472271,48.682617:-211.275373,-387.916383,-423.534819,-235.556542,-94.082889,80.739027,118.152685,81.163358,-65.270697,-101.740303,-41.092412,43.298814,249.261046,344.077355,473.085614,496.195543,504.720025,518.629315,505.707695,436.987311,412.209564,409.003487,415.903921,380.058319,249.529528,177.210679,114.483277,136.720936,177.860798,146.281803,20.798792,-10.651089,64.995629,182.861776,197.305096,168.924005,148.93021,103.684204,100.809497,123.946017,60.000605,6.671268,-34.551245,-5.898553,81.294882,90.365628,-18.268843,-98.201948,-190.515172,-209.207623,-189.92119,-63.756575,7.569546,91.276548,115.90112,162.442377,212.16041,206.684373,90.122675,33.176352,43.024917,91.385269,114.102784,48.675472,-102.801297,-126.694409,-125.411789,-121.154947,-95.336067,10.897271,64.065325,91.076339,-10.74297,-88.814619,-135.081499,-60.332564,86.567102,75.380816,45.886364,96.549139,125.860988,-140.854397,-268.388265,-232.511036,-105.656649,39.933426,-7.670222,-218.671985,-279.438084,-209.664997,-11.562924,45.387122,-15.121734,-97.144433,-166.755589,-151.781415,-175.172198,-274.404358,-301.845549,-250.129461,-190.207866,-102.969686,-95.362058,-124.429462,-138.912744,-145.413026,-148.629054,-99.829043,76.129955,135.689883,160.718152,152.264727,63.254435,-123.160817,-166.987656,-93.310798,-48.749678,-38.29532,-41.201472,-72.277178,-145.438391,-168.781247,-175.344732,-138.030674,12.032411,64.91929,20.14044,-62.17035,-218.399617,-255.003736,-229.993731,-131.625059,-96.018635,-71.181473,-49.195582,22.143403,105.44026,128.528752,126.46018,145.247085,219.934232,224.721051,171.642089,143.675071,88.390399,55.249861,62.151205,116.17198,148.490792,200.175057,221.365754,240.34666,179.182455,100.809324,-92.815881,-149.416098,-176.895213,-186.734115,-183.641032,-153.500814,-99.184663,-185.702116,-275.180594,-384.645634,-378.255982,-361.393159,-398.455732,-571.537266,-639.147867,-592.290941,-545.446465,-549.777892,-448.598322,-376.761138,-281.989142,-228.550635,-89.916383,23.389994,48.184107,65.33955,91.171483,174.267901,191.088945,136.324819,97.860603,114.287001,168.84485,190.06348,212.090992,202.019481,126.682795,98.114443,121.044524,146.640203,132.056213,104.75696,103.824683,103.678869,99.325514,37.387541,-68.213768,-97.485063,-78.144878,-14.778859,175.182531,245.248087,244.310057,190.033888,103.126944,38.948059,-3.666688,-33.22634,-33.880678,-109.585658,-168.157192,-223.759554,-209.204303,-203.422457,-181.850595,-143.385089,-60.869496,-66.984003,-126.267007,-134.836762,-168.876001,-267.948468,-275.35433,-220.342926,-219.095989,-194.506225,-120.531732,15.246454,-43.634276,-87.972609,-41.466178,46.97184,215.204842,253.818401,271.165916,264.354324,205.520855,168.206398,188.656557,269.649337,293.97206,228.108744,154.516492,29.625954,8.857275,35.345472,109.408429,147.16056,194.251271,191.837025,152.406557,119.791193,44.287543,16.617747,1.682289,-26.682009,-15.859061,29.504172,42.343594,23.767726,-5.102431,-10.56701,-63.2475,-115.631794,-177.868115,-146.626559,-3.576478,50.757179,51.447866,-73.689351,-121.560884,-90.192763,-57.305004,-48.03771,-57.715637,-69.834416,-56.715513,-46.757426,-31.804755,-16.634399,5.550959,-5.372604,-28.105722,-25.739702,-21.020666,-30.755156,-28.815976,34.652994,67.571335,69.0333,69.75882,121.818103,181.634792,205.385375,247.994256,272.055434,322.110383,331.544832,271.815407,203.740005,91.6021,121.152842,156.527774,173.80096,161.777061,126.636044,91.556834,-5.755386,-24.853059,1.815421,36.29492,40.648629,94.567377,143.5453,170.068621,112.037651,-26.11046,-19.856752,29.977827,193.57792,261.63109,269.720249,239.983477,188.738585,121.229777,78.078046,23.912204,33.377482,54.986168,34.008603,-17.864858,-25.06217,-29.859594,-118.966559,-196.295117,-219.939232,-115.830855,163.271794,239.46052,201.482251,130.924873,129.407518,73.264594,24.632638,29.998523,81.67234,173.673897,181.079404,105.158365,-4.616054,-63.066401,-114.081245,-69.865065,50.676932,74.046366,40.503127,-69.431965,-132.059273,-186.702378,-141.142372,30.031398,77.31674,30.423485,-18.452753,-69.180442,-128.349261,-177.864574,-217.351793,-195.536572,-142.46993,-126.982645,-67.064101,46.879533,63.142058,-43.626675,-99.262079,-83.588925,-54.874409,-96.022371,-164.763023,-304.31291,-365.011738,-362.194815,-250.402391,-154.202251,7.910034,54.794016,44.766029,-49.416105,-82.200386,-80.51176,-40.766648,65.037868,101.357735,98.540074,52.74565:-241.904944,-331.331128,-320.615626,-195.286473,-119.65201,-29.560083,-34.650653,-104.968826,-146.513396,-139.45438,-31.547966,76.136769,292.002444,364.859247,435.974664,420.42609,332.838802,347.473145,395.177801,442.561663,422.088392,383.356825,378.741073,294.561446,142.706012,95.851479,80.223541,102.730991,126.498441,88.387089,-33.095254,-49.087442,26.180907,39.590782,28.958305,104.709291,156.725783,161.271173,125.502102,44.76014,-13.956227,-29.632343,-11.986187,9.97121,10.975567,-0.126598,-27.929983,-69.776263,-177.699245,-246.301225,-245.80252,-125.854728,-38.086578,82.64803,120.272262,198.197528,214.019569,163.380675,3.668768,-35.785553,27.278538,70.179629,40.975457,-19.191268,-112.195045,-135.330342,-147.945212,-123.825912,-54.420639,114.868403,143.306844,38.364272,-128.443363,-189.419862,-192.009478,-114.852709,53.475061,78.219562,63.97729,64.990946,29.439163,-127.34557,-188.261872,-116.051318,-31.152283,36.080315,4.388619,-151.832955,-291.151923,-275.143992,-98.650349,-7.227161,67.603798,34.336243,-136.285378,-224.907134,-273.303878,-201.321327,-202.014178,-244.230792,-209.176118,-35.190258,15.811138,-47.31351,-174.174248,-216.299261,-200.862014,-121.360046,107.292938,188.892452,187.769428,122.397877,-9.947631,-72.104866,-98.822852,-124.817176,-102.942323,-32.61422,-17.245905,-68.67435,-217.32656,-287.40666,-274.924996,-193.02206,-49.878182,-28.444911,-51.161433,-78.957064,-161.661221,-315.071898,-364.478503,-245.095589,-129.581076,-18.982452,-30.199704,-64.805118,-39.430201,-16.824151,32.9093,83.566858,209.67372,240.275204,214.293377,171.412942,68.641172,17.094069,18.831977,61.94913,94.984487,142.982842,158.465501,171.908839,88.844598,7.958414,-131.257512,-151.770953,-130.150512,-122.161253,-123.997325,-132.216997,-190.456656,-293.217304,-329.643711,-311.723157,-277.520139,-276.706506,-317.173541,-442.464054,-521.90396,-485.470823,-359.30917,-348.097846,-360.984034,-323.016368,-197.330891,-136.291739,24.06616,163.929109,183.730364,208.966673,234.850435,250.31513,237.981856,209.597458,186.256426,182.539248,223.232589,270.645117,343.364753,333.484209,243.53947,182.81703,33.351396,-88.710738,-85.164744,63.964079,146.554833,209.125434,186.098165,59.409447,-80.348426,-115.203057,-25.352277,92.344194,258.661651,266.070043,242.699472,234.069079,171.347346,43.3294,-10.06041,-11.223519,26.491397,34.31281,-27.916704,-178.940514,-234.310554,-258.053804,-255.724607,-184.90294,-19.880888,1.355909,-50.387532,-72.078219,-66.241337,-73.913829,-95.746616,-95.643483,-75.986931,-57.120366,-48.894987,2.166572,61.234663,66.234351,81.893736,126.979272,223.159357,235.523785,207.299185,173.953217,103.373384,129.921168,169.969825,239.281928,258.683525,254.047156,217.179284,61.529654,-55.849889,-38.40425,107.846383,178.712381,224.342434,208.500929,174.680778,157.30658,62.309951,-22.02998,-15.886858,43.417668,79.478132,134.793894,125.305432,66.428287,69.63913,63.126806,7.728902,-1.947637,30.404949,44.380553,16.918415,-18.109327,-60.448382,-53.858342,-32.029177,66.38831,107.162212,99.479387,66.595009,28.645859,55.222606,66.555494,89.92268,115.899004,153.460136,146.419414,103.241005,79.144493,50.54919,42.474941,43.430476,81.156699,105.942975,150.891447,165.439347,155.780267,176.122692,211.862011,275.440901,293.777491,309.747511,314.583902,293.756474,246.460187,125.769094,45.380003,27.053035,84.194624,140.912735,157.586076,96.309554,-83.144779,-151.676984,-121.715373,-13.600492,44.107709,119.994986,131.786376,116.465756,86.044998,26.18982,40.748423,81.625037,211.05061,260.925694,280.291196,256.4208,158.719608,56.634844,28.135208,45.578524,66.45274,21.825048,-28.625797,-82.320117,-76.015818,-11.567978,3.230587,-33.403278,-60.711282,-10.779678,147.673575,190.864723,153.959399,118.31652,117.548663,86.13329,69.927201,63.860823,70.572862,79.47283,55.419186,-23.554401,-38.122212,-38.942481,-41.073215,-16.369666,53.840893,56.049408,-26.549179,-103.79469,-121.763593,-107.408568,-55.427135,69.245224,86.851651,12.093381,-43.917419,-120.731832,-165.225363,-171.922001,-139.334081,-121.048931,-116.117603,-131.433472,-137.565487,-6.690249,49.667585,19.316384,-11.915241,-29.98355,-51.996686,-131.444427,-173.80909,-270.176143,-330.945369,-292.780766,-85.047783,10.536644,92.013008,96.133671,46.006908,-24.41048,-29.997184,19.756546,63.672476,125.468059,125.425722,59.038124,0.957326:-71.353217,-264.485739,-348.279737,-313.636841,-210.981743,-20.36272,31.592048,-9.603585,-131.880025,-142.096996,-94.664396,-41.968108,173.002782,279.0938,325.182427,303.996992,341.654934,387.530996,347.287893,248.329307,237.753374,238.579518,213.140708,97.521077,-19.919479,-44.771862,-31.70811,-11.88487,4.848878,-8.202716,-46.38938,-48.922594,12.079495,168.494221,245.426479,249.549584,184.582256,82.499663,90.015155,155.626382,165.657645,158.881834,154.536909,154.603172,141.163646,112.455971,20.483087,-7.273227,3.930947,15.132234,9.363437,27.872782,52.357815,91.6655,128.988855,284.623526,408.066332,421.089029,305.791865,180.480039,-17.534126,-17.726387,84.322415,100.826532,40.309999,-0.721181,10.529063,78.550843,113.662617,187.012874,229.896675,236.897181,106.829824,20.414835,-89.030418,-61.390682,98.241328,152.450659,149.468593,116.95165,63.11257,5.314099,-27.900948,12.153951,84.383036,154.855272,109.765589,-42.707196,-39.423225,19.978338,99.993316,115.107746,101.391647,57.830097,-50.632367,-83.24213,-72.634755,-71.799628,-133.776039,-273.691976,-275.819243,-181.569024,-156.446012,-186.563362,-160.308314,-112.927783,-52.877136,-42.803626,-8.783809,24.633005,92.338042,94.624018,-15.221763,-147.458732,-139.50558,2.606312,48.479203,6.921061,-23.775886,-56.268152,-105.448596,-140.853139,-213.068765,-204.990706,-87.817538,-30.205358,26.294765,24.097597,-50.204684,-152.705835,-187.283505,-219.994083,-222.044115,-179.753302,-128.434096,-13.948216,71.585263,96.084082,97.309383,93.29889,71.50602,41.055825,6.869384,7.580672,6.709566,64.845912,115.480966,170.385097,149.050021,85.030926,94.833913,138.250675,140.366861,147.051105,98.195302,40.902331,-7.142339,-8.939805,-56.788245,-74.082233,-78.985941,-202.25446,-278.208589,-260.619565,-191.414019,-148.931408,-206.836093,-389.197085,-394.140409,-320.666644,-207.330496,-177.049701,-96.305003,-60.344904,-38.392651,-31.356436,1.754751,38.191305,65.348319,143.249574,178.676163,199.0905,192.140936,203.975669,227.486661,219.819364,175.569994,174.275159,252.934158,294.253203,284.704281,236.95565,129.257825,66.342,61.908354,90.408059,77.922184,-9.420886,-33.86707,-45.324827,-98.89689,-110.485074,3.234695,101.553651,175.816704,129.998846,49.305563,62.109118,87.372714,-28.595634,-108.357243,-188.198405,-187.751115,-150.972135,-124.785784,-131.743682,-234.126377,-268.545585,-267.05823,-231.431489,-107.363275,-66.065786,-118.98017,-186.886291,-259.236654,-196.026784,-172.990451,-204.234801,-213.458505,-143.846506,-93.737332,-11.612334,105.860214,170.461074,246.530946,263.419758,304.30082,340.893976,412.437494,393.86545,238.281999,206.011976,278.799054,424.247717,426.281379,291.628296,217.565896,127.419981,63.239299,59.097381,88.606816,96.551553,114.087903,117.823116,83.347841,55.574642,8.592239,-17.819768,-36.199031,-96.399529,-134.218575,-158.902257,-115.169425,16.942751,70.108745,41.664365,-95.235087,-160.750021,-216.651004,-201.508549,-123.560476,-81.318337,-17.546435,-56.179185,-91.06953,-36.830012,25.015459,35.794313,-1.222718,-22.894285,5.16283,-6.753554,-103.108596,-144.028516,-144.250001,-120.210885,-57.449593,-32.424526,-16.89416,16.381415,47.476381,73.418045,44.202625,-44.354295,-50.95997,32.550427,207.822144,304.368047,374.790777,337.460078,243.127178,215.789838,186.883868,178.953364,193.074145,229.304611,220.997218,202.870173,225.956857,275.884058,270.418894,181.80775,120.480093,147.760429,247.310791,272.594173,231.834606,179.037485,35.364227,-46.014282,-139.916736,-126.77871,-123.127061,-93.525709,-58.808405,-22.756073,-15.868547,-11.634535,-70.800347,-105.565704,-137.792191,-133.173898,-99.515003,-85.666013,-101.750438,-120.329643,-113.361327,-100.828797,-125.999404,-143.541726,-104.928348,-4.242747,36.633593,83.334764,67.708558,49.161783,-3.422086,-27.964653,-5.241247,30.241196,43.686804,25.698696,33.356328,87.770537,76.376175,-31.023914,-72.116837,-50.787217,-21.514355,-60.170931,-173.481073,-194.815474,-190.195217,-181.036523,-150.342397,-133.065073,-56.644152,-6.751327,6.821618,-98.667571,-148.728293,-183.924604,-172.697039,-131.355097,-117.148085,-86.656442,-20.851748,-5.544614,-48.817242,-83.856277,-151.265429,-180.80549,-228.153274,-262.472763,-358.281692,-397.813427,-382.005632,-287.582289,-233.095155,-136.106102,-81.808612,-45.672332,-104.69493,-122.150627,-101.22806,-56.250441,41.978681,67.060164,74.49683,34.069156:-115.092695,-225.476964,-264.248859,-213.683045,-112.77487,92.639725,144.432825,123.076783,22.510058,1.551876,56.075865,127.915303,321.038342,404.505144,494.826706,490.727714,437.337693,484.16903,514.192128,481.984544,446.021341,379.854362,338.948774,275.928688,242.770855,204.57008,160.965795,203.44818,290.985495,264.75611,173.096971,178.66961,225.026619,157.477129,124.357265,147.230588,178.270168,242.978512,269.816009,256.221734,188.44594,164.911057,116.854285,86.643377,53.691543,58.873667,94.458976,112.410872,118.365939,93.076056,82.012974,128.175637,178.963015,213.13898,212.591686,284.051764,331.850605,314.46894,219.378921,157.349128,92.208113,109.289356,182.348228,195.058597,108.580681,-55.568233,-117.940145,-104.541179,-27.084055,143.903563,186.803987,143.025219,7.566262,-54.65954,-144.73334,-153.711818,-60.883467,12.879474,113.579249,130.972304,94.840609,-37.877643,-77.972666,6.400597,71.273505,72.755015,29.10104,-47.272205,-70.450187,-68.068938,-45.158129,-12.262736,21.321623,-12.204639,-96.463392,-109.541814,-121.373299,-231.881104,-297.485745,-262.396521,-183.952232,-137.769477,-180.890627,-218.226256,-118.137438,-78.962883,-78.698757,-71.890679,-6.594931,20.453465,60.79381,72.525147,2.845965,-146.894352,-199.55365,-232.495712,-211.871028,-114.362495,-78.855084,-111.70063,-151.29828,-159.956795,-210.218614,-209.648972,-100.840425,-27.714382,53.880197,31.89,-95.453432,-202.488768,-217.683107,-136.875897,-71.119698,26.751718,52.602745,22.615863,-44.43649,-51.340665,-31.436562,2.696311,90.346237,109.001104,72.756762,26.744093,-42.902045,-24.19302,-3.582622,20.358734,27.10713,87.575714,139.654641,194.078438,146.143501,89.972827,-28.518425,-50.217729,-39.400876,-54.398031,-163.484931,-219.697422,-224.061175,-202.929204,-251.81129,-366.410818,-370.198692,-327.576972,-336.128085,-419.874094,-495.619092,-521.710883,-511.250821,-440.255498,-267.216731,-235.279638,-218.617187,-183.557115,-83.78788,-37.440624,-49.544497,-55.236624,-12.490792,83.884851,90.734231,37.764424,1.200462,3.275317,17.12043,23.925886,0.322987,-23.58835,20.282785,69.938915,71.696703,-19.222062,-28.374207,69.420303,109.558056,41.168522,-32.354047,-144.684054,-166.464073,-160.715169,-169.047094,-157.159137,-83.433952,-53.941318,-10.822494,17.633862,30.36487,-97.040992,-182.739165,-278.318835,-272.744338,-194.479119,-162.571986,-210.795721,-340.531647,-370.460467,-338.598959,-296.241189,-199.423776,-171.139337,-157.366201,-138.852458,-107.842275,-180.308593,-239.875768,-323.855132,-308.061186,-146.25683,-57.378256,44.901855,86.949343,91.169748,117.591429,166.136558,277.10873,303.749323,327.960114,329.13445,267.081408,218.106777,233.043633,302.850783,328.163218,318.545686,282.077899,137.867566,1.970346,-9.644735,68.869462,116.119413,129.006497,104.22811,84.978489,98.836675,153.270431,143.938411,72.457357,-49.353711,-35.896605,42.419913,47.199296,8.240731,28.487903,40.061347,-61.275122,-147.66096,-181.005017,-105.190936,76.149346,126.301582,135.974637,53.732648,9.108563,7.426816,23.609332,17.724425,20.037154,32.034011,19.491991,15.0921,10.611601,25.321127,73.035568,82.579065,89.405046,86.935129,66.958535,83.401413,96.024313,86.621207,73.962207,76.34363,84.00799,113.617753,274.283564,357.190169,364.684137,343.275646,367.994762,364.883698,231.015069,144.331352,96.900431,152.41218,147.939449,99.236625,83.154606,110.07591,156.601195,192.52849,114.065331,108.780791,181.212437,211.878065,237.252707,236.754718,167.751165,99.437358,11.838904,49.128259,71.709684,72.347126,57.857449,65.432216,111.32015,200.738143,125.00653,57.251451,-32.262586,-59.223922,-81.01226,-65.974706,-5.95562,14.71032,5.69197,-116.604218,-217.576031,-300.548612,-232.971511,-4.328889,82.849105,141.252948,121.668526,100.058738,45.317661,32.032033,52.753532,85.797985,178.5895,218.126602,239.957236,134.661119,52.114066,-9.579148,30.57931,121.588365,133.811216,85.253389,-22.193811,-60.802316,-77.543898,-75.944399,-87.815642,-88.812525,-66.378333,-61.305183,-86.316431,-163.117417,-214.846032,-287.63235,-285.566581,-182.292291,-114.233014,-64.830702,-85.009183,-94.221755,-164.03265,-210.256328,-235.376744,-218.326166,-211.457776,-241.710881,-328.312202,-392.655142,-415.025646,-426.790999,-402.332221,-248.839846,-125.847744,60.208719,26.043832,-36.664826,-98.967231,-63.813536,48.604168,75.399972,60.597509,20.562658:-315.161247,-355.564126,-348.119394,-203.614679,-95.747412,69.757707,103.118326,8.927146,-164.191825,-190.805996,-148.666651,-97.062532,84.845455,189.445371,293.280394,272.877092,225.106889,281.984041,289.043955,188.68005,142.247839,182.401122,234.880388,222.937375,77.136685,23.821213,-19.343586,-15.805182,-24.259879,-43.43984,-57.641922,-68.679258,-75.268495,59.426917,140.968623,185.40036,151.45211,71.072917,49.137071,56.939572,118.187098,134.783577,107.83787,88.297476,88.561526,99.078346,54.437993,-24.882944,-192.069732,-169.050715,-121.177193,-62.226355,-34.232973,14.693902,33.83426,114.595446,207.303357,210.234351,111.510558,57.971909,39.298699,42.840939,-33.931585,-97.42922,-148.687598,-96.221372,-77.873126,-61.90091,-49.333021,-7.042965,22.684944,75.43809,81.258691,36.035255,-106.742849,-115.607907,75.029273,188.167288,262.570918,241.023624,147.848887,-29.227663,-105.484476,-48.341797,51.627926,120.711656,58.607072,-138.117007,-171.706913,-91.620936,34.271581,34.424527,9.090291,-6.752493,-55.062058,-64.758911,-92.015435,-201.102319,-255.2781,-283.263463,-255.271975,-178.166183,-151.386112,-118.483728,-83.355078,-79.635208,-80.361121,-51.721303,67.517983,125.492377,152.391097,114.698475,41.243953,16.149527,-5.649612,-13.229915,16.280112,46.990384,21.6931,-56.244168,-62.704488,-45.059173,-40.607137,-44.872505,-37.686044,-40.130599,-12.833878,9.404258,-59.380539,-195.55828,-234.1559,-255.106108,-244.918256,-208.201789,-190.08425,-175.04444,-140.358627,-93.363771,34.162187,100.146131,139.995913,107.472388,72.623903,58.273622,-45.871051,-48.020256,13.260092,132.85016,167.00384,192.168435,198.827573,216.434336,172.282822,98.664091,-76.677162,-116.049123,-126.914222,-145.442679,-121.213958,-66.880954,-55.075812,-197.35494,-261.340468,-310.76227,-300.545144,-290.778493,-331.784395,-461.920463,-416.033367,-334.642883,-231.427461,-208.00404,-157.169895,-124.660033,-20.729655,39.727046,140.297319,204.499213,224.642451,266.313216,277.793861,250.996021,228.714927,208.903701,234.244163,267.033916,348.300099,387.204129,418.569082,400.956922,360.100739,341.299958,235.996513,113.900519,87.985597,71.044613,68.32593,98.229007,120.951551,78.011032,-54.661617,-77.97319,41.901059,160.961516,297.968249,250.739863,80.931669,46.957293,85.180559,55.161618,-5.707712,-64.430521,-57.669087,-21.976507,18.453569,8.73315,-210.146538,-277.086966,-187.416474,-103.653167,-30.919173,-46.304767,-103.645254,-117.510618,-105.9102,-139.018077,-181.613201,-202.810414,-179.067524,-125.36044,-91.91109,-16.173197,35.382035,73.559744,219.956939,290.257329,296.833243,247.631023,199.271381,201.799429,156.209712,140.576462,201.982069,363.422579,379.888276,248.198713,168.587512,98.708465,94.545355,88.490526,109.743599,157.559183,217.533466,176.13283,45.602431,15.876338,-6.55249,-15.070335,-5.068751,5.518613,0.282642,-8.588432,7.190566,94.862092,114.588936,76.52503,-16.463594,-57.885579,-135.396882,-147.192032,-100.505045,-93.196717,-142.650404,-124.668191,-73.461274,26.339101,43.277431,30.235823,28.569678,28.916648,0.394575,7.964937,49.681595,45.391027,-19.537276,-50.607144,-33.118969,1.5223,44.330635,85.842635,114.036731,133.678913,100.576406,23.415867,27.870333,94.464068,245.125849,335.665666,368.01591,312.940334,238.584879,244.095765,277.793995,280.182427,218.800253,128.178074,121.32181,167.901911,158.910093,80.675071,68.994795,20.756255,-89.617628,-78.667027,22.07558,52.00559,84.406786,108.142163,114.727893,69.683408,15.736838,78.907054,95.837869,103.367494,125.488202,201.835194,218.285564,136.158766,-21.698829,-81.356973,-128.658817,-118.689513,-55.229697,-20.161906,-0.10553,-8.927942,-23.586087,-76.999486,-120.691438,-149.774201,-120.986574,-18.481323,50.480096,156.255816,124.778784,88.188409,12.591343,-21.117135,-52.002746,-57.977872,-58.529218,-35.09852,17.037949,-7.039772,-37.83822,-93.91969,-97.893328,-58.532499,-50.70953,-99.715696,-107.871614,-73.58697,-18.694754,-3.123503,18.389526,0.75294,-82.191038,-111.616065,-115.676927,-124.964747,-142.841933,-137.596611,-115.580008,-112.09327,-124.203882,-86.361462,25.988042,63.419894,-9.641937,-95.029079,-184.121577,-174.345714,-129.970767,-134.472022,-229.184199,-281.636248,-254.875697,-158.235604,-101.275117,46.078609,98.614323,25.945358,-140.106841,-173.985374,-127.005477,-77.113738,-0.039834,18.402594,11.733649,-7.878625:forward
111.860976,80.070681,39.253465,-44.547508,-57.594733,-20.142002,24.925074,162.908432,240.883573,217.850564,111.289733,67.364886,40.424981,42.750738,66.565179,91.702522,106.70213,34.850731,2.19764,114.736164,265.238455,460.270279,426.208046,274.087611,259.907739,272.562868,203.402958,172.852238,268.311425,340.684341,382.748861,357.428947,289.311487,262.312849,238.750746,109.731179,42.596975,24.999765,67.022102,109.980443,-29.713518,-115.095709,-199.705058,-223.524017,-262.316206,-244.083516,-110.872372,-57.442519,-106.35677,-214.84274,-266.909157,-373.933068,-374.804148,-280.121581,-245.870603,-251.839369,-269.002789,-253.424732,-184.775792,-151.781606,-121.740986,-102.698002,13.654858,78.757471,44.555333,-192.857069,-294.887337,-289.918698,-181.822957,3.286601,-9.201828,-184.035632,-295.00988,-281.640782,-232.946723,-234.52654,-175.205121,-92.158472,26.477017,26.066172,-33.700924,-87.572001,-105.843397,-128.784317,-120.001588,-98.636012,-122.019322,-192.962653,-206.084776,-210.49509,-249.76635,-264.8554,-227.587927,-174.094601,-50.216236,-18.495222,-44.574196,-81.56933,-99.421443,-152.099772,-146.535525,-109.648034,-127.071704,-143.237992,-65.395986,-29.819597,-9.105065,-4.477323,10.846559,-25.250842,-165.853508,-198.341719,-135.153379,-22.523972,-17.669168,-131.235333,-175.63253,-135.985767,-83.560421,-57.248581,-184.422815,-227.77046,-197.353333,-164.629176,-145.784324,-150.517108,-112.223724,-73.64701,-55.624947,-112.407948,-128.674367,-86.271162,-52.044654,-79.357863,-118.543539,-124.571433,-107.625573,-112.386283,-119.798035,-117.740033,-121.015079,-130.876537,-77.848431,-0.576911,119.026062,100.844997,69.87503,27.271572,35.373838,130.925869,175.291442,119.952445,-16.142649,-33.183799,-65.744333,-117.292376,-157.828352,-128.835579,-25.368677,43.775079,200.096142,274.784757,229.55339,90.778827,72.712184,134.075385,185.421228,226.530656,65.106384,-53.354863,-247.436172,-290.363039,-218.127866,-134.437178,20.65645,67.227211,69.67748,32.579453,10.752853,-36.459763,-28.61467,36.745662,60.037452,68.662218,47.738128,38.532458,-1.431848,-17.048964,92.578259,186.716056,253.168975,210.988962,59.020022,13.999011,55.017158,106.100539,96.115942,115.211433,163.004647,213.729073,117.800741,61.974297,-20.777484,-57.301763,-75.752382,-24.806348,206.784311,322.378366,311.384878,42.059878,-64.879047,-105.648416,-64.225817,4.358123,23.930815,98.987588,97.110924,31.699583,-77.273284,-73.193658,-31.750564,-36.627302,-19.388718,28.482899,95.877775,29.972356,-46.48109,-194.490144,-217.309415,-168.513863,-132.343539,-86.641587,-123.256502,-156.583659,-185.754083,-183.75584,-167.486985,-154.681955,-95.709555,-50.256556,17.202724,9.183462,-37.875512,-145.378255,-135.660663,-2.670982,33.871631,-62.611956,-184.414228,-188.7135,-176.63867,-191.688971,-207.181546,-202.180277,-193.774783,-172.827152,-95.108144,-46.228547,-69.561383,-163.211282,-181.727122,-165.087382,-147.483034,-129.93532,-221.001886,-269.997403,-266.535669,-224.431936,-154.419372,-153.159209,-151.271983,-124.275319,-89.435364,-138.625054,-176.674776,-243.158281,-269.320616,-300.937176,-291.042909,-239.636146,-191.660205,-153.148921,-141.704615,-203.663564,-256.422984,-168.014433,96.122864,164.405323,95.888866,-77.185961,-148.317602,-215.42729,-193.669831,-77.562817,-13.17035,82.427789,76.934402,73.413186,94.888298,75.284369,37.968786,83.90191,230.660936,247.951537,115.232892,-29.609765,-53.781387,-45.389089,-18.20702,33.295892,44.759086,47.612324,21.096437,12.575921,18.642578,42.562901,142.118318,193.377079,235.009462,230.519459,208.583688,205.699894,201.568135,150.542495,131.225044,140.862713,149.053755,140.520615,66.036858,12.78813,-54.222742,-54.946022,17.077199,87.913152,194.745646,176.34183,7.871014,-179.476237,-229.040733,-204.200917,-141.114844,11.066664,73.286897,120.338004,59.88382,29.883024,-27.306881,-72.934573,-129.111566,-100.612035,31.280342,85.758979,101.610659,39.103429,12.761082,-19.528351,-29.660356,0.699654,49.715479,119.045846,46.534718,-2.320778,-2.283132,52.311035,201.703094,272.397615,383.798136,400.374387,298.755044,163.306157,154.774164,207.462978,219.296693,193.824278,202.986642,282.09089,262.013711,233.439234,180.365343,126.646907,46.832424,83.933716,323.837906,446.655927,477.352635,331.027578,281.140871,227.539523,197.939873,129.026624,106.733661,107.074141,104.659189,97.021884,74.384573,68.224253,107.24434,121.733243,102.509926,105.508825:-7.222735,83.935979,123.379297,41.03284,-15.433135,6.970069,85.041043,245.59827,279.942182,277.074282,250.384883,200.020993,27.523738,-34.069357,33.831383,102.948333,65.301476,-60.562062,-47.458536,165.895317,312.222684,418.942504,353.108296,221.400758,220.228002,205.998516,98.021282,80.684342,235.384696,335.124193,412.188507,393.475299,289.368425,152.534946,94.244655,34.034085,23.950399,1.604206,8.373978,26.191798,-111.523823,-196.10796,-246.846449,-215.831703,-112.85861,-45.561681,80.298082,69.377071,-105.524283,-230.695396,-271.187925,-319.915638,-274.455143,-103.297889,-66.571682,-132.860908,-188.839873,-185.883035,-159.688605,-125.668431,-25.811193,15.21917,78.225352,89.311276,-7.441426,-187.502411,-250.145986,-256.043465,-183.956211,-5.833598,28.857003,-21.519657,-103.341884,-129.576783,-136.830835,-107.223299,-0.816945,45.061315,63.183192,52.684495,79.37512,68.734923,-4.419465,-162.123582,-178.203371,-106.707756,-72.92952,-64.268456,-89.507021,-109.022797,-185.049834,-211.221578,-149.405235,-71.554526,77.774789,112.135186,136.138588,147.913965,104.533117,-48.438332,-80.488072,-34.729301,1.793359,57.870083,27.244417,-7.468741,-42.861282,-32.951027,5.847044,-1.01963,-35.072942,-36.712366,-60.872766,-70.887041,-61.145495,-84.309966,-104.490682,-79.596814,-31.898423,12.637639,-89.453027,-138.186677,-193.338977,-209.98013,-186.717098,-140.367024,-14.525748,24.148901,-31.94233,-134.879629,-147.394453,-72.346879,-3.081051,92.824315,113.049129,147.854489,106.778237,55.745217,-18.221436,-40.564094,-114.831259,-138.533105,-19.155147,85.128062,164.24075,86.914295,46.177539,43.7668,91.22706,222.753069,261.984421,231.094498,163.879668,153.575287,95.522353,27.122313,-73.465678,-75.758844,-20.7506,10.980466,50.793302,112.690405,128.307376,53.047582,4.145097,49.788377,142.812261,195.358237,-50.422541,-157.420907,-181.798694,-131.810972,-29.228668,23.731341,180.227843,248.547768,258.193654,82.613999,-15.021204,-39.347666,24.57053,103.162695,83.801526,37.753869,78.008473,94.968355,46.537719,25.242009,115.595176,178.200458,168.076636,102.977542,-26.314983,-71.515848,-61.7793,-20.541459,-4.32931,39.844414,73.054022,99.281199,26.874057,-18.604122,-100.18566,-118.829836,-27.252495,49.897545,127.011502,124.28662,43.348821,-76.293864,-116.824344,-147.166269,-135.969752,-79.462808,-43.717248,16.141896,46.243801,41.20242,-38.684645,-81.256045,-78.891762,-37.485629,114.822784,196.906758,189.162195,-20.024886,-105.162585,-161.933758,-148.383343,-81.193461,-21.213786,94.248391,18.855967,-82.001477,-258.745726,-305.058049,-317.573595,-271.513744,-59.727567,31.718338,10.967212,-137.401289,-209.90568,-309.97981,-300.682156,-179.597083,-123.190496,-105.895168,-109.47915,-94.831249,-116.140563,-141.085493,-132.914196,-121.998309,-136.708926,-131.169694,-61.342229,14.316251,18.077736,-59.092909,-103.759972,-116.369264,-86.639476,-58.821592,-149.872666,-188.1088,-167.104449,-144.620678,-153.722425,-170.527488,-181.42403,-190.333114,-244.008242,-259.639803,-241.960192,-222.84126,-242.518642,-309.432068,-320.168799,-277.492504,-200.146957,-171.428262,-192.146726,-228.96564,-240.206269,-175.788983,12.028126,47.497449,-44.342862,-169.822598,-227.338309,-305.182828,-275.902906,-89.384687,3.637207,78.752592,44.035082,35.61847,18.171832,-33.348976,-126.703894,-100.266614,44.509168,94.289396,40.179039,-132.866744,-191.839525,-217.653376,-196.526153,-127.788209,-96.767727,-73.755842,-142.204167,-183.94822,-156.599747,-100.648336,-31.881825,-7.199079,121.92779,193.932488,185.587529,80.123839,66.299781,78.583384,80.254627,81.373012,80.088263,53.702844,-9.70401,-43.058184,-90.867245,-110.620055,-96.510254,-11.261965,240.74442,280.412575,82.133822,-154.085835,-205.891173,-161.112646,-57.465853,168.451892,214.94844,174.991736,115.626839,112.808917,35.594157,-43.44413,-87.931339,-34.541029,88.16279,124.435752,114.23266,-8.10762,-60.49589,-34.162338,28.370636,153.332768,204.042373,255.674444,214.036366,189.552187,200.268912,237.569447,345.720874,396.712441,419.649269,376.668257,252.697962,173.872484,148.618721,150.912668,175.154382,200.050481,211.341218,214.169631,91.079352,40.869862,29.450063,27.056185,44.926205,104.254303,300.712204,381.597559,413.91317,357.786289,312.531758,181.063813,135.689041,122.302891,108.255146,18.841101,-49.216726,-59.714768,-71.55534,-57.982251,35.159873,61.228008,-21.17508,-67.775312:119.498214,104.768652,68.159475,-3.606386,-4.935659,102.69799,195.870389,296.812177,176.467308,105.885156,42.50052,25.091075,-7.283664,-2.416411,97.185158,144.973159,79.090616,-30.494076,-17.930668,157.760596,273.650294,361.043122,324.983666,239.028715,231.844625,240.080033,185.913829,137.833801,133.864617,195.171441,320.970446,312.658797,184.675689,65.538526,-8.521002,-121.018341,-118.298728,-57.69554,-32.269251,-62.453228,-224.685351,-289.869248,-274.194712,-212.11784,-70.671736,-1.318645,67.762681,40.090627,-37.789796,-137.826494,-238.302894,-368.490218,-323.824662,-119.940659,-40.841824,-23.664195,-128.805565,-164.929776,-169.442064,-145.271664,-41.798491,23.828216,141.825013,165.668882,87.999103,-87.276833,-169.0019,-205.653262,-144.585551,35.049023,101.944437,76.89238,-99.478852,-144.439145,-116.304967,-88.548812,-47.736181,-35.442052,-11.09601,-6.842245,-46.506357,-116.405841,-172.299095,-259.539971,-245.337226,-151.708292,-126.311718,-174.221533,-278.271972,-314.52355,-358.349757,-364.51917,-300.933977,-215.683841,-2.447451,69.215512,119.583885,62.462837,-19.210832,-122.438414,-78.91006,67.565143,103.742047,93.28386,18.711708,-45.740232,-232.980462,-274.410404,-113.892288,-12.946694,2.354029,-51.001626,-136.972567,-152.065433,-147.919481,-89.1636,-36.246305,17.959906,2.910468,-38.260702,-30.539451,-56.667257,-233.569245,-309.397278,-287.993594,-221.736361,-93.996184,-68.040397,-116.108104,-230.965681,-283.441726,-231.823143,-112.635554,108.369954,129.916272,61.788191,40.873784,39.116142,14.437771,7.540105,17.56613,20.302284,49.106326,94.491444,200.715804,188.95173,130.480657,68.902189,99.82222,235.160964,306.292146,353.201338,263.41721,206.034445,146.348648,162.435856,189.649297,158.537885,79.507246,67.990123,67.141127,13.480177,-19.917431,-29.954742,-9.518077,68.476638,123.681155,114.620191,-101.834321,-191.690931,-212.017928,-153.119569,-38.913749,-16.303971,62.699983,122.696573,110.932765,-60.615545,-120.343843,-135.89837,-100.421046,-15.540368,-8.347444,-56.253105,-55.544164,-25.768495,-26.184531,-77.666893,-181.163425,-181.387049,-97.362048,-86.99545,-215.684116,-299.180003,-267.967615,-190.526678,-164.052816,-69.18996,-10.841509,38.503999,-23.751611,-79.272356,-212.513605,-260.626251,-233.269903,-161.160522,22.282834,91.55555,72.019368,-64.557294,-106.510572,-86.21592,-22.60939,98.953514,104.007783,37.477701,6.020079,-7.063625,-127.751992,-193.026215,-112.659243,22.101484,237.214989,242.878549,88.285762,-45.948556,-68.628234,-69.160458,-64.573632,-50.448964,-43.481262,-40.282713,-39.661083,-64.617873,-214.929954,-295.485965,-309.873256,-250.550342,-99.842951,-48.250302,-89.423233,-290.739841,-387.754115,-408.354666,-332.802733,-196.204048,-159.226217,-99.805657,-90.526316,-109.669078,-134.779703,-107.101774,-32.050784,-26.242246,-43.550082,-46.051243,-26.299455,-2.745032,-8.526113,-26.245611,-28.438487,19.435428,84.02454,147.114129,-7.897907,-85.829176,-143.16078,-146.865461,-138.031899,-118.431786,-65.401791,-54.764916,-77.404464,-103.004289,-122.925676,-176.596658,-184.022047,-129.132081,-81.130985,-20.755035,-58.339234,-101.28113,-170.710345,-182.562443,-140.670398,-71.552286,68.697996,72.989991,-5.294357,-51.501254,-78.74995,-110.606023,-76.785228,63.905197,122.552349,88.693745,-41.890474,-69.285352,-107.88937,-132.370302,-94.95278,-34.457263,75.361447,90.286063,-3.271089,-142.842353,-185.351627,-234.513739,-252.858907,-214.061149,-140.287205,-51.07691,-176.387725,-243.399849,-270.02226,-242.955976,-124.161336,-33.780492,143.229305,177.359851,92.302884,4.118666,3.855771,47.801588,73.459147,117.346254,124.726705,38.687444,-77.834444,-63.300917,55.762827,93.356673,122.268654,169.913782,330.388945,360.401786,227.512547,-8.378132,-97.64957,-92.052299,-0.72754,179.513981,224.689705,248.754125,234.294571,214.390842,148.052623,130.338901,141.782842,148.22818,166.50034,176.281624,120.984336,-12.519559,-47.072196,24.980463,89.904109,154.095754,188.248906,337.838206,402.934091,372.021225,319.914416,334.195907,395.792359,423.606478,504.425727,542.422813,486.565955,327.706029,289.270354,285.078065,282.305956,284.433587,303.734301,273.397554,129.745483,86.474025,30.796492,-2.139946,20.946177,86.466787,240.284698,298.384961,362.013252,343.991238,285.616328,183.974886,188.735772,210.528178,159.191934,-34.919531,-101.233779,-85.27343,-109.450153,-123.445725,-4.092842,75.918325,47.098669,-31.402207:74.703155,80.987541,27.585066,-118.995096,-136.571515,-59.413225,-6.71867,67.053684,68.163211,68.721281,62.960719,29.599083,-31.056081,-18.253168,77.383096,118.708712,102.0123,-11.706429,-46.880945,22.542558,108.811277,244.392997,271.946242,292.602217,303.120021,287.666434,176.220462,120.026185,140.624312,218.515278,362.681447,367.214771,253.671773,139.182867,93.074523,8.151652,-10.030449,4.67019,17.87343,-38.319576,-241.842111,-331.536395,-373.075902,-335.402703,-211.281739,-150.802273,-87.030656,-76.754698,-78.508378,-197.632426,-306.889712,-426.491169,-359.199219,-143.238606,-109.393259,-139.892384,-161.157053,-192.942625,-233.6227,-197.032794,-46.677132,24.56978,117.344796,127.68113,39.258308,-134.759893,-211.975551,-276.096815,-231.951037,-27.237337,47.689801,-4.377952,-149.553712,-171.53224,-157.953803,-158.889983,-121.943579,-69.15906,3.67732,2.768151,-41.38531,-158.403203,-234.63141,-298.039312,-280.965309,-265.783327,-280.348487,-286.077426,-236.546033,-241.452237,-370.810515,-434.964321,-393.430957,-281.23604,3.360233,97.657193,105.918462,46.887883,22.642823,-41.785739,-45.049181,14.225855,22.344805,-26.580715,-28.543873,-13.497377,-59.816237,-96.719,-57.837495,-24.964734,-55.073296,-83.832781,-108.888026,-131.686159,-156.912901,-197.261677,-192.816722,-144.270124,-106.090817,-76.665383,-213.112104,-291.972079,-387.863325,-403.375896,-331.72645,-272.192885,-214.22635,-204.927836,-201.189635,-256.415592,-284.971962,-217.485467,-117.708896,14.222784,12.773143,10.303674,9.159719,-21.905438,-67.237127,-61.608417,-34.675377,-14.822037,95.0718,170.98294,241.178556,185.030601,136.129073,62.360978,69.537012,170.889868,225.486179,228.664239,144.538413,110.953383,21.688571,-36.574522,-84.626269,-55.710391,43.952405,74.908459,80.052628,79.729647,73.926168,38.072722,14.407193,10.406573,54.875823,126.695081,2.183951,-102.328512,-262.855512,-280.913293,-233.358142,-201.104762,-66.995192,17.606121,25.299801,-152.192307,-209.299084,-162.237757,-95.707175,-24.761059,-24.111634,-5.148394,9.826004,-6.090208,-86.347749,-126.661775,-93.174057,-28.987128,55.301472,42.237905,-80.016144,-162.402382,-157.331427,-127.615781,-96.277969,50.364597,130.749157,160.987728,50.719864,10.276977,-52.479355,-96.122385,-114.091874,-52.186062,148.314104,222.745119,205.864517,76.203231,39.472326,36.586327,34.993757,24.173901,52.132498,154.951174,144.336534,89.916419,-5.78929,-27.493869,-31.263664,-8.753526,98.101195,149.895981,119.799572,-56.279389,-129.620723,-187.16676,-176.181538,-116.900755,-89.282099,-56.202601,-84.480475,-129.284339,-249.227005,-290.378996,-265.236478,-213.053127,-96.917907,-57.155825,-103.132017,-272.27114,-337.701738,-360.252082,-307.66418,-137.70124,-79.848055,-103.021009,-162.382545,-151.96111,-129.581213,-136.67244,-147.980415,-142.590037,-113.684578,-98.064865,-65.860154,-22.416286,-34.148098,-131.165117,-147.547924,-32.167248,53.203348,117.612625,7.826163,-55.910339,-109.160103,-99.332728,-64.414895,-59.00119,-29.041637,11.708003,54.360069,-14.63404,-64.453765,-157.290698,-175.144405,-133.016186,-104.742939,-82.73333,-53.436184,-23.799718,-29.147337,-78.875313,-105.341391,-19.71535,230.721318,288.856397,222.905336,82.16727,-1.925806,-110.457772,-84.128322,77.4162,163.200978,236.544834,154.734213,123.187682,96.720405,63.46364,25.838516,60.213839,167.720213,199.670891,179.393467,67.401263,-0.230065,-93.905486,-103.454634,-51.543237,4.334338,95.296507,20.656827,-58.476644,-163.70129,-161.302908,-70.406202,-4.509194,146.462423,201.743379,155.106593,52.834312,57.421179,99.479462,102.385114,127.562857,164.807391,168.226846,43.218344,5.125953,9.592776,25.156158,102.401107,175.580018,301.645449,291.799619,106.006852,-70.453386,-99.146908,-87.998599,-52.743112,121.135922,230.922034,285.818154,114.915979,44.115742,-52.281168,-90.598846,-60.362092,-0.981424,101.355865,128.596291,73.727613,-111.363206,-184.010253,-208.069235,-164.139337,-25.749472,36.24044,91.736797,70.856455,59.801373,51.181789,66.008188,198.239599,305.804923,486.959598,511.621765,405.026592,273.378399,275.263853,369.001216,395.84743,337.171364,287.154535,235.964038,233.61157,255.253423,238.417426,166.236527,88.705506,145.309003,358.823407,442.528277,445.9375,323.761893,271.084853,219.217443,216.965492,197.676554,171.998706,140.31075,90.189424,41.080153,-51.058913,-59.296966,34.96276,96.720002,163.56392,180.317823:31.302224,-39.261098,-83.257248,-116.626504,-83.44263,28.177278,79.588062,102.462417,4.532163,-28.002658,-17.366153,-11.211448,-11.745965,12.545106,137.309325,192.31867,158.831553,9.714983,-45.765247,8.965699,117.985238,287.16247,293.516022,221.358277,184.427897,176.092485,129.770672,127.741571,215.232611,269.166745,313.081805,289.311299,176.346211,52.129083,-8.558745,-84.496139,-74.055601,-7.944141,7.138526,-69.081324,-242.813695,-299.056816,-269.496401,-184.933244,17.638737,81.266148,116.376567,105.206822,35.093083,-149.074477,-259.85694,-338.989845,-287.502452,-117.632093,-32.512044,64.381807,-12.001979,-71.205153,-95.218992,-59.945583,45.875118,116.915002,279.916153,307.394578,201.271922,33.668111,-67.493308,-180.894293,-129.628975,64.511003,129.620645,139.302695,63.019832,29.124543,-87.417127,-154.988779,-119.441062,-23.074327,115.498959,112.351799,16.013739,-75.828886,-117.552781,-194.532159,-215.12527,-212.095393,-206.357247,-228.984073,-268.841649,-309.557291,-452.40584,-498.831501,-408.66095,-268.18135,44.846618,110.404676,57.815489,43.138352,49.627645,42.355122,59.664449,127.115415,140.002474,70.788225,-22.634737,-34.53903,-75.880003,-108.62663,-88.279562,-40.00013,74.765892,106.121723,3.377114,-152.574772,-154.195498,-18.981079,57.497183,95.502007,63.207403,-7.922624,-95.064725,-159.509692,-302.190192,-336.277895,-276.214695,-217.6618,-149.828491,-162.916538,-245.13857,-317.161193,-332.788899,-243.90318,-130.098901,124.311587,197.826325,198.210986,120.77638,78.607226,-11.054566,-28.883726,19.157735,54.804228,168.697103,259.672429,362.284376,255.53649,197.746623,200.924229,221.871548,244.830995,291.905355,411.804634,339.651249,251.103508,130.093774,117.439235,122.948793,115.878274,129.4625,155.581621,153.310897,52.461152,7.326164,42.897275,95.019203,133.97497,131.40766,81.00968,-44.013899,-108.184071,-204.597263,-212.80846,-116.285056,-44.408842,52.932709,65.26443,-0.762436,-146.884547,-190.944475,-148.051917,-93.977573,-27.704897,-25.735979,-48.077502,-66.345184,-86.410792,-117.713604,-84.304747,63.015613,119.605699,152.005081,124.503994,-8.116723,-113.559546,-122.661726,-75.507536,-31.547933,124.749866,237.689368,357.261362,196.886504,95.257984,-23.838812,-53.454456,-31.951189,42.48151,256.317887,332.568039,359.401131,269.577874,208.473659,160.698418,198.411277,298.817659,324.488208,311.645092,217.958362,164.359306,97.250461,105.21843,178.956557,206.619852,269.486254,309.789163,275.234337,86.212658,12.288875,-13.81339,-0.806112,27.646146,87.350358,266.694593,144.159092,-29.004714,-199.571851,-146.42598,-12.657761,2.818552,25.854071,45.80039,-20.529317,-215.669486,-285.628751,-241.052185,-134.751277,63.171397,91.327425,14.337484,-78.038976,-93.271916,-76.4458,-48.529424,4.266263,6.443957,-0.312212,21.039196,75.415788,29.33059,-21.674357,-74.890725,-59.547217,48.1098,129.644252,205.279318,72.699333,-2.335677,-73.506866,-70.188584,-4.145066,35.477104,98.185514,120.078634,103.019225,9.016657,-31.132743,-39.302278,-34.457433,-41.30524,-25.834059,-4.484116,-75.306069,-129.469152,-233.286986,-262.570066,-185.662887,-69.324897,154.983686,177.422979,59.26374,-82.745575,-146.316802,-229.612178,-219.525926,-108.195398,-49.042381,-20.048317,-61.845211,-96.717038,-193.476814,-211.489684,-150.149695,-96.346473,26.489946,62.977767,5.299279,-186.233921,-294.479378,-373.308351,-316.761833,-167.209486,-129.149161,-150.893934,-256.103459,-303.271857,-357.617475,-360.882209,-265.971137,-156.890819,76.40669,125.80312,28.165034,-110.83941,-120.486699,-39.8381,12.406384,91.611913,112.919438,68.653778,-58.175055,-96.709352,-70.16241,-12.865109,140.059761,218.750126,333.14967,332.644787,184.770899,-8.173114,-75.691489,-96.404935,-32.568699,168.998974,245.369475,252.382562,118.76827,42.065813,-50.466752,-50.975128,3.767971,59.325337,211.855897,248.245832,133.840326,-95.675122,-165.908222,-127.461099,-52.325032,87.364762,142.167533,186.947109,114.164032,71.406817,59.839477,97.57106,232.547083,324.596934,514.908069,550.165552,449.447465,331.978161,299.52051,265.259463,273.910877,329.978285,350.923997,291.529344,95.369331,28.974855,-14.568911,-25.348757,51.956145,159.46291,354.598388,362.968347,235.602949,147.381742,128.793685,100.228071,96.626787,86.656606,63.473753,-16.061144,-148.032952,-232.143858,-346.368468,-325.54107,-136.375575,-46.498593,-12.618967,-48.764021:-75.388542,-115.646767,-143.890108,-167.361797,-164.385407,-148.122225,-111.828918,8.361486,9.276704,-35.265767,-56.974899,-30.023463,-4.394274,-4.434931,43.658848,82.11999,94.776498,14.838587,-5.990093,73.611603,151.879993,265.509817,292.408504,356.602618,384.603335,339.833314,214.47676,198.305754,279.918025,327.034352,362.037664,347.348788,244.544213,184.030626,183.428319,108.075905,41.97046,4.272576,53.368818,134.032786,-44.181499,-199.365925,-432.399935,-459.588396,-359.975382,-286.580974,-148.052285,-82.999691,-53.048427,-250.35854,-398.250321,-546.974086,-486.537098,-282.442869,-226.672704,-190.516777,-139.823661,-116.749645,-150.529741,-209.989149,-256.484848,-191.374649,-6.562804,36.520857,-21.074924,-211.152809,-319.947631,-379.835897,-287.029715,-56.024229,-24.29676,-144.195475,-334.993525,-376.513317,-301.985647,-238.366642,-139.792242,-108.658542,-73.277851,-67.070434,-119.91486,-214.790804,-248.084466,-249.94035,-219.909664,-194.44724,-219.686391,-261.258427,-245.131887,-257.610918,-323.6728,-319.791556,-191.763811,-109.628468,1.168419,17.30324,-24.968094,-67.085878,-65.242159,-32.739181,-3.344627,19.975704,0.792096,-8.66936,61.829371,85.864976,70.810451,58.875201,61.958208,51.617514,14.705021,19.466352,59.066546,77.91452,68.278943,14.607494,-15.830379,-44.734205,-24.939346,0.171594,-120.543294,-181.782307,-228.585575,-253.833841,-314.948504,-305.788188,-204.95422,-170.01982,-189.727322,-195.647476,-171.284676,-84.262528,-41.486656,-27.67873,-33.833917,-4.159066,8.062194,-3.748763,-39.752734,-59.736795,-30.833957,36.503264,197.409809,257.818418,327.441744,295.800896,233.345294,134.699995,150.393401,225.621536,226.078529,160.627052,111.798757,110.60857,68.033874,14.121098,-42.871634,-38.223271,35.284085,140.355019,396.594214,391.818146,285.721775,132.127874,137.664839,209.862764,232.819887,213.52368,56.377264,-40.819044,-180.50256,-222.321262,-239.403224,-209.648422,-52.665516,38.571535,30.75272,-143.286224,-166.755763,-55.716463,19.03676,104.634832,131.071193,192.298218,150.106084,81.96678,-4.851056,13.295541,114.881809,141.859866,98.329276,63.344382,71.060012,182.840278,210.067469,150.424566,123.998972,178.00384,237.732056,323.902593,290.81725,239.925461,93.49356,25.531629,39.738418,119.620165,305.630039,369.396966,357.541477,235.272225,184.551421,119.489662,104.019172,144.546786,204.643346,314.381284,261.076679,197.936972,132.610159,132.895128,145.660841,155.716402,209.689573,234.587988,192.229607,94.174077,62.781164,18.331316,-3.040582,-12.782713,27.07206,135.854912,70.782125,11.446812,-7.965711,20.076535,89.892592,120.801224,193.278716,237.469793,283.909961,253.795527,212.568463,121.23975,106.195359,146.267142,157.191713,63.43144,-13.97564,4.345402,29.455957,36.188664,134.95744,185.529403,134.272144,59.311548,-30.572045,1.53595,7.038275,-38.884464,-45.535695,-6.18119,16.207186,-1.892413,-138.426602,-181.040264,-118.278123,-65.869197,-69.445678,-117.565494,-169.20429,-144.054735,-44.965602,-19.208813,-64.929903,-196.605002,-234.182403,-236.570807,-223.377476,-257.332693,-304.729376,-273.409024,-240.800165,-295.410381,-370.760428,-307.044852,-73.959542,-5.359681,-61.675279,-234.320441,-294.227491,-302.412504,-271.362713,-228.839393,-209.438491,-164.38264,-154.967398,-120.641537,-50.632333,-79.872195,-137.706787,-96.21225,13.11579,11.181755,-100.545912,-153.527771,-122.53864,-44.062685,-34.7451,-52.7601,-33.902599,34.457775,6.912494,-21.844296,-85.416684,-123.497933,-112.489951,-45.726377,102.319469,142.218498,107.958438,-23.688472,-81.664173,-126.470319,-103.232668,-20.601875,2.497693,-1.919432,-48.430567,-93.280024,-187.328511,-180.093212,-9.085393,92.053389,192.052949,183.514374,33.467416,-233.054535,-356.088227,-381.75295,-248.298418,66.621117,150.828862,157.704985,-0.001937,-79.644789,-130.067917,-124.190052,-66.841117,-5.494131,92.10412,79.280289,-41.664569,-128.349506,-150.146786,-224.688385,-260.821636,-197.433479,-116.473099,-67.760296,-160.11737,-177.657877,-166.190662,-162.310286,-119.956978,-59.024548,134.095398,214.695285,219.242122,105.250321,65.158842,63.987742,92.847928,138.991423,148.985475,163.128028,149.316682,134.496485,91.755283,68.008271,102.613714,163.949501,275.295954,295.508425,230.141942,117.535054,80.822202,26.659477,12.855652,0.087397,-10.514976,-20.795334,-67.798388,-102.987304,-107.314524,-73.386133,-34.953206,-62.658129,-116.561097,-92.603282:-97.838122,-150.348633,-179.404072,-221.168434,-208.856085,-131.822151,-104.367212,-118.616471,-142.999685,-136.404843,-130.668127,-128.346441,-53.167463,25.60593,188.995623,211.456401,99.303146,-34.925356,-67.753464,-35.742873,36.046664,226.60211,301.625456,353.888841,314.339369,272.29412,154.620734,120.062497,175.349194,247.198383,371.588395,362.06798,197.707852,88.243123,62.413436,-17.353749,-53.471977,-27.252207,37.005017,86.757423,-117.010023,-238.461817,-347.702812,-324.412696,-173.365332,-92.911428,7.606702,23.160147,-45.680999,-202.998617,-280.690015,-362.759581,-336.487992,-181.944782,-99.490383,-15.384279,-79.893492,-134.335433,-198.862837,-199.143549,-103.527125,-10.128097,144.134894,148.966018,39.345827,-102.464555,-180.649947,-248.697026,-171.736723,99.667587,192.480428,185.260614,-12.964424,-104.745396,-177.258896,-177.689627,-122.32687,-61.360504,64.128478,69.484035,-102.604757,-240.899659,-230.183422,-187.402958,-189.454708,-203.642172,-204.735578,-219.59643,-270.952594,-301.553136,-345.653672,-340.878466,-259.402127,-178.365461,60.763381,159.388655,152.697149,37.342532,13.33394,11.689586,41.470474,123.777316,141.866488,129.458305,95.788054,87.599789,46.409998,14.541885,33.033018,77.296656,136.982181,142.333073,115.077619,68.004319,44.086137,20.9376,27.355112,65.777945,108.603604,153.227371,-13.88744,-124.721946,-301.235711,-351.518829,-298.086711,-217.767717,-125.047108,-148.287779,-254.651528,-291.529216,-286.369725,-218.65781,-131.474106,80.985889,146.979318,156.071958,68.653966,20.798111,-10.768715,14.322068,111.116039,174.81821,333.799003,404.766048,417.30083,249.395242,155.486677,105.214856,156.707155,256.712646,272.057726,275.023388,239.433964,191.520129,52.815186,5.389073,25.839874,64.244319,151.579176,203.504015,244.098405,146.09295,79.727343,19.583107,32.91593,85.275427,118.617582,136.917535,12.168619,-86.163984,-267.495181,-294.646984,-213.173366,-155.096325,-22.215457,49.358399,52.98297,-143.799326,-210.206993,-145.146707,-60.13148,95.540592,155.210396,182.260453,84.728396,26.797668,-48.207967,-43.331456,34.42616,62.723707,89.576008,95.605395,43.883844,-7.854543,-6.002962,34.906426,98.528989,300.490127,375.637583,385.281008,251.367461,154.669157,-31.75794,-66.360111,48.622965,143.570176,269.547214,305.89527,376.898479,385.52485,335.104565,196.887959,162.092222,232.739072,328.639179,462.619441,281.305809,144.115269,22.285242,46.91046,158.720653,201.635769,300.267831,350.596259,287.774842,73.203021,-10.440713,-91.041627,-82.268493,6.065631,68.3924,184.079531,134.985208,35.105255,-132.483162,-118.011187,61.143113,129.912854,170.932547,183.479676,164.738561,12.657993,-65.579692,-90.577046,-34.272403,142.161307,219.072623,202.883333,15.563297,-48.888009,-85.732253,-58.318373,76.159684,134.54395,157.538848,146.230488,129.405731,87.623714,52.10646,-29.84643,-57.443922,-11.148553,79.770901,230.412034,83.341862,-41.393691,-189.039476,-201.529452,-146.320803,-84.04991,82.900088,142.708203,128.884608,-13.824485,-94.953102,-190.809569,-185.590929,-130.474295,-111.390311,-121.026796,-184.909507,-222.342993,-300.159148,-327.99549,-281.683099,-199.667585,-21.416382,24.175275,0.656126,-145.790954,-223.755582,-261.858506,-228.616598,-154.438252,-119.785365,-75.759315,-106.842195,-117.913722,-158.801287,-205.26921,-218.950793,-164.926436,-74.008389,-69.827431,-127.149086,-241.30823,-300.451106,-314.487481,-241.045658,-44.323946,12.962983,-26.934767,-223.090791,-313.774769,-387.873636,-376.139724,-269.44749,-178.304903,16.539037,84.392708,87.128326,-105.925381,-209.925073,-232.309196,-142.045511,78.763972,144.759036,102.722242,-91.868983,-162.931837,-188.786851,-146.617777,21.071758,118.590319,276.457784,299.900017,192.473526,-5.083481,-97.740965,-161.77828,-104.691828,100.980457,199.44775,239.680719,14.044515,-102.202937,-190.266382,-176.211484,-81.488596,-14.790506,98.780044,112.509272,13.731089,-164.495167,-227.44856,-234.585521,-193.574686,-101.958969,-65.557463,-41.335637,-95.498633,-131.862172,-183.126197,-178.834545,-39.924712,82.026712,282.34319,307.338537,224.973625,157.450219,154.256047,189.568656,229.043988,293.250761,301.046745,271.766786,167.354532,110.320022,14.871361,-14.284295,59.420581,164.063696,345.051631,347.834182,182.886406,0.788837,-51.887353,-56.52322,-19.3682,45.161036,51.286615,-28.146389,-233.450755,-311.974312,-347.985835,-330.824533,-209.257076,-116.984854,-11.368057,-20.174051:3.897616,-30.732585,-37.885011,-33.863889,-33.476959,-35.484247,-11.67205,71.655334,17.157902,-33.498749,-39.758909,-19.451474,32.632918,85.089768,203.412964,238.162045,231.463167,138.467967,80.442957,40.587506,82.500084,210.945288,273.571819,375.58043,328.859191,261.02294,157.678132,159.498988,269.495854,304.228618,218.745498,150.215351,85.38197,90.07327,72.187821,-23.689907,-48.951608,-0.835126,29.199543,41.685529,43.648593,32.440922,-144.000428,-277.856517,-335.25084,-249.445214,-109.5415,-94.002284,-127.529014,-270.237975,-346.738078,-355.582374,-296.804696,-246.883368,-272.276527,-270.56628,-156.401498,-108.344088,-144.382663,-220.092769,-334.391598,-321.999855,-160.920195,-79.837739,-106.804518,-315.266708,-405.380665,-507.538176,-521.207434,-431.49559,-341.667181,-229.807148,-288.628741,-323.234539,-326.388769,-314.060722,-256.571808,-210.603544,-119.889191,-91.086736,-166.318334,-324.801418,-340.096509,-255.083555,-207.093786,-155.506513,-139.162611,-82.805461,-84.23114,-120.682159,-152.652467,-121.918534,-31.022348,6.563394,67.263178,80.583309,80.122974,80.182792,56.528088,-7.313155,9.378722,118.13575,149.728405,159.030338,157.648073,145.779931,78.61828,52.328908,69.357399,61.567475,-26.731729,-42.908654,14.11432,55.689029,48.438113,-8.167885,-56.918974,-144.409704,-135.743434,-43.009893,-76.365596,-153.025565,-292.35065,-323.80044,-276.608907,-214.102261,-132.110597,-130.803941,-183.528746,-224.072587,-214.977098,-188.733864,-188.719779,-234.566177,-270.819347,-312.922954,-308.730371,-266.576467,-115.433379,-56.755182,2.41418,35.247666,132.413378,170.139916,205.345331,206.95851,167.351046,50.160351,10.357645,-73.085518,-126.545364,-181.84422,-141.603477,-101.649028,-101.936423,-156.515902,-217.459988,-173.340487,47.575662,177.713319,315.36096,227.262012,158.541354,132.389237,173.882173,198.687368,143.930851,18.176448,6.625531,5.582082,-127.886653,-237.630104,-315.832533,-245.526328,-30.315651,35.196339,26.500408,-44.899261,-76.40607,-98.438312,-64.844514,23.277985,39.346549,31.02724,-57.937069,-113.129325,-156.245189,-125.689216,30.638423,89.490602,41.541991,-20.4856,-41.02479,119.137837,185.124334,164.068984,126.700224,142.195526,199.854162,290.409157,219.770844,156.417585,27.467186,-47.483708,-146.473682,-121.860599,62.431909,157.743562,225.391233,211.68224,197.384899,143.084868,129.349605,147.143829,169.594972,197.900807,105.496587,42.134553,-39.705527,-57.19698,-12.233711,39.123917,123.479216,140.251602,85.674898,-12.06907,-20.368174,100.932571,181.909494,166.107368,100.554923,108.610263,141.762723,97.663367,95.915157,160.917263,244.391087,248.067808,284.436714,324.307435,436.536318,540.86016,523.045016,377.213617,317.1696,314.235159,341.511813,314.803364,227.110897,209.678361,209.519143,221.807098,276.6514,304.467842,309.113746,276.184411,184.251355,129.83416,110.241619,92.585031,104.068561,125.960784,126.980973,132.885472,88.026645,34.284062,2.914084,55.955233,180.29297,207.157101,201.634222,199.42011,235.686533,233.241239,161.318811,-58.537533,-117.888332,-87.290218,-56.380626,-83.96421,-154.547385,-149.771951,-125.040296,-138.629461,-95.046493,-8.970462,130.494423,140.418175,84.482193,18.497732,-8.67352,-60.108236,-81.722348,-114.506177,-111.879814,-42.584216,18.632915,46.466186,103.640711,101.576674,70.044074,71.062668,89.911047,87.539192,41.53419,37.80159,78.072388,154.489105,164.224242,162.65606,166.994689,172.062848,140.438516,106.28,25.285345,-3.198359,-3.052875,27.409477,111.600248,139.731432,123.10409,76.169424,51.453822,-47.939424,-88.014801,-44.93039,19.259765,102.854334,40.177194,-9.114566,-69.141635,-65.109379,46.122508,124.310946,208.03875,179.055863,-39.742136,-269.577593,-311.039817,-242.282612,-160.826607,-24.710314,1.865973,11.134451,6.350687,-6.838108,-102.197903,-163.45042,-155.926285,-96.830989,-14.884688,-6.732651,-51.979661,-178.842298,-235.918613,-240.572355,-201.402291,-154.388514,-166.045525,-230.295232,-253.537662,-246.966315,-299.163885,-350.966337,-346.425664,-274.420681,-91.062656,-14.628257,45.728037,-6.24315,-43.979641,-83.364803,-76.246274,-28.237217,7.504067,90.885549,114.457786,111.604868,81.649412,36.032113,0.992409,43.350176,101.116212,70.975404,-51.930311,-93.632799,-57.009428,41.309592,49.433015,-72.768118,-146.465472,-123.185326,-7.295492,14.688789,13.047107,5.664539,11.727688,15.256486,-17.333781,-35.519899:103.268633,106.955339,80.763633,2.01672,-13.226322,29.953968,57.152928,88.62091,108.110105,126.801168,161.881391,149.523885,85.155154,78.311407,152.74567,187.970525,156.694607,111.978716,128.284329,202.500702,240.492994,290.161404,313.873734,355.052256,287.909191,240.827246,198.958648,209.493055,283.525117,303.50817,254.31025,226.525259,224.641906,234.736811,214.198991,37.00334,-70.524008,-77.362777,8.964957,126.805664,50.872352,-34.565231,-225.607937,-295.057074,-313.684776,-277.593079,-181.48706,-140.013779,-115.441601,-209.155252,-296.566626,-402.414115,-375.156441,-270.967422,-241.225634,-203.540687,-152.387671,-131.28999,-128.224042,-146.472278,-165.886369,-149.055891,-76.552598,-42.478432,-74.176584,-263.330615,-362.465979,-418.063314,-353.786775,-167.594366,-123.949853,-203.882358,-327.177146,-322.285308,-236.26851,-213.591503,-197.965422,-175.243936,-103.495505,-69.242757,-86.534254,-197.854529,-220.246649,-195.123947,-164.934249,-32.791515,39.48816,25.136028,-113.915914,-137.908834,-118.281474,-104.57081,-71.82913,-59.959583,-45.918172,-36.965331,-40.344332,-80.651455,-110.101176,-148.846426,-131.592305,-88.236043,-104.760172,-118.535094,2.55625,59.38187,80.781396,70.168695,53.459961,16.807665,-94.080061,-91.952076,12.21706,-9.797418,-75.291147,-214.523284,-253.361486,-228.789463,-191.632417,-155.224269,-192.884111,-219.18548,-254.701634,-243.873551,-166.684451,-150.438847,-171.795367,-165.175771,-138.905739,-126.996092,-109.015408,-96.399112,-132.920311,-270.080239,-313.889215,-296.378207,-234.020122,-204.195332,-174.697863,-163.048545,-91.638955,-42.084874,47.04701,88.640386,173.784368,232.774695,220.996405,120.402948,68.137149,-16.510946,-55.631458,-110.489757,-111.8048,-94.148877,-92.725479,-118.330676,-127.318468,-89.794936,34.143936,113.098786,309.868382,388.583476,317.263428,139.738027,123.950979,171.889818,173.144355,111.072222,5.414597,-62.044427,-201.859105,-248.198809,-239.755047,-195.611165,-84.767384,-36.840535,-16.141347,-81.468502,-122.097803,-215.879837,-240.842464,-195.440742,-144.076795,-16.003546,43.465852,20.492438,-53.806271,-43.072927,136.486766,233.915126,242.803982,173.46313,57.776456,53.367806,81.427434,133.052979,140.002681,162.759444,195.33691,207.924031,111.898707,56.916273,-90.398924,-168.804126,-190.660044,-127.080329,59.848574,145.248575,154.08416,-1.297208,-58.963406,-109.763409,-110.151886,-96.757817,-76.487779,19.110492,35.733303,-9.810974,-83.844275,-77.779376,-38.740009,-29.348641,19.828534,55.918396,57.438596,-24.525648,-60.460017,-67.827137,-42.093539,-21.863033,-35.680756,1.434746,78.891071,77.301802,55.027824,69.154853,107.762382,111.454723,139.566633,169.723557,247.767278,360.587983,372.440073,253.052149,195.796157,201.766752,215.321914,144.814187,45.066926,29.573468,15.821518,7.002009,11.110541,8.721062,-4.480654,-2.244974,10.669296,45.258101,50.824782,25.860841,10.622977,-16.773138,-16.37714,5.155724,-87.126157,-161.18203,-200.196426,-134.818825,52.114918,95.712205,125.089778,150.4324,161.540457,121.553375,70.795896,-97.695008,-151.754868,-142.520788,-129.879416,-169.088536,-230.148977,-226.095328,-172.010799,-161.459537,-115.879093,-45.879551,85.672825,105.059221,88.053916,19.562405,-25.133874,-55.36139,-32.286194,13.059351,15.17825,25.566465,115.379337,181.589087,241.836193,213.631011,158.405017,173.092269,226.736275,227.160015,203.754716,170.509885,131.726179,97.275246,126.505344,178.998836,174.636164,129.316274,83.906382,102.092057,206.326825,243.165687,251.735143,240.741203,217.707154,210.62331,198.177912,182.660718,161.217537,57.209519,-2.659772,-38.320404,-8.572036,85.117432,131.770361,114.85753,21.936898,-17.273727,3.938629,50.505362,113.690002,89.342261,-100.233857,-316.750185,-378.795329,-343.440654,-233.088544,3.228746,50.142384,25.929873,-9.507507,-15.750214,-26.794645,-30.20203,-17.785027,1.492767,101.046765,163.534563,187.397618,122.237942,104.713696,75.150338,51.209982,38.598912,65.113176,104.279583,40.230241,-9.530743,-78.876823,-81.977098,-20.6565,20.909022,124.431436,191.534705,220.408706,55.748248,-21.009659,-56.812808,-40.624969,-27.576509,-8.330726,98.007815,126.825849,95.154299,27.94849,-0.526536,-20.102151,-0.758255,61.582549,85.151103,83.290521,42.472615,34.423657,45.741219,37.656252,-45.75507,-84.145602,-80.322929,-56.458493,-42.111138,33.504194,79.752916,111.236072,88.310793,51.591961,53.421841:10.046815,14.592501,-29.770515,-72.55423,-52.74249,-22.389172,-46.02057,-106.392739,-7.634727,62.924706,64.369793,22.98961,30.634229,84.839547,205.396055,242.763234,229.765896,162.18182,124.728886,47.116061,36.697966,131.686595,225.994427,394.057912,383.892459,324.117644,205.361298,173.77123,178.85093,202.564773,250.509259,233.68716,83.321423,31.200127,59.644662,34.603643,-7.016146,-10.099344,21.038599,38.781151,-66.553721,-124.728641,-158.656612,-146.319847,-120.388831,-106.892555,-56.055924,-1.479876,108.075121,15.227376,-76.710321,-121.579964,-72.813171,-68.186821,-147.495728,-254.714875,-141.501168,-75.706763,-73.619156,-129.887005,-222.51891,-207.522165,-72.388131,0.844143,24.232922,-180.614916,-302.178748,-417.991671,-379.063248,-184.471984,-112.575061,-109.707995,-261.223251,-332.019989,-335.553884,-310.711027,-243.098188,-160.866213,21.508226,47.072588,-68.082881,-196.341249,-233.181219,-297.54229,-301.983473,-231.666997,-187.987493,-128.152258,-108.012278,-126.311072,-207.194005,-225.069296,-163.386319,-107.008751,-10.09703,12.71107,42.647578,112.814422,122.10102,78.830962,74.998018,100.945748,100.538322,93.287979,116.305114,140.931176,142.818674,106.77427,41.014611,22.637477,-14.441458,-32.047847,-1.099362,132.837547,156.537446,39.653793,-36.727312,-68.245127,-21.002889,49.016724,-28.269423,-77.668106,-176.635643,-224.692043,-227.84767,-199.051222,-206.499604,-233.239028,-230.233284,-183.216266,-175.604802,-151.124739,-129.278771,-121.682059,-112.684565,-18.202875,4.742279,-21.817342,-17.169315,17.760325,120.206604,165.905918,180.754466,178.903269,228.025346,206.13834,146.455627,47.735118,43.945191,43.353233,5.597829,-56.747196,-4.039526,31.489269,-18.292865,-97.808236,-151.948662,-92.580615,97.122361,187.718099,277.886876,196.115241,127.195147,73.110581,94.218078,78.532772,22.500133,-33.465468,-37.184164,-89.739623,-233.606589,-278.49494,-331.144787,-327.092392,-171.640633,-61.682335,28.431928,-30.742275,-77.093228,-127.185547,-102.837893,-13.567669,25.993027,65.315668,-53.3482,-127.501648,-116.736582,-71.087339,-45.227593,-46.810506,-22.96935,4.963736,68.349372,91.919835,79.149247,62.47033,107.136807,248.691266,266.552162,185.842747,99.300638,59.203896,-36.135218,-65.894996,-17.873855,41.492136,140.814081,176.105406,245.336571,242.983013,174.034422,13.358528,-0.693898,122.35721,212.23229,255.974668,61.722112,-16.199931,-68.615425,-86.206306,-80.260174,-43.654866,65.365401,99.576196,41.224025,-39.903219,-43.387463,-62.966719,-86.022947,-56.421782,2.222544,115.78525,98.235059,43.272143,2.997709,33.049858,86.519425,114.275949,215.06757,252.297207,238.454949,186.352568,165.012767,131.137337,132.283872,221.942032,289.824399,306.303358,186.432113,161.811963,172.87435,196.152019,268.222027,264.344041,179.147256,159.749774,149.71609,77.64477,52.964393,29.053629,9.247969,40.379274,115.058557,205.00815,41.291207,-58.00476,-86.618468,-41.788274,7.931107,18.98128,79.8366,117.068473,152.859966,104.73103,41.409576,-112.915737,-158.913544,-147.045639,-107.422213,-71.936847,-116.168978,-103.82327,-120.469788,-199.905153,-251.203844,-156.66541,71.014471,119.878559,107.224407,24.237325,-56.591267,-182.719459,-175.047336,-91.287241,-58.051433,-13.066537,-33.031232,-64.505812,-108.216211,-94.299793,2.999426,24.585341,-30.960309,-59.198355,-86.821812,-109.267022,-105.733569,-58.270194,-42.523205,-34.926718,-14.904478,28.846377,-31.91102,-80.276735,-128.074939,-135.544705,-125.859921,-98.66269,17.064526,100.537636,160.379747,1.822297,-72.988434,-120.086855,-92.469747,33.920787,85.122741,57.613773,-22.939987,-43.370802,-108.323474,-126.921188,-8.917264,99.079261,220.264858,195.700908,18.125949,-136.29534,-155.54977,-104.399513,-51.649111,39.260647,69.861424,102.933805,40.865627,-11.232219,-105.444612,-127.441941,-71.132104,-7.967177,101.433655,109.527459,2.556183,-131.381233,-180.219048,-275.841196,-311.282169,-318.677364,-301.180753,-240.682185,-164.492259,-155.89707,-226.681885,-265.753625,-248.846518,-190.490346,-10.54897,69.978381,66.407965,6.099629,48.608774,146.792367,146.072804,117.213376,132.653761,202.055254,179.378009,133.903005,66.145916,64.718048,172.992355,259.746939,323.124432,265.539991,64.686154,-45.280473,-43.389192,-17.290765,-21.190044,-74.013212,-97.624319,-96.327712,-93.796555,-94.792471,-113.275179,-132.342286,-159.216298,-148.801723,-69.219579,-36.177265:forward
119.577281,147.507813,171.906981,218.977282,221.703932,174.932412,145.809476,67.916248,-26.774309,-50.03642,-67.078042,-84.979746,-161.286769,-195.773664,-191.275024,-173.164348,-150.922908,-103.161373,-74.401858,-44.070973,-39.10363,-13.589462,0.007741,-65.472502,-183.32783,-175.057136,-19.425834,71.314289,184.935381,204.395795,203.793156,206.10528,280.043875,375.671803,369.861672,295.57944,258.157655,158.678346,87.568422,-30.053354,-57.016801,-56.447522,-52.291348,-46.060129,-49.035608,-54.616965,-59.921328,-76.30255,-129.896131,-197.785348,-229.620034,-218.773387,-183.977062,-142.901273,-157.262768,-219.253787,-201.451339,-162.221901,-61.844556,-9.949642,-0.321902,-40.177688,-60.027185,-46.807516,-50.54415,24.673534,81.917661,89.274957,33.141035,-66.039792,-72.164684,-81.414618,-92.397423,-37.167994,146.863987,209.177562,214.192654,182.257969,102.107258,47.529957,-21.351416,55.394751,106.251801,167.416901,171.453502,155.686007,153.397337,138.149815,148.042389,167.274044,160.62009,125.870475,52.98425,52.750494,72.813781,29.345161,-121.173373,-192.045167,-176.927545,-29.451309,43.202371,16.476289,-52.026813,-141.274319,-100.920926,-51.300559,46.14243,91.057749,106.83505,46.64545,-118.795437,-147.800975,-62.301435,-14.655902,-29.944382,31.272485,96.176404,100.952886,51.939471,13.38636,112.661507,202.260092,368.426988,399.608675,360.18111,328.209389,256.847754,188.810856,20.856952,-16.717817,25.149555,112.951539,105.662061,-20.905078,-91.177859,-182.197699,-194.508715,-158.620746,-14.579538,57.293109,56.642563,-3.746294,-78.135615,-90.729996,-132.947301,-171.649246,-150.874758,16.044883,96.091338,79.852667,13.357408,-81.964851,-72.962814,-78.773406,-173.792967,-195.181072,-94.215785,-36.091962,-41.163907,-93.38151,-171.418799,-97.602792,-29.619959,45.019873,26.86539,-64.946396,-117.443522,-230.612862,-266.116854,-246.712357,-180.444676,-128.319293,-37.995157,-23.802882,-8.284271,3.554245,-21.696018,-74.600528,-46.671076,88.908387,117.369066,36.563771,-18.097948,-64.80533,-15.865967,35.32134,99.043278,87.061291,3.267761,-35.820811,-90.400568,-134.626611,-215.781204,-200.582044,-195.273792,-164.671627,-129.505354,-93.219668,-80.237624,-88.14085,-185.775669,-204.376569,-118.648616,-56.285551,-8.228131,-27.564197,-90.157024,-116.149462,-102.357296,-31.516675,-20.087741,9.527463,59.612082,169.345425,193.599067,216.2745,249.998318,236.108032,177.283071,172.429824,180.346821,170.981686,139.783268,121.289155,88.69166,138.131151,207.700713,317.388968,295.487447,140.252454,55.424408,-82.288646,-84.327629,-46.442458,-27.979214,-60.189882,-172.051405,-225.621134,-267.38255,-260.535236,-239.686847,-204.334449,-142.563892,1.510776,11.320951,-50.716748,-61.80584,-34.72997,27.574167,34.058261,-81.90827,-149.591134,-169.71727,-154.16134,-129.820245,-92.448882,54.649272,166.229828,171.780704,148.046757,119.524239,-23.607142,-104.866262,-200.484978,-188.599669,-142.509911,-43.992589,-23.867233,-40.969861,-53.675595,-40.857007,-17.724682,44.935443,88.552577,110.41536,160.929127,159.71521,152.130539,168.115084,149.514588,95.156708,98.488849,143.18654,161.836259,103.64833,23.71347,-125.930832,-153.721365,-95.399315,17.483165,70.611129,159.444381,189.974762,205.206337,163.058975,-24.795969,-128.092434,-98.590309,1.560874,9.294324,-89.276008,-144.657491,-172.827684,-146.232281,-10.000604,121.058619,146.308668,151.026848,118.025265,-26.042301,-89.870572,-104.194674,-64.412844,-93.235907,-214.294465,-250.413051,-250.41346,-245.609052,-328.638857,-414.175986,-461.553393,-243.583008,-147.634858,-115.407982,-128.666773,-122.298916,-122.682232,-215.690871,-378.368451,-413.915821,-312.374122,-202.643785,-77.163133,-122.474812,-288.655369,-314.121672,-211.417324,-78.823687,-43.391453,-8.166777,-9.672284,-58.233347,-95.630577,-167.297757,-225.607853,-267.336191,-307.065748,-255.273821,-98.860167,-58.848677,-64.995924,-98.614373,-173.50229,-169.362135,-154.721316,-187.739266,-225.147929,-225.051252,-187.311522,-151.332186,-141.949324,-113.718266,-55.498557,-48.360531,-84.85025,-109.444603,-146.991238,-172.311504,-206.839387,-171.400588,-140.3673,-99.800701,-104.304259,-152.861295,-205.90998,-373.262457,-447.086386,-421.166424,-359.40466,-342.230519,-296.125867,-263.729116,-233.629448,-251.503836,-280.119986,-208.086622,-142.769929,-22.617923,-4.816512,-38.874416,-43.227421,-12.051728,-22.636144,-33.786356,9.721722,42.561068,19.454904,-30.44831,-99.183067,-104.113226:176.22677,199.387096,198.101111,200.901873,215.736047,223.326285,199.490655,90.703143,34.641132,38.353627,-29.429282,-96.425116,-155.128873,-136.620729,-112.386983,-120.025843,-98.313795,-41.303981,-3.000953,96.378366,116.335834,45.190191,-22.258329,-148.817826,-134.957006,-69.075449,51.94402,85.57712,140.722162,166.849049,174.011954,161.16381,209.25249,366.937426,421.551064,391.588044,319.00112,160.064986,95.162163,3.456879,-27.28667,-36.197156,-42.507906,-21.610347,22.544092,0.764385,-124.90819,-176.299068,-197.789961,-224.593735,-241.87321,-213.90205,-205.333677,-280.535138,-323.433754,-341.647048,-299.826861,-250.746245,-90.738379,-42.879754,-127.668675,-192.362021,-191.924436,-152.242844,-117.893993,-138.492971,-124.130825,-18.794798,26.366461,19.647406,-16.460795,-73.801178,-7.605807,83.220378,227.684926,225.387402,151.66373,142.829752,150.632921,125.433039,65.319691,96.699013,138.65907,182.55033,158.203447,98.290817,85.112182,23.852566,20.109931,77.946993,158.754381,134.069876,48.012745,43.019048,23.289784,-38.009102,-122.532964,-52.779051,5.373673,125.888265,146.88342,55.038994,-12.64225,-82.761203,-40.469553,10.826268,93.251572,107.809405,86.245131,50.298189,-57.175975,-110.90139,-130.953715,-17.881478,41.402605,106.831882,100.955814,42.51159,20.015677,-30.825896,-42.553133,41.207973,317.893032,392.839799,316.88239,231.83069,92.019455,31.121622,-87.177992,-121.292678,-92.35123,-47.780843,-71.305902,-190.090401,-255.060208,-283.178139,-140.377132,-55.183954,64.65373,79.071294,26.760132,-6.553209,-67.980303,-108.492821,-146.94471,-48.753461,26.969331,118.568833,119.864122,99.819331,77.124864,-34.577765,-109.887427,-79.114613,69.493539,115.935261,61.581222,14.023442,-13.769803,-19.663224,-46.482803,-42.767469,-16.92528,62.623992,85.063284,27.861831,-59.177019,-240.550853,-239.0439,-173.027147,12.98262,98.940972,149.63442,114.864465,5.95352,-36.988565,-51.735461,-17.613517,17.250762,94.025764,87.540373,27.108686,20.724805,3.760011,-45.438579,-30.582959,68.592098,104.209299,62.753324,-10.751692,-124.913899,-109.673539,-34.135422,-93.787588,-120.85808,-63.168094,-24.252379,-39.525483,-75.253501,-145.953721,-197.951225,-196.223315,-103.679753,-39.74862,2.555237,-18.422188,-88.309472,-131.212902,-184.913379,-178.410915,-165.390845,-105.048152,-64.16577,-3.79454,4.776839,-17.778379,-2.888214,23.935934,91.198411,121.468085,89.784513,34.29991,-19.596577,-2.245662,61.820916,110.348924,139.283246,190.112338,155.922757,-49.267337,-143.702648,-157.194563,1.066277,43.697907,16.310547,-4.882904,-78.480391,-153.972483,-310.589233,-341.754679,-287.053919,-179.506198,-113.741176,12.423379,27.015893,-25.767842,-32.85162,31.481703,59.775099,34.567086,3.960572,7.059973,-32.184935,-69.904752,-99.369948,-62.512901,99.536235,190.570347,181.891346,146.866169,130.954248,66.975568,22.95818,-74.469996,-92.701883,-43.910225,53.595597,71.378277,59.082729,19.666016,-112.706714,-151.326344,-55.122087,100.531602,126.24483,121.682263,117.450621,106.385971,94.78496,64.280116,98.055359,141.415908,186.28642,174.428072,100.088561,48.052114,-21.603717,-17.709702,49.170917,110.598145,144.425385,266.375873,307.136132,226.1114,139.298019,6.734585,-33.631304,0.305269,154.029353,193.878383,70.151636,-35.550376,-166.676238,-175.551331,-73.01748,106.6294,171.049373,170.688363,92.092342,-138.893861,-213.051991,-186.121191,-102.298485,-123.48994,-200.146713,-190.05833,-135.677127,-126.804598,-139.501705,-158.298889,-208.375364,-219.646874,-181.00275,-93.336881,-92.983696,-143.377127,-169.505161,-250.552642,-330.130868,-319.434811,-164.881377,-75.940833,-36.906993,-65.948673,-111.823557,-128.312935,-123.612031,-18.987479,44.386453,73.919171,30.892411,-66.729238,-104.219827,-176.267923,-193.347089,-191.573779,-185.569814,-149.785515,-62.458854,-45.646532,-53.29137,-62.115832,-72.0755,-90.014164,-96.659294,-120.796857,-168.099278,-261.659535,-245.986119,-156.518505,-127.105589,-117.463428,-79.711209,-79.31179,-149.169407,-175.047625,-162.429116,-164.129409,-201.969421,-191.804342,-155.577344,-102.139526,-125.546712,-239.017333,-298.367668,-369.457938,-334.086261,-316.900558,-336.971415,-339.712237,-315.816583,-331.109868,-396.899686,-397.324846,-327.585157,-257.680247,-227.233136,-125.44121,-76.910867,-82.014129,-109.60728,-90.998882,-18.486132,0.680498,6.636248,-3.89586,-107.068773,-196.97157,-336.282786,-352.347338:50.638227,88.138609,111.370796,160.980572,180.15363,123.836292,52.118194,-40.713082,-2.715602,0.227653,-91.74607,-136.387808,-152.64118,-162.568655,-241.701559,-256.385163,-132.80691,10.146762,38.992496,61.485335,55.865741,2.51404,-33.761631,-91.5998,-58.17665,-26.587273,19.338264,55.164321,140.091071,164.593177,177.830542,194.221577,295.512074,342.504512,307.962986,248.138155,235.317936,139.591246,52.533963,-70.294285,-41.585154,-12.060891,7.011116,0.835387,-19.894854,-47.5259,-144.996603,-177.528965,-212.640476,-267.752425,-255.856629,-173.130199,-166.668668,-265.166875,-326.563282,-355.271731,-250.490804,-179.787687,-49.063218,-25.169212,-126.150877,-189.798677,-194.79817,-157.478077,-56.090185,40.69545,55.3993,21.121452,-13.392535,-103.034662,-156.240763,-201.488798,-38.37954,77.877787,217.529978,238.700245,198.519034,144.687041,27.597998,-16.090697,-15.467828,45.42043,56.764211,61.278455,69.18565,80.157072,56.075404,-32.799637,-17.360215,33.119938,160.200532,205.725583,156.745443,81.1383,-32.619689,-45.785511,-2.724909,52.30217,91.323774,153.487071,135.149429,59.701756,36.915813,-9.621543,-3.850852,41.168948,116.763984,131.661167,147.858473,132.219311,27.338903,-21.209704,-10.954962,51.065943,74.868604,131.343721,135.613588,46.307917,-20.130293,-102.379684,-13.213909,109.144671,340.398038,348.608681,137.716113,14.993276,-101.565897,-120.405947,-175.352981,-187.341585,-151.44799,-88.716365,-98.063467,-188.239767,-253.260972,-308.438447,-163.053409,-57.121478,84.505379,104.862219,85.575223,50.147541,-53.446411,-84.228149,-60.608312,9.014874,50.634154,124.992031,139.648463,105.202541,64.035455,-1.495259,6.796839,32.757232,66.638087,49.059935,3.0392,16.973585,61.053485,62.700988,96.283598,149.642143,152.448638,114.962821,81.014646,-6.120667,-56.901572,-117.127929,-84.600067,-40.393743,113.240842,184.092333,190.782253,151.009866,79.161813,56.623058,74.809178,116.882176,127.283254,150.206192,150.157198,114.095453,98.586647,130.080569,168.526123,143.925858,112.206381,145.811527,165.198486,106.57292,-27.331192,-65.577609,-92.148654,-63.880114,-27.568482,56.901907,56.353298,-77.617414,-161.061152,-237.178104,-216.462377,-186.466883,-62.402043,1.26594,3.238096,-40.824617,-103.829911,-112.879591,-105.850285,-88.215846,-66.865144,-4.282202,15.484715,34.781034,28.084984,-21.100203,0.95107,42.392069,90.133816,79.933912,22.452966,-2.567989,-54.013673,-80.092403,-39.868261,106.90361,172.021308,197.608649,133.700425,-48.744446,-108.056334,-140.729267,-85.942198,-62.137938,-78.687532,-102.130659,-142.005066,-167.153076,-239.401009,-264.135355,-231.548047,-124.971628,-67.115038,-6.294469,-13.909311,-44.210457,-54.993085,-30.354322,90.510274,128.53719,118.227034,93.510023,34.54231,17.511515,13.291888,24.978172,105.804358,197.895577,206.078224,174.047151,159.444822,131.83035,104.316688,3.903141,-72.598695,-54.25797,112.805367,188.122677,110.609047,-7.212917,-157.161742,-141.473418,25.858969,143.861008,149.935641,156.957852,164.46918,140.904457,116.81781,93.644648,118.742901,144.654456,208.229191,209.659063,101.204275,38.866758,-21.516529,-41.352641,-61.71302,21.446755,99.49034,229.606984,241.494449,135.478884,30.464064,-125.527458,-57.221593,-0.122952,74.265398,89.7181,23.645316,-45.652561,-133.88316,-131.659768,-80.67575,-64.34245,-59.910605,-9.661065,-8.87478,-153.515389,-263.188933,-377.97184,-289.375691,-222.180362,-177.499749,-204.358956,-230.565557,-204.253025,-226.677703,-293.356573,-318.329859,-150.908637,-90.600781,-118.607232,-176.030855,-257.344866,-263.448724,-257.451561,-254.92872,-220.201428,-65.302635,0.613501,11.872105,-11.177923,-32.422624,-27.9573,-1.859349,6.207127,9.669299,18.500588,-8.469266,-122.472268,-158.217314,-141.038951,-127.018548,-164.006937,-269.09365,-282.869849,-213.937195,-181.901331,-199.599289,-208.772659,-139.863331,-56.856837,-36.719113,-58.700184,-107.750464,-209.112579,-222.141016,-174.05526,-157.162469,-160.450035,-129.331466,-122.542899,-206.038886,-265.735187,-284.905654,-229.015525,-70.475939,-18.964486,-45.224529,-144.098229,-195.112485,-252.383554,-269.165993,-282.045704,-237.062932,-223.684926,-244.598199,-269.203728,-291.575433,-273.40092,-263.044097,-294.853766,-323.654798,-214.925945,-153.694223,-110.563264,-104.395319,-60.895598,-45.250633,-64.096766,-47.079862,-8.962602,22.994644,-8.648465,-136.442781,-198.379997,-279.131866,-300.341168:57.49074,95.173287,134.888306,181.661866,171.309061,135.531194,113.33239,0.995659,-117.626295,-142.992685,-185.816257,-225.635133,-307.939365,-315.892339,-276.465352,-250.289434,-161.33895,-106.15365,-89.956757,22.063621,81.103625,89.169382,38.137032,-125.271727,-185.591169,-138.300625,33.453927,121.524222,220.867752,222.042584,193.539831,187.694672,220.951468,289.062064,316.581876,343.058706,334.825859,243.266986,138.764231,-116.13434,-199.784442,-162.383246,-24.478428,39.135361,64.273564,14.230229,-124.154208,-163.940981,-160.935451,-148.998466,-155.741753,-150.123476,-148.834882,-188.577101,-211.027015,-220.09837,-139.106799,-71.751195,27.044688,36.754642,-18.501332,-44.077256,-8.56187,21.182466,24.758976,35.598405,63.417589,87.688694,64.742017,10.47638,-8.128141,-77.965064,-63.725948,30.636536,240.581762,283.523405,259.252579,226.305707,122.832285,50.145259,-67.646788,-56.373874,-11.720188,94.918024,127.423533,123.348772,111.544322,105.695238,152.070814,175.647309,155.549495,137.521931,145.823964,144.121562,36.813539,-33.068809,-20.685196,73.872584,75.43219,77.999421,96.783583,91.392296,64.472716,33.727739,88.581673,115.627955,127.383629,141.1294,178.310911,153.083176,-7.511475,-89.961867,-130.499541,-16.439357,51.573726,134.582496,136.109006,78.346993,47.165901,35.683579,100.973804,149.705928,243.011124,267.937141,247.423496,220.354569,140.905909,68.661698,-69.400444,-66.475872,-37.611986,-9.828958,-21.682168,-119.866491,-185.785937,-243.141232,-143.338633,-55.202723,132.60773,195.556795,191.014386,153.007376,95.323128,58.839321,-65.921782,-115.286649,-63.323688,80.216249,97.875604,60.301278,57.632017,40.450196,1.65584,-3.086525,-10.40737,-8.794699,-4.975374,-14.242529,-35.329494,-37.264663,-21.945973,-0.011843,28.717151,93.610467,76.859023,-50.95229,-123.886509,-225.802803,-187.787315,-136.813516,-50.240938,-13.346956,26.788474,29.325147,21.82747,15.054822,34.932332,92.361009,126.526614,187.736117,185.427539,143.060326,139.464346,121.143995,53.552967,57.694253,182.179703,234.324054,169.593052,103.016592,60.430192,58.158442,9.963113,-37.788025,-30.682899,66.956181,106.814761,53.369359,-7.794354,-84.92525,-83.87899,-49.790238,87.681613,151.878408,151.83067,103.132208,23.487672,1.362481,5.93253,70.107695,90.565225,108.912784,127.419566,180.194694,189.153596,173.100409,219.853738,240.187436,186.58812,147.617008,125.021259,139.181317,165.698901,149.728628,99.812392,126.733944,178.496382,271.318762,263.113456,148.705823,80.162627,-27.303822,-40.770867,-18.523814,-15.91558,-46.872449,-142.992826,-201.742264,-277.512728,-282.592768,-269.103757,-229.523515,-177.171219,-14.630732,42.380594,29.374827,-9.822443,-42.312656,19.875049,49.954227,50.439819,33.489961,-31.096599,-75.188625,-81.432613,-32.683829,55.769798,65.292894,61.776505,50.946066,37.556451,-15.021649,-76.530068,-263.437109,-280.453809,-179.671566,30.072278,59.112798,-32.18778,-103.820819,-160.096437,-130.720207,-28.052858,41.499525,58.007554,96.320127,114.738184,131.128531,133.394363,111.656082,86.959757,103.169689,144.665566,141.990598,94.76191,54.617972,-44.56453,-80.915124,-92.634891,-32.432104,31.045374,167.964737,185.231934,89.721801,17.114543,-113.412396,-166.164241,-147.53332,-57.864581,-25.106977,-97.688795,-187.032078,-294.157747,-280.521185,-168.334687,-72.795437,-47.276302,-13.167025,-42.299091,-215.036067,-290.70635,-317.868058,-303.008944,-323.869038,-357.7032,-346.465193,-352.375888,-379.051477,-412.698952,-424.930578,-443.887422,-390.48343,-340.514174,-248.704046,-225.835327,-257.604554,-313.83373,-442.802581,-426.35237,-357.444875,-199.930596,-131.014723,-67.089377,-86.829351,-180.87208,-213.048495,-163.134603,-47.614438,-19.389062,-20.003328,-37.362,-119.300382,-178.552627,-237.842199,-246.257449,-301.188394,-417.194445,-395.076882,-278.036428,-260.72157,-264.692388,-248.076379,-204.737101,-231.709626,-267.993585,-303.728808,-300.220075,-272.223738,-242.210221,-168.950754,-119.908523,-106.626876,-86.473083,-96.307401,-214.933301,-282.431428,-291.635702,-240.388997,-141.422802,-154.517276,-181.166275,-224.131225,-251.967175,-313.064702,-334.217483,-323.865332,-239.191011,-210.661393,-238.012514,-268.40882,-260.275117,-223.16352,-198.115922,-228.467339,-294.1419,-259.952464,-195.310322,-32.803417,20.741541,32.89912,23.031946,46.274311,72.352212,77.542538,130.309576,151.531182,51.984179,-49.315647,-182.908976,-190.211335:30.511042,112.236271,145.017038,190.086446,200.606095,137.803853,60.192017,-78.363236,-114.029536,-118.1177,-119.010351,-107.871475,-90.43607,-98.972684,-166.470045,-205.930709,-170.459381,-6.941594,73.804906,189.044574,188.843796,90.059944,38.384864,-53.601037,-97.230716,-60.309323,110.196196,185.432683,222.408851,211.929386,184.029936,156.337763,140.044398,247.183995,315.679894,370.877972,313.53963,85.634881,-10.266591,-109.699465,-136.375102,-134.431748,-77.07172,-26.007558,16.973917,-18.491887,-160.188574,-214.916134,-188.767574,-65.330956,-43.938827,-113.330375,-167.119349,-239.655515,-261.865758,-253.929845,-106.621658,-19.795282,90.217696,114.685513,67.973696,-0.435351,-93.3007,-78.989986,29.500234,86.732962,84.875402,44.061393,0.395621,-78.270169,-104.785952,-130.872202,-21.963639,71.95119,201.536935,207.30976,121.025661,47.618668,-100.294511,-131.257031,-97.468948,-35.825974,8.247472,103.752788,120.731355,80.960395,41.70502,-16.892097,49.96046,113.629013,187.810197,180.083234,116.991283,90.681439,27.999292,-20.032236,-45.752581,75.102399,144.566519,191.225868,158.247218,73.871847,48.054156,40.867788,120.293246,172.257679,257.46883,287.890086,272.590997,208.00716,26.237442,-32.911112,-21.139779,43.36711,72.051827,73.96521,23.033236,-78.854957,-99.09757,-100.801009,2.120213,83.560641,189.024437,194.991968,133.897135,75.916038,-106.344738,-204.195501,-237.010734,-110.119032,-80.549359,-104.587403,-128.272655,-205.309858,-268.079946,-333.961557,-155.235271,-19.242182,186.066653,228.254127,179.006696,137.767446,102.506945,69.512226,-56.774593,-90.585924,-17.841133,135.504369,139.046021,77.844274,45.783925,-16.680654,-6.076858,20.587289,65.526094,88.162635,134.679196,136.304528,31.884137,-32.479411,9.934313,197.039204,263.018491,260.716532,171.873163,-95.127469,-210.374072,-327.326559,-240.3267,-130.209666,94.112678,141.840156,75.886984,19.997348,-42.718264,-49.591245,-3.767075,69.20749,108.577908,170.438793,157.673132,69.489367,31.626638,28.886802,111.489237,131.251935,120.036915,114.103764,94.951979,78.490385,29.687505,5.268572,2.232658,28.183947,43.032687,99.406475,114.982576,43.28276,-38.650339,-190.260911,-183.33204,-118.010672,61.160997,124.306933,84.414634,-1.088898,-154.978186,-183.434478,-147.92534,-79.070934,-34.42361,81.035858,112.076928,60.443778,0.646365,-54.512251,-5.316802,0.725721,20.837741,64.697102,128.978409,113.060875,10.569974,-33.554429,0.725786,129.594407,178.960888,201.604035,155.062677,3.74427,-55.448702,-87.715938,-28.434143,1.842894,21.108138,-2.399134,-85.827876,-125.906116,-248.441428,-325.649129,-347.287605,-166.32598,-77.017166,20.89204,34.484652,-23.956093,-78.185006,-90.72179,51.867923,93.168332,87.545349,88.641074,79.324032,56.150274,-1.813817,-31.773002,-28.763236,74.103064,110.975407,90.82357,56.3491,-7.57811,-63.694229,-229.078788,-258.278263,-180.02721,41.134437,81.980167,-52.642837,-135.635299,-155.017914,-119.847553,-39.257535,41.499293,77.775131,122.572706,117.392585,64.105282,34.252022,-17.271455,-40.238721,-25.440377,81.259577,134.209877,106.694625,46.032944,-71.639987,-113.230408,-117.497677,6.834754,92.198321,197.755843,179.601505,24.996554,-77.518638,-242.551785,-206.09596,-138.74483,-47.404907,-37.460841,-131.333795,-224.544347,-342.154834,-327.076434,-212.548502,-134.568414,-122.524937,-123.631944,-147.774526,-291.846421,-387.648687,-474.069828,-404.035156,-373.317124,-354.587314,-347.465758,-348.550956,-377.794006,-511.600869,-568.288171,-524.571331,-380.795719,-334.696964,-318.079655,-323.869625,-320.384136,-325.389844,-357.558356,-373.750525,-351.183883,-225.136091,-156.411816,-105.397967,-127.562106,-209.89921,-227.292017,-128.179118,45.27501,87.557922,-0.199775,-100.138743,-230.717512,-246.602941,-254.389329,-265.548591,-286.129694,-314.84869,-301.621583,-280.552858,-298.309496,-314.544227,-280.515909,-174.375039,-135.508891,-150.364221,-173.088806,-169.571308,-167.378846,-168.972266,-133.629648,-83.056256,-69.498858,-33.981075,-30.265112,-113.262221,-168.890722,-221.99986,-217.898819,-168.613834,-80.975325,-39.134676,-104.894661,-214.938446,-361.149147,-358.97675,-305.1841,-265.055867,-244.614479,-193.633983,-179.419046,-194.336478,-217.795878,-295.081022,-326.844263,-310.896686,-217.820827,-150.563853,4.124201,47.838468,21.093165,-11.519092,-37.552637,-17.103522,6.815782,69.137215,71.534548,-46.852653,-133.777663,-291.465136,-342.646879:-8.060471,32.896134,71.819138,163.243263,175.477058,122.415076,99.134505,12.951719,-203.132138,-301.113958,-328.330703,-269.967569,-190.002578,-189.151985,-194.412582,-194.627268,-166.952749,-61.331784,0.861973,42.098797,15.101972,-16.162701,-10.446727,-82.175542,-212.206384,-211.470851,-75.789408,19.28279,171.489158,193.094925,166.134572,165.329303,222.983038,277.48191,271.460473,226.102372,207.106445,154.973986,107.069047,-12.177823,-51.004266,-33.281518,16.861432,51.477214,130.558744,144.410879,65.090943,-6.630882,-78.698517,-71.927959,-91.611626,-122.210907,-114.905478,-138.49569,-169.205575,-157.587666,-7.263386,68.854752,141.815251,148.578928,86.695572,29.879209,-3.359616,27.496608,77.34393,67.370244,53.561031,48.056029,58.888614,67.905381,52.13047,-4.736992,-0.472531,38.192213,147.302347,205.330579,231.791006,176.245796,34.421103,-20.936974,-77.996356,-10.432432,50.976357,149.670932,174.530375,189.694305,183.408223,130.973212,83.686003,100.335921,209.710079,245.199605,174.319387,115.016955,45.735996,18.292498,-25.574277,-63.50447,-64.477572,46.277087,90.337684,-16.855092,-110.935174,-192.987092,-90.996758,-3.218748,112.064534,121.704897,72.747292,43.47216,25.316264,5.165521,-68.910747,-25.685303,37.620773,154.166373,188.129349,168.181075,117.868651,31.226501,105.120563,193.74842,331.150433,347.879954,300.907196,261.061515,168.289003,113.661496,34.49343,37.318154,52.498376,82.44304,76.528738,-30.277801,-106.306648,-217.523609,-212.432864,-151.831215,21.472572,82.863083,81.190714,48.223418,9.037065,-15.319464,-115.649908,-182.008139,-163.4784,-44.981587,2.833226,-12.952591,-58.806039,-132.283068,-139.459382,-146.396652,-181.766177,-181.194173,-176.289866,-193.22698,-193.377334,-171.378825,-139.931099,-108.371857,-87.648084,-35.721813,-14.006252,-48.251051,-110.939513,-228.976347,-220.836664,-176.8557,-54.588016,18.918347,93.470661,61.476869,-26.861392,-34.80093,-15.797417,-14.335612,6.358985,116.887695,168.782168,208.575802,205.232079,114.134014,-12.459837,-13.338052,77.568449,111.161866,81.5802,33.48083,-28.958847,-19.91796,-10.178753,-127.212246,-170.281999,-58.429104,42.494867,102.269496,53.723828,-85.218008,-115.987243,-78.577172,25.30096,79.726507,142.920383,122.284299,22.427112,-9.162016,-7.426699,-19.238182,-14.939254,92.033616,147.167431,147.601599,113.307663,99.965918,193.97257,218.957075,242.919805,287.886208,337.835853,296.128169,169.197488,117.714763,64.21863,84.179532,120.532103,204.716168,223.083711,210.362846,177.558272,53.591803,-16.44408,-34.051383,-108.098829,-149.955713,-223.879797,-259.899893,-298.622766,-289.675276,-226.012925,-172.000739,-160.703712,-105.0708,-53.985664,-11.326887,-51.444086,-151.320263,-122.486614,-108.870172,-158.314168,-186.441482,-210.803931,-208.297776,-159.515963,-114.66455,15.692572,97.986203,79.181064,7.614991,-8.912733,-52.245356,-114.259428,-298.739787,-346.678788,-282.32392,-154.34766,-142.007351,-181.408132,-194.423185,-140.669674,-82.540348,17.895491,30.502899,24.119805,34.698781,30.628736,-1.240944,3.3072,13.841542,-39.191234,-30.707181,74.165146,88.949673,-41.325388,-113.740457,-127.163588,-84.87356,-7.212887,-10.359349,-25.101703,-23.403568,-12.568426,-16.415841,-37.795244,-105.634766,-138.851068,-114.895768,-47.026519,-54.460785,-150.330699,-189.314842,-171.076724,-114.102382,30.576467,42.922111,13.827127,-14.791214,-40.150742,-84.05395,-63.280438,-35.789262,-171.667657,-243.845232,-229.440525,-181.657346,-212.107231,-284.354275,-414.330829,-470.788913,-542.275589,-441.171135,-351.059818,-234.976399,-218.877288,-193.983958,-200.929726,-323.799167,-429.352069,-423.770445,-313.606561,-241.093788,-189.808128,-228.784496,-315.219016,-313.606628,-234.496158,-125.328333,-74.818823,-11.683521,-12.262063,-70.62588,-111.499217,-218.677762,-387.536809,-461.989456,-503.993391,-478.031602,-376.874502,-308.191081,-180.43997,-157.787696,-183.420876,-242.845122,-292.675518,-362.22994,-350.735954,-235.538186,-172.70377,-164.320159,-228.821064,-204.569981,-76.765835,-60.737075,-161.980681,-196.352748,-175.084099,-175.373096,-205.850706,-179.331848,-150.439846,-120.932041,-138.505999,-214.865254,-245.300502,-272.610907,-273.813198,-260.165847,-232.56168,-208.555033,-112.407866,-73.87831,-102.83712,-158.302412,-227.709765,-131.633987,-32.884252,104.12199,100.901127,55.486484,44.988164,12.759575,24.315381,72.641862,182.450178,190.300259,89.34909,25.710846,-46.896413,-55.850885:9.934867,95.106278,111.369419,122.362707,121.989755,73.079085,21.198229,-86.473373,-159.605956,-192.718335,-213.287677,-186.563815,-153.348554,-166.657535,-200.870183,-207.515561,-166.844761,-83.919671,-38.778435,23.725188,10.008178,-47.129073,-65.052163,-160.821123,-211.061279,-144.14636,65.983243,144.758854,235.107599,246.274163,178.087738,148.733772,243.49512,391.461243,399.43608,302.74813,234.078825,92.477318,17.284005,-108.650485,-99.961033,-42.342711,92.11878,122.12007,64.937729,5.443637,-99.376518,-126.055583,-101.33245,-51.996242,-39.898329,-13.473586,-23.204707,-104.325706,-142.494182,-174.075376,-91.052819,-15.432481,78.329344,89.616237,121.588504,131.505457,54.425849,-7.479888,-39.583973,18.754511,24.74771,-3.03213,-13.480361,-64.99972,-129.550531,-262.993731,-161.96853,-34.673745,146.336283,161.327182,75.014559,7.093076,-112.201971,-155.98568,-191.689193,-150.71956,-97.532678,38.484475,64.842736,21.79314,1.406789,-10.878746,8.881142,36.793392,109.014556,137.29262,149.516436,149.74911,114.930566,58.31583,-40.236125,-12.503386,34.585745,123.864529,119.989612,9.217705,-36.437722,-32.641496,26.817518,77.420819,196.779362,217.477176,179.876344,157.709498,75.023469,7.880481,-38.227198,53.248285,89.429796,117.677201,120.02229,118.716843,110.705904,61.983281,110.003041,205.63671,362.693506,357.11761,208.262041,122.335432,-15.70311,-89.408193,-184.931142,-102.534876,-40.353901,-0.950307,-25.00361,-102.226132,-146.132282,-240.917104,-247.256341,-188.716075,19.779216,119.454076,165.850816,129.586848,78.439461,54.004199,-62.376555,-107.342334,-49.860291,106.225003,141.039362,100.782264,49.63038,-45.730945,-44.242084,-29.704628,-39.8496,-40.50307,-23.010115,-50.562853,-207.099962,-272.193723,-210.787307,-4.359543,56.824612,52.702921,0.253379,-168.968688,-259.938749,-358.021182,-301.492066,-245.268728,-98.696335,-24.467369,19.233511,-13.053504,-86.272278,-102.513486,-86.746846,-9.061653,64.806022,215.359553,228.265465,139.849176,103.283107,111.343098,137.269246,130.31611,146.790498,175.241033,140.47941,51.421085,-124.161158,-145.013021,-86.378077,-84.319079,-93.09593,-4.157137,49.051304,13.799759,-47.932208,-145.462096,-149.72619,-77.215725,146.225956,192.251218,88.820692,11.388924,-114.932417,-157.31132,-130.965838,-15.260908,27.034338,86.343395,114.697687,115.112919,68.658571,13.721479,98.454966,113.758156,110.422895,150.158128,194.557864,146.727978,15.614026,-18.465843,-12.681333,44.400916,93.753774,189.774023,189.959942,73.58729,-10.176473,-111.707478,-68.83329,-38.494091,5.335447,19.257299,-42.081696,-124.585514,-278.847399,-297.529898,-220.79944,-133.356239,-84.170622,25.784825,41.856782,-29.170604,-84.082491,-131.573923,-92.150922,-75.466099,-23.947648,27.929601,74.307599,38.956631,-44.547268,-48.258643,42.392091,151.741214,158.131792,107.736392,79.556703,-20.877045,-107.572442,-260.646064,-231.976261,-171.771726,-91.850688,-78.471608,-94.855151,-124.509063,-155.031391,-131.779355,-9.422946,78.771804,64.136195,-3.426806,-18.72322,-1.889956,4.699973,-27.935107,-12.125817,45.868621,177.226619,195.040801,85.409636,6.709629,-93.914089,-125.097726,-144.111208,-111.392449,-86.487145,-22.537521,-10.00457,-69.960742,-128.961961,-234.758376,-181.983177,-97.132447,34.583243,27.736674,-137.043986,-231.93434,-312.647785,-294.269633,-187.422698,-104.030242,-86.583355,-92.040528,-127.74063,-223.73517,-271.724748,-375.690311,-383.51232,-344.23632,-247.7354,-210.821697,-253.190115,-333.952653,-479.163181,-506.76766,-453.50544,-282.559608,-196.282696,-154.612029,-206.394576,-332.753808,-382.404994,-474.430462,-483.613952,-438.783315,-305.746454,-247.743122,-213.481256,-249.845003,-374.329283,-397.191376,-250.730205,-26.062973,23.00907,-48.54757,-135.488363,-265.136517,-288.810508,-336.609651,-399.688074,-407.483834,-356.606148,-315.134027,-285.343805,-302.136526,-309.997009,-285.40916,-220.714465,-152.393075,-101.282774,-56.950938,-110.146666,-226.303503,-206.202134,-69.566198,-6.066325,1.366044,41.424679,45.145797,-56.667194,-123.612271,-205.756274,-227.755522,-207.012443,-101.830381,-64.683973,-90.598491,-143.311991,-259.297668,-311.849547,-385.785891,-345.27008,-287.385233,-169.281224,-126.636158,-124.421715,-174.91265,-304.584269,-336.645698,-305.638121,-211.240176,-149.407941,-19.229388,19.702968,-17.458757,-79.55714,-132.435941,-2.517834,70.454539,139.134907,118.098245,-45.240459,-127.660881,-179.556144,-177.970384:-88.427947,-50.99117,-32.089349,12.470036,50.244675,114.793761,129.367871,73.765489,-107.292013,-184.175442,-218.8299,-180.664274,-55.572918,3.71925,43.897343,15.90973,-8.761467,82.363715,115.11661,114.961103,109.155916,119.782297,112.564283,17.263413,-70.575742,-80.289224,-58.718419,-32.419088,23.915291,47.523484,100.670192,119.4215,130.932745,138.668143,136.559143,127.558697,123.909073,134.744248,145.94476,78.836378,-27.223559,-4.796009,127.083596,160.330992,130.015377,107.643811,99.79193,96.341364,75.309423,39.146372,18.142591,-20.28536,-61.61381,-138.587236,-117.380042,26.150588,169.829243,203.751183,181.31628,165.460437,159.119898,142.094137,84.891459,66.484224,34.564221,-36.593974,-54.568683,7.26951,43.95663,24.499093,-18.397217,-157.197963,-220.148265,-149.358513,53.98305,102.709211,57.647307,-2.945924,-104.689748,-147.172233,-220.374443,-143.993648,-61.653283,71.155091,107.394433,134.8597,135.13061,140.504128,158.059438,158.078818,160.761502,174.629039,179.867429,156.01156,79.545177,19.571266,-136.123386,-230.70605,-233.6451,-173.686823,-154.32169,-166.877969,-151.699162,-65.428896,-17.310683,-4.38339,57.208042,108.800011,169.796349,155.261122,108.483933,97.381701,33.004481,-1.198853,43.172682,174.699752,209.691011,200.524489,185.079056,179.078483,253.976775,300.061912,325.485777,327.575775,341.821516,316.170182,178.460095,113.634544,83.379514,109.359544,113.123412,172.34475,205.210845,126.875644,39.129225,-133.750682,-228.132368,-202.040872,-94.484917,-54.667157,11.176284,22.938652,-46.127257,-107.243091,-197.908451,-180.637007,-127.59521,-7.796445,8.198293,-90.572139,-167.845436,-241.621432,-212.166088,-228.511738,-319.727971,-323.021462,-245.395212,-231.779903,-283.974913,-321.98669,-338.004427,-230.357567,-167.171133,-68.906525,-40.322347,-50.690532,-78.13199,-130.77727,-110.624981,-63.05243,21.486348,35.955278,46.026379,58.146402,81.706724,81.264417,44.749011,-14.432555,0.545961,182.561468,273.671947,252.537435,168.701247,38.179527,51.204836,90.81927,138.386631,135.558317,87.535752,45.463476,-67.252868,-130.532544,-204.135468,-179.498204,-139.217429,-35.604083,-5.652859,6.570115,8.759742,4.695542,35.627983,69.812038,117.556417,132.456773,172.539505,187.030446,160.749657,113.433653,-28.43391,-141.345302,-145.310801,-38.966147,14.611952,17.865803,0.048269,20.430702,100.909515,129.936616,141.743003,138.176494,81.19764,22.680562,-70.288282,-97.819706,-153.883526,-163.209301,-120.605578,42.540306,118.234421,112.324109,23.206394,-146.03392,-126.606955,-100.433859,-158.256332,-215.581963,-265.307316,-258.058329,-246.048438,-248.77383,-229.984826,-163.118678,-120.981526,-70.61906,-78.374059,-137.685917,-176.351246,-238.732009,-258.061962,-271.619331,-300.078952,-287.43016,-254.24743,-260.287409,-259.660897,-227.321268,-110.690083,-46.852003,-50.066561,-30.873822,-7.365024,-33.267605,-95.227474,-266.782845,-335.925875,-282.759073,-122.957439,-90.563439,-109.306446,-99.35389,6.341809,52.184897,31.970776,-32.479131,-58.798512,-112.143782,-111.326938,-23.304227,18.029222,-37.07657,-167.001181,-182.091967,-133.633271,-115.408965,-124.986613,-138.756727,-171.377577,-200.508155,-244.893739,-186.715687,-148.994363,-113.668438,-101.255103,-72.163622,-71.673611,-116.187491,-125.135366,-90.025471,16.013829,46.788375,-6.764898,-52.112894,-28.618796,34.145828,173.848189,268.210466,272.720768,218.736132,206.242852,247.681915,268.523428,212.103128,86.710835,50.329791,41.576135,31.994084,-82.690534,-160.539147,-262.325678,-286.240502,-261.156005,-119.378946,-33.289886,35.591298,8.775096,-27.441424,-34.076022,-155.252947,-313.309479,-329.237304,-240.686157,-151.807242,-17.99639,-55.117028,-272.17916,-333.221224,-238.109716,-62.296305,-21.760357,-5.334553,-2.388909,-18.445973,-49.561735,-127.369807,-176.315167,-200.842903,-254.797989,-256.626565,-154.027411,-57.207249,117.797422,132.824447,14.514042,-117.04264,-154.830601,-192.98267,-205.694748,-192.55251,-157.858413,-104.836301,-75.827072,-47.580878,-0.734211,6.306176,-10.093472,-22.262366,-13.538094,-14.267943,-73.923393,-86.804563,-49.590347,39.332796,65.381711,65.639377,36.401916,-42.175968,-54.622102,-41.669949,-26.49966,-9.438861,50.463975,54.585286,-29.784393,-68.553224,-46.694098,-26.470152,-43.262221,-29.132115,11.214676,63.562414,48.275153,-35.206463,-76.789599,-66.877488,-31.428429,-1.685645,75.24422,97.890829,132.313225,151.301883:45.118071,114.591146,177.197019,218.80252,175.372474,104.74483,122.423136,138.42185,-46.870806,-167.958745,-258.656587,-215.097512,-133.045563,-141.726257,-150.35156,-113.429166,-17.202763,42.355861,50.361212,5.063109,-32.344466,-29.363744,15.26301,34.739506,-95.602847,-166.363868,-198.188046,-137.333002,45.010077,119.503244,208.050129,219.6635,239.758894,269.141083,234.079317,146.011486,158.882612,264.404803,287.237283,181.812763,27.410105,-3.539162,8.218993,19.447008,-28.947957,-70.429061,-67.816284,-31.867361,23.752273,-10.498308,-54.225231,-105.217608,-101.634753,-73.590991,-59.901217,-30.584917,50.987835,80.964671,46.962699,25.841062,59.555568,92.283876,113.888135,81.386408,-42.916686,-44.768869,29.415711,135.507982,104.02447,-14.930545,-48.457276,-99.926443,-105.790067,-57.341565,99.062458,163.440608,151.773061,82.427186,3.372017,-0.611417,-78.748815,-137.046313,-99.906252,47.716081,88.843512,68.046739,53.835448,28.172003,31.902201,61.927919,68.597416,43.769954,23.619242,28.236088,41.60234,37.74912,-24.959849,-118.180361,-137.466008,-65.621071,-18.764576,-39.342742,-86.979044,-131.11302,-52.765882,-5.568083,19.673754,11.145812,2.179438,-1.94899,-12.572995,-12.917703,3.153519,22.187644,35.758379,134.947488,201.553905,249.758456,231.123504,187.59252,246.108528,313.730651,444.794978,492.846104,525.092514,491.430195,331.930984,226.424645,65.40778,61.572916,91.738593,142.513382,144.329552,113.909159,77.401351,-86.812326,-202.653983,-168.303899,0.617699,66.838744,75.532701,39.566576,-6.631072,-23.32161,-82.937941,-123.086794,-106.04928,-7.625643,22.603279,-18.235736,-50.57953,-57.63085,-53.004598,-97.268378,-232.674976,-244.14995,-138.92448,-87.740034,-90.750412,-151.040133,-262.000906,-158.311283,-60.417195,63.71851,71.828643,24.451609,-13.274285,-81.232948,-83.63055,-73.941297,-87.313879,-96.008477,-42.98762,22.915133,105.972627,77.635716,-19.804598,-23.92803,12.516097,132.458685,172.556528,143.12798,103.533517,41.831615,70.281953,113.683201,134.780526,102.333324,29.490391,21.191297,24.851912,-20.596886,-191.385988,-262.12239,-234.482236,-131.020521,-100.482411,-98.030813,-92.48721,-101.123804,-192.574862,-214.599426,-130.836497,-41.640335,102.614175,112.639482,84.107707,98.086591,132.446986,37.770404,-22.41235,-14.68706,47.105706,146.517384,156.833219,145.166557,161.223728,179.051661,209.803803,214.925371,179.293961,135.21335,40.093948,3.571237,-45.210919,-25.371391,29.300413,199.48548,260.125679,207.355728,104.584932,-89.146923,-68.455675,-37.693787,-151.005025,-251.485429,-328.955704,-302.877212,-224.409765,-192.63564,-119.884092,-47.306994,-30.277562,-20.272556,-20.828231,-28.254458,-45.319637,-105.985232,-101.60677,-95.164305,-150.343181,-201.528664,-306.635077,-334.007656,-277.750447,-203.12021,-10.50217,126.119642,133.989025,85.023807,50.951957,-51.116345,-113.12676,-206.913204,-186.027623,-131.216293,-37.765553,-13.056242,-0.077638,-1.727106,32.85406,61.66174,79.899106,54.379186,53.58325,71.288575,84.075443,135.306973,152.430924,113.712742,95.456053,115.771324,112.523032,79.200825,20.573105,10.910328,-15.845437,-44.144996,-55.388862,14.476957,37.782013,67.459418,128.875783,305.819934,305.192546,69.121204,-34.343634,25.760324,86.441275,19.004649,-162.217037,-180.460279,-24.869949,73.220374,168.597136,214.327049,226.509435,167.952064,108.322259,41.174876,66.940666,144.062592,106.41408,53.694965,-68.007872,-111.083504,-134.462275,-127.011793,-192.657955,-283.206053,-383.715367,-219.637217,-99.244361,35.616326,41.118459,42.103898,31.946461,-106.248897,-287.503817,-338.729138,-319.571044,-248.562668,-149.558876,-197.04123,-363.640831,-379.854067,-243.875403,-57.188601,7.027102,60.226914,60.84013,27.496358,-15.591984,-139.47325,-219.1508,-228.362731,-209.692893,-184.892773,-120.679185,-87.025577,-43.617736,-58.27435,-142.124062,-187.218321,-181.400621,-164.097646,-185.006556,-271.708264,-297.953016,-278.350682,-220.834869,-201.172125,-120.896912,-37.092816,86.204573,69.64899,-54.154211,-100.901492,-127.425354,-157.928067,-164.472184,-87.247721,-32.708633,-17.298067,-61.86108,-168.276204,-209.030496,-219.685067,-227.249844,-175.104058,24.362345,77.329533,-19.527693,-99.228821,-130.150718,-39.66683,-2.120801,17.162881,4.971018,20.854423,49.16113,24.412416,-50.136839,-43.837402,21.922654,46.767611,60.819813,66.544945,115.906845,145.949037:22.976075,61.549706,66.334057,86.823358,84.328873,44.31164,19.316913,-36.657618,-137.464044,-187.454149,-189.000481,-152.520438,-102.580324,-94.354133,-103.232512,-104.603088,-52.717267,4.6414,12.474189,0.873974,-12.949974,-26.182887,-23.199473,-64.855663,-171.366149,-198.727677,-148.652868,-75.003204,106.08822,163.536835,166.383114,136.806895,99.940023,145.213391,167.753161,187.753182,197.412687,187.46137,138.368596,-46.402533,-113.383659,-50.947295,85.353193,100.00322,84.742883,88.049117,82.055384,58.526202,52.099385,90.972734,60.58752,-72.329298,-126.590616,-153.690967,-122.520245,-25.493126,96.441831,162.794673,220.090122,205.758532,139.734585,109.684499,59.967352,18.627834,-59.539484,-64.296408,-44.160806,50.45253,87.621267,22.872422,-69.02352,-267.124497,-266.664827,-156.477627,66.630864,119.074967,142.257397,110.459275,-58.256481,-145.428267,-154.560112,-7.387784,32.066881,35.164118,50.240395,123.408876,144.900568,94.122103,37.289204,57.434677,161.386723,213.299003,216.577899,167.016886,82.274289,56.548741,-13.515776,-77.465032,-90.085671,-80.641041,-64.818262,1.557125,45.967929,47.827536,-41.937721,-38.228494,70.308987,131.080092,169.788678,130.232595,14.702557,-22.611024,-50.962266,9.013627,64.951061,130.735424,127.305061,121.51559,137.409218,108.410163,88.79377,155.385475,309.842215,342.784956,310.24188,240.427611,44.014098,-32.198459,-48.803802,-12.602758,-40.115422,-92.479466,-89.16537,-65.050812,-67.030199,-139.448302,-188.552575,-156.792535,-39.17439,-0.504109,54.669095,99.74805,128.087157,57.581881,-141.593301,-143.508249,-84.749084,24.108691,54.351499,39.514401,-6.353301,-121.076844,-151.322237,-153.872832,-221.514521,-254.530289,-262.987123,-266.101312,-302.563117,-322.004721,-266.067268,-90.390062,-41.419336,-55.758017,-70.418324,-92.941547,-138.636327,-259.29152,-194.969036,-120.70629,-28.85616,-1.987865,46.513267,64.475433,72.674609,48.931977,-42.153035,-31.243466,42.99916,205.154455,242.844404,264.195239,280.230525,256.088521,183.547086,188.870784,226.291898,218.527548,142.556352,94.354212,12.281733,-6.134833,8.970069,-21.527034,-44.778131,4.587586,45.338753,33.473917,-13.911213,-113.671211,-61.272163,47.31488,225.876572,224.138752,149.945698,130.545482,46.236807,-24.455211,-87.917407,-27.176878,15.033185,57.447525,42.113357,-7.70223,-11.303189,13.256629,70.086889,104.276019,155.253486,183.463384,213.659061,164.369612,-41.992525,-122.739827,-147.561184,-97.951881,-59.167202,45.154527,68.96463,8.38001,-51.167881,-124.328205,-80.404426,-59.649596,-107.594755,-140.671592,-142.895206,-133.544168,-162.513518,-188.064241,-163.826495,-101.098858,-100.009005,-48.312656,5.609148,-19.650637,-94.446927,-181.396308,-175.058464,-180.784525,-213.722205,-220.739535,-213.972533,-192.309331,-111.798633,-78.002139,-43.286289,-29.010802,8.180865,137.494241,160.577551,54.337276,-33.200789,-219.831686,-304.179088,-235.666565,-40.30206,-14.90053,-93.364797,-129.025664,-85.83075,-46.446433,-35.121231,-32.677917,-38.921444,-101.476338,-122.384818,-55.327473,3.523553,5.737082,-86.966535,-91.4681,-39.305796,-24.693867,-66.717131,-109.679145,-145.339519,-128.995228,-107.907364,-150.388146,-167.936531,-164.172953,-155.378774,-141.480199,-138.177813,-160.239963,-136.618885,-72.33377,33.427746,8.174936,-132.32186,-159.074506,-98.940727,-69.043809,-12.009236,57.186693,63.533109,75.430498,91.838736,74.892222,30.431851,-81.941429,-146.535058,-164.159765,-200.133273,-211.333963,-201.643219,-194.034568,-264.832061,-349.241713,-446.917038,-308.030107,-219.549745,-163.890114,-184.541409,-201.516523,-181.886512,-205.425893,-331.108341,-356.08909,-269.259395,-178.235968,-59.082247,-85.761389,-199.542242,-202.309812,-88.549712,21.232739,41.92131,47.373864,32.033638,-77.45961,-153.034358,-259.151324,-258.750835,-230.023103,-173.215653,-154.991973,-161.804946,-156.72238,0.435234,88.342657,48.188982,-100.689856,-107.740716,-38.302684,-10.176936,25.798142,24.854195,-17.61686,36.890802,87.13917,96.953067,77.802533,53.61891,36.414912,-10.416833,-23.750011,0.015964,14.107758,-6.505905,-36.672033,-43.584191,-111.194381,-148.922875,-147.933018,-142.735159,-164.686617,-159.276703,-100.183475,20.918521,22.564984,-104.205349,-179.996852,-189.954929,-7.673274,66.466598,74.208262,67.634941,142.096093,160.073411,32.890705,-67.920164,-26.351675,126.897029,161.381516,89.056753,31.176575,-19.237713,-12.544657:forward
312.827078,305.160781,256.209367,215.864634,262.0018,341.840821,333.176941,251.525197,194.077738,205.252268,252.437809,253.878667,244.202621,284.300768,417.373482,423.224959,226.245348,-64.141089,-128.886475,-13.617929,93.403049,168.292295,125.738504,38.830551,32.204558,16.786126,-59.821848,-77.360137,-66.141046,-76.168449,-72.049316,-35.259501,34.21563,64.669374,74.228385,143.890069,216.895463,370.676074,399.319696,335.303373,248.097195,210.099131,187.915709,242.278225,410.62364,441.416699,347.744902,285.929098,245.875649,239.059681,225.292724,265.604774,317.276379,348.035878,281.807067,62.166852,5.941344,32.967093,71.287088,69.499538,41.521233,33.658685,31.143569,8.238995,-100.802156,-265.43704,-350.530018,-412.123151,-371.863203,-203.854918,-111.0047,-20.413472,-138.615911,-224.828902,-258.074244,-202.056259,-69.119096,-27.619548,-44.314784,-111.833618,-292.81672,-378.481404,-369.830174,-266.692845,-188.919498,-60.264979,-21.791114,30.356863,43.774511,22.91334,4.195592,31.840631,117.044053,167.100902,223.720935,197.997374,156.510135,224.297185,257.255138,353.145555,421.820418,515.760508,520.04795,443.597051,280.923834,179.493717,85.318017,117.321817,151.805036,129.439612,81.48509,47.846649,-26.983899,-73.807561,-91.825853,-83.178514,-46.124471,98.568395,195.569292,277.791437,110.824573,-6.532499,-157.112309,-142.847669,61.36954,169.382668,196.686467,120.882926,-52.751337,-103.407205,-75.303853,-6.902101,7.327743,74.243167,113.549257,52.727109,-70.880634,-112.083816,-163.970867,-148.811742,-51.63729,-1.357834,64.532405,60.09851,-24.407376,-55.679983,-13.652096,72.863691,78.546831,87.314161,92.786963,57.726886,31.66956,23.821966,42.891298,64.28562,80.136524,93.163954,93.972225,58.334052,-42.794404,-218.658611,-301.513924,-280.237892,-183.532639,-3.760485,30.276319,-15.301068,-165.988002,-222.211536,-183.539673,-110.055317,7.34495,22.910042,5.734061,-13.980953,-75.404339,-127.58872,-136.296827,-141.043937,-145.858368,-107.726921,-35.78682,171.303295,246.630799,189.730434,98.303758,159.469563,360.830951,396.585234,348.449307,313.938303,233.776162,132.694278,114.546943,189.221699,241.701165,309.514846,329.581508,324.56796,244.024467,166.399976,-32.494745,-108.89162,-163.341278,-138.861421,-57.637722,-63.126526,-175.742248,-260.662384,-262.841692,-215.008906,-175.197756,-37.945306,31.627033,49.589694,-95.338371,-209.199797,-403.859042,-409.461933,-255.05905,-182.272145,-163.626895,-181.173923,-136.683853,-76.975737,-118.954351,-253.577336,-263.640283,-166.325058,-116.334785,-119.361148,-230.339522,-293.233422,-329.87257,-282.873492,-150.50796,-81.514123,54.382322,67.660424,-79.44534,-225.633486,-207.194083,-53.635332,18.369938,110.230929,136.145616,185.844384,195.976943,133.3973,-24.375933,-45.705131,-27.39803,-14.035128,31.127132,17.348027,-144.419676,-316.373983,-336.425416,-262.728347,-222.770543,-144.114074,-100.162475,-133.160702,-264.351409,-288.834932,-309.387571,-341.2687,-361.890828,-317.249183,-227.54305,-234.597304,-378.336448,-568.001971,-588.941528,-467.298596,-382.123745,-247.945704,-217.462974,-241.490583,-308.312935,-357.25522,-449.395808,-433.70613,-281.559622,-214.677175,-189.748634,-224.625321,-332.217669,-441.77206,-468.019025,-376.896147,-284.632416,-144.31366,-132.029636,-170.464043,-206.716461,-261.107837,-379.72827,-350.057046,-97.683401,15.978837,24.479462,-31.134083,-40.254203,-22.637403,-72.71994,-143.697385,-110.618353,69.178115,189.414165,369.506415,262.530851,130.323123,36.150925,103.927138,220.966402,232.298081,237.503632,230.303848,164.272409,66.952489,62.005077,145.007638,173.829003,158.600795,149.465196,197.012137,203.313049,122.733266,-39.775504,-17.849052,154.680063,196.30604,58.25449,-78.1634,-242.099212,-219.111609,-215.491664,-267.849754,-274.67718,-195.492026,-152.692162,-165.478759,-224.537914,-228.038441,-191.005349,-158.7119,-120.259407,-115.855513,-77.650253,-64.740646,-135.018895,-250.295109,-264.212962,-193.487929,-149.37088,-72.767063,-48.371729,-90.581931,-185.163007,-205.083469,-192.859776,-181.791592,-143.154856,-88.150316,-8.677161,-56.685876,-230.85324,-228.267846,-158.443066,-60.539939,-53.31358,15.778383,89.38307,139.825954,-51.089323,-174.050929,-251.335003,-198.707731,-118.194769,-118.260046,-124.199855,-147.769138,-198.180272,-146.861938,-132.813438,-201.827613,-264.256661,-355.413845,-373.188342,-384.639075,-307.844539,-256.803517,-213.523604,-192.795242,-89.803095,-23.584751,44.491797,37.607781:280.412695,244.157844,243.977609,308.968506,359.64674,340.084589,277.560977,187.016554,188.339759,227.994814,330.986072,342.873372,315.588812,333.535407,385.321114,343.409488,114.533647,-112.503628,-167.072048,-81.18125,15.625484,56.456811,-16.200027,-121.661289,-127.473926,-143.029529,-105.684482,-24.682972,101.098735,106.916083,103.523201,106.252153,70.478886,103.044851,172.146831,326.98997,394.324653,499.806801,513.140177,399.164899,247.051765,232.564045,306.852044,358.753812,430.311422,427.888298,361.816923,342.973056,317.755929,244.946818,236.408546,307.445695,362.682898,397.160964,328.267425,136.537197,79.825715,53.210935,23.166462,45.378547,95.336243,103.359905,59.880759,11.375778,-118.070651,-245.451368,-272.626861,-264.274329,-250.956857,-201.563096,-150.891644,-44.512789,-168.106173,-284.595197,-299.473611,-202.957139,-34.025528,2.82088,-1.380075,-40.350231,-195.286934,-378.854633,-417.837399,-303.96303,-172.383903,73.707456,114.84167,21.945073,-28.797578,5.49921,76.626774,101.676763,202.213594,264.332376,269.379346,215.802328,165.717459,229.781969,277.994018,382.883646,412.222698,413.894667,412.031286,367.963144,228.973396,181.812963,209.558606,238.421406,229.724158,214.730565,162.385031,97.6795,-73.823333,-217.667989,-251.165835,-175.935443,-82.871539,105.137952,170.520949,171.063319,-20.774403,-113.674445,-92.109804,18.613862,252.558584,289.458316,183.487601,120.727677,54.583681,-83.779597,-151.581953,-89.069497,15.845545,145.085721,123.709386,-5.793163,-86.337152,-123.125908,-162.335447,-121.55576,33.362491,93.166277,84.247352,17.46247,-99.819541,-60.652259,-33.746781,-58.70782,-36.920524,184.750169,258.172742,130.544144,-33.845779,-59.943975,-5.717495,42.001012,69.055259,55.818398,10.161469,2.064692,19.912821,-159.257156,-286.93362,-291.938879,-182.707173,-7.483277,1.34021,-119.155859,-319.514507,-411.376587,-450.931456,-371.523011,-138.342454,-47.553871,2.472828,-36.986521,-155.970857,-242.703991,-264.120702,-262.941876,-249.694094,-203.267564,-155.388666,-19.024948,69.581763,62.557329,17.393067,41.472784,177.833799,230.870131,252.156625,228.003672,96.935377,-51.655933,-58.248235,83.426751,153.983264,169.815185,153.355237,150.831972,60.528705,-38.669162,-159.436582,-146.479962,-137.607967,-171.984402,-228.894544,-222.735382,-204.709092,-291.957836,-316.115071,-200.738541,-113.776846,-68.94731,-102.369807,-118.891142,-148.943074,-252.074283,-511.272115,-552.192817,-404.212782,-304.123488,-222.562496,-230.011132,-259.561017,-272.092589,-291.398012,-329.668663,-285.39119,-127.675262,-111.686944,-201.85877,-271.060071,-296.603466,-304.140654,-247.532596,-22.203414,86.589175,129.573272,68.769615,-78.206816,-210.838852,-233.441158,-93.436887,31.950842,210.932547,235.814348,248.456687,209.437993,145.410604,56.116181,66.921027,116.880335,122.870591,96.085524,61.237475,-61.867668,-187.61829,-202.271875,-155.905843,-126.540568,-54.118845,-35.203381,-120.481323,-259.442702,-309.204629,-377.659706,-363.647996,-216.952129,-149.451899,-159.210776,-212.009311,-327.082013,-442.475692,-485.740338,-507.897336,-474.398983,-324.366814,-282.723481,-385.894563,-523.426932,-547.721392,-514.00049,-460.278598,-325.763241,-282.470669,-315.352318,-386.215013,-495.180304,-456.145173,-426.918547,-361.629064,-313.620676,-229.496879,-198.867448,-167.728225,-266.369721,-348.257487,-381.70604,-301.312768,-111.593072,-73.197439,-45.511842,-15.190829,2.145902,-73.758383,-100.801386,-83.613037,-58.766788,7.087051,69.578794,179.168479,76.778943,-29.079659,-97.052205,-29.285896,96.904872,104.074463,106.359001,115.493611,59.767204,-46.200919,-41.626476,81.766553,132.293539,152.981569,148.033651,135.805636,88.052532,62.675481,74.274313,99.143063,134.050626,124.6422,-11.206444,-101.835107,-188.652823,-245.880152,-275.89744,-228.376907,-165.573462,-89.60837,-85.542356,-91.62527,-82.603761,-82.975762,-91.444739,-80.53586,-31.677602,-14.838763,-21.657313,-46.464107,-133.879014,-241.139118,-263.922934,-206.423126,-166.985993,-130.442846,-127.154823,-180.146134,-281.754728,-302.647279,-271.348193,-236.28485,-138.084243,-80.40572,-53.055717,-132.133102,-327.263669,-290.9208,-217.736977,-135.780047,-140.724397,-120.794531,-78.531993,-30.514729,-87.767718,-141.898757,-175.143217,-139.024295,-82.485401,-78.926172,-96.19032,-136.044053,-260.431414,-290.782695,-260.885923,-241.349348,-274.519835,-323.766799,-325.282869,-351.205682,-355.791201,-328.821567,-218.54024,-135.511811,26.366407,54.925593,17.639123,17.707566:184.896496,169.873687,200.837857,186.924975,174.252784,286.710771,352.158783,324.706011,200.988841,170.273393,212.129793,239.818282,218.420322,197.622826,193.398542,179.668505,42.123222,-167.72806,-209.312723,-72.248365,40.425592,103.891221,38.232038,-87.168815,-93.404852,-84.037527,-31.141548,8.563099,63.168138,84.943095,110.769437,88.827617,29.91723,95.068902,141.095642,235.695319,338.19799,587.977443,623.64682,453.241405,228.143198,163.774104,178.085239,251.885745,394.8445,401.834809,316.129796,285.687736,247.025455,165.483136,157.850296,229.264684,272.784013,276.272027,229.779915,169.332688,136.203419,83.505744,82.388136,143.808261,145.931864,72.590743,-22.123205,-5.353765,-35.623279,-234.478001,-266.446177,-134.123229,-62.803674,-37.7301,-57.772457,-65.1785,-86.421224,-116.630931,-103.97753,-59.042271,8.832343,16.166118,-3.060094,-34.892189,-157.507806,-273.746542,-283.773996,-186.949043,-110.254515,-6.096996,-7.967958,-58.034922,-48.252992,-28.754932,32.449147,78.561581,206.841344,272.591888,275.339872,213.601372,135.545582,193.027477,265.172573,408.469927,420.923183,335.558228,296.411383,292.672651,238.632976,204.487495,254.941519,289.437743,248.461364,222.592008,193.127401,134.941128,-64.776891,-209.573304,-206.840861,-132.002029,-93.126552,34.243151,97.892288,81.134821,-91.559779,-143.293389,-28.248456,100.827491,246.464428,209.27474,73.823154,78.459102,142.025461,-37.322359,-157.724522,-192.579269,-99.660908,136.074076,177.141002,-4.724733,-247.162561,-260.998664,-98.218837,-29.787378,-38.037988,-63.52072,-101.017578,-113.554309,-107.260749,-65.008085,-42.046642,-69.622155,-81.153707,61.738747,145.964226,125.178495,-20.064363,-72.759841,-46.868259,25.641298,147.872517,169.134904,137.746348,108.385058,61.568279,-75.923388,-142.509051,-88.908583,2.088908,108.330993,83.166318,-84.571819,-269.008872,-337.82624,-312.524663,-205.891492,-31.326536,5.952221,69.464324,53.86244,-154.205999,-354.65352,-365.374809,-267.191929,-190.03108,-73.749379,-91.387705,-160.28109,-64.218195,-38.718257,-85.536174,-56.743478,128.909349,206.85848,229.560112,174.891949,-11.790981,-121.445542,-77.597844,139.325178,208.41444,148.788807,84.71667,15.120845,-42.577538,-78.848014,-128.431367,-144.721558,-172.781192,-191.231364,-253.322579,-262.443,-239.14018,-280.350566,-277.227626,-141.791505,-38.570992,76.659934,36.503825,-144.179116,-271.728576,-311.211125,-402.517791,-429.751258,-357.378737,-300.092754,-236.849787,-224.674915,-271.593033,-330.82893,-314.476767,-258.207871,-229.775266,-128.778664,-91.941579,-143.876351,-252.129737,-291.142816,-318.712913,-256.682622,59.608183,216.87544,238.609173,123.170488,-60.607106,-102.65361,-90.158989,8.238424,63.927169,96.481579,87.523455,137.357284,159.493185,99.772054,3.174937,4.708592,16.337168,26.189734,59.260728,44.727781,-37.212897,-45.801574,-20.503664,-41.690212,-82.695128,-71.492455,-21.479793,3.391006,-151.870892,-275.330285,-430.324095,-368.586432,-72.570012,9.568324,-69.811824,-137.044364,-252.845554,-377.360179,-375.19439,-286.151484,-268.039168,-256.182942,-239.353688,-245.90188,-364.592225,-429.814778,-433.721158,-362.547433,-145.196308,-58.238906,-91.563634,-176.392758,-274.820551,-318.664337,-322.54801,-186.384899,-93.994188,-31.658087,-31.294512,26.570291,-4.156265,-77.704814,-107.140667,-39.399757,100.184663,131.576847,129.489807,108.563441,-1.566152,-59.625161,-4.032321,96.966426,82.258557,64.673961,95.390999,71.650115,-62.329154,-81.576328,-9.465189,50.864527,146.114395,158.987543,163.467253,186.775952,204.597308,115.089078,90.442709,96.34885,98.704248,176.501767,240.03824,244.826592,164.612585,151.837816,167.812447,197.957261,279.39502,269.115305,51.880526,-77.200657,-177.430508,-161.113132,-138.689654,-46.82486,1.942252,-20.568699,-94.695578,-193.867218,-176.405952,-165.712551,-116.399572,-61.679683,46.511433,63.404202,-12.506439,-78.626739,-178.800222,-260.725881,-274.495539,-135.895056,-33.389949,-5.798275,-93.521655,-245.539027,-281.433467,-318.951577,-319.454393,-238.483894,-78.036264,-60.429972,-126.947174,-196.221961,-340.601008,-331.508272,-261.27121,-151.762342,-156.658633,-149.610099,-95.095374,-8.308258,-100.977937,-178.948216,-181.820197,-102.977776,-24.653757,-61.608443,-162.318554,-205.445711,-265.44775,-266.57771,-259.767081,-252.42004,-268.39034,-333.271773,-353.904256,-337.972711,-303.357773,-298.76831,-252.80455,-221.801532,-204.374263,-194.722164,-86.362603,-11.700214:146.410349,98.865664,111.284206,175.287399,204.497749,235.361534,218.720875,118.899742,81.109011,104.347252,170.682386,192.284063,238.692284,280.744083,312.84032,253.454904,46.247504,-86.225995,-96.787255,0.825519,89.859863,208.144948,190.546302,71.748533,-8.541137,-37.321233,-58.147498,-43.328917,-18.431245,-3.500677,72.70739,97.319416,90.463348,139.104473,180.91445,240.687459,268.528413,349.013687,374.577391,324.462649,242.934714,221.7674,214.671509,236.893454,300.259916,307.735462,276.751806,272.299599,288.865831,249.337382,227.675968,257.488064,291.434316,300.510836,247.61374,83.514096,14.010574,12.055683,37.685117,60.12207,90.684996,93.805373,59.21153,17.930761,-133.535369,-306.510067,-329.092175,-255.663202,-219.052318,-170.458118,-138.830146,-75.558718,-110.276442,-166.335689,-219.650659,-188.973783,-80.08583,-31.80888,0.894798,-32.872252,-156.467296,-234.47374,-227.48421,-137.902316,-94.242865,-64.523464,-63.649162,-25.513207,54.384265,80.088889,85.481253,85.131097,127.477144,179.275077,281.398973,278.94537,199.884639,184.471886,197.822785,233.090846,261.321835,330.914381,340.357716,276.547869,203.118775,184.383083,198.429866,204.941596,135.904392,102.859889,76.341739,29.589454,-122.187432,-231.159155,-239.202962,-149.868795,-74.790106,120.927108,212.891567,213.744356,10.830793,-66.817648,-44.312805,30.235352,155.89719,166.793324,67.451029,8.432909,-15.919014,-48.42589,-81.767578,-64.89462,-5.502471,155.648475,193.437054,92.938042,-59.554872,-107.763898,-127.718036,-109.584076,-63.761822,-31.024157,1.073562,-29.217131,-88.142353,-38.394025,2.997902,66.140209,81.964559,121.849545,138.930583,77.098475,-69.61803,-113.879407,-49.814714,26.553686,132.408517,151.660555,98.375545,32.460219,-74.540952,-148.007656,-171.434186,-91.201565,-3.71902,126.262119,125.595422,-11.720163,-211.675201,-279.094596,-226.27298,-134.885537,-16.206992,20.363034,102.124264,92.101577,-79.719745,-236.966262,-235.804548,-146.052132,-108.727,-61.73763,-49.683687,-26.814355,55.82108,95.960389,115.486591,129.037831,255.727298,332.115951,366.558386,322.926735,190.532855,71.720343,49.717563,123.067853,191.09396,278.155954,287.072816,254.33741,125.560241,30.630219,-116.766791,-140.067203,-89.218,-34.641985,2.009085,-32.120797,-97.27571,-140.093504,-150.772776,-90.188925,-22.69527,107.964496,131.160517,58.81969,-99.332724,-189.794523,-316.478244,-314.773825,-227.344483,-187.833771,-155.030635,-159.86119,-195.573758,-239.181891,-260.919646,-257.45924,-211.03453,-114.698128,-118.658521,-195.028851,-258.853454,-289.320205,-288.285429,-225.801523,-3.983277,112.556998,204.857441,144.995082,-54.28984,-98.692277,-51.250762,71.581465,102.017247,69.313038,51.885076,152.670179,249.632448,186.293195,-25.30702,-82.810533,-78.328154,-32.686707,35.507345,4.767672,-108.522034,-155.819151,-175.77116,-196.234131,-164.391717,-11.403344,69.426896,83.92025,-144.791733,-267.748671,-319.334359,-236.595406,-71.86835,-72.46592,-155.673818,-165.113467,-178.103006,-328.919605,-384.424647,-336.178874,-270.112865,-106.711976,-49.161138,-91.261249,-190.246979,-236.904032,-323.159699,-297.679764,-84.389388,5.287743,-15.171762,-87.764235,-222.75642,-318.331365,-315.459175,-142.92146,-35.567276,49.073535,47.515281,62.642005,5.897157,-74.479694,-150.517915,-96.575146,72.229068,131.082001,186.318641,198.08143,178.359949,79.981381,48.01685,62.283216,84.282988,154.991227,209.32964,264.896511,137.497065,49.759894,27.152688,109.454851,294.537855,341.883009,343.947316,311.338799,225.57397,154.981991,137.43162,142.730652,156.446331,241.55939,294.349539,290.45213,163.672112,102.403941,63.010763,93.445645,182.593411,186.883668,41.75215,-59.865983,-131.482934,-86.133492,-79.860105,-73.198388,-60.302423,-66.088781,-90.2326,-134.651343,-148.101683,-138.810912,-103.119843,-80.911742,-13.680855,15.00774,-20.503002,-72.599096,-146.005462,-209.357033,-235.785445,-189.192232,-140.733113,-100.656281,-118.932715,-213.39115,-292.483307,-297.06225,-245.178356,-226.622458,-246.723032,-223.39513,-98.15823,-111.225203,-325.483444,-412.664595,-354.743212,-209.828329,-176.217096,-111.978225,-65.883432,-36.717961,-137.202092,-215.444346,-310.703788,-311.520162,-282.866091,-261.93722,-224.22741,-241.085014,-311.323891,-268.261949,-217.930704,-202.498375,-272.969897,-458.45579,-497.255521,-472.928611,-463.484161,-475.515288,-449.481809,-398.135748,-234.63082,-147.820725,-84.658407,-92.379248:113.138442,46.942836,45.41444,84.788676,117.912083,254.184234,307.712025,242.193615,103.156663,93.223365,158.295089,185.056616,262.23091,311.960079,261.899991,164.365593,22.40093,-44.796602,-60.645228,11.324078,80.542798,173.151539,173.136997,111.11983,8.141091,-46.469448,-108.586669,-111.285735,-57.526091,-0.658461,74.587679,48.413688,-67.972197,-94.985108,-61.102989,78.574242,179.37077,336.816924,333.806433,189.724958,32.777853,-3.691369,43.654229,104.794871,232.986001,275.103566,276.281979,255.486179,185.75465,67.01921,59.22507,173.08565,230.584729,256.16706,220.812716,82.295086,-61.245104,-98.922865,-36.156134,38.628412,134.544505,134.427305,61.778725,14.794302,-115.255082,-288.640773,-301.003443,-172.759879,-101.911639,-38.868513,-64.662887,-144.476924,-113.320282,-83.473424,-38.59133,-18.557182,44.730065,91.769039,143.594587,115.546607,-30.212559,-141.455705,-134.459584,-25.156481,33.609426,65.220344,30.719262,-18.011791,9.88541,16.517372,43.508008,79.195013,167.955974,199.156432,192.299993,168.351313,137.086602,115.36195,119.502252,207.978906,277.81997,366.597485,355.812667,256.561673,119.801898,79.227472,152.146595,210.287595,176.592818,123.870867,55.373269,-9.590877,-230.470822,-357.388577,-328.152414,-154.064964,-58.494364,101.925213,143.471776,114.539579,7.27247,-55.146799,-108.093144,-55.139656,157.299988,234.291758,192.1781,122.232732,42.651225,-31.149424,-76.018503,-113.882089,-78.907682,97.4885,139.417926,-15.866101,-177.139901,-184.131384,-131.294506,-99.768976,-55.180562,-48.460375,-86.25544,-120.28394,-146.656481,-129.007747,-113.220444,-96.089344,-78.741137,80.948084,158.432456,95.691486,-92.806615,-155.57649,-146.392597,-73.102625,97.413547,149.507861,135.530976,91.353926,13.106208,-88.788579,-127.440392,-77.856361,-1.558279,150.548542,168.593028,25.62167,-168.751058,-214.490403,-149.101587,-67.544177,41.035831,71.877004,116.221227,77.998181,-126.001254,-252.110886,-233.929251,-115.743403,-55.744658,31.13612,40.075638,-5.389298,1.113327,28.150523,64.852752,87.654254,203.09932,269.175869,270.414702,215.401591,96.547027,-10.125671,-12.057084,107.28566,175.128712,223.578366,209.177822,145.182194,-13.710485,-114.337067,-216.774731,-192.483854,-27.229487,50.157058,24.012356,-44.453747,-107.979338,-99.104823,-91.731641,-32.115879,48.935917,211.927959,197.397441,-2.35465,-157.500224,-181.358085,-170.259089,-165.883818,-138.258711,-101.493921,-53.444327,-72.585614,-194.473646,-266.231953,-235.912612,-132.679037,-83.248327,36.164361,67.414155,-22.78186,-201.16073,-255.657595,-227.929886,-132.227652,195.991551,329.840144,289.121565,156.765737,-72.648017,-154.344694,-143.928076,-40.558059,21.802525,80.135203,79.766925,105.817366,111.447167,56.559456,-67.971193,-80.534688,-40.389466,-16.236432,25.155294,21.498966,-78.535045,-200.077854,-211.976999,-161.805603,-122.296044,-16.044381,36.507745,63.976388,-77.69665,-196.616054,-361.55702,-337.32834,-140.696875,-63.565277,-50.923617,-82.839619,-217.711684,-384.999529,-388.305496,-279.293931,-241.085695,-180.18468,-148.218419,-172.421494,-278.437207,-319.661131,-306.045178,-224.732625,28.050946,108.821888,15.316888,-100.957234,-229.008983,-227.947353,-211.405893,-82.49737,22.284342,135.641179,104.771813,3.549377,-1.038126,-13.901716,-88.442322,-84.701655,77.299197,172.243349,216.236379,173.599933,26.880558,-105.464657,-86.510465,65.654162,129.176608,213.665918,221.190079,82.593812,-99.974195,-116.71089,-44.826449,-11.627852,34.383794,63.457056,135.415961,178.552778,223.39223,128.003889,74.080927,55.461306,74.60638,155.917303,197.215723,161.321712,43.805014,2.533951,12.081536,67.847928,156.741593,141.731866,7.801878,-53.718437,-102.360585,-159.540934,-155.442661,-22.156467,43.315137,45.734896,-6.792978,-134.092269,-187.896405,-171.08697,-74.316724,-18.326116,47.962263,49.445004,9.166098,-4.36805,-19.543197,-150.558123,-207.897357,-124.10811,-38.838536,-15.416648,-81.906833,-227.150677,-331.441787,-373.286447,-353.780052,-290.810712,-145.090898,-79.292096,-6.263235,-46.759387,-294.249804,-467.066725,-435.6006,-264.790074,-208.645221,-166.068168,-145.986133,-120.193148,-196.877475,-271.585633,-355.084235,-335.584369,-226.30039,-162.986812,-115.420814,-155.055303,-293.673965,-357.684492,-336.128444,-268.239459,-268.906267,-334.750937,-379.962153,-444.543139,-442.256406,-443.01262,-387.356111,-322.936997,-228.808073,-202.749892,-128.064426,-94.559385:184.623515,163.486632,171.552941,191.044832,216.16296,293.658864,304.89242,226.043061,150.346172,159.882461,220.191035,229.903456,231.239672,256.057637,294.160126,250.01898,39.168581,-97.437595,-74.95609,62.809639,100.955028,107.076849,139.551633,219.585337,115.424453,32.746272,-8.900793,22.145159,19.703285,-11.882984,-13.812765,-14.056394,-73.194166,-28.988468,33.789788,113.821883,127.739664,164.809027,178.042033,169.177104,170.810774,169.388881,142.994553,154.806545,281.668329,351.16213,371.121879,333.696256,264.187956,222.302314,218.552151,258.519136,287.851842,277.529918,189.751179,-50.639375,-76.361835,-22.190395,73.891744,90.482177,62.102908,37.943456,-11.431004,-47.397601,-146.354843,-256.613426,-289.700642,-263.997011,-207.814312,-53.448344,10.032283,56.531057,40.161624,29.066893,33.211102,41.151287,36.405095,55.896497,122.930182,97.015548,-65.871813,-130.053433,-89.335388,30.293013,57.990021,38.086117,12.139722,-14.327942,39.461096,79.327126,137.625507,157.426758,206.429531,254.916706,334.681506,312.648992,214.276548,170.067672,154.374512,154.131639,190.866869,294.044316,315.775333,294.562446,238.484602,169.675707,28.750493,25.561998,105.245644,121.500963,7.316854,-100.22967,-213.919298,-176.424126,-152.379238,-82.715582,-25.337512,117.958251,188.107335,230.042568,126.923946,74.428447,39.096782,65.046165,176.731461,212.612327,153.197973,87.275977,10.890949,-2.222962,-6.94627,10.11169,46.316282,183.43712,229.198486,124.733864,-42.380649,-88.834854,-137.684052,-132.04908,-73.319252,-30.591598,49.790961,46.935662,-53.790982,-100.670762,-75.811072,4.545135,34.63938,77.756851,78.051098,2.871091,-29.352689,-9.496046,47.838609,82.227809,135.863352,137.339263,49.669577,-28.837773,-152.214509,-242.414261,-284.401631,-231.984808,-119.619208,85.981537,103.395068,4.318736,-76.932815,-80.679981,-8.261064,62.915289,143.484785,129.422832,103.293457,92.384256,1.597376,-78.092094,-100.782021,-135.684043,-111.029504,53.316933,145.463157,264.80057,261.964559,183.712778,27.661007,59.405794,291.211857,380.050971,353.449581,270.30229,134.902155,82.894732,83.530598,166.718289,223.74962,308.102872,334.070155,294.828979,143.115335,71.383202,-34.992363,-72.433809,-98.479095,-89.962214,-74.097973,-69.933521,-50.978995,-44.480817,-36.921615,52.939033,129.281668,262.095933,293.003806,264.332043,141.955768,70.495383,-48.972438,-70.683586,-39.424499,-18.07687,-7.517338,-26.230055,-58.361358,-25.10472,-15.802847,-38.208597,-43.882374,-21.338554,-16.702327,-87.093361,-242.248849,-297.121073,-265.200414,-189.965718,-30.054979,14.019681,-15.220044,-73.597146,-147.803715,-109.295279,-78.507712,-8.120285,14.446207,-2.269038,-14.671791,16.494502,46.608175,-1.616127,-196.137213,-270.95533,-255.23034,-183.829512,-95.559007,-139.226989,-343.104761,-477.733672,-471.589275,-360.645261,-300.724062,-174.505063,-105.205691,-76.087133,-274.387172,-390.441734,-485.201843,-456.955194,-320.440529,-252.612916,-216.950813,-264.243177,-426.591858,-500.26125,-460.071852,-314.339835,-249.280532,-88.394943,-14.471359,-41.486277,-220.341599,-285.82522,-282.35184,-195.644888,-5.049898,13.501791,-60.773729,-101.114991,-193.717382,-321.389112,-340.504467,-199.58405,-91.398181,17.32433,8.820949,-17.277138,-38.677129,-107.393978,-310.224772,-352.44968,-205.467587,-71.760478,92.408318,101.880891,44.441546,-78.785567,-139.039529,-186.942878,-167.04003,-11.315774,114.406211,288.378549,239.639371,166.092433,84.510741,118.349715,203.739955,195.27213,134.501725,112.540776,77.77523,58.97982,60.65109,66.577121,62.381998,46.285952,28.404896,-30.87318,-59.327098,-70.107704,-90.131398,-60.583438,96.009648,141.277973,-44.431029,-207.504706,-280.512064,-133.36657,-124.07776,-132.677057,-88.830264,-4.431872,-18.300649,-130.337643,-156.88766,-104.001951,15.279506,34.719372,14.865027,13.509657,18.794611,0.560593,-52.950599,-142.727333,-190.367881,-159.722988,-102.289603,-43.766596,-58.206079,-123.450902,-137.236768,-116.800807,-50.331058,-18.403959,25.396635,34.568004,-17.896074,-103.903653,-272.024406,-238.535177,-165.276867,-39.893748,-18.883088,3.173494,30.958691,37.598541,-136.416028,-264.916889,-420.235146,-395.67312,-239.376756,-168.883224,-108.592969,-133.171548,-232.694031,-269.53724,-262.291991,-244.808224,-279.112973,-460.599382,-541.19846,-593.871626,-580.438683,-558.27067,-442.757994,-344.028958,-146.876674,-95.777717,-123.040311,-159.263263:17.069952,28.764091,67.506897,141.424353,156.453605,183.350822,186.391203,131.207775,55.567342,38.351751,86.420086,139.665208,247.312699,290.034139,281.068629,213.048899,21.326214,-132.086126,-142.088167,-4.500783,92.976392,231.894759,253.085457,171.79707,-34.767555,-121.348959,-117.018571,-47.994124,32.795203,15.469627,-48.070393,-81.455846,-161.448146,-151.330221,-99.797789,27.135832,94.921626,211.748091,217.722811,113.58063,16.643393,5.113262,78.076283,149.506203,275.37256,315.848654,335.675743,302.235048,160.527625,31.436094,33.389163,178.219014,262.139778,301.488403,231.616639,-11.831851,-160.527512,-163.058635,-74.274677,10.398642,218.618635,275.835217,158.251013,24.870869,-184.261286,-251.266745,-239.701537,-143.262265,-80.695221,6.958772,8.618796,-41.981639,-54.157711,-47.504593,-57.523879,-69.176184,-20.935089,55.919353,182.109375,157.560948,-11.777035,-76.951526,-50.085693,45.183354,83.643204,93.73596,52.255348,-59.986157,-64.469295,-35.571176,72.397748,145.172591,254.621745,291.223215,302.762894,262.651846,180.839539,121.229261,96.005155,157.371874,235.066685,305.969073,270.323343,181.037076,140.887873,110.891017,69.658577,82.577321,135.352291,155.334161,87.711689,-30.111876,-298.183449,-384.432779,-335.66628,-172.067326,-115.320345,12.453561,92.33525,102.508242,-78.299689,-145.293356,-118.767729,-17.987346,239.088177,297.818896,193.469795,102.368279,-11.316159,-60.868375,-59.788705,29.351252,96.439725,173.021305,146.481971,17.421467,-53.581918,-82.874865,-139.978932,-124.127263,8.030646,65.448727,38.487543,-12.938224,-50.970331,-64.041987,-80.910265,-27.822528,38.424665,129.371699,123.984162,7.787917,-160.753192,-210.127468,-126.873024,-13.087959,194.196679,242.596656,172.585041,77.82561,-96.270271,-199.972593,-208.034372,-67.761599,42.638899,182.453126,182.195688,47.082996,-130.886884,-173.745707,-105.592187,-19.114602,122.609083,157.853872,168.757372,119.631483,-104.194319,-256.146074,-225.798256,-85.217591,-36.687029,84.331185,151.516061,129.8238,-20.559326,-45.601048,37.712142,112.450346,269.420715,330.361207,318.85814,230.979765,13.481895,-61.186074,-26.814547,108.862289,182.036242,291.426451,297.040991,184.713562,-37.013486,-147.239848,-214.192708,-149.063482,54.310052,124.294742,103.984182,41.783962,-1.442447,74.856374,104.687673,172.346336,231.513395,333.690153,338.572751,244.388985,82.647234,9.129911,-71.105385,-61.962608,30.782195,69.173226,58.686013,16.652672,-119.240719,-227.164493,-209.820093,-73.674423,-10.380586,51.920667,41.958863,-69.208102,-260.747714,-324.707281,-247.670456,-125.221209,138.798423,225.827511,197.117369,87.10654,-136.613874,-194.945815,-164.729664,-39.672827,24.014803,81.539363,75.24193,48.017835,-0.924238,-53.252771,-138.817209,-143.16848,-101.545559,-73.043116,-93.953544,-162.82989,-291.28249,-332.248095,-336.265067,-283.13918,-216.324351,-69.650135,-24.483049,-48.363627,-253.37176,-371.184342,-441.071129,-363.198649,-155.515576,-113.477898,-136.090025,-167.354183,-291.987519,-418.20913,-412.254371,-294.714609,-238.443601,-147.52713,-104.826013,-94.89921,-199.11308,-258.879367,-286.471519,-220.996106,-15.833443,52.159445,21.868993,-65.906584,-276.562913,-381.30678,-358.366301,-169.469922,-54.116569,69.794091,64.809835,20.199152,-27.108415,-82.900462,-176.613936,-159.227037,-13.582276,53.191392,69.513131,35.87617,-73.284926,-208.11737,-215.052,-92.971159,-20.324653,105.493877,152.319944,144.299062,17.393888,-51.453272,-74.614143,-4.7945,119.697205,109.63576,54.470126,60.223303,85.306508,57.853065,33.457019,-11.073244,9.124093,179.690558,225.448296,40.786042,-193.969397,-219.971492,-97.626985,-2.572912,122.433013,125.955991,-2.248265,-88.826704,-162.803524,-124.240459,-89.658786,-31.635279,-24.485047,-38.043359,-56.737695,-154.879163,-218.593215,-185.898388,-69.333335,-21.664706,68.586188,104.459233,45.488296,-33.269103,-112.230411,-150.131716,-177.954761,-93.617026,6.174018,87.77479,36.919688,-127.385222,-230.671403,-239.764768,-184.913452,-138.719654,-26.307713,23.912484,-21.464336,-140.443303,-384.741721,-387.126938,-302.549444,-136.796475,-92.303294,-32.381581,-14.081945,-49.554843,-198.685844,-305.332352,-461.271876,-454.844395,-307.901713,-224.864491,-125.458065,-125.27652,-215.222625,-311.089439,-314.105586,-253.638378,-249.219238,-334.156797,-396.631866,-515.890806,-571.909322,-562.940403,-445.916251,-364.409525,-246.316065,-202.726165,-144.749562,-131.782526:272.194383,239.244587,216.918497,196.420553,239.173088,402.520765,437.858618,343.337667,245.795797,231.554111,229.449626,251.813414,333.55598,349.779744,253.250999,156.992616,4.536932,-73.660401,-100.378019,-63.322185,-14.574594,83.324303,132.371355,194.169824,211.082604,202.09674,144.546188,100.741498,-11.180637,-46.706711,-33.626379,-29.941796,-73.714756,-37.161482,14.531315,96.53708,120.093236,161.504845,183.446593,205.988543,170.812499,138.555015,103.659197,129.225203,254.242144,306.620187,293.536157,235.117317,110.855444,77.91796,95.120158,141.485412,148.704783,114.632684,75.751868,-28.664872,-63.810214,-17.921967,136.383297,196.011679,228.581672,201.1884,71.9651,-3.630573,-92.048343,-139.914059,-163.000312,-132.261963,-74.322185,50.755429,99.592781,150.105585,145.775796,150.873785,173.870809,175.974829,197.520266,223.63761,197.657401,123.163258,9.566551,37.4181,54.685929,73.903711,82.74558,85.096052,70.283757,29.669733,28.961008,21.307848,-18.51017,-22.71065,47.217299,110.50202,172.196106,142.71407,68.490252,68.828894,80.014723,100.304729,101.233871,82.245646,77.16379,68.776154,10.795793,-28.245325,-64.816084,-54.963954,-38.666257,-38.917486,-84.661062,-148.951979,-225.323472,-126.860504,-72.917598,-19.182128,3.366579,104.783816,179.353232,247.986729,122.917669,40.266665,-3.578406,39.45125,128.478193,143.520151,111.882565,73.582902,26.557461,50.153336,73.93144,136.112992,161.40116,177.055107,166.674263,76.694375,-65.02641,-92.122075,-34.06529,5.010499,33.916302,41.1223,47.626593,21.188922,-77.999079,-102.169097,-74.670985,-25.055365,-25.738386,-28.31956,-12.512282,-25.190605,-49.868965,-17.783745,70.511935,108.10156,125.797731,69.548731,-115.537024,-162.541817,-123.083707,-179.436809,-227.677901,-140.194075,-37.206203,68.536786,54.774397,54.695668,177.2283,231.167853,272.345302,259.903863,198.611694,182.540958,200.148312,204.313279,152.886741,62.989639,19.022633,-16.093217,4.825869,113.217855,201.154938,385.837718,393.851409,305.823663,107.59355,67.046272,96.072651,130.119942,148.388735,112.273215,45.10991,92.441793,119.273507,92.073791,59.824907,88.54833,160.93938,222.481448,50.981857,-37.615653,-138.887471,-163.048923,-146.44404,-118.655014,-80.897341,-75.185191,-87.84325,-121.279711,-125.986182,-61.605297,2.981315,164.021974,240.230593,299.953179,223.779793,171.66791,94.602032,85.322805,161.032041,222.634366,252.527109,194.252254,92.124627,166.721984,201.172173,157.533922,114.03356,77.49079,69.740699,-8.2841,-153.301714,-213.171152,-235.291271,-198.541623,-99.432695,-61.050255,-41.250803,-56.954546,-48.615034,20.19528,25.372145,-12.98544,-35.5651,-95.377014,-130.187805,-161.104891,-131.389066,-149.280922,-255.487808,-283.670225,-280.607084,-284.362578,-328.869133,-373.897483,-463.340899,-448.056134,-420.291723,-394.883119,-384.166522,-299.611758,-239.781311,-184.069888,-213.80972,-247.4055,-337.52157,-368.158329,-315.200237,-240.361943,-149.488839,-180.952855,-355.152471,-459.138599,-421.937116,-245.473219,-160.527567,-4.945661,51.632941,46.931829,-30.830648,-78.437118,-116.218762,-63.998797,51.050936,44.782585,-20.585487,-42.611186,-106.018196,-153.519862,-123.705227,1.015393,59.317614,185.941819,244.45577,218.82184,-0.683205,-110.48294,-212.109854,-207.221953,-117.276823,-47.233296,43.67669,56.756397,87.925022,44.899485,-16.460401,-57.940049,-19.444214,86.95601,125.474284,174.692708,229.156536,212.753595,99.439057,94.417863,215.513543,238.8887,99.625106,5.708126,-61.993159,-2.091581,36.660529,90.943311,97.644642,86.652084,68.43768,-29.819706,-149.902294,-171.895354,-123.219992,-70.656594,42.51711,89.956664,104.022438,55.320927,-14.555595,6.870981,-17.508177,-65.118661,-30.429573,72.101218,66.999442,-80.832046,-94.445572,-16.619753,61.463218,41.496211,-20.364341,-35.624422,13.620899,52.81421,48.216164,-67.44475,-129.535535,-155.569228,-115.466094,14.689561,74.498951,124.01189,170.000861,206.79761,215.399562,186.192768,174.982881,212.437978,247.340117,195.182533,77.352595,103.648713,129.627355,125.393984,112.011178,157.554159,206.671899,186.267552,-24.198308,-111.185669,-140.041352,-122.920763,-123.022408,-107.476892,-15.087548,-9.867789,-142.535122,-268.153046,-283.607757,-263.077261,-272.684145,-350.91867,-396.539283,-489.797324,-529.174704,-498.510286,-349.943311,-270.895592,-205.256764,-208.302507,-193.53976,-181.699672:349.283101,219.703744,135.538712,75.108855,107.680262,199.730043,235.802969,227.468074,184.964974,192.029495,222.706059,233.777235,264.617342,290.981311,276.898158,208.625029,60.153079,-62.167868,-121.115809,-93.612994,-2.260647,160.835012,178.304773,112.864001,51.805389,24.582042,-24.513121,-31.127896,-73.028136,-123.067327,-175.7337,-161.64922,-104.492781,-37.996838,-2.299358,51.870445,66.886251,125.06268,162.529495,203.531033,214.458976,178.183291,50.632218,37.362352,153.721465,210.677062,172.539242,93.828848,-22.964788,-22.970537,-7.585987,38.395892,65.992817,90.483703,60.28273,-65.806986,-93.292764,-60.234497,39.649742,89.41121,87.490419,45.894387,33.812335,47.54068,-10.279885,-157.224611,-223.435144,-282.859346,-271.852431,-141.642004,-33.948509,118.79157,76.330607,30.605737,6.741985,15.283781,39.004414,67.300935,75.999679,8.194102,-147.071904,-133.993845,-115.181441,-128.041771,-121.618363,-23.713918,39.910691,77.972414,-7.607158,-52.578985,-72.423464,-43.744809,31.732806,63.276214,84.186198,65.501795,72.852672,161.765257,178.614608,177.758138,187.507388,220.278292,233.168399,211.461641,89.015377,-2.714617,-127.590003,-130.615804,-111.288601,-106.572619,-107.094694,-129.006481,-170.778822,-153.193692,-123.116645,1.711504,68.241328,138.800029,165.761218,253.273066,256.381332,180.799251,0.134479,-25.74984,59.448882,128.738784,174.377756,104.105765,-57.330719,-47.806599,-34.07691,-39.728765,-30.061013,29.297273,46.172987,-15.591976,-42.120589,-16.229112,-27.901061,-56.906771,-30.267866,21.481125,72.801178,42.868899,-62.55468,-124.726928,-131.463268,-72.374233,-22.535941,28.190882,21.900801,9.606884,54.124671,92.37608,188.548593,213.932678,133.520418,72.296689,57.970753,80.067431,38.061771,-156.808648,-259.210117,-313.624367,-259.705619,-95.073823,-14.195887,86.631976,78.052648,80.328157,141.261941,170.491479,186.366157,179.55586,171.136235,174.947967,172.616959,107.295349,56.064736,-10.10781,5.162096,182.03,313.335975,475.830096,437.768689,369.56697,262.615916,283.124672,366.285564,345.411791,222.415397,178.877222,147.622113,131.706986,128.887998,181.041153,213.272872,263.001481,305.43739,376.398102,285.462638,158.386247,-110.260684,-174.880123,-186.76155,-165.727079,-108.478429,-110.579815,-193.429335,-274.984189,-287.363684,-202.836293,-115.350664,38.533204,82.199805,142.567182,144.79475,62.781523,-164.3119,-182.879596,-14.751364,62.829832,64.380252,29.737775,41.786943,122.774754,115.206413,14.588404,-15.171971,3.533504,22.200835,34.676264,-19.437717,-86.023609,-208.683799,-219.35816,-163.536306,-126.339834,-78.383076,-90.347098,-196.867499,-300.593578,-305.467758,-232.443245,-191.604858,-117.004699,-66.054082,17.484874,24.375763,-2.957038,-116.802254,-176.864432,-258.768326,-261.127201,-201.907425,-213.360712,-342.437183,-394.883336,-377.900962,-333.580253,-326.826436,-290.321737,-245.417027,-186.771211,-206.684345,-222.702349,-226.97249,-215.521569,-183.302026,-166.524449,-159.513847,-196.245378,-362.414084,-500.655313,-483.115355,-266.430691,-122.375022,84.559991,98.841687,14.690759,-0.43855,-5.87289,-71.530637,-84.196813,-33.030897,-0.030639,36.14061,27.473275,-58.49098,-155.123787,-160.508267,-73.404503,-21.48658,53.874632,93.351261,146.580818,34.088183,-93.762732,-290.752279,-266.170384,15.560446,169.206222,205.431355,113.292414,44.598427,45.396971,-4.902837,-0.363254,94.113829,326.798912,424.153696,527.679215,440.693617,352.69959,281.797103,340.672926,482.3554,488.15323,377.269241,280.631152,94.613768,114.005043,192.739941,320.532067,323.388415,258.767128,244.601096,268.330652,204.186018,110.13544,-30.16695,-16.309987,76.168008,100.788626,58.406835,-14.789859,-150.073635,-201.377268,-228.318602,-234.378879,-188.377095,-48.177504,0.902041,-33.338782,-102.450348,-107.980654,-138.178945,-167.549897,-192.923951,-165.311805,-78.418842,-65.222398,-131.058759,-199.608314,-192.713917,-148.276386,-134.1909,-70.388314,-20.923597,37.355975,53.543156,67.197712,79.441909,67.573426,57.770207,78.797111,106.070096,79.021155,13.775986,57.284296,100.501841,122.088519,107.276312,143.497018,197.674888,249.018768,108.485555,-11.055191,-186.769824,-202.277833,-140.272249,-93.194272,-14.9245,-18.337392,-116.509036,-226.015922,-248.065141,-208.478179,-189.00127,-244.157522,-304.83172,-410.86746,-388.16552,-325.102649,-184.379218,-132.347649,-77.420067,-53.33398,3.335801,8.825731:123.052951,59.545637,48.568649,129.703673,172.780496,145.572572,121.219129,137.996009,77.112651,8.022748,7.513232,91.451373,233.259716,243.601558,179.535072,119.931019,-16.274244,-77.65339,-82.788285,-49.683415,-0.594072,130.129725,174.384467,159.102207,65.35815,43.240432,100.645876,133.230701,75.45254,28.94821,-1.447808,-36.196615,-126.906034,-49.35862,3.66459,13.848923,11.888441,84.735396,121.373001,131.736382,173.804627,196.285107,173.919801,164.358155,220.700865,265.526855,319.085921,321.886681,256.924587,143.099102,136.837066,240.270509,277.890795,230.277559,170.378427,31.177495,-23.531907,0.017539,95.761601,159.428887,232.82181,195.674925,12.826048,-80.195952,-186.815603,-231.415796,-244.471323,-213.621504,-170.721818,-59.631623,-25.391104,-30.167616,-24.672989,-18.859407,6.258787,42.480062,102.766505,125.047824,166.395847,144.218085,69.307898,106.613235,134.860538,143.431517,121.605799,77.907326,60.561433,-10.246348,-8.940694,20.498014,43.854038,67.330962,165.7977,203.87177,202.883212,178.619608,148.054244,121.233493,90.892578,23.416956,11.670675,80.535304,140.493879,199.170458,146.159355,100.009897,65.353971,91.273456,73.340329,-4.03931,-176.996198,-232.858908,-264.225726,-260.469795,-269.558823,-249.683091,-207.187627,-80.689342,-19.951105,31.541973,40.45615,22.061431,-50.242458,-27.270916,112.117735,124.435564,7.943076,-50.944623,-70.503095,1.077501,30.663373,68.53163,89.166981,149.404017,175.280268,136.347282,-17.631624,-91.752034,-134.869467,-109.104211,-50.20247,-36.166864,-52.459165,-65.4748,-43.73146,-52.625998,-82.548984,-110.429544,-87.489561,3.981712,37.724043,39.778692,-7.958386,-23.008337,40.696068,117.636112,169.986763,98.75486,-105.533417,-176.7983,-202.413798,-147.905694,-141.555999,-144.72039,-114.921045,4.499315,34.635851,6.652859,27.713105,38.124125,53.636352,98.251509,179.727531,162.848982,54.999504,20.091771,48.357089,84.61128,80.416444,91.113745,107.509919,174.459758,235.219132,313.129596,224.675136,142.992439,38.363413,54.094158,174.482967,228.400436,230.271417,167.297321,14.482472,-14.616417,14.380929,104.263046,151.837975,223.781579,246.712207,211.937105,67.62259,-4.635124,-124.058721,-146.156871,-55.008571,19.252057,61.318079,24.056501,-24.515829,37.117316,70.197426,108.12346,139.852078,225.993,248.628975,223.207003,152.915709,123.475082,67.556285,31.688274,-5.794976,34.481743,179.222612,190.009536,59.952266,0.462809,36.757084,111.232228,98.669081,33.117005,18.285909,-7.925259,-51.707336,-94.476268,-199.724334,-185.637052,-7.643047,66.887262,52.933696,-9.803998,-88.227199,-74.783238,-65.309927,-12.906405,10.228352,-10.306875,-24.750293,-43.142596,-83.191375,-121.472775,-258.243432,-317.611158,-297.483951,-238.819122,-206.745903,-257.123514,-354.433645,-354.42907,-335.143481,-285.653273,-248.442951,-136.77516,-91.478421,-103.774023,-211.239229,-276.01315,-376.712073,-384.020941,-294.1077,-227.152242,-172.895932,-193.752747,-284.81133,-352.527256,-312.245954,-111.190835,-34.488755,14.104535,28.572014,45.634186,-11.367714,-57.956585,-75.717581,-13.30559,112.477682,114.318014,37.296581,-8.311641,-89.507784,-213.014362,-276.536425,-222.837316,-97.088963,86.305777,82.741233,49.448518,50.368529,1.725134,-139.160519,-167.194379,-112.244235,-47.578081,72.001993,92.065121,63.945409,43.25712,42.26583,2.017747,-21.086543,41.558626,113.518659,186.058197,122.3095,75.666199,68.627587,108.413524,122.776535,72.648408,-6.151453,13.753211,117.630288,140.878165,103.885963,57.639175,75.171295,108.737866,102.921874,38.460857,-71.009644,-95.579066,-24.267824,53.7195,174.656847,169.164086,40.966348,-21.375331,-34.010681,-21.419637,-53.362006,-107.614832,-88.941076,21.67021,62.86131,32.074042,-15.939359,0.98954,39.191527,32.54335,9.246567,23.066085,78.091981,86.29233,48.62036,-14.936964,-44.680995,-54.962273,-38.852961,-36.462708,-46.236278,2.884723,75.788346,71.547078,51.609605,69.264621,131.651148,159.288532,168.250687,120.393934,-33.111396,-82.279307,-64.246279,-26.967984,-9.380457,67.902358,89.759757,-5.787615,-116.821888,-139.729698,-170.416735,-184.403706,-176.957632,-133.788526,-46.360724,-59.953455,-177.833658,-248.803227,-241.582166,-168.785937,-149.471481,-244.009175,-326.946502,-437.37032,-453.997339,-451.949395,-416.038317,-364.795295,-236.504863,-180.399717,-88.185514,-55.061297:forward
-135.497192,-150.376734,-110.965257,-28.306534,-11.859145,-2.439974,15.090372,49.450768,-76.855448,-162.000056,-129.792808,-31.830886,56.432684,43.609625,86.482769,114.087962,-10.179257,-181.626411,-178.062016,-87.863434,-66.699713,-104.640402,-148.557833,-211.951114,-294.944246,-365.792632,-394.105908,-317.203303,-145.758293,-113.494155,-141.798738,-178.841748,-321.539353,-438.670722,-395.478159,-204.718599,-146.997905,-114.169064,-104.576736,-96.400254,-111.404316,-106.125713,-44.556272,2.265025,119.909841,168.052249,155.159378,106.026853,1.458966,-71.574753,-76.608964,-36.584936,-28.284544,-59.537784,-86.379164,-150.822492,-208.464936,-208.650525,-126.981018,-87.236658,-103.313467,-140.514017,-191.127958,-186.692916,-120.299713,-12.95622,35.043455,71.417316,68.303704,38.885807,-5.068857,-123.618521,-159.455491,-127.698946,-22.227758,19.364571,72.219928,83.787641,32.422607,-9.231673,-62.286668,-142.648349,-192.958678,-270.773962,-274.570762,-182.807743,-114.398757,-17.965328,-28.374044,-63.863141,-91.407649,-56.62527,93.505374,183.090627,296.325962,306.935623,254.700699,149.423192,132.094389,182.754314,209.973628,193.23058,147.751952,68.191843,30.06446,3.844843,-17.875308,-6.57307,13.027143,8.89946,-21.637575,-13.863025,90.301256,147.974386,120.674925,19.985764,-14.424637,-40.65188,-66.116553,-147.591695,-220.648382,-268.964883,-324.514376,-304.55324,-301.4832,-358.624895,-493.003024,-520.552293,-481.976842,-421.30599,-405.602028,-322.725699,-228.734202,-83.393053,-80.245199,-102.566814,-94.415778,-107.432673,-124.672236,-105.277137,-53.714421,-54.132922,-112.423759,-121.722799,-39.285193,82.455191,126.866876,112.572981,58.634891,-40.01034,-71.193968,-109.277249,-152.794341,-179.782243,-151.173156,-111.551741,-126.169916,-169.663813,-201.753502,-182.918987,-158.641151,-183.184547,-176.733596,-62.972576,30.512979,159.006048,152.830872,55.280569,-33.773837,-51.491603,-30.472674,-26.736985,-74.467776,-101.865489,-141.045167,-150.086276,-141.408764,-172.281985,-189.454281,-124.705562,-38.77477,110.802203,115.707657,17.554265,-129.789801,-189.934689,-213.274057,-210.051082,-243.707688,-261.076563,-279.538759,-279.408219,-267.557161,-256.335613,-209.681447,-42.786653,11.831858,-23.175202,-85.458912,-225.55402,-378.391158,-434.402094,-436.683519,-398.59742,-300.262136,-262.228608,-272.906077,-299.629717,-336.518965,-395.294218,-418.819217,-407.358766,-367.544591,-294.885324,-308.08041,-374.641434,-382.021453,-391.660577,-398.240323,-368.998301,-279.465048,-242.803546,-224.274952,-246.452166,-330.954982,-446.698309,-484.295567,-416.468488,-319.51871,-177.269334,-186.538255,-283.378845,-369.524675,-385.757852,-294.552876,-234.105476,-208.654148,-227.261806,-276.713448,-297.095375,-316.984244,-351.049678,-359.765883,-365.196175,-380.176969,-366.666537,-329.819271,-239.951161,-169.675939,-150.675943,-110.802286,-104.250376,-122.582292,-111.672445,-28.881675,9.42907,0.29676,-38.017678,-11.310876,89.462206,142.365565,273.833525,324.416209,265.686467,8.925151,-112.800457,-165.99023,-96.020247,34.884302,24.843659,-90.072603,-114.194464,-7.842871,128.895942,163.953823,193.155292,188.666709,167.278016,160.67559,123.363007,56.393638,49.223133,117.285762,145.487168,108.081074,81.166577,88.753605,92.815117,19.063713,-3.583246,73.71626,251.198136,280.650427,256.059043,232.249404,179.558046,104.668449,91.263127,193.994139,263.015418,296.52032,272.823124,232.192014,222.133264,165.114478,68.571972,36.232519,4.157173,8.634542,32.969861,24.573256,-17.96143,-87.429513,-132.931507,-135.279448,-79.793515,6.817706,9.285649,-15.391823,-16.794735,-3.961976,-53.633694,-76.544967,-32.37325,32.591672,157.834205,165.73881,78.931801,48.859092,73.396109,114.012016,127.020893,175.072238,197.474239,189.060311,165.900006,114.747521,75.519223,83.355087,163.456306,210.015356,267.385298,273.762129,202.462288,52.25962,34.979658,240.452876,391.091511,588.411398,619.739512,546.595905,489.61066,422.639708,319.502256,260.632522,198.644691,200.333119,196.222044,148.708392,23.97274,3.935998,19.631688,65.927796,100.379359,162.37389,157.881578,69.623945,29.480593,-5.823593,-18.657976,8.485048,118.367399,164.954517,183.356972,153.439458,94.232924,23.869508,-33.467054,-68.630344,-29.505544,57.463925,67.258612,1.650615,-59.830543,-176.375068,-119.497171,0.89106,271.764074,356.743609,372.482484,313.678777,139.096385,9.991046,5.585638,109.943915,169.873843,232.867853,234.665864,154.746711,86.155482:-144.730621,-110.243321,-17.86171,181.086156,218.663636,132.328988,58.93531,-30.427185,-46.259251,-40.945812,-1.633254,43.333038,129.272014,135.339501,106.333482,87.363447,11.586716,-44.831913,-45.461437,-45.04618,-32.634968,44.492591,59.730812,-53.521597,-234.478631,-292.259299,-298.724749,-242.105366,-70.571799,-1.869904,4.886113,-50.297394,-201.10104,-286.315606,-242.594421,-60.145773,-6.739468,-12.811399,-43.983802,-120.170847,-149.729897,-117.52863,28.114335,106.756411,208.936187,210.493282,119.766163,59.122229,-69.252825,-174.264496,-174.991394,-66.745247,-7.67019,5.515907,-39.299337,-141.53209,-185.8632,-167.038904,-27.267534,45.162758,83.944227,52.770564,-66.319556,-114.863169,-113.583789,-33.977592,11.814181,105.037098,140.7471,120.00905,59.820781,-87.766968,-176.729857,-186.844516,-160.526806,-120.684553,11.412651,71.389304,68.775706,-2.437292,-175.956094,-245.925252,-242.847331,-222.375752,-210.748371,-187.571824,-173.611007,-120.251773,-98.457093,-121.28396,-132.601809,-84.318144,69.496565,122.240591,120.881351,100.71092,74.555755,10.834243,-21.436074,20.173214,88.015212,149.497722,109.56015,-32.504582,-127.420507,-117.883611,-49.100183,-42.016783,-80.215806,-96.061497,-89.800448,-74.086622,-69.968067,-117.508142,-140.9335,-183.515456,-200.516326,-206.588923,-195.436323,-201.143982,-337.700476,-421.147289,-425.641416,-345.47776,-256.773084,-317.591638,-512.650205,-559.249396,-576.785936,-539.161535,-477.542731,-281.79752,-163.394807,-31.187869,-71.237156,-253.867423,-342.290088,-330.312493,-241.199264,-188.937444,-107.261662,-106.853147,-195.148238,-223.69957,-170.460254,-71.185597,-27.405773,41.948053,54.429763,6.778805,-52.562256,-199.786106,-269.328706,-250.638796,-137.644046,-80.723513,-53.398647,-78.121738,-131.72305,-143.340156,-170.440891,-172.973393,-129.258159,-28.403309,-0.185729,13.412088,-9.127846,-100.192283,-166.394199,-155.478756,-86.631326,-73.52465,-81.190342,-87.721645,-136.831416,-174.784604,-250.568717,-283.39015,-252.427081,-98.958948,-10.645352,85.731218,71.697269,-45.4153,-214.260597,-268.873298,-252.060485,-234.739466,-282.774022,-303.276023,-292.800094,-299.61231,-332.736481,-300.914058,-264.039295,-175.019567,-126.063193,-76.651032,-106.815849,-286.903242,-457.182705,-467.537144,-383.938158,-354.864905,-346.418694,-343.009126,-379.957388,-433.972116,-545.874094,-541.432944,-490.488543,-371.6924,-345.949393,-408.017918,-454.866807,-466.646394,-482.629763,-520.199033,-514.542697,-450.269221,-310.902385,-271.369796,-301.27561,-375.942852,-511.162429,-474.426456,-412.691004,-256.731933,-182.688365,-164.937186,-231.008871,-354.077032,-398.855519,-405.578874,-334.040298,-266.125286,-178.557185,-178.714236,-237.071798,-270.001168,-326.880551,-368.8068,-359.682654,-304.764809,-285.701022,-266.979627,-255.755295,-220.783834,-192.043737,-171.274797,-103.123043,-77.436014,-75.64392,-82.868455,-31.003905,28.052188,92.674478,88.083999,110.736635,166.153848,175.85801,164.301358,140.641628,62.343018,-55.471533,-109.745481,-113.967689,-55.335738,65.787175,69.670703,-14.694787,-45.273819,-4.286268,100.967097,134.676104,154.222288,165.593189,207.365307,216.251234,168.301426,78.706289,72.484332,174.081575,236.87697,282.082355,271.907572,272.550715,288.655342,279.408401,261.577986,296.032874,387.454596,398.353901,365.58045,358.305537,360.558183,288.862507,266.154629,364.014321,461.605946,586.358605,569.244602,420.930587,332.646076,153.205482,60.046785,71.96634,85.511455,77.818291,62.128055,42.366705,15.279598,14.135048,-1.569243,-21.610594,-2.487545,68.172414,95.372514,101.271991,87.318978,44.553398,3.652803,0.740033,67.722667,127.949169,195.810237,198.041056,207.965668,161.689394,122.109069,107.445148,136.166357,216.092557,232.832467,210.10112,198.505523,197.70211,198.669938,210.275197,254.737788,269.99842,276.648408,273.18112,238.670022,164.638537,157.584382,284.122965,395.215283,594.14244,635.443727,569.572513,491.584026,303.640898,185.162664,202.9333,273.268963,268.883644,207.530544,165.243575,48.53575,-62.63565,-79.661416,-15.507644,39.788583,127.141875,146.978619,118.345203,67.73163,-66.117607,-72.755248,10.786463,215.19809,258.323455,205.716852,165.68284,134.852701,73.577773,40.487424,78.47152,124.147542,147.024268,114.83727,-18.06313,-98.003401,-197.255331,-137.219797,-39.570048,183.062487,252.197967,277.415586,238.913987,94.77561,-23.422983,-30.853195,36.050999,64.788886,70.914193,55.619859,-19.934327,-69.877896:-50.247992,-59.651005,-16.667917,102.880106,143.756311,101.04289,22.280105,-88.531267,-43.366945,6.12593,104.011176,160.50666,244.598486,233.761224,165.15221,136.958757,44.623337,16.125749,56.37247,125.449417,148.180238,186.899152,175.089252,59.551307,-110.578089,-171.940713,-185.911485,-142.043476,-13.060555,41.576624,53.06038,-6.752764,-167.387285,-166.128561,-91.086536,45.348323,45.022993,-75.456401,-127.719998,-154.261872,-194.804975,-190.579197,-52.995781,42.261342,179.361392,200.647232,141.594808,71.111123,-92.634399,-132.726526,-97.076676,-41.802238,-37.301543,-53.384442,-98.258179,-240.422901,-253.805391,-188.438806,-44.708896,-6.65181,17.988685,4.052221,-90.286566,-129.861805,-103.900528,-22.798237,12.623047,99.390311,145.704529,159.521519,100.134352,-95.973315,-178.671381,-140.0933,-46.298844,-32.203532,-15.442717,6.916782,25.252104,-9.198489,-145.292174,-231.812142,-224.651837,-170.163573,-164.832093,-213.991596,-226.242069,-172.019222,-137.956504,-146.769983,-133.870442,-91.348306,8.984956,25.246274,-9.686865,-42.315659,-151.499325,-217.459349,-187.383529,-78.078156,-39.722545,-29.481981,-45.218198,-76.160496,-104.338767,-121.991513,-160.774761,-158.757652,-73.843672,-37.547335,-44.548047,-47.636468,-47.307849,-127.637553,-181.661259,-232.654206,-211.215204,-139.692379,-147.768667,-301.651783,-487.617505,-524.886001,-431.993079,-342.12699,-248.85581,-275.521363,-399.854253,-451.606186,-537.33722,-526.939907,-439.70964,-206.655151,-119.963122,-75.217879,-105.691625,-181.552155,-190.490517,-166.042588,-146.694735,-160.100375,-144.704795,-121.687983,-120.477629,-141.944135,-207.305698,-202.5276,-159.787352,-124.932453,-138.453772,-139.877753,-151.418273,-270.266371,-361.824113,-320.024047,-86.613293,7.5547,-23.177564,-95.722525,-169.978745,-160.848631,-125.046863,-125.822339,-125.286112,-76.033508,-38.482189,-7.707171,-4.020528,37.981992,65.843373,53.746688,10.31822,2.034069,24.274738,43.340797,44.646393,5.28471,-89.44474,-72.533055,-46.866943,-10.990927,22.144173,100.003013,102.935038,-9.565473,-196.020276,-247.375686,-183.653697,-110.794149,-43.038384,-55.795276,-85.267086,-83.954069,-134.592916,-226.897968,-203.273355,-74.771847,-48.09285,-74.362517,-104.639867,-224.989571,-371.693792,-405.951678,-356.897027,-308.852471,-269.027433,-275.692675,-297.244758,-324.580265,-452.442167,-488.072828,-435.399934,-348.994633,-345.533459,-407.131696,-457.918665,-494.191877,-437.797836,-421.230047,-418.492545,-403.825114,-300.075988,-242.303377,-247.277899,-319.298661,-480.826774,-447.691078,-367.32104,-211.646192,-157.673334,-174.317321,-240.084751,-335.878031,-381.846101,-388.363747,-298.419306,-232.423116,-197.320177,-242.679788,-363.436852,-389.169886,-352.425479,-266.122324,-240.945977,-252.620738,-257.55307,-229.333206,-211.069336,-152.792703,-85.353253,-81.75216,-121.115546,-111.218769,23.470068,80.365361,44.560805,-3.554395,-32.165069,58.492895,120.332714,154.572956,134.279983,106.082422,85.879402,9.018784,-67.546224,-97.092429,-91.178156,-46.525204,57.799676,70.450458,-17.575265,-71.550991,-75.1178,45.767406,116.339021,195.073657,194.873584,144.661678,109.588434,40.735889,-10.78526,4.669626,143.928063,215.033832,269.825393,269.447329,261.485105,245.009474,159.628474,151.482591,216.606158,349.881166,368.423763,336.274617,309.433345,263.61129,194.999112,182.543241,291.860224,380.648653,494.270952,491.549136,394.403038,320.86223,123.341363,-23.27207,-20.580962,69.645303,100.241275,57.691278,-6.491019,-119.071146,-129.243409,-95.760519,29.758555,101.80564,188.288538,178.149173,112.711158,103.642532,125.833399,130.303626,115.403692,80.033013,93.852363,168.254475,175.243773,79.259559,-28.95346,-24.905052,56.349826,69.275787,55.919374,69.76375,95.844849,79.366476,6.035785,7.537876,68.782072,219.512299,252.404496,206.557756,179.125547,166.80253,108.817818,98.436413,211.777783,297.378121,405.221336,415.690696,374.387706,334.915561,238.536245,184.902024,215.348326,328.331608,338.643035,231.589493,152.871579,-6.089633,-118.255998,-105.582153,23.945898,85.118355,167.022054,181.364081,124.047186,74.61178,25.28823,77.538794,120.174327,207.056579,238.808081,235.404846,206.094541,147.008398,68.364493,34.073675,54.597281,73.01712,28.785623,-4.383465,-40.437668,-59.347826,-99.298934,-84.956186,-58.949622,35.739604,102.387029,153.968517,109.544331,-25.754353,-131.549494,-144.155747,-10.798523,95.415307,205.686628,180.358062,57.582662,6.40539:1.758767,33.850286,49.898557,19.493054,11.338627,25.761979,25.582448,25.608611,-8.597073,-30.174387,47.919103,139.738758,268.128935,274.173994,224.105962,183.364188,54.251432,-27.646341,-11.26789,63.624951,82.946255,83.109747,72.542758,-22.382561,-215.376499,-283.459156,-293.044382,-267.166117,-183.945333,-121.447275,-68.998197,-116.005733,-260.90793,-287.263372,-240.675706,-126.911614,-92.487416,-93.716304,-118.598597,-142.222624,-128.895583,-107.500687,22.008373,95.578483,149.980379,148.294767,133.101338,91.005228,-89.826177,-193.37582,-166.043159,-60.786097,-34.708407,-79.44899,-131.474567,-187.511703,-152.262778,-129.877572,-88.806355,-67.583494,-49.512391,-65.514677,-132.183699,-158.236914,-175.159847,-123.959055,-71.040078,19.239276,51.573497,96.92713,84.190974,-15.345045,-104.753584,-103.934099,31.01661,106.969349,106.27854,60.063665,22.139397,18.76678,-60.015601,-200.975946,-242.927634,-227.99395,-187.022097,-150.243926,-184.358286,-287.012854,-302.70753,-270.249015,-182.563183,-152.543508,-55.94432,29.992983,148.253392,134.982505,6.380468,-92.315675,-82.644261,28.849943,82.205791,76.814812,35.056829,-3.348807,-3.389631,-16.746446,-40.856926,-42.405885,-18.902497,5.105888,35.257525,33.398374,37.702728,35.004228,-1.808563,-96.229504,-115.174813,-110.104498,-103.628987,-126.368175,-275.880116,-363.199659,-378.954287,-318.464007,-259.666953,-302.669816,-457.726163,-498.311847,-453.13502,-360.18335,-316.076638,-211.385835,-146.504047,-46.31412,-40.214528,-84.122833,-98.767569,-94.260345,-72.376734,-60.682841,-71.821296,-94.447561,-134.423268,-132.291198,-88.981864,-22.239531,7.266216,-4.746277,-34.63783,-64.907266,-65.979289,-88.659584,-151.685328,-159.763629,-78.190788,-32.837874,-31.402168,-42.294603,-41.254347,-62.136866,-132.858243,-127.549052,-97.179748,-15.792058,34.233624,136.041761,168.861784,152.9714,74.153738,58.178573,44.52411,10.672674,-45.744183,-24.631579,32.953757,17.835199,-76.88681,-130.323693,-112.972063,-26.322392,13.946171,47.891814,34.599162,-36.441173,-140.400568,-191.378427,-222.805592,-200.718032,-151.819969,-133.854338,-101.538926,-100.458259,-144.510178,-173.956251,-141.640349,10.653547,73.446156,59.109596,-5.041116,-157.744894,-294.95043,-324.061762,-227.611512,-146.901734,-71.565822,-78.181252,-135.529503,-187.913228,-335.353905,-442.891173,-454.261537,-419.695172,-387.186573,-365.941901,-409.536837,-519.896712,-524.341948,-502.771788,-401.913571,-331.360061,-238.502732,-223.227003,-263.283903,-321.025678,-434.351918,-419.862066,-370.620402,-263.794933,-213.154209,-197.705289,-269.8038,-422.467883,-424.072487,-385.67285,-253.605204,-201.074403,-169.840484,-173.137947,-250.181794,-317.936553,-398.865243,-350.721378,-299.565924,-230.218417,-224.68119,-229.970618,-219.856094,-159.125371,-105.196274,-85.284547,-49.283175,-40.647102,6.439911,45.753203,61.503884,50.940038,83.84965,125.368098,135.616132,164.921245,183.842917,223.929686,227.35841,156.011112,5.026821,-66.057808,-107.286619,-77.958833,-26.643623,-40.761374,-126.356038,-158.26475,-140.818249,-83.553364,-53.177092,56.215245,116.654937,140.538147,99.845502,-19.06146,-90.793886,-72.572989,26.592347,61.604203,86.537702,91.064941,106.742665,110.840245,39.668908,-6.964882,57.047624,195.378146,199.034143,165.132467,151.980078,86.236578,-14.249505,-25.280969,110.253142,196.895609,260.551147,254.099058,198.231588,141.133085,-10.303222,-68.260922,-38.388895,-16.540142,-54.764393,-138.498698,-164.666048,-202.644418,-227.971008,-225.923982,-172.321418,-132.557583,-62.975539,-33.156671,4.33906,-1.748921,-65.296106,-147.654239,-159.600945,-54.324532,31.085706,91.275387,65.124383,12.019706,-57.702179,-76.939786,-19.671185,19.254782,34.46975,14.79127,-22.353793,-20.731241,-12.81987,-6.726448,21.186009,112.636757,160.721969,210.002159,190.923564,109.941498,76.759751,90.06127,175.679398,241.170651,392.082519,449.42691,466.302945,436.189882,295.257012,169.205844,190.731774,258.163779,236.718397,172.166276,157.144874,72.195179,-82.943138,-110.563255,-61.30852,-27.879149,62.838958,98.726469,72.721776,44.303141,8.391899,-36.864045,-24.95493,101.215649,159.142628,186.168219,180.161548,162.339289,73.702419,8.750273,-44.816616,-17.370731,61.697599,68.484516,1.085703,-34.235186,-28.121583,58.800111,101.886554,168.684767,219.30706,345.465496,363.477759,217.778052,-16.432752,-61.876403,34.147562,104.076849,169.770372,171.337234,135.156439,115.47163:-195.003156,-177.521781,-77.35761,124.350191,176.733427,146.46498,75.825535,-84.64697,-156.429057,-116.49413,82.142298,176.684977,276.744227,286.360249,219.569829,149.243745,4.433193,-4.464968,49.064649,181.113542,229.662465,209.375972,134.934523,-61.797014,-208.373139,-216.859215,-133.307462,-97.343592,-54.136608,-24.436038,-15.358947,-73.175435,-221.153477,-195.521955,-124.832601,-5.477839,21.869224,22.075627,-0.011442,-56.588614,-125.064658,-145.48567,-73.827712,5.169723,137.706665,169.572911,168.850603,131.657967,16.406307,-29.272196,-10.162999,38.734681,34.825238,-44.016729,-97.528591,-184.709343,-195.660313,-150.992417,-28.956526,3.754958,2.875399,-14.470721,-57.539873,-77.140261,-104.435176,-73.799811,-29.79131,74.381304,115.317631,117.672003,75.155776,-41.411004,-114.430817,-83.470973,77.082093,127.230035,132.967322,125.118424,71.684441,-1.882798,-208.712771,-275.255858,-228.97434,-124.261001,-109.892612,-143.824685,-158.660853,-167.029806,-240.930322,-288.592148,-252.47044,-150.218949,93.740021,167.379425,150.470745,71.685271,-116.64094,-163.624609,-129.143667,-8.218317,65.447078,171.672584,179.530304,122.070494,28.317246,0.328351,-4.056274,4.145187,50.557432,78.46543,78.535274,47.658495,-63.495437,-119.47569,-86.912137,-20.304629,-21.79397,-58.143078,-97.456812,-293.516796,-518.011175,-533.830889,-376.400295,-290.400877,-250.972609,-287.382145,-358.68635,-374.301618,-407.902701,-378.234402,-310.412646,-125.533938,-42.445191,14.204974,-16.245747,-83.287081,-89.363751,-83.968866,-84.884942,-84.859768,-60.198942,-52.46573,-57.094184,-54.015514,-91.254188,-158.5547,-143.761778,-71.95105,-67.959772,-97.941111,-102.343318,-131.963331,-199.606452,-206.665142,-118.786914,-40.848662,47.165222,32.379259,-10.710131,-20.469317,-73.055786,-155.935838,-158.891953,7.147764,122.010565,194.881678,155.996886,62.965679,28.733057,58.108326,120.154339,100.352648,81.541102,132.819479,183.032377,106.958252,-114.8862,-117.779706,-44.219531,81.676474,117.085268,168.412176,170.408664,69.767279,-84.775425,-112.852517,-25.742009,45.774811,114.063769,100.639618,18.303628,-28.937516,-114.249115,-122.761762,-74.51551,50.31226,96.43787,141.674013,116.809276,-63.435043,-237.29238,-238.284303,-89.514075,-25.820292,-35.370563,-64.729788,-119.101986,-181.436734,-359.615836,-362.342566,-291.196912,-158.899929,-125.302711,-179.055522,-252.982122,-353.739634,-397.767333,-409.865407,-358.196008,-300.07663,-193.164229,-168.745855,-202.512297,-258.600167,-369.900655,-327.646725,-260.174903,-145.479047,-109.327235,-142.839769,-228.319697,-403.317152,-413.153086,-359.415676,-221.765431,-164.764114,-142.534013,-188.377465,-304.428062,-343.134637,-372.744272,-306.364105,-243.581167,-120.659405,-69.480375,-57.54872,-107.06408,-182.54721,-177.177963,-174.298308,-128.447265,-50.02915,140.235272,159.292889,-3.326236,-90.253353,-116.249231,-14.997891,42.439725,96.000799,95.064779,114.998804,127.244462,29.439648,-176.176574,-221.42609,-164.526845,-120.43466,-74.311558,-69.291029,-84.430178,-85.531225,-62.543592,-26.153431,4.948112,89.066331,135.038059,172.431597,133.355259,-43.965077,-156.255022,-130.918923,-15.30037,32.599696,111.741585,137.839099,148.656302,119.286649,-28.890049,-60.094862,13.321376,156.20978,184.013727,190.119258,167.910886,25.434867,-146.012096,-139.991997,73.88294,180.029658,260.633982,257.031958,193.852423,140.795315,13.816029,-88.235764,-108.976942,-73.108144,-33.584681,-21.107549,-66.899711,-189.446052,-265.356714,-267.720673,-204.293385,-150.650065,-32.119481,-5.376329,-38.080726,-68.786701,-120.492593,-87.133207,-31.566247,91.05369,145.352299,204.539277,177.401871,0.137759,-205.129289,-231.970913,-106.698862,-36.767016,24.95802,31.870992,0.571323,-38.34501,-116.86884,-92.016378,-24.562571,135.746269,199.273745,247.674464,215.733696,101.712991,59.117451,84.74827,191.170613,247.059403,365.010159,414.34114,392.334705,318.714427,158.614118,156.215814,214.598988,297.05701,294.840915,220.810915,149.757728,-54.533651,-221.927306,-204.811457,1.887696,97.396759,146.430719,103.165203,-16.73066,-46.585556,-57.647386,-16.937429,29.380398,135.355222,183.291982,208.650579,175.696105,89.973027,28.689823,21.970976,52.602214,60.464589,68.708298,75.824667,47.784624,15.969916,-39.638996,-28.021551,5.551974,126.187397,212.283587,304.420695,266.137713,96.73072,-61.896112,-77.162921,65.136201,166.803796,262.329595,233.088265,99.78096,20.632491:47.104818,-55.924859,-45.097167,24.825684,53.968486,92.037598,84.160309,7.383765,-110.375983,-140.929424,-11.882845,118.338096,293.861296,313.370795,293.289154,263.206728,135.476737,35.631554,55.655118,151.912539,152.633849,41.997846,-23.987597,-157.640723,-335.438295,-398.389777,-361.889471,-284.059621,-134.734367,-85.896061,-89.024722,-171.974513,-405.638616,-371.196974,-260.014007,-132.119972,-118.340473,-36.638283,2.56987,-84.272904,-205.005142,-160.31562,63.655502,145.633993,197.512749,192.417563,122.419573,67.876978,-35.269375,-94.364978,-81.751768,-15.169972,-5.336755,-101.159464,-184.266218,-258.929127,-246.235773,-253.136582,-214.997559,-161.406255,-94.457187,-108.109725,-177.669181,-186.287141,-117.487452,-7.7178,40.835314,49.450409,6.514263,-38.829897,-21.847421,31.84828,83.744437,108.359832,147.911123,160.162959,172.206396,182.837085,194.682209,158.989784,-20.504894,-174.070171,-179.268018,-145.48812,-162.140624,-206.579836,-191.665343,-117.891697,-118.610112,-146.422461,-166.477475,-144.107036,-11.71516,96.520431,253.511086,253.816773,149.916189,97.284331,143.741052,286.145551,311.768604,255.674705,215.958026,140.005833,27.389552,-5.479616,62.686444,128.857922,203.74202,183.939406,61.082002,35.903432,133.911357,195.958811,166.632153,80.693768,50.175601,-35.259949,-101.605793,-235.367643,-382.981693,-443.057052,-429.051899,-382.831378,-366.744848,-405.783824,-494.425356,-519.363667,-517.427474,-407.475816,-314.621024,-169.83897,-150.517016,-171.401841,-180.403388,-149.791367,-95.341348,-65.185182,26.945877,57.239253,39.745678,21.297619,26.92666,54.51028,88.648656,40.687371,21.375431,-1.946817,-14.097413,-14.401532,-32.136786,-145.979838,-205.718587,-183.186628,-92.725387,-78.617646,-150.617636,-182.254917,-170.237625,-158.146647,-148.001871,-90.467293,-51.961501,-2.40442,41.548528,211.024767,264.394925,176.342475,29.834321,12.916096,46.291606,47.778854,3.296594,-9.605431,14.590556,33.263386,29.925389,-8.105525,6.59562,116.269347,171.617952,174.243829,109.328211,-13.953636,-15.133271,-5.542797,-19.876234,-49.78679,-149.438558,-179.74924,-120.871691,-73.465189,-88.220266,-102.397176,-40.966677,87.250792,110.513827,126.332245,130.108656,72.672847,-74.573276,-111.394399,-39.381897,18.587146,67.392684,51.08743,-36.569381,-73.444416,-131.670116,-274.056258,-335.783259,-330.911499,-273.165903,-178.51882,-202.500371,-357.11615,-394.487973,-353.01984,-295.824385,-297.583261,-295.463226,-272.827349,-226.740931,-227.211192,-239.744774,-242.569054,-249.504549,-219.024284,-179.200696,-152.789703,-186.226877,-251.089484,-291.701694,-299.107812,-212.534062,-140.398167,-43.857917,-41.239113,-145.731981,-233.62963,-360.97249,-354.758152,-326.0293,-290.554785,-283.009414,-267.840419,-265.727076,-233.987738,-188.795726,-183.099825,-168.037371,-160.099498,-156.537388,-141.029807,-75.346772,-55.200325,-90.703714,-95.916896,-42.761315,72.800454,105.10392,166.927795,193.914574,165.271823,0.728,-80.950673,-106.624105,-80.479286,-82.583394,-101.648044,-114.131977,-95.064276,-22.032443,12.529464,17.150284,63.751278,97.881497,115.4117,93.036433,7.439267,-95.615591,-97.595109,19.190424,57.958743,10.27912,-16.214105,39.654175,86.581447,48.581219,-90.115946,-78.702496,98.976547,161.962454,114.657944,35.357782,-146.109272,-310.209049,-319.848295,-111.977618,9.501621,68.589995,38.091633,-12.810351,-30.495631,-83.636586,-129.318112,-121.890985,-81.307232,-80.973913,-142.280556,-195.866502,-273.354023,-276.691782,-272.009851,-227.861712,-183.935591,-111.755733,-106.812177,-148.275844,-170.716746,-178.156674,-149.79464,-137.024115,-140.875054,-144.66708,-81.465148,-34.63494,-48.814573,-155.581553,-175.767531,-115.191921,-54.106697,30.986546,23.564076,-16.947017,-7.170968,-22.779177,-106.730376,-102.803068,-14.267533,15.9506,26.935842,31.121272,26.662292,5.567679,25.935547,172.085031,258.50286,362.347896,379.529489,343.739793,298.814157,221.754027,222.9395,245.953604,264.968349,243.529896,124.440245,46.611323,-47.061734,-60.461912,-36.225628,118.015896,199.918179,223.780952,163.874189,5.119153,-38.499421,-45.239823,-53.4001,-57.207417,-19.286181,27.087127,143.342837,184.57128,150.1562,-23.239442,-83.01891,-58.809626,-21.105159,-3.061477,-13.360619,-25.176166,-32.742657,-70.37728,-34.870768,56.524557,275.322745,328.927402,320.967904,282.042756,178.663976,58.207102,11.927367,71.195835,163.844707,277.257523,246.184183,106.245232,70.773479:-33.382236,-90.732443,-14.517938,148.188679,152.188761,23.927999,-50.549073,-136.127188,-187.48267,-187.031824,-24.295492,124.893723,378.912969,420.173527,320.885588,218.485867,13.500444,-42.764207,4.416084,114.054661,118.201633,54.561451,19.238597,-97.748426,-258.173351,-298.0962,-282.473248,-231.949446,-71.246618,-25.797676,-98.469494,-177.12933,-332.892804,-362.173718,-283.415757,-76.048946,-13.770447,31.625221,21.083077,-73.523416,-150.803932,-131.462029,41.15924,143.547835,221.960811,196.141879,120.395431,81.642343,-54.473393,-144.190411,-92.723763,68.272093,75.783921,-57.580386,-134.552275,-212.882888,-236.704003,-232.010323,-117.585191,-36.196513,5.47962,-40.818293,-108.00962,-106.168871,-132.79088,-139.348008,-95.332324,7.78971,43.06936,70.974155,40.197237,-64.985862,-65.907542,-24.08599,94.394207,149.051483,183.339346,161.667282,88.54713,34.248265,-133.080148,-236.803421,-207.12363,-79.324974,-54.792395,-109.688074,-149.275734,-191.44873,-242.857725,-275.597509,-240.601627,-159.10443,58.064536,146.333883,197.89584,174.923189,91.713499,24.431357,38.755106,152.929099,210.735654,248.474131,235.196865,194.745492,60.768724,-11.470883,26.691074,102.025433,166.601508,156.925617,133.41317,126.83593,96.210971,28.842347,1.295336,9.91874,44.240335,71.596243,19.425489,-214.440861,-437.311458,-459.694616,-315.564412,-229.902231,-201.690811,-255.690463,-406.902462,-456.273121,-440.991271,-309.14388,-222.623109,-73.309945,-42.350279,-75.769729,-92.268823,-58.624147,-65.242697,-99.687274,-89.146633,-25.426494,89.644649,96.411494,38.543532,3.214916,-91.731589,-156.278759,-136.893447,-33.961984,16.589711,41.245054,0.750146,-117.57168,-131.114746,-90.937653,-18.174218,-3.850682,15.907292,24.798357,-5.119364,-46.085806,-126.394059,-105.922221,-37.994377,114.590046,160.853833,213.001082,227.149386,164.157474,32.810678,35.21649,119.460713,112.992491,55.207692,72.93557,120.915994,85.212867,-47.302745,-45.336975,4.951101,79.038696,103.472094,145.59017,130.572851,32.874051,-70.890058,-102.969777,-73.939878,-33.764742,-0.938349,-6.247808,-11.004985,-6.689164,-13.490018,-5.94262,28.301682,110.399385,148.337464,228.768138,224.737285,18.271943,-241.72692,-253.609465,-33.290131,92.892782,192.600083,164.105937,37.971276,-29.025685,-182.195237,-320.273759,-320.541268,-143.76168,-23.362588,41.488515,-59.275922,-322.328826,-345.129363,-287.8149,-198.802712,-178.776514,-126.032311,-92.973164,-79.459696,-112.734397,-244.920824,-328.712457,-305.573832,-157.225993,-66.687664,7.692096,-53.135829,-277.495774,-382.124754,-356.514732,-206.006188,-115.280009,10.158721,8.673772,-149.811807,-269.574378,-443.581946,-398.199885,-310.540254,-150.544699,-117.410673,-119.209166,-122.405686,-108.161561,-132.278281,-167.123483,-202.326364,-157.727217,67.604824,159.24548,108.092039,14.730536,-125.036671,-162.65612,-130.458057,17.860375,84.782544,118.848931,89.352693,-10.41697,-116.696358,-144.228481,-97.484873,-54.408656,-40.618442,-72.223472,-144.564175,-163.119551,-173.020655,-162.088116,-118.259613,30.066225,99.693415,186.407546,182.93213,42.292538,-156.740028,-194.222895,-117.015463,-53.920549,30.416964,60.254417,97.329953,72.609697,-82.130566,-140.028035,-64.388139,113.385395,125.428029,-2.53142,-104.425307,-302.549272,-319.830365,-230.88182,-6.499475,64.114162,130.56895,141.650091,97.026786,44.666592,-89.789855,-168.814353,-155.115084,-91.003485,-82.648074,-129.638139,-186.99082,-341.078628,-427.091298,-423.694762,-295.676001,-196.669439,-63.430268,-47.604511,-92.874119,-135.392733,-211.057251,-199.58698,-154.170161,-42.633347,16.657245,103.55357,85.993356,-71.811084,-213.590675,-218.753914,-150.903702,-125.346831,-62.658112,-15.004133,16.3443,-10.148304,-53.688261,-4.630911,45.634792,152.372955,189.224799,198.240008,186.681345,163.231495,87.312367,68.964793,183.027844,267.889216,368.732929,393.36675,390.562269,340.861457,192.652939,176.289361,229.247414,319.674581,316.091746,207.640104,134.934944,2.065692,-120.886671,-133.241717,-9.22541,65.091034,124.213775,105.589107,-20.10739,-92.459466,-172.72667,-146.338609,-89.506637,49.933918,107.957339,191.687716,201.237304,87.30596,-112.759346,-147.080792,-43.647773,29.384524,86.099045,80.507359,65.67199,54.373949,-4.053966,1.78754,66.046151,191.675914,219.894559,264.081445,274.842578,151.05012,-57.129969,-80.612643,30.761485,101.208311,191.273207,196.616717,141.8675,112.979522:30.191116,-45.793363,-39.322911,-17.166028,-9.712186,42.097074,56.032817,-17.329647,-134.887393,-137.803098,17.538786,133.115707,304.547448,330.382083,284.900714,252.117589,202.393429,149.256814,134.594353,135.158157,121.776623,-5.160145,-95.371183,-193.192702,-260.674175,-309.654639,-297.195391,-255.338901,-222.368655,-197.150435,-64.456895,-16.126613,-83.259746,-177.323839,-136.636059,53.911466,130.3551,201.276025,201.82895,116.584432,24.04252,17.741548,102.238903,177.362434,296.824676,302.4532,212.416938,164.496647,102.021792,61.244914,69.174434,77.586375,42.347023,-81.165959,-149.227933,-207.352561,-139.015018,-122.937636,-133.951098,-115.800043,-68.528222,-65.003585,-28.122172,14.051949,92.923342,133.951595,142.732954,141.988902,146.072733,227.352191,287.429026,354.153345,342.99648,333.800791,365.184776,403.385348,442.037355,424.765186,377.848755,356.798668,289.994407,187.720206,138.06191,109.22731,127.821885,121.592059,74.979543,3.439101,-6.385118,-14.434177,21.885005,81.035333,227.883214,285.756795,335.390784,337.321822,303.696568,255.276109,267.805555,318.151021,311.706435,251.296802,205.620356,78.225477,-1.618894,0.512992,76.084298,125.486727,209.356953,228.067944,187.160316,176.223406,224.856778,225.906588,220.460757,208.920257,156.794325,-53.812627,-153.838267,-230.890566,-283.549486,-357.419304,-460.645054,-435.689954,-318.125137,-284.382087,-320.887549,-352.622746,-304.462037,-161.032008,-96.816091,-42.677173,-57.190004,-63.165935,-20.863751,94.288488,79.256048,51.858372,104.469768,155.396126,238.088246,272.720652,281.329505,268.127398,258.416319,213.211798,162.384865,31.917484,-6.228068,27.170732,66.0253,92.252602,57.470021,40.227158,8.128994,-25.376176,-123.123089,-151.147829,-117.925419,-65.108801,48.383132,98.583457,98.142169,92.31747,121.547973,257.367951,331.35255,412.501743,330.40502,261.690647,258.816349,316.969653,386.942459,378.065011,331.098785,322.147704,309.439812,220.9035,173.661837,166.675944,199.802851,218.243914,187.839971,146.015218,141.309392,135.473801,137.578727,138.344656,124.656923,108.111616,33.233209,-12.475234,-40.762786,34.465085,88.521544,189.887159,216.045455,212.605798,205.479546,199.384697,210.89966,212.775492,235.652446,286.002102,394.702972,386.182007,199.836109,102.545267,77.047575,61.475552,0.281286,-61.874867,-27.096599,29.354117,-5.463607,-116.775747,-153.515362,-146.765331,-114.783365,-123.453137,-175.682966,-151.721833,-45.988879,-45.800421,-86.308876,-24.96517,-0.537802,-25.742669,-20.201119,57.082173,59.702593,-45.224513,-137.222727,-145.268241,-93.2968,-57.086306,-22.695746,-38.138982,-112.338086,-151.305899,-227.663492,-260.662794,-238.879096,-205.129412,-215.455156,-228.67971,-222.950397,-229.183172,-230.89196,-207.550787,-191.387438,-215.510274,-241.578991,-232.239552,-237.973431,-266.567969,-308.537109,-223.675769,-148.434192,-111.74273,-165.951504,-211.24374,-164.513819,-91.006321,-172.598583,-224.948422,-256.831283,-238.925734,-163.69713,-133.418379,-151.568415,-187.337729,-245.384972,-217.48327,-155.945841,-25.552795,-10.296588,-40.646779,-32.104097,7.392067,-52.872249,-79.611737,-39.954051,-7.08586,-4.656785,-21.759568,-8.421621,7.535266,-60.841971,-162.335771,-145.977126,-96.436544,-138.245052,-276.831165,-309.526254,-344.561141,-454.425404,-478.947101,-342.687731,-242.096008,-162.178134,-173.784156,-200.788773,-213.947831,-265.116716,-256.380297,-202.295522,-108.348627,-117.471511,-220.659322,-263.311453,-239.742261,-205.917425,-254.986853,-381.533828,-396.451104,-330.524238,-277.003723,-190.031312,-167.490398,-179.608713,-264.697966,-291.358889,-261.183589,-230.287899,-194.095748,-172.842202,-71.728818,-59.127144,-130.096041,-193.188621,-125.200901,30.572096,35.509801,-39.67023,-55.160946,-99.9697,-227.724356,-245.361774,-162.258562,-111.947778,-48.984514,-54.799511,-191.488383,-319.829512,-294.575027,-101.143262,-5.483288,118.892647,172.858719,198.994457,142.793056,38.750599,78.39115,104.66265,45.964503,-15.758001,-63.379071,-38.320737,20.226618,-18.258241,-41.159797,8.417347,64.056122,130.546335,119.805512,33.219159,-12.865739,-54.540483,-36.950815,-17.56029,-26.862876,-46.373231,-10.169368,23.458049,-26.669104,-223.314197,-298.359599,-290.068966,-234.153354,-154.073643,-145.181308,-128.573237,-124.270916,-173.744861,-151.306647,-67.320746,97.481715,126.391185,124.658907,108.212914,13.594459,-104.269998,-116.692846,7.399769,95.309352,162.797179,126.961343,0.401507,-28.566306:-140.07518,-200.397746,-197.868357,-154.460814,-127.145884,-57.553325,-39.985365,-133.955056,-269.79547,-259.570301,-84.57254,9.283532,109.541606,131.694296,135.187319,113.751851,19.328531,-85.86677,-88.380586,-19.600485,-5.699632,-72.583821,-121.661026,-170.837667,-271.333703,-380.066957,-485.906713,-417.249349,-220.103187,-156.317383,-71.24873,-67.606383,-228.944795,-356.482697,-300.177341,-94.731521,-14.586611,84.147397,91.511881,6.568835,-112.749687,-141.58041,-55.495794,56.60869,273.886945,315.359186,239.278401,160.832958,21.877722,-17.816028,5.012527,47.309692,40.716774,14.601942,2.795254,-33.797455,-85.196052,-99.402374,-56.985959,-21.697791,-7.17111,-34.430836,-103.684013,-104.071834,-5.048559,63.174193,55.725958,43.133119,68.41597,166.634939,191.668245,152.015995,120.906089,118.95261,123.459251,138.761334,187.041494,199.476373,166.142003,132.059994,75.741298,31.547481,9.264101,-26.39306,-24.489055,27.260251,60.354476,114.677208,61.798933,0.457736,13.407071,108.113334,296.242343,340.047718,351.300211,353.143737,327.407852,188.370012,151.814349,196.332588,211.751773,185.816922,177.4414,178.982877,126.740207,85.11022,53.385727,65.636171,109.868391,130.943701,152.990518,176.43455,253.094359,246.37722,196.442264,37.954938,-43.083047,-108.08682,-83.847608,-22.498457,-111.274005,-197.190133,-269.688057,-247.05524,-229.366172,-265.144537,-388.914313,-432.749438,-379.594892,-217.357521,-160.427709,-122.012989,-105.928666,-50.643443,-43.10397,-66.914394,-90.569908,-104.424928,-58.347226,15.852479,158.608852,175.617364,96.985868,57.158034,77.955888,139.188005,158.945623,140.833855,100.44912,14.465231,-30.851254,-139.234851,-217.608793,-229.041753,-185.789162,-152.999225,-147.918489,-173.867673,-205.189572,-192.672427,-139.590003,-81.505854,-34.599318,79.046804,124.097415,197.982027,222.624005,202.984232,124.458567,92.318575,85.314609,104.14023,128.736144,136.510396,177.986152,189.548386,134.853346,51.138072,40.702017,128.328114,202.22013,266.321908,232.945131,96.145208,-8.538343,-21.190034,-24.749518,-57.240089,-167.485531,-189.817637,-143.163296,-134.208201,-213.793914,-218.266929,-139.5552,46.331598,97.801938,101.906767,67.319123,-26.560775,-136.442957,-187.494255,-223.879226,-194.563685,-73.80334,-39.084299,-119.726058,-183.371882,-204.088253,-141.731376,-118.650827,-123.96534,-134.749252,-149.686202,-186.714592,-294.732462,-284.171723,-250.61857,-245.714676,-261.285716,-191.082903,-99.9646,20.373799,-0.008706,-125.423157,-215.551072,-210.975451,-122.65095,-79.705186,-48.43564,-53.779493,-70.845136,-98.830894,-109.633377,-59.719124,4.367087,130.226723,138.168342,15.661413,-57.542378,-137.5352,-222.640871,-270.713025,-304.752718,-280.433767,-193.275389,-167.114505,-171.125626,-146.116627,-105.028135,-79.466697,-109.379714,-131.256944,-102.827573,-53.236714,-61.809964,-128.674858,-119.953621,-56.221994,49.362788,53.176748,65.670284,103.724994,134.500211,-41.808667,-150.622135,-205.657334,-158.105107,-79.843172,-89.636596,-137.458941,-112.739498,29.850257,60.731366,27.694132,7.413628,31.828034,84.076856,74.852216,-51.240393,-111.964849,-55.363481,98.039131,138.563924,134.445076,106.191456,65.433597,62.110929,-43.64101,-234.096744,-218.442438,-15.204104,37.90245,-48.90944,-117.291107,-152.400823,-131.987053,-139.160935,-121.023941,-90.262493,-47.413066,-29.581928,16.642979,7.727452,-105.004897,-179.599876,-159.699848,-76.785838,-59.236672,-66.930759,-56.802017,-26.860816,-147.911467,-259.00358,-359.136736,-294.094897,-83.663899,-50.049117,-124.266986,-132.427355,-73.272562,-92.394636,-100.334515,-66.348953,-58.099495,-45.134542,-13.021537,53.383707,1.366146,-56.83228,-80.42271,-31.458255,65.665978,77.014847,52.631094,44.202116,-16.049262,-154.36505,-173.961512,-87.965421,-56.987476,-93.982057,-118.842011,-115.694478,-106.656527,-93.346651,28.025191,120.698218,271.814433,308.762908,262.11321,195.809032,110.968132,124.197169,130.10343,77.32498,43.781928,26.967241,22.3008,-13.542465,-15.021806,15.052735,82.638865,98.926728,119.825386,124.602711,96.583584,79.822798,59.77719,39.247932,36.048747,34.463179,44.794182,116.230551,151.959911,128.158316,-47.837287,-136.90992,-183.269835,-151.25586,-63.913469,-25.623696,-9.705429,-56.55174,-191.305212,-166.734989,-80.544507,98.369089,144.995864,147.623232,116.965212,15.635582,-100.936008,-115.374317,-15.712657,31.01194,43.975872,47.969535,42.466754,13.860373:38.643528,-30.744264,-4.214718,35.495065,15.466504,3.773734,20.888404,5.388751,-99.033892,-122.827236,58.67966,210.857433,385.315258,411.501894,421.354617,385.728393,236.080292,153.057665,162.088332,172.813197,147.926833,51.270233,-10.749437,-119.761057,-150.576336,-145.12204,-158.534272,-189.473449,-189.153691,-113.846186,45.977787,40.346351,-141.244144,-223.923637,-161.430861,22.108145,100.668776,184.938568,156.181618,11.474679,-35.733025,-12.636727,79.776078,142.140657,243.492499,248.233804,162.320208,99.263077,-59.892447,-150.8275,-106.46495,34.359151,26.50227,-182.860312,-288.388475,-285.823009,-150.846248,-134.880567,-151.784265,-127.414952,-34.10982,-12.0532,-29.398265,-32.905669,-17.705383,-4.692437,27.412337,105.210064,123.436893,160.485412,185.839682,209.845195,172.082971,166.022986,261.322878,322.099977,353.369056,340.671471,282.041324,211.877264,50.61673,38.482083,84.326923,101.893862,43.854158,-98.085866,-140.876307,-158.479512,-191.504313,-220.170205,-149.730346,-59.285088,70.694383,112.403496,158.371417,143.549543,103.321483,138.107215,183.736813,264.413389,270.174144,242.098522,235.197676,238.391159,187.530328,143.594993,138.151166,185.867989,275.646915,284.167015,229.5464,197.895396,144.630191,85.038721,106.163423,179.138951,140.533079,-44.816984,-115.337694,-161.018228,-220.122139,-290.638266,-378.989123,-360.927893,-304.756984,-304.115708,-350.181866,-370.40436,-301.437618,-110.20963,-50.197243,-113.192167,-192.107166,-225.189034,-162.969272,-32.483424,-10.199041,-10.381254,62.67323,102.765088,86.511946,73.871355,147.451748,196.677439,200.2839,110.482263,64.792153,-18.677505,-40.566105,-5.486701,22.968125,23.404021,-15.493577,-19.335851,-3.684059,-6.191133,-3.478821,24.497565,65.853395,56.849214,30.166756,20.859949,27.406086,48.2886,65.497435,147.15417,184.091433,151.659967,60.955074,72.894846,178.586604,191.982518,122.925019,108.655286,164.55999,196.470623,186.907042,87.81836,49.240717,14.234296,9.129099,26.380999,29.254979,12.898489,29.575016,34.191303,37.981114,45.020674,29.578524,5.169525,-24.273791,-27.434796,-55.173224,-26.341056,36.613039,148.755867,173.281729,195.046839,192.953648,162.15706,116.98744,118.271264,217.563771,272.217685,272.310795,229.577931,129.282709,87.454709,-2.961503,-96.737745,-87.632023,16.952879,43.876081,-34.730212,-122.973644,-250.15274,-246.088212,-244.491277,-245.955157,-226.679183,-144.051264,-118.594985,-182.057608,-237.142692,-278.481416,-213.120223,-169.636691,-119.928355,-88.295082,-47.836453,-92.760939,-259.185999,-337.338163,-318.950725,-197.383753,-131.490486,-49.096534,-54.87062,-168.505396,-234.057189,-313.938881,-356.63976,-358.277969,-267.632353,-203.380832,-138.652829,-133.450387,-109.078444,-96.508619,-124.005071,-185.86569,-172.381141,-55.214084,-8.78712,-43.017296,-99.733238,-167.31214,-161.050108,-141.685459,-84.069219,-75.83829,-94.23917,-86.09828,-51.398354,-144.431885,-207.949644,-160.120226,-84.600829,-88.601541,-171.1815,-283.39768,-262.116563,-132.211575,-9.28417,26.09892,27.225126,22.789203,76.789883,92.835397,-16.620313,-126.9817,-108.494972,-14.793235,15.644137,41.704681,43.299526,19.227336,3.420428,-23.04703,-102.802738,-132.186038,-67.892327,-30.508116,-140.340491,-255.752425,-366.880948,-359.423129,-373.031507,-302.897547,-213.418897,-95.238107,-83.071217,-83.817158,-76.835643,-68.116117,-127.797635,-155.56551,-158.46397,-178.022279,-308.149004,-371.0468,-342.852694,-257.773434,-301.565721,-429.662805,-411.687396,-224.23767,-150.793525,-201.86383,-264.02906,-274.129048,-279.273858,-299.239545,-239.464302,-148.986177,16.420742,11.63456,-148.623704,-267.123804,-269.352925,-174.524549,-111.158394,-1.31015,33.459032,16.101429,-11.4314,-66.282446,-127.385548,-119.161323,-53.81031,-47.242077,-67.85157,-43.681878,83.733129,95.505404,43.919089,43.767085,124.850204,295.481713,331.212827,308.085667,275.571013,214.980012,158.492676,147.997052,150.331911,139.217754,77.102685,20.52714,-76.108253,-55.11676,1.322748,162.012516,203.067554,131.276161,66.755043,-21.746185,-34.552522,-40.055268,-84.564218,-90.280165,-37.55143,-6.297025,33.861812,43.813901,31.89145,-24.479312,-65.993277,-113.265096,-104.311435,-30.594724,6.475883,-13.597765,-53.218305,-72.911292,17.765646,70.374768,88.192386,95.089682,258.945366,337.757131,240.548564,27.347145,4.140605,94.186451,124.532139,109.058447,119.157784,174.036681,158.523862:forward
209.162226,240.022269,211.474219,93.458694,21.402094,-62.013868,-58.348989,-50.867693,-140.827673,-208.868231,-323.880615,-341.681074,-270.179029,-192.183402,-1.919666,86.035358,173.591051,108.612269,63.546435,79.986244,129.172316,181.253142,176.574597,157.543795,212.986366,272.649056,344.681814,332.963218,214.306481,152.163676,180.113066,241.368297,291.1288,292.222832,300.658376,295.667542,294.795496,363.002787,426.719366,495.189249,469.695577,468.538992,461.606078,415.610352,232.104849,150.98361,96.199376,90.83509,90.622646,130.690379,160.871492,216.040962,215.414213,179.39537,174.432589,138.578519,65.622312,56.708032,82.161804,89.762796,32.772656,-14.336893,-27.975824,6.82878,85.959672,139.082395,149.817434,128.755072,106.653502,91.299286,91.172317,73.570721,120.014605,145.718061,61.457358,-23.754723,-133.87308,-133.888354,-57.343091,-14.873081,81.718033,206.908609,239.102041,221.999523,190.762325,162.907627,184.163942,219.825042,247.473711,287.365429,326.72268,294.204568,194.593603,183.057868,275.821132,341.968187,432.765279,396.662497,332.517251,273.691281,302.31189,368.067237,376.28896,338.37258,163.752807,24.883609,-185.063014,-224.489613,-243.98561,-232.897493,-148.387455,-81.933742,54.933945,98.031054,79.993685,35.364148,8.914446,-55.013631,-74.766353,-100.568855,-119.913875,-119.931741,-129.167176,-139.296368,-151.751045,-143.329917,-103.847822,-82.834131,-10.9965,35.463195,21.550186,-51.12156,-114.114503,-251.64519,-276.853764,-222.892887,-137.429677,-124.584431,-158.695187,-168.711892,-157.462848,-153.229144,-177.93673,-206.719702,-238.714728,-200.986907,-154.106306,-26.34286,8.409317,-21.082389,-23.657626,73.656209,123.037182,97.462865,64.049309,101.704516,236.504961,280.962219,307.381321,307.401675,261.696665,187.928834,181.885194,179.336972,133.363949,-15.211267,-72.860164,-134.729513,-136.880866,-132.392238,-169.618411,-198.334548,-270.800844,-309.708502,-313.940712,-273.043456,-143.23578,-20.658543,10.480469,-8.845539,-61.141423,-190.823117,-221.439354,-166.164191,-53.287492,-31.020954,-88.135428,-143.814792,-240.212247,-257.039022,-200.641172,-128.784232,66.664098,175.52269,158.964582,79.221619,64.923577,73.032371,78.299487,118.197088,131.527728,86.991671,-14.555878,-21.448953,-25.246482,-44.542134,-22.904786,6.843781,7.248416,-27.398075,-14.772316,99.150639,155.959081,174.111544,148.311527,91.857748,110.973318,140.887459,183.922071,187.565979,109.842154,58.960113,74.011224,118.221166,175.297387,231.836686,253.541137,192.291834,108.416805,-41.873049,-61.026986,-13.929518,-36.503617,-117.943155,-262.952374,-259.836918,-227.057031,-257.801324,-305.201633,-273.519246,-155.967389,-132.808034,-166.924367,-228.408294,-263.132106,-377.97101,-419.135419,-405.691796,-283.740528,-199.074714,-68.264807,-55.600792,-131.977779,-181.710765,-255.02031,-280.797772,-268.350294,-175.575573,-121.54321,-46.719966,-54.137049,-135.664011,-153.161833,-103.343953,-56.740944,-70.819875,-175.45368,-234.472483,-349.002743,-398.046848,-386.526023,-344.593175,-326.077083,-326.461146,-289.331569,-216.110223,-229.893809,-299.670577,-285.297314,-139.665737,25.031122,70.427542,45.706795,-2.051352,-88.824948,-101.115853,-54.870325,-41.496958,-106.665231,-192.966163,-204.707917,-201.407982,-213.137119,-242.09526,-232.304532,-185.913806,-180.245622,-195.714346,-262.70249,-311.203944,-351.336212,-296.832964,-97.424389,-27.855796,-27.043179,-141.082292,-186.051363,-153.6818,-99.061952,-54.421483,-73.713926,-109.304327,-77.154401,-71.387918,-150.845834,-200.63375,-243.400377,-237.304782,-183.869236,-162.187148,-168.68155,-174.353892,-148.063526,-66.789214,-61.295594,-104.403485,-97.352345,-11.039757,96.33113,112.824564,2.086909,-97.061147,-237.365412,-241.054774,-178.781525,-160.035227,-111.681521,38.910032,111.190649,110.845962,37.019482,-55.444002,-15.16582,103.492211,129.010643,116.912158,47.224859,1.219416,-99.485699,-142.052007,-140.660409,-123.452484,-187.378781,-260.814721,-228.940044,-124.117248,-112.150476,-145.204224,-160.740208,-133.681488,20.755174,90.116931,68.120048,-14.881129,-212.460361,-276.004345,-303.037663,-284.861644,-156.940951,30.63749,73.095823,43.908256,6.238455,-42.119976,-43.74646,-48.839704,-52.174506,-27.0756,91.180357,133.969927,74.148195,23.214592,24.252107,59.41373,98.436617,71.936972,70.115966,84.411859,63.250432,14.217594,33.829371,112.358344,180.165074,212.787913,184.880703,122.687847,53.738692,85.94731,211.460922,255.735635:155.11507,171.772044,165.656934,74.760561,3.730114,-64.702675,-40.887011,41.890513,86.267568,63.329146,-65.713298,-113.593644,-54.932578,50.823847,295.732144,367.516425,374.61296,314.801564,285.39827,249.81651,227.247854,159.643472,156.647107,245.044958,323.653395,317.54728,248.032138,223.364004,223.287481,235.450332,248.670262,256.586657,336.847422,426.893371,405.67533,254.721262,220.745736,362.520582,455.708142,470.100267,417.659589,415.287365,392.380189,358.571696,233.246084,166.25839,101.291662,101.402899,141.982812,161.962474,147.503502,131.718939,149.243492,221.826672,248.773815,215.519614,107.970867,66.598596,61.69807,68.001924,16.082566,3.222429,77.867748,120.215274,188.05596,263.6188,268.990466,209.064369,167.433418,97.956855,76.450973,107.913939,162.099782,140.980694,69.886829,30.303966,-90.708871,-124.699272,-29.835288,54.715628,163.124429,210.109896,232.772754,245.651318,207.057236,127.856235,148.345783,274.557875,366.519437,363.507323,277.379548,229.100075,190.080186,212.466803,326.4724,386.639576,479.323655,538.000173,541.731195,463.691268,382.694478,265.226685,263.946259,263.010112,116.653232,6.243545,-173.884293,-228.537141,-273.980184,-265.941712,-218.76329,-187.484408,-120.758685,-78.504197,-66.877441,-30.139251,-26.419941,-63.758306,-80.957926,-90.606402,-53.986162,-48.069113,-131.370058,-181.132839,-192.371626,-166.827564,-125.599704,-105.092145,-7.10413,77.477547,63.15179,-57.795212,-129.980785,-203.948687,-198.824886,-147.256457,-24.906545,32.029287,6.303701,-73.771477,-198.67327,-189.34359,-124.444198,-126.510117,-150.90392,-125.358684,-100.527551,-29.5308,-0.473443,36.623242,64.721356,128.893811,120.794065,95.384039,65.925782,65.237352,76.414864,99.287163,218.975012,296.839943,344.403437,263.177193,251.014317,233.379249,157.664941,-84.24815,-157.15924,-98.837354,-22.928258,-52.081013,-93.492229,-99.762204,-217.124844,-282.884837,-237.830594,-145.274994,1.775043,4.340984,-24.590398,-110.16656,-161.565435,-201.332453,-182.964459,-174.573077,-164.972819,-123.827391,-72.40389,-122.410711,-324.522491,-373.779258,-259.542533,-154.108429,10.822186,32.571901,-9.802885,-104.525399,-113.650075,-40.909881,11.890065,78.680465,28.612301,-33.215641,-133.786161,-153.036132,-124.671947,-86.10779,-57.364697,-76.858331,-94.720407,-36.506083,10.948662,32.429406,-14.17964,-85.404864,-78.008547,-58.740061,-14.91982,32.255865,66.283159,14.8254,-143.11829,-166.761178,-59.196018,3.835402,82.965388,148.835642,154.472444,56.704281,-29.311604,-132.524725,-120.397493,-63.303418,-117.35967,-185.755428,-309.434059,-345.115057,-389.908487,-393.713452,-340.414818,-314.27283,-296.55093,-268.043491,-250.062447,-225.793083,-253.171158,-381.567358,-423.205403,-395.232839,-260.296446,-189.986827,-122.19585,-127.913075,-159.799691,-159.597456,-169.888213,-199.555496,-232.333,-208.069422,-205.481759,-192.419438,-167.534314,-161.490154,-192.386347,-172.286744,-29.432167,-18.013801,-124.061247,-182.207877,-311.470371,-368.936529,-351.260059,-287.783253,-164.683196,-125.988581,-145.030148,-258.841087,-343.409657,-408.839533,-339.103128,-117.450556,-11.266143,-7.121533,-20.683897,-34.371421,-77.748392,-68.745358,44.646485,94.105971,77.403119,-38.185365,-83.723541,-97.102959,-92.074047,-98.88473,-102.896321,-118.930017,-147.191922,-159.777903,-180.454539,-184.51497,-142.910372,-74.209252,105.51292,154.365619,133.685763,3.945755,-57.634257,-98.810634,-111.912446,-137.218972,-116.677758,-44.317566,15.957346,23.173573,-85.300709,-175.708054,-263.364851,-235.075135,-136.683034,-116.491234,-144.718799,-136.307685,-101.423071,-90.595131,-141.953748,-245.760914,-251.761518,-182.778627,-61.935482,-8.446854,6.529337,-61.172039,-236.809679,-257.230689,-186.67848,-157.514882,-93.100928,19.319783,63.049347,52.791864,-0.892713,-58.766014,-26.717253,82.643687,132.33971,105.83614,-16.931141,-86.710004,-199.14407,-222.384683,-197.443516,-170.532205,-154.591333,-161.193904,-142.039455,-126.735135,-159.570348,-192.897789,-167.71619,-99.350397,-9.982718,15.287206,-35.390304,-97.597171,-250.144591,-298.791373,-281.119284,-252.665409,-166.341436,64.517293,176.02976,191.256631,122.892685,47.847742,45.474544,22.081388,24.966705,49.448145,119.440385,156.834956,182.275099,163.225758,119.706016,123.103202,151.369693,121.149808,85.484011,4.43892,-34.294105,-68.380751,-43.367087,68.975915,198.623663,228.276836,165.101774,108.780482,52.304735,56.319145,82.423359,104.94353:209.371666,190.797859,136.551908,15.617206,-45.254314,-98.297761,-70.914195,23.570887,53.919785,16.130992,-123.250436,-172.903348,-135.307181,-41.978084,167.796911,228.721026,280.077591,269.677834,228.882005,110.510894,53.256177,4.302497,29.111648,163.512456,324.582573,354.483287,296.183892,245.417099,193.754565,217.107121,311.430578,349.661561,409.589375,402.715103,355.405785,254.396385,243.381551,315.195538,365.00241,404.354909,347.886639,310.254661,261.985621,228.947818,90.326459,16.88221,-21.089744,30.180468,186.729074,226.948594,205.006512,177.810682,176.275474,156.874737,132.640526,122.856664,159.436631,144.505264,95.503919,91.0625,101.54236,110.555683,129.939837,149.587037,247.60496,318.825571,306.747292,239.819243,205.946637,143.156354,114.431981,118.129948,216.556659,243.110203,175.343506,97.494545,-32.244299,-35.316421,57.31661,105.143722,192.184569,235.883793,229.341858,215.444686,200.941876,196.397649,242.952853,348.174019,371.186719,351.578628,260.253209,214.198579,191.416804,235.521559,382.644336,423.58996,425.911594,402.491522,366.055045,243.014287,186.16717,133.153349,126.917307,124.454512,74.576035,14.293285,-114.067562,-160.701509,-215.243487,-227.62085,-220.306061,-188.909932,-98.091968,-74.251364,-80.20768,-90.542936,-105.832436,-146.336464,-160.131789,-167.030338,-111.750714,-65.425894,-30.268911,-68.540432,-183.543995,-185.351263,-67.967864,-24.288804,-22.315304,-11.290208,1.060731,-52.642613,-120.398074,-208.959956,-197.082758,-104.80511,16.217039,45.752716,-34.922096,-124.245775,-266.650918,-266.646362,-141.488504,-86.532495,-83.574313,-75.440879,-21.445821,78.11373,101.487946,170.525509,202.911987,189.102027,117.025782,99.934147,124.21616,140.416823,175.313095,214.137845,282.177893,278.954174,245.738406,272.226292,306.410742,294.914028,215.574335,-1.041002,-86.549201,-136.407148,-31.26893,12.501286,-59.569125,-150.102279,-248.744268,-223.235194,-125.303313,-95.512466,-70.984618,-65.0931,-76.693512,-130.977927,-160.20911,-197.22565,-206.957303,-216.236216,-169.590814,-134.830834,-104.977267,-141.366694,-300.792084,-340.657338,-226.500959,-121.109076,20.733887,15.715164,-13.959154,-65.18527,-59.610704,29.258473,71.448283,99.325041,82.060939,41.174387,-59.106162,-94.012258,-132.359964,-125.729964,-121.243552,-142.998368,-143.178861,-91.154381,-73.173998,-61.014411,-81.994758,-133.575852,-119.056601,-18.126869,57.625695,64.7037,50.136762,23.97851,-77.257977,-103.000241,-21.003971,41.213888,94.168654,124.026641,163.543361,183.110683,115.982929,-21.472515,-15.268558,54.457879,-1.188484,-62.750679,-191.028521,-254.428519,-341.07059,-343.79837,-296.063902,-257.715384,-129.364065,-102.484232,-168.09855,-269.762944,-261.659823,-223.16777,-230.815129,-262.078513,-232.265549,-206.689537,-162.656023,-147.372659,-153.163896,-176.989634,-237.426699,-238.802286,-172.191251,-148.365549,-166.569213,-229.550384,-238.913259,-157.859968,-104.056625,-54.067257,-68.664978,-110.780852,-221.664472,-251.70614,-285.479759,-296.792248,-255.672091,-211.366,-135.935256,-158.667194,-226.55127,-381.242551,-423.388807,-393.290655,-322.885002,-141.651423,-22.058041,-8.28775,-43.453105,-61.893567,-56.105701,-37.204321,19.991588,61.964147,101.097681,25.397685,0.510486,13.11871,9.687349,-42.060469,-62.18836,-42.335565,14.356785,27.097489,-7.98754,-43.374616,-81.093971,-50.003687,97.133628,152.995404,167.624583,123.67767,89.69671,12.107519,-19.29034,-38.338846,-13.918773,79.625195,112.882484,93.716477,42.595868,11.122898,-106.032749,-149.62511,-97.962291,-53.923327,-60.257728,-94.866575,-88.787368,-118.063068,-183.555816,-290.935275,-278.92609,-175.268266,-70.99357,-49.409224,-124.929284,-206.654943,-329.02397,-330.21412,-224.633794,-143.879121,-9.707731,14.846421,6.155504,-14.617913,-16.935721,55.8043,115.025053,179.976147,150.487705,104.268552,-2.234977,-55.168292,-147.03679,-145.932931,-59.793272,-32.940248,-44.641851,-51.628437,-42.462233,-86.154366,-141.432467,-151.190492,-88.444712,27.817886,49.371776,21.707003,-105.79884,-187.038424,-309.828207,-323.691447,-270.618155,-216.310939,-32.317594,140.570876,171.925054,142.331309,94.601569,26.09301,40.442661,103.865997,157.679867,196.032323,221.072692,187.003463,121.333138,122.265581,149.37409,159.031835,170.917052,120.378848,73.85647,13.692014,7.371757,-12.332199,-23.293528,37.083421,144.199794,150.298737,70.523305,15.056972,-46.840664,-22.443935,108.764971,175.274859:123.870405,135.666677,99.763914,-40.343948,-119.81035,-175.65111,-128.432283,3.530803,-39.783946,-129.482603,-286.596978,-316.603249,-265.552623,-182.181376,18.910123,89.225366,157.450806,187.116404,196.633165,164.249938,94.708608,-71.155471,-79.20876,94.148216,247.560088,270.989468,292.061594,286.182462,211.112362,176.074748,158.016469,166.226326,216.6853,244.420328,235.928492,230.551985,252.820975,341.363774,383.819283,396.192471,332.513413,300.437877,259.526733,254.237496,195.548988,112.420797,-42.205972,-48.834245,61.025707,103.274919,73.860495,53.483872,73.253839,99.410694,97.133078,63.713269,71.816838,106.252722,163.461235,159.938385,88.267759,59.339933,97.997121,150.52492,258.458537,305.70263,278.752562,190.71168,179.784523,244.807575,271.907352,227.949999,164.544962,143.253434,66.86408,14.573137,-80.933407,-108.29153,-46.140645,45.007447,223.241444,240.526391,206.568431,126.812243,83.383937,62.236519,92.992006,160.994159,235.342071,256.368943,205.825731,165.410043,126.449621,135.481178,236.811788,320.925003,476.637726,474.026807,420.966141,351.763166,337.962592,318.645751,322.314799,301.051023,159.915285,68.434431,-93.262953,-150.532856,-256.71593,-311.767729,-296.695042,-192.333056,51.737362,103.003493,80.789524,39.917258,11.628079,-37.241832,-43.507196,-54.031669,-10.912711,46.546101,131.199863,120.938815,-8.560409,-80.852784,-111.270304,-63.555548,75.175775,96.667838,54.19777,-100.482643,-209.525577,-337.705961,-309.21979,-180.993657,-84.747974,-64.145163,-97.867448,-128.110693,-177.857664,-197.762927,-212.131831,-220.162167,-250.734879,-248.260043,-204.295275,-26.383727,47.547175,62.736547,35.904366,30.457636,69.950868,71.086931,79.068343,111.728156,169.377383,186.679905,263.292962,292.589953,256.684888,192.700666,202.302388,262.848168,243.802044,87.873642,17.747982,-3.934774,28.495321,5.936479,-118.224854,-177.052113,-227.999371,-240.365278,-270.716595,-265.797147,-194.354984,-104.016422,-80.484634,-100.634986,-124.519183,-156.260927,-169.726916,-191.734082,-154.739268,-108.97394,-31.137819,-45.472876,-190.364227,-240.228385,-135.30285,-26.789033,125.296769,156.78577,148.058424,132.032508,143.860697,193.84471,200.949488,175.049856,162.275736,142.727921,34.175454,-10.274597,-8.712875,4.009818,-8.79789,-26.087699,-27.957426,-9.95237,-5.301606,13.560538,13.964632,-15.016278,-27.040727,7.52026,125.250984,156.466251,97.057755,56.435719,40.406103,50.559739,94.030785,128.007311,209.431762,216.489302,174.987484,84.055257,28.714827,-80.580685,-78.524425,1.956194,-9.321439,-46.648075,-133.999917,-187.456711,-294.099829,-308.780514,-240.046157,-214.20297,-211.176243,-147.149856,-103.996621,-66.495046,-104.816324,-303.387546,-374.332659,-305.123866,-187.741016,-196.276261,-250.555511,-237.192702,-165.174911,-139.294853,-148.469139,-194.84374,-267.454382,-180.297327,-132.479258,-157.550555,-201.712323,-191.075637,-130.11993,-74.142227,-153.052543,-162.213945,-109.43504,-115.361101,-221.767233,-260.254687,-227.534988,-186.45819,-139.236215,-199.219079,-252.636137,-305.344098,-293.129146,-232.965969,-197.319619,-91.845806,51.454561,81.489201,36.049674,4.917544,-31.230388,-21.479875,25.212159,1.721125,-136.797473,-205.767238,-177.203802,-69.642907,-59.397816,-140.100563,-167.518325,-76.430807,75.298403,69.378325,-73.89811,-125.836408,-127.045053,-98.992089,-26.079205,2.473594,57.389901,103.561323,80.981636,-12.727183,-27.942394,44.80425,104.093852,162.824001,130.352546,99.061346,30.21243,-12.390115,-150.900028,-190.877398,-132.362729,-117.135779,-192.790449,-184.963352,-130.640614,-98.214466,-163.002121,-318.022617,-340.434721,-249.295801,-74.116553,-29.993038,-95.604876,-165.905629,-268.582838,-282.022203,-245.149014,-207.404386,-110.826978,12.802733,74.028819,132.906612,110.025142,25.674482,30.698681,156.698805,217.188098,171.741617,49.136729,-3.229454,-121.444853,-138.143972,-42.669207,-17.919884,-94.884154,-101.199144,-47.091217,41.9246,46.539761,39.031319,41.315699,33.53298,66.046911,97.144145,81.285732,-1.032599,-247.400539,-319.341517,-261.329352,-175.206652,29.594498,173.379944,167.554132,62.89251,25.394834,24.439935,34.822884,40.280862,103.400524,142.330975,152.096852,135.683831,137.178844,167.906781,242.055382,253.53101,204.969049,173.597921,176.58244,132.882444,83.268704,-16.318032,-41.681042,7.597202,118.644387,128.288721,59.853329,26.62834,-19.29071,-17.409611,65.070154,106.65957:101.945827,101.286998,58.353573,-4.525426,-29.688645,-60.037922,-41.080331,29.33804,23.992057,-45.777395,-253.895964,-323.728803,-327.609734,-259.953233,-59.091649,16.626621,96.131156,125.307916,104.629319,-5.823494,-60.100909,-84.414106,-50.560225,55.96026,164.720277,216.214628,237.161161,184.858525,78.702014,63.259083,77.582143,128.13127,317.044508,344.122522,269.216532,136.611313,130.163749,251.516121,340.014637,430.718215,352.490885,280.123506,190.696606,174.777842,115.797163,73.674648,40.576407,64.251383,127.420719,101.28398,60.833036,25.806824,43.017084,77.401703,69.990954,60.609429,137.717064,165.119609,137.475098,101.553178,40.942474,37.432363,116.819152,192.838626,336.922549,326.112264,276.669447,192.07702,160.784895,124.112927,124.814194,139.275483,116.516886,93.499781,68.641575,42.324456,-76.226337,-119.364879,-77.223427,-9.216673,158.304807,247.382012,207.475176,25.363267,-26.449745,50.657238,99.827759,100.281204,165.550762,214.285445,181.083304,105.104537,15.062253,57.861923,237.597894,312.393848,419.643358,445.193459,382.804704,170.406698,107.24498,132.748,159.308376,172.264194,125.652388,41.828706,-183.225218,-268.314359,-345.581224,-330.357924,-210.342548,-148.26824,-68.466872,6.743893,38.231735,-25.157256,-126.565002,-232.429793,-188.879781,-93.31746,-63.070799,-23.45236,54.319326,25.720529,-162.033851,-213.856969,-95.263485,-1.391599,72.032753,31.633639,-9.268138,-172.114544,-266.264565,-307.993138,-244.006665,-85.097986,-13.361348,-23.391371,-108.716391,-154.45459,-191.294152,-168.76438,-112.988417,-124.879298,-166.886655,-87.731625,-23.895257,20.647425,10.652109,78.71404,137.473451,180.615011,172.692245,155.914609,118.751193,121.953687,154.970402,179.198345,231.115277,242.741429,246.593219,248.758835,240.769346,154.856811,79.081676,-35.378355,-33.835961,69.528289,122.899048,82.184946,-73.240743,-151.927812,-257.733874,-266.52561,-210.579915,-177.174434,-146.717823,-99.470015,-72.01366,-124.910984,-199.736838,-276.375617,-239.236089,-85.763077,-25.062946,-59.194128,-118.249425,-125.789948,-187.21972,-222.180172,-152.967334,-43.362759,186.676594,236.141657,196.515889,150.065121,170.514572,266.037715,294.493333,226.103232,148.470852,139.665314,107.01683,73.010986,-22.204722,-62.023421,-67.960661,-33.070729,58.603303,60.260433,35.569022,12.98047,-0.200607,-58.766126,-71.989109,6.536124,155.841783,177.231143,83.738026,15.164191,-88.010738,-93.39433,5.021088,70.051529,185.738519,277.188107,268.919684,141.086543,66.589645,-25.816153,-23.37641,85.810975,187.934718,184.54242,76.057782,-11.554011,-172.127592,-196.865493,-118.185034,-65.194815,2.14332,28.758692,23.73088,-16.584047,-60.308371,-167.120856,-180.583727,-86.625675,-26.860199,-61.846541,-137.494624,-145.704855,-174.825175,-200.170942,-200.346907,-153.086717,-4.689916,-11.562583,-96.527205,-249.742569,-259.329933,-161.131564,-114.643199,-77.353446,-14.069205,1.55186,-55.690285,-107.757218,-236.62711,-276.254351,-198.432862,-105.209093,53.313794,-8.277996,-126.187608,-325.100723,-356.552092,-341.034174,-303.030634,-121.734287,65.361443,86.126879,5.792591,-48.834473,-83.377404,-43.905334,47.481993,57.136517,45.457699,34.595388,32.78083,55.809853,60.513448,13.129913,-9.217725,51.221256,163.767359,155.834075,14.146564,-60.744138,-104.913453,-62.76463,61.70348,113.514944,190.644078,136.872794,56.314632,-63.131993,-55.673223,77.26692,144.548141,189.113102,190.284443,189.654794,183.856276,147.749741,-54.659623,-146.796155,-147.466454,-109.732132,-70.638186,-38.698103,-58.968585,-208.56951,-277.409881,-305.610279,-295.467232,-249.400902,-110.754459,-59.953629,-115.57044,-189.97882,-309.258661,-328.177652,-241.127311,-142.771053,44.337626,108.811804,114.046069,81.123633,37.667678,32.043575,108.882913,287.321987,305.768242,243.14085,91.14664,38.467887,-58.912736,-97.661352,-67.96396,-3.733123,125.332038,115.879265,59.158089,-59.60256,-88.322703,-46.027888,-6.180728,22.027955,53.624586,65.852021,-40.766656,-158.610281,-342.985203,-342.226313,-188.164578,-98.772298,33.823799,112.675428,109.40147,-2.28182,-54.676582,-8.750672,47.868135,78.760738,144.133623,187.696556,142.008778,76.283725,-7.006915,6.332882,140.310076,203.808247,194.828259,116.24294,120.004871,119.759039,54.12109,-112.7161,-129.950936,4.652284,122.65367,99.029915,-46.859886,-117.322641,-186.168101,-154.337882,28.788696,124.180329:70.617162,136.349375,56.957253,-134.389425,-189.098995,-241.886848,-245.964761,-230.618393,-258.408729,-313.075928,-476.464464,-530.29759,-507.2016,-430.331293,-175.987634,-45.381241,78.883112,16.378721,-7.062461,1.684312,-30.246218,-154.989879,-158.355187,13.336019,194.2211,231.346232,243.295094,239.030323,174.748591,109.864727,20.92691,42.877969,197.816101,254.5559,211.739643,201.393366,276.749655,441.837737,487.695402,506.581438,411.692811,350.265292,294.82836,279.93142,130.104886,-2.143827,-197.405508,-211.749125,-69.95802,82.879298,95.429026,83.719973,89.489956,108.413313,103.917654,43.495141,56.563492,118.256934,194.331926,155.619986,-17.0374,-78.11102,-60.168916,-1.583095,135.593118,137.631067,68.24436,4.948977,52.133743,126.128986,96.539787,-9.561521,-14.445294,9.423363,-12.321301,-75.346264,-220.161198,-225.306492,-51.292835,52.164343,161.93841,155.491511,144.334402,147.458034,142.775029,165.229466,202.257687,210.000531,182.658188,207.548821,246.624426,218.619969,76.403408,31.60849,163.810744,290.855479,395.653137,277.452487,235.663121,283.335397,318.432576,325.756703,312.778718,260.834035,137.690272,40.559875,-167.418937,-255.738926,-364.787756,-344.842242,-151.342981,-50.799611,54.863017,122.780591,155.356066,142.185944,95.5962,41.06313,50.469681,61.49826,67.384071,79.579782,103.819831,111.572113,86.43341,75.745632,104.55522,130.238065,180.348379,166.17958,131.388353,37.219844,-34.526349,-174.509727,-166.757212,-14.717389,28.738057,-9.98224,-124.618324,-176.143401,-237.919546,-251.410227,-252.237335,-252.448511,-263.157184,-228.520335,-188.285247,-97.064206,-56.459063,21.812142,57.58134,103.225595,108.572729,89.540362,73.412413,97.913904,145.788053,151.664285,134.467848,118.430124,155.051085,260.94582,280.685984,213.958515,138.224663,2.255849,-26.412061,-30.049224,-19.01865,-38.733405,-144.667324,-201.947855,-299.552383,-334.000302,-312.527044,-266.383862,-165.583549,-71.410154,-42.403016,-51.619183,-89.831672,-176.430301,-187.91198,-143.709782,-100.751859,-91.334302,-85.148745,-90.977786,-107.744726,-101.46042,-44.335314,18.313381,201.299453,299.455874,284.727904,202.660731,172.938767,164.366997,189.916977,275.051932,280.023577,231.631374,106.348797,70.429674,66.499928,91.444974,145.376943,124.469469,-9.009075,-91.614763,-78.980634,32.345061,92.091601,185.612597,230.374643,282.793066,246.965517,206.835383,191.677415,242.913444,333.239556,314.056225,194.419691,164.224496,233.095539,258.153367,211.510459,116.142906,86.077448,37.81558,24.491689,28.879974,39.824256,29.177366,-46.515503,-88.580607,-148.854327,-183.726657,-201.930726,-150.919974,-19.56987,-9.380182,-30.093154,-75.932636,-127.220205,-264.926195,-290.606087,-220.999967,-138.881956,-119.893017,-84.055742,-61.593317,-71.99309,-93.429833,-117.671499,-140.746609,-155.738756,-48.125118,-7.45955,-50.501086,-112.521246,-211.441683,-217.803898,-130.069205,-15.326861,-12.302583,-106.682434,-163.196166,-266.112431,-299.577453,-290.495256,-275.695836,-310.253765,-360.09718,-354.904959,-272.009078,-215.376922,-179.800659,-198.91526,-135.378401,100.075403,161.708,79.585337,24.639154,-14.486217,-41.196064,-157.702898,-227.664452,-311.263706,-287.535422,-268.979049,-297.924202,-323.199155,-299.240146,-259.556473,-168.555018,-75.151021,-69.933688,-174.882912,-243.520982,-313.800799,-287.814745,-120.162593,-38.746994,-3.540919,-93.914674,-128.170019,-71.386177,-6.67049,46.570903,38.711505,65.546458,159.732697,197.802777,189.421151,137.088277,-2.880607,-34.824369,-28.888617,-61.720836,-159.858085,-90.451399,-41.541129,-47.110777,-83.497162,-118.379968,-85.816385,40.889716,100.918774,67.887072,-56.824362,-100.177096,-140.485022,-159.876601,-187.350292,-166.156214,-18.852909,144.023029,190.066988,203.327779,160.247871,92.503435,135.563224,261.833368,276.239788,261.33013,170.744642,95.776011,-23.210674,-50.26966,-74.0221,-78.097244,-73.649573,-110.584545,-137.864398,-124.812679,-84.544788,11.119054,50.638703,98.921355,123.23399,123.767941,94.254455,49.888501,-161.580245,-285.358842,-339.703654,-256.610294,-36.785789,65.70977,56.078566,10.860488,-4.649504,-32.96843,-23.412072,79.065085,138.22208,95.391585,-27.012644,-38.489924,41.551596,104.985158,203.899385,212.993301,215.14427,237.467262,248.558721,226.276797,147.617614,-21.977618,-14.7391,124.346949,138.886138,98.962044,59.023283,59.003051,9.798497,-29.098489,-8.696854,58.647431:67.509488,84.888279,4.679949,-161.97235,-200.161859,-199.273422,-162.837269,-40.666296,-9.62755,-82.748107,-317.31991,-391.997359,-369.278732,-305.612854,-147.472271,-57.324869,116.670059,192.83073,164.351267,23.818831,-41.594811,-101.808625,-84.862913,50.581639,177.805007,212.030644,241.784602,207.256947,36.819738,-36.83109,-41.530101,18.689833,173.782375,252.504002,239.944395,178.739165,182.275655,282.063182,330.229105,330.428884,294.201341,276.727468,189.428929,114.611966,-66.500539,-133.264317,-130.592819,-70.289326,42.939545,12.987929,-16.62317,8.071422,31.194305,21.842941,4.231208,13.070317,132.620226,191.731648,176.60386,97.339064,-66.855089,-75.460666,85.692145,192.337172,287.456077,210.698597,154.104143,75.878539,55.758909,66.479804,97.71891,175.929243,173.326817,93.42395,-131.706068,-209.367034,-246.516175,-209.005792,-64.196416,10.129152,140.609151,208.156714,179.206751,20.250355,-56.431361,-83.223421,-46.841441,32.009104,124.552453,148.556171,80.691082,14.711921,-74.490263,-52.230333,131.097521,235.567822,398.307927,429.268789,366.347044,187.172269,137.747815,210.694288,284.375079,285.572276,104.461405,-0.032894,-188.756929,-273.116613,-422.370192,-436.787635,-271.433655,-154.025104,25.730821,96.456147,72.986328,-46.563922,-87.312424,-2.161771,89.685611,151.320658,94.319137,106.909554,172.432289,152.263629,-17.613663,-88.420616,-47.913102,44.204603,201.659089,101.580959,-18.000301,-192.77694,-246.127603,-277.682725,-224.987631,-43.392641,80.729719,76.069975,-58.444267,-144.951049,-291.658457,-322.952278,-232.363519,-157.870885,-92.477195,-119.018813,-147.077982,-155.272917,-126.119024,-34.055542,23.474197,136.593931,182.907299,156.76277,69.627472,46.929723,33.839171,38.750188,93.605842,137.353452,235.19036,238.244484,196.60625,129.717412,94.218686,-22.407989,-59.583845,21.62254,129.418891,96.00224,-81.464268,-152.425554,-216.510843,-232.22447,-242.784488,-231.70751,-167.759747,-111.001346,-120.050377,-182.403093,-214.844302,-239.045202,-208.577106,-79.87022,3.869732,-20.731291,-112.079089,-129.186039,-180.928368,-206.712153,-77.805058,52.402959,246.179517,299.908951,276.138325,196.729378,182.321901,207.347716,224.620637,257.424707,287.435098,262.426194,116.897064,37.188012,-57.205956,-53.80859,29.253145,72.806871,119.201022,110.731929,84.089984,24.888673,30.027512,88.19486,104.120032,147.948089,244.840147,250.190921,119.606376,36.781573,-48.70422,-35.479523,62.686342,109.05699,211.49876,314.777038,309.665934,174.732895,84.262729,-5.561087,18.215189,115.684099,145.447729,124.759034,49.686032,-5.479657,-140.615184,-170.963587,-99.600385,-50.57426,23.211936,138.822655,169.413679,71.713472,-39.698623,-228.943021,-228.758109,-61.444354,52.340315,48.494616,-5.930078,-36.789967,-81.457412,-58.160561,42.624226,49.108968,9.107643,71.322015,88.197508,-52.338856,-155.194172,-192.770864,-126.684307,-3.162179,42.105459,50.238421,9.204157,-42.723381,-137.340375,-143.9941,-86.923135,-44.178281,28.904911,-23.811707,-80.832651,-164.458754,-207.364762,-261.692047,-217.643708,16.793541,215.335468,212.351699,51.932459,-7.670918,33.469008,74.325443,22.829263,-48.922205,-122.801349,-90.34348,-87.840315,-156.880363,-186.827926,-122.9291,-48.137842,68.415104,121.113054,110.36979,-7.75139,-97.076674,-259.147039,-273.321836,-115.694586,-16.640417,67.735762,69.404946,59.452867,-46.227156,-124.678402,-115.331413,-0.777524,211.198919,219.197687,191.246462,120.444127,52.874211,-136.107499,-193.187057,-159.047198,-123.670435,-117.074184,-131.824318,-124.548757,-154.484339,-226.95681,-347.243633,-316.410092,-113.249272,68.184553,82.542827,-61.383983,-173.579197,-309.124902,-289.803274,-163.484995,-116.638916,-54.557771,37.797807,89.913643,137.386392,115.7994,103.826113,163.456333,316.47686,335.545446,276.829899,110.368316,45.999264,-31.557558,-50.732561,-55.718681,-32.129988,90.057722,145.169613,93.072701,-29.464452,-38.164156,23.636111,60.030809,121.478846,195.540203,206.119964,84.089431,-33.291076,-258.180864,-305.905625,-235.32414,-158.246141,9.637969,96.012146,74.784027,-19.680832,-50.797908,-36.233065,1.077055,86.642924,134.616453,116.915199,32.481403,13.1511,37.835038,64.138289,107.763339,114.012242,144.245201,217.5139,229.446466,120.835564,10.692789,-122.191385,-94.36371,32.286282,104.428089,104.164967,41.707382,-8.135139,-132.060122,-168.7952,-80.420925,20.078387:-60.222977,-72.043553,-105.501025,-135.851397,-138.992811,-220.861408,-271.188683,-275.276365,-267.487673,-340.976466,-573.202718,-628.071924,-565.333298,-508.994471,-373.296961,-278.199614,-120.49676,-98.978963,-100.058579,-78.489698,-77.670701,-108.313376,-120.290519,-99.559788,15.814112,81.414676,132.827929,124.28281,50.685022,-5.303429,-17.141892,44.937376,196.545763,269.010644,254.865202,193.949757,200.513844,278.27353,297.389642,268.694797,218.280602,183.109488,65.7971,-9.705287,-140.181562,-191.204911,-295.158525,-327.000461,-249.965459,-111.792279,-81.44309,-19.52032,30.108507,86.204257,67.415942,-28.266436,-80.808622,-66.96823,-6.171308,10.251884,-54.598717,-129.911171,-229.460269,-213.890616,-103.166425,-52.586494,-69.344965,-83.850143,-71.917339,-84.141801,-121.577732,-219.474083,-283.988122,-309.379903,-387.403099,-425.373932,-447.044657,-426.020022,-270.573815,-146.807691,15.816435,-7.907432,-30.459542,-7.102859,24.060271,107.467788,165.323567,203.873603,76.937778,39.970151,106.536704,155.004714,146.098083,99.736673,57.389914,84.555458,182.520584,272.019255,305.326019,310.526768,277.525365,247.748129,283.729861,344.396211,240.516714,114.089221,-196.134169,-313.015838,-447.734586,-468.905026,-328.358077,-186.258008,23.661326,65.535504,74.929609,125.739121,167.363912,219.264232,191.744756,76.775711,69.168008,95.247327,81.470945,42.980739,-12.386979,13.308907,191.721438,276.493366,302.791758,261.094127,237.986083,105.092239,14.38005,-33.261747,35.355916,197.820824,207.252053,155.414295,-3.968673,-84.500323,-178.117718,-181.772664,-137.543287,-129.038695,-155.862442,-106.510329,-50.265832,17.304376,18.720781,43.96548,83.494745,150.203162,168.823982,175.653122,201.464993,207.347842,147.899551,95.518158,39.591528,48.502689,126.715123,224.756369,244.86681,212.030909,148.782369,-28.137892,-75.386181,-62.249839,-72.171616,-117.677424,-215.263528,-220.960421,-190.335663,-187.131249,-171.525897,-157.307329,-118.130687,-32.979285,-8.181185,-52.580277,-104.896974,-167.035745,-155.903913,-105.119694,-41.510783,-17.804488,-26.862599,-23.025426,69.283121,134.521659,210.455971,215.984482,273.536518,397.811818,414.863296,339.391241,284.965005,235.296067,254.910982,274.162312,190.907428,163.477447,168.209077,165.768909,140.888477,151.302037,186.668532,163.017976,83.357716,101.697518,147.49252,290.712512,345.595259,318.699661,279.393326,250.895792,221.766202,203.996273,230.632493,283.403133,390.670537,418.961082,425.489261,411.374729,364.614931,324.774063,320.663327,305.293608,267.307037,146.173569,104.477206,121.272121,101.098479,39.297883,-44.644781,-39.322533,15.494722,46.262719,91.087155,104.428895,149.960058,203.025721,216.050331,225.815177,200.805026,64.82734,2.647286,3.390519,143.225228,218.180396,299.703292,298.148519,210.766776,157.195306,101.853805,80.828293,56.004618,112.89883,139.917895,121.263433,72.192544,-54.122747,-81.252697,-30.309344,25.282457,21.005908,-39.890531,-97.482297,-262.639156,-309.976013,-214.268791,-149.078527,-176.787057,-199.037751,-143.472815,-32.767091,-28.316976,-87.148098,-111.021827,-78.375353,81.375115,148.062176,126.518875,85.715404,56.385652,28.569647,-148.442426,-272.875943,-421.81217,-369.290618,-323.756446,-310.534797,-360.130953,-454.002129,-424.134965,-249.022418,-170.377541,-202.322928,-276.190222,-271.65904,-273.873338,-312.943225,-303.640535,-210.071187,-16.297237,-50.094841,-125.924728,-193.192651,-158.397985,-49.309055,-10.971605,66.047584,224.808774,287.332996,243.164404,176.96572,107.593158,95.008963,51.206843,15.549923,-26.421376,75.725301,146.933516,176.238027,142.108234,82.277874,75.618031,110.324394,189.243084,209.129663,131.671224,53.476002,-44.652693,-34.974555,-4.945106,-16.04753,3.165736,109.06603,151.604862,170.820912,158.743959,172.991252,215.716596,275.537988,204.370255,158.407435,127.152079,122.105041,37.020656,-35.603603,-143.395551,-164.242902,-152.990771,-90.345137,-64.03224,-41.247159,-35.3342,-23.602949,-8.753665,41.999598,81.693859,76.524517,-6.562372,-51.231996,-117.429153,-162.993664,-259.723635,-285.346921,-234.369631,-84.080608,-49.452698,-94.532488,-120.655011,-103.471842,-69.328661,-0.548213,-35.033751,-89.935932,-124.007332,-76.645829,0.271221,-13.646035,-57.613563,-57.488696,-31.760768,14.029739,58.859807,172.028829,193.549171,127.363168,94.675395,157.19649,279.414757,300.435453,276.667964,247.885273,141.186329,76.13028,55.793962,120.227859:126.574004,108.104526,68.081338,-46.747043,-115.603373,-207.06066,-214.823332,-252.154043,-343.929431,-381.955442,-456.818985,-486.668184,-497.925669,-467.770662,-304.207322,-184.975359,23.701866,60.74752,16.585006,-40.198197,-15.320246,17.983584,-19.247051,-100.169221,-19.383262,67.090077,210.250285,229.653553,122.592179,41.034875,-10.139276,24.473163,135.472413,201.795499,203.14137,207.883481,231.579475,312.786754,361.538629,395.811892,299.954023,247.101653,190.285743,171.802239,58.328735,-25.166651,-121.869486,-133.660688,-61.039458,92.459228,123.727752,133.258599,160.444987,221.210882,208.530533,92.331982,24.709872,31.82634,56.091869,58.162318,-1.95307,-62.923666,-145.483644,-148.70406,-117.518498,-40.706685,15.606692,117.351529,125.210687,36.516268,-13.7418,-34.90327,-27.30529,-64.324533,-167.535453,-171.136139,-126.511725,-128.256635,-118.036644,-75.218399,44.940399,120.813185,134.476945,147.657045,148.690905,152.335084,162.313632,185.16174,211.46831,218.617098,213.869229,204.100252,135.531791,95.487467,113.439853,161.233291,247.537908,306.632822,316.991276,282.274108,244.937612,223.313845,262.040859,330.624019,229.226686,94.448671,-220.164636,-318.547425,-362.368145,-346.821878,-265.619809,-198.389348,-90.428063,-59.42229,-31.723106,17.203228,-10.217779,-95.387477,-89.77898,-43.142695,-65.629802,-75.38814,-67.777449,-65.538646,-76.184128,-77.740746,-53.911873,-41.771409,-17.153483,29.446063,40.124407,11.784738,-35.548899,-133.688756,-130.467264,-65.316675,-70.898854,-87.760279,-117.337269,-151.967595,-281.635439,-329.687783,-308.810209,-279.947753,-234.740178,-119.004395,-50.056089,34.540054,18.355808,-53.601728,-35.680397,74.693954,125.808987,125.418573,131.126525,146.84588,133.157399,112.221139,179.202031,242.161961,254.605362,149.349709,114.22086,90.336057,56.7748,-57.943756,-95.947738,-132.626074,-162.345563,-179.669229,-237.774163,-247.825817,-226.536774,-235.984646,-248.325176,-205.807208,-38.307811,122.644443,153.724787,34.107145,-100.25419,-284.994278,-261.545344,-103.108268,-60.953158,-96.543622,-164.764126,-158.943301,-88.520576,-63.490586,-59.017979,-45.938274,56.887236,190.580038,230.239414,226.431083,200.01058,187.771677,219.509761,283.10489,222.435918,152.931891,80.500129,114.81904,202.047222,200.638827,144.365276,103.645893,9.31988,15.50072,85.511949,218.846011,207.615925,118.524258,122.687047,198.485175,191.898348,167.316402,207.746333,274.636734,337.869594,304.344358,250.004551,278.447108,374.945264,362.932345,305.87361,201.912351,183.809638,159.7782,130.708202,78.419015,54.564898,13.937191,-96.241285,-123.716195,-122.001299,-97.737211,-24.102942,-4.267115,-19.849865,-56.856948,-64.938206,-69.452795,-86.549973,-164.937081,-192.196115,-124.488472,37.864035,80.727814,83.124725,80.50876,48.09403,-1.01272,-116.775465,-149.087518,-133.13405,-62.067552,-27.777895,-7.586499,-57.169291,-228.185702,-250.583077,-96.866651,15.909302,-24.956745,-203.975178,-286.855411,-399.023702,-404.183611,-293.50563,-234.486437,-207.810089,-172.420797,-123.069203,-61.115853,-84.512434,-182.668334,-194.517013,-47.00165,227.714693,302.884097,239.787362,161.489624,-1.130919,-74.757433,-181.892397,-249.688421,-378.937462,-333.959978,-292.858203,-314.854473,-370.080484,-456.424291,-449.712731,-350.359776,-236.009553,-212.244644,-254.490512,-289.989459,-311.054897,-286.03935,-188.553115,-142.31232,-103.310477,-145.107074,-171.255874,-149.683587,-120.878378,-83.125901,-42.170957,77.298366,142.905469,159.164584,145.904292,104.817955,-9.034126,-25.014085,58.672679,72.821985,-13.285991,11.55902,80.992501,183.021812,173.299157,131.809655,178.775213,332.202355,329.111667,274.942732,164.620326,108.923807,-25.698925,-70.750056,-31.227041,33.685763,143.433442,173.685975,152.450104,83.830458,69.642701,80.277163,85.102899,103.764843,139.870987,136.074002,84.129634,59.123783,-6.343418,-51.593175,-118.881212,-130.274213,-125.281433,-150.292784,-158.150678,-90.523781,-52.098566,-49.116255,-46.785221,-4.749164,6.93678,-0.907807,-21.740968,-27.56855,-49.173782,-74.128714,-136.691421,-154.704042,-101.817258,6.810715,34.724547,44.698965,26.231054,-32.630475,-40.358437,-42.666622,-104.900159,-137.902407,-140.313994,-113.408312,-90.83863,-96.207005,-63.877795,-32.678777,34.282605,99.016639,106.953099,63.477515,29.340835,-4.95366,19.048528,147.16646,234.867988,235.801806,189.843117,143.652254,38.502763,22.471544,98.00728,151.220409:-71.634275,-48.544432,-88.145404,-115.660019,-135.131694,-243.042315,-274.247205,-213.403855,-160.228062,-212.06047,-391.343604,-436.427401,-440.310308,-442.062218,-371.179471,-266.936063,-34.072293,57.186366,38.983022,-42.425058,-76.172828,-118.278523,-131.949638,-98.015359,66.200559,154.534035,211.000759,156.736687,-55.665241,-134.896857,-103.00111,-41.46303,49.641756,113.905656,108.686086,79.342865,118.254765,266.284609,311.850831,274.120281,153.565372,123.839487,101.68353,52.999096,-104.481257,-164.000106,-236.971706,-251.91322,-167.286905,-11.778422,30.041933,30.140597,5.195668,-8.806705,13.033342,28.734561,59.95769,97.767977,69.894705,10.404725,-33.994121,-22.594777,6.211571,42.102379,124.313596,144.874616,135.035466,82.839325,52.919949,29.085653,22.402538,-13.103929,-19.665708,-55.057764,-250.685832,-326.535599,-314.938763,-283.814293,-252.892465,-217.902165,-57.975669,64.99627,61.312626,14.502096,14.502691,54.282682,79.963086,92.780061,58.69368,75.538109,133.174524,106.029543,-44.687539,-84.3111,5.981745,96.040076,280.722778,351.756258,315.050281,233.276865,231.931589,288.817375,303.951325,245.562172,153.297359,73.526867,-140.52174,-203.885951,-262.06289,-313.451744,-375.148074,-325.275848,-108.506983,71.13949,86.229554,26.43984,24.366203,123.233226,157.858378,91.94676,59.959707,92.523538,141.773421,142.599043,139.966808,163.162579,244.98009,263.874448,261.485478,281.923494,257.660063,69.014531,-44.586467,-109.979828,-43.242882,95.574916,101.240084,86.178637,21.501473,-36.15892,-182.49787,-252.693014,-287.435154,-242.164154,-133.128371,-92.971936,-83.418599,-51.176217,-43.022367,-12.05189,46.481132,199.586261,251.212372,241.257823,209.015402,190.728083,116.852324,68.075637,24.428416,41.437161,126.955161,196.660669,204.172539,187.094894,153.479027,27.417423,-20.020147,-0.541381,108.640361,125.536073,27.522365,-32.052974,-89.652785,-102.326758,-116.183225,-121.342221,-125.607427,-89.517611,-53.827003,5.065253,-19.842449,-160.218078,-188.449036,-82.122663,54.765168,66.791247,26.155709,30.432949,11.982896,-31.705318,4.712829,106.91759,282.868354,293.177597,269.180747,246.73043,253.092424,243.3565,227.021929,251.482374,338.451206,320.818741,130.800452,60.708047,93.303063,134.151512,170.370295,181.464946,179.923297,103.540912,56.30047,45.291226,84.093193,165.028353,200.183352,252.693045,194.843649,153.666303,158.657471,177.388149,157.552484,159.222673,258.646881,309.620015,327.73595,296.117052,282.406547,233.359014,187.098489,64.297813,8.189247,3.585486,108.393305,111.112526,27.21568,21.604469,33.025343,-9.166969,-63.369933,-23.418909,94.915113,156.031204,178.920648,176.114255,112.087036,-79.778385,-127.093621,-41.385407,89.923224,95.056122,43.83284,58.912152,179.766524,222.887727,182.531106,113.973063,19.534193,80.029703,112.569518,47.096042,-34.070481,-175.353484,-204.56477,-153.346707,-12.828421,19.906403,-30.321887,-57.201654,-69.699263,-78.669164,-81.151231,-80.221056,-127.463511,-142.012966,-99.385617,-30.908673,-82.937948,-258.177765,-262.95496,-91.146765,69.99599,85.7364,27.165579,8.791536,-28.958674,-69.726634,-128.674283,-147.730624,-223.983231,-284.808214,-281.666282,-254.625271,-229.464544,-128.070658,-88.168069,-88.272723,-86.151769,-72.478392,-93.592869,-129.052591,-201.295228,-229.888119,-205.184943,-151.875021,-49.038454,18.300207,38.931736,52.967635,41.394535,-16.49202,-23.874778,90.779803,214.377875,197.733791,83.79373,58.705553,49.403181,21.181233,-51.550137,-82.627651,-134.261761,-127.849098,-81.906462,15.781357,-8.088151,-148.441208,-156.34506,-1.311309,82.717931,31.797717,-130.136031,-175.220883,-177.343585,-156.907432,-130.834428,-147.923385,-158.192436,-43.573592,13.620846,94.020501,120.474409,118.79428,113.834423,163.658319,259.315785,260.275941,114.671231,39.922937,-31.478776,-56.318245,-90.544903,-83.491963,-24.444913,-0.843711,-20.213828,-80.866129,-105.030131,-62.712142,20.016573,175.733519,176.980864,135.780687,27.184052,-32.04546,-175.625831,-238.532519,-256.827718,-223.67444,-153.539342,-143.160898,-149.556415,-120.128497,-96.735486,-94.371548,-106.902248,-101.304371,-105.346654,-137.66724,-206.709384,-181.025058,5.150961,88.741789,107.977873,75.572299,90.273517,160.689467,160.781916,122.445742,91.237824,4.621873,-4.562652,81.930297,147.89049,156.532773,155.636257,136.933338,38.396006,-10.478398,9.841769,70.033428:forward
92.552056,93.004418,109.138274,257.531718,345.267438,340.206333,280.601478,250.110677,326.806815,361.606589,388.204469,391.941235,387.874308,354.167599,237.335047,172.977005,28.336427,3.458177,49.273686,97.368322,66.25914,-24.402327,-32.611036,-27.826306,-94.732833,-102.639004,-42.614331,-7.423461,67.939138,90.090049,14.060494,-57.680686,-98.270977,-20.261271,-23.69098,-127.342779,-161.574357,-118.721736,-67.898177,-11.529439,-4.830337,31.178206,151.678744,179.652673,99.76998,36.177919,18.40872,48.138273,48.16066,89.715474,171.571088,327.009547,347.99797,291.713699,246.576912,132.76149,19.765471,-4.639185,3.574376,27.507304,68.383238,73.135627,102.136008,119.235288,63.881996,-37.031254,-40.399835,8.276886,8.99651,-62.916813,-110.19154,-193.01369,-179.559928,-113.306173,13.22864,19.655938,-61.557316,-117.73276,-222.304964,-261.176111,-278.678035,-219.50985,-178.86926,-102.167665,-86.704156,-78.14423,-36.341491,75.978792,-1.89233,-77.293825,-87.346751,-11.937496,135.150446,129.459884,-51.72762,-170.623871,-327.339074,-278.819384,-212.825586,-110.01732,-81.717736,-84.344595,-88.119493,-46.538615,-50.119956,-61.125461,-5.618422,51.550399,97.482932,64.605596,-7.523309,-20.477855,-41.000023,-62.088337,-48.937392,85.886982,196.402505,345.954464,343.824602,284.271165,293.719732,295.911205,246.634853,234.522502,235.00574,200.543811,93.345121,51.126638,-41.875289,-106.295935,-105.66442,-103.460818,-127.858871,-208.754769,-226.157632,-173.562113,-133.853752,-132.800159,-113.697192,-101.618291,-86.015841,-67.467819,8.940606,31.37064,-9.099434,-56.917417,-61.306925,-26.930405,4.605217,-5.49502,-68.591836,-180.193697,-152.396216,-118.45979,-71.98101,-44.998319,10.686181,-5.065307,-98.823136,-119.352212,-81.216047,-24.432878,-20.88047,-13.69356,25.901576,130.818652,132.315061,-22.8641,-171.074158,-177.42257,-141.800325,-134.695145,-99.722663,-57.375566,29.348131,41.299838,-29.269355,-145.136999,-169.445537,-76.215919,7.408383,65.208838,1.9187,-220.722716,-317.407604,-260.078784,-74.387436,-28.602232,-34.525497,-44.617793,-60.792011,-94.562742,-236.140087,-353.416998,-380.409166,-389.426678,-375.014056,-359.827944,-378.292697,-434.596921,-431.798521,-402.556204,-315.56744,-252.055266,-126.031407,-101.862606,-139.298109,-177.622237,-234.11856,-252.620338,-258.290443,-226.494219,-174.98419,-119.751624,-149.6554,-220.324805,-192.020499,-151.280232,-127.330703,-142.373037,-109.799428,-77.54838,-148.071969,-265.529403,-489.673529,-481.920392,-423.959228,-339.103219,-305.649066,-244.983027,-241.744392,-307.383405,-360.692325,-336.761953,-198.751847,-119.906649,-48.057229,-86.830421,-257.891433,-323.787814,-351.191424,-311.345262,-297.762203,-289.568045,-286.761028,-319.236861,-350.8025,-391.631424,-406.174376,-383.272785,-249.024467,-176.914502,-88.5053,-63.125956,-33.235041,-36.217547,-52.478833,10.001521,48.587414,63.435965,53.375266,38.754014,15.663582,-120.213815,-244.058008,-238.913415,-140.97596,-77.643497,5.551169,-10.615098,-76.631262,-59.823579,39.684121,17.246623,-74.308936,-284.69925,-330.438386,-304.636717,-277.668507,-265.706578,-357.05098,-415.583832,-461.383702,-441.87594,-341.192413,-278.652712,-199.622236,-195.68486,-210.854399,-189.580352,-190.741064,-216.677498,-203.433057,-131.92105,-99.431045,-79.097595,-139.850277,-165.92106,-147.897765,-112.470589,-38.53636,-24.990616,-91.554528,-165.605951,-302.703396,-299.333576,-231.612852,-30.271319,52.45274,102.460421,83.295161,-19.641347,-144.652735,-172.478679,-187.406625,-172.433821,-65.588912,-22.803511,-62.797297,-124.017989,-208.744534,-99.623082,-0.252582,113.87705,103.107492,-23.38963,-94.205187,-151.928599,-147.48481,-125.324654,-42.130506,-3.604083,75.353878,127.378648,179.007002,143.281266,8.010007,-82.31535,-105.614506,-130.694819,-119.879368,-60.81246,-42.151713,-30.209056,6.952821,34.676199,86.483393,98.497675,84.46738,79.441909,116.069073,140.441072,148.817005,190.121053,243.842079,371.370096,429.980766,465.07884,418.629703,280.222689,291.298687,351.557052,399.249894,365.4354,291.123608,288.128532,310.816728,279.963404,115.833569,19.845341,25.183221,64.256576,74.131025,32.431188,-17.70331,-122.491912,-132.60148,-73.171138,48.506414,72.930579,93.611121,75.657917,-23.254461,-58.674148,-81.458949,-127.765676,-154.100849,-108.673158,-32.374914,98.324845,125.607401,119.457678,47.592317,19.641202,62.328002,127.890907,252.690232,271.097576,200.559998,126.949857:77.2226,141.498702,179.729021,281.365702,341.52009,348.955904,283.232791,202.33851,290.34262,336.509599,367.188645,373.411567,334.624161,259.944276,109.336952,78.437422,26.459058,-29.259657,-5.251663,88.299248,90.818235,-12.794959,-65.379069,-103.220861,-86.792833,-63.865273,-26.729389,-9.923345,46.618377,75.888775,79.094215,43.222651,7.903333,62.242378,68.225301,54.394773,68.712026,77.025496,45.73465,-19.094449,39.180595,139.534844,354.325531,386.075164,252.808683,164.375589,133.819149,154.119258,146.541723,201.692927,255.462697,316.672478,311.824307,239.528506,196.487062,120.498085,64.894999,69.793355,97.682525,93.31123,55.953886,33.545656,3.831635,-4.038007,-48.244541,-109.430309,-106.26986,-13.475166,35.349311,10.602565,-57.391611,-196.407141,-248.402842,-234.219658,-155.431423,-113.27298,-123.180793,-180.867186,-295.943569,-343.870397,-399.073942,-327.143512,-263.307087,-146.234447,-130.319531,-190.385443,-194.805255,-87.197831,-11.516487,-2.759486,19.564911,41.40663,116.316882,157.344614,169.567139,107.72603,-102.394402,-172.804072,-125.347742,-26.929933,-18.680608,-49.357375,-79.350809,-165.841821,-201.634696,-177.904916,-91.104742,-43.757456,27.083913,20.316634,-40.289208,-37.172852,22.275422,-32.834672,-69.504595,36.076513,149.226573,265.033631,251.10374,230.433936,300.265149,320.84592,277.474306,268.196543,341.950195,355.321962,232.177938,149.324021,107.894912,191.468969,202.153584,103.503925,33.660162,-58.847655,-71.417074,-38.415425,-21.076563,-36.029017,-32.954243,14.283647,119.291414,126.346311,35.117636,-44.51723,-129.174152,-21.455343,1.205412,-117.995456,-178.360918,-190.886106,-176.711776,-196.983857,-257.697572,-262.713509,-223.724633,-197.037938,-140.382662,-128.76023,-186.942548,-236.852437,-265.659095,-184.560791,-147.968043,-108.92483,-94.780135,-78.439223,-78.025998,-119.092083,-208.222841,-196.280083,-62.555768,-25.171326,-78.269729,-122.493903,-124.515269,-95.102304,-85.591098,-61.751142,-7.689276,71.42705,53.746549,-63.004156,-122.411904,-196.320576,-211.588843,-194.089672,-97.51382,-35.613113,-3.972601,-48.32342,-161.968956,-207.717738,-300.598893,-392.315422,-409.651464,-376.150915,-365.983196,-414.800864,-436.628418,-417.191936,-379.994839,-370.226453,-346.005624,-297.770014,-177.136216,-169.666399,-223.243565,-240.45167,-265.590668,-261.916326,-249.455875,-215.844617,-194.741184,-214.312283,-262.963659,-352.600289,-362.077711,-333.424796,-233.599765,-198.060696,-226.379262,-268.26603,-367.443566,-438.575867,-524.889672,-463.920666,-434.095474,-403.858949,-402.408126,-414.676028,-387.649631,-318.879477,-370.831004,-398.027203,-342.0975,-257.799867,-86.473561,-71.99706,-227.923793,-336.912385,-448.552234,-381.306666,-326.78423,-245.216013,-225.735559,-251.736861,-286.865843,-329.129828,-319.970303,-305.91343,-241.841884,-195.249741,-134.400619,-111.853711,-62.810321,-79.945428,-167.724784,-92.629606,-23.326984,-0.312578,-30.817301,-86.494433,-128.411572,-269.969421,-368.778697,-356.580338,-251.934059,-190.216741,-104.964623,-106.892758,-156.373545,-173.305333,-166.460814,-102.572991,-106.983058,-201.460225,-234.137311,-243.098331,-237.73909,-244.44258,-284.166127,-292.625085,-280.952728,-259.627213,-188.368535,-155.50287,-144.379573,-180.017686,-253.05148,-196.932689,-168.385916,-178.705877,-165.993359,-42.396465,14.838355,-13.274722,-111.920723,-118.014448,-40.570567,20.78511,81.249398,60.845645,-11.803083,-60.754738,-191.192469,-209.61807,-133.297577,104.389773,185.743726,160.510179,95.491819,-15.580376,-40.235529,-41.172845,-74.944687,-62.061861,58.872893,100.682311,36.591478,-45.279911,-140.698198,-15.525459,79.78356,202.600597,207.919242,113.233656,45.529693,-55.98625,-62.350017,-24.142974,61.059385,73.994121,55.27552,55.030953,77.400835,73.779727,29.382486,-8.230646,-18.122686,-15.876897,-5.430312,23.80024,32.03897,35.733771,100.942982,145.672181,161.134817,134.334615,99.136908,94.192065,57.531002,33.967964,76.403195,246.2452,321.267481,411.735481,440.380267,463.081194,434.012009,279.283309,253.363267,334.220635,441.041828,408.950017,291.690005,269.185495,276.235968,243.592001,104.129131,84.026406,121.577595,151.160284,111.906305,-43.863075,-94.648238,-82.295649,-41.989861,3.841881,110.330118,122.943824,108.826895,105.192686,44.845038,-19.913873,-125.474178,-103.0251,-57.672779,-6.625797,-8.746191,21.991391,60.725009,37.502014,-96.673076,-109.843396,-18.344374,39.897594,114.892077,124.129913,73.828757,7.566693:70.744198,191.587527,254.889845,286.756774,278.754269,265.728731,271.203783,299.15331,300.304481,300.300504,332.989292,363.823671,380.032561,333.5477,231.005545,212.732993,151.959444,78.753232,101.587116,188.680322,183.310663,97.476432,69.217529,34.436231,2.109809,12.414953,39.702255,35.700649,14.291257,14.364289,30.769203,37.455033,95.687899,172.751619,164.742669,157.286571,202.699401,269.902553,264.377442,266.724506,333.133448,375.987326,466.758419,497.637626,417.161966,333.2075,271.827191,286.335297,316.595994,336.536468,326.687136,288.228775,275.623508,243.779571,214.437668,123.687482,35.796846,19.58317,86.690369,150.717185,161.92415,95.702887,-20.189432,-50.531348,-108.439567,-92.440198,-46.179112,24.730943,17.053445,-62.090958,-102.708985,-159.981402,-143.382779,-96.154243,-7.105052,-2.706784,-85.967971,-152.120297,-279.417581,-322.311981,-322.591078,-259.322453,-242.648118,-248.288816,-274.178514,-333.585807,-306.52076,-125.562817,-10.24441,6.492821,30.899093,42.666232,72.436884,90.579753,76.116456,16.338793,-137.13534,-147.647205,-93.345912,52.561702,94.416265,51.033823,-10.946481,-166.977303,-288.830006,-291.101211,-170.658747,-87.630403,8.68634,8.718459,-44.836289,-75.847965,-90.391051,-23.098364,24.133238,147.00939,180.546103,135.824043,135.197319,242.72223,339.414192,368.692425,369.301611,331.01579,255.520419,264.778329,299.139613,247.465007,71.260683,59.453205,100.023453,116.126559,89.327496,39.981741,4.710007,-126.967867,-182.583525,-143.524405,-17.700183,36.525998,84.577511,66.924569,4.565717,-18.484335,-39.066619,-41.409925,-68.911772,-131.35307,-142.954018,-148.496001,-149.03967,-144.789652,-135.831571,-130.689247,-115.766214,-108.58683,-126.50392,-154.480455,-214.150706,-240.384634,-257.378305,-178.079651,-141.468554,-141.133528,-156.023609,-159.444196,-147.110346,-148.532149,-196.331449,-194.099925,-100.641931,-46.405694,-39.41592,-89.002666,-196.513283,-222.03628,-167.787743,-5.981319,59.316101,72.070103,22.442169,-111.689981,-171.590196,-239.824463,-202.33798,-171.84292,-146.839311,-115.944045,0.471752,9.262235,-172.032301,-297.499623,-405.74747,-335.504743,-307.99005,-308.985978,-309.40546,-280.357857,-279.921283,-366.786226,-434.839703,-411.24686,-329.070589,-290.662098,-184.141804,-151.994164,-259.767622,-356.655832,-416.364316,-302.586282,-233.247476,-143.046773,-166.629485,-341.688357,-408.233244,-405.318408,-338.407831,-297.844067,-263.821841,-288.321264,-298.12761,-254.065678,-260.200739,-370.925856,-553.920008,-434.759087,-363.17071,-366.539762,-405.495361,-432.663422,-432.004141,-485.879457,-507.710301,-487.434275,-422.732694,-349.258792,-142.721986,-89.117168,-167.307571,-254.0633,-348.27482,-302.452189,-282.216305,-267.829388,-263.055933,-287.236681,-308.495227,-317.684741,-265.980762,-228.338627,-162.009091,-128.702943,-92.802205,-100.754027,-165.755105,-217.054634,-223.30249,-56.941581,-3.298944,3.571692,5.044534,-20.716631,-89.038707,-298.85575,-380.943591,-337.100029,-208.256157,-160.831317,-94.464556,-85.475418,-147.363124,-182.428586,-142.833289,-48.132982,-42.083214,-109.646852,-143.90211,-140.13771,-121.970731,-160.795786,-220.00434,-214.461675,-216.800191,-216.506847,-124.516414,-72.09449,-65.948979,-97.382018,-149.002542,-147.694339,-134.946821,-95.276215,-77.361116,-62.218623,-58.091286,-73.18405,-142.674987,-164.139022,-126.279998,-84.980934,-41.248375,-54.30638,-123.499417,-165.809659,-221.364948,-159.134572,-82.628374,86.270559,136.877447,125.731853,75.995902,-29.554131,-9.444936,15.342176,-2.986854,-7.109905,42.302997,50.415648,-2.850159,-36.33645,-37.292847,27.4722,51.815266,136.29838,175.196843,122.997095,63.137519,-22.427968,-53.439142,-29.277715,90.235319,142.395864,131.986293,73.690351,-34.751496,-53.89422,-73.597455,-94.503109,-73.749087,33.380235,72.223548,63.09234,54.580975,85.135994,134.180188,154.910785,183.823031,193.019181,170.669402,130.122755,47.003178,36.627359,127.027403,278.317526,335.782706,406.176398,409.052589,351.653629,313.379159,227.217284,227.36098,292.443611,411.0567,411.95307,307.497191,250.758531,218.352987,216.447537,200.53511,238.771951,236.494842,127.092601,61.918267,-5.838425,-10.914549,-33.22677,-36.396157,18.037624,143.626639,156.53604,131.20335,126.952074,79.280265,19.059332,-56.677143,19.344987,68.703798,137.319627,150.626574,102.593039,61.468034,6.820803,1.926762,-1.530344,-42.461204,-55.480534,-43.896982,-36.170985,-44.90238,-68.058871:227.991511,328.983116,352.612937,371.663592,394.934005,415.275538,396.205392,366.653064,414.594402,452.420873,508.751452,534.379168,530.225611,465.345503,318.07296,282.187932,223.249188,207.545015,231.868463,241.79239,223.000324,183.852266,166.273591,121.467406,48.29107,30.043156,92.725221,156.72467,212.372924,170.677665,50.598423,23.658657,58.271554,167.018445,203.769416,192.788046,177.430007,179.097969,189.156443,223.754239,299.200131,342.824391,409.696844,418.42036,330.38028,249.854678,171.628887,197.91454,278.86605,299.954941,293.451677,312.847417,341.960082,335.482566,275.105281,126.867961,56.621714,58.053284,103.899492,122.283399,123.098086,113.099565,104.210051,100.465076,53.508354,8.663422,10.365855,58.048588,72.887809,3.374625,-52.087681,-102.579454,-94.533448,-70.072131,30.370343,63.969694,-18.611302,-109.121621,-230.640789,-246.325276,-260.872401,-251.138991,-216.862217,-119.329704,-95.336829,-114.574363,-96.531835,21.578352,15.765066,-23.074091,-6.948083,34.651632,88.983087,96.479784,32.249238,-66.51449,-268.312098,-212.310482,-114.54072,57.040856,109.505757,132.274967,106.789987,6.117822,-107.900695,-128.030189,-58.189763,13.259316,111.057549,97.343961,21.933868,13.39168,43.991672,36.354614,29.674159,138.189629,246.551029,380.150715,358.982465,233.025868,220.703854,261.458644,292.773467,273.844657,265.132419,274.347757,215.140435,142.647913,10.461443,-15.038729,-6.048458,-32.2027,-65.143018,-145.462585,-183.178018,-212.07846,-183.876463,-152.526336,-78.921734,-38.492374,45.652746,55.003446,1.094955,-25.267933,-54.349375,-71.517033,-80.871695,-83.610645,-71.905338,-84.568444,-127.825257,-203.472512,-168.340778,-136.169715,-112.85052,-101.551987,-58.513456,-67.242191,-150.847078,-180.983654,-175.413977,-149.907853,-144.63821,-89.725037,-42.590656,-29.427409,-74.575651,-190.911794,-214.69618,-166.186385,-93.251172,-116.157718,-184.801574,-193.054842,-187.926502,-186.626323,-187.130741,-154.465286,-115.017833,-21.643475,-0.356408,-90.843638,-181.548937,-307.950721,-310.046769,-278.872351,-164.72555,-99.248771,-39.188137,-54.391032,-105.844617,-130.25313,-191.385213,-272.327357,-322.791862,-362.14749,-328.322806,-254.327706,-254.366961,-331.364857,-409.727136,-400.575053,-310.587352,-253.304176,-147.987572,-122.556532,-126.407616,-142.510676,-207.948983,-245.341026,-218.935944,-111.666554,-81.222533,-161.939528,-228.438428,-249.08162,-122.330056,-60.404474,-81.583664,-149.034171,-206.869067,-180.517435,-193.676753,-287.16245,-513.024281,-511.915326,-435.272714,-300.624899,-293.909281,-384.725629,-422.893257,-410.066656,-392.954535,-413.112547,-429.785854,-392.470095,-250.817022,-193.894251,-209.379909,-299.468637,-524.515833,-513.730353,-442.23609,-389.795026,-412.95381,-459.414107,-452.079334,-385.588178,-364.609869,-366.177994,-316.463644,-250.242728,-110.370936,-99.799054,-214.523927,-280.336939,-287.457204,-131.400997,-48.550008,41.446439,45.962318,-20.507136,-75.80497,-206.139099,-289.990337,-271.466285,-172.972321,-132.065683,-98.744065,-116.934999,-187.722603,-201.67768,-164.230649,-56.32609,-15.944718,-60.668401,-122.764972,-202.066581,-192.528315,-128.75729,-172.963115,-246.236471,-383.988229,-397.471927,-321.770276,-289.928965,-283.005985,-277.343723,-236.195936,-192.808801,-189.791781,-198.243723,-173.578993,-81.924982,-55.773619,-70.31232,-157.316748,-212.264702,-228.037759,-167.04761,-14.614996,26.920649,7.604273,-54.143492,-206.790151,-189.828573,-113.538419,29.430078,63.319655,72.876156,72.556499,69.758527,-15.837849,-75.188152,-112.130343,-82.160148,-4.831096,-1.275534,-78.397651,-119.267084,-132.930809,-74.907674,-45.674105,-18.266597,-11.593102,-9.423701,-19.022096,-61.498878,-109.350978,-102.618902,-8.821834,51.034681,107.59445,94.910649,17.200974,-39.471394,-145.892763,-169.107819,-147.247852,-86.715408,-58.796506,-7.725259,16.026281,43.341969,68.604157,100.900905,152.539867,147.276178,111.189309,88.923031,24.094692,4.043764,60.86982,242.951527,332.412945,438.403852,453.447315,427.198105,398.028759,304.977182,235.809459,253.646567,323.946196,329.57179,276.742976,260.060245,300.359442,311.527555,245.011636,175.821685,151.875312,61.945079,-3.631046,-89.298458,-82.513472,-43.784242,-69.552419,-54.578666,33.295214,52.838659,45.13398,37.00941,-1.60812,-33.659806,-78.19012,-67.466886,-70.956044,-71.256045,-45.648912,8.757154,27.361639,60.884869,64.266197,55.607886,48.152437,62.701796,107.433,114.856105,81.216168,41.018495:-48.210556,93.070844,168.999485,253.112422,247.451212,134.716441,78.908527,61.953764,124.824639,177.474592,292.665554,325.339409,289.713648,233.431313,128.8663,105.673083,105.053448,145.968966,181.270825,203.070169,172.06451,100.924859,93.459797,76.66511,-16.695661,-34.926926,45.544633,106.249095,157.62074,129.576415,27.259788,-15.308877,-41.973566,40.48755,101.805122,176.919568,181.539843,180.440546,184.789554,214.269868,334.350616,403.56068,478.65991,469.12526,291.068706,165.346911,75.017796,106.545834,159.683368,176.659474,198.649712,258.267777,257.304699,154.180354,96.280826,48.174114,33.738773,25.297139,55.57978,106.529664,173.886306,147.512115,28.875952,-29.631584,-113.499898,-89.425656,-33.289432,70.144985,62.641276,-55.026824,-103.774747,-132.866423,-117.24627,-92.720259,-3.274664,42.896216,35.472401,-27.823867,-170.084804,-210.398403,-225.689868,-204.667435,-200.40939,-183.835429,-163.180122,-147.44279,-140.512449,-66.575951,9.271094,29.988703,50.330397,51.937712,68.999735,90.013679,54.402498,-44.272353,-260.344625,-192.741673,-73.288934,105.087943,126.518807,62.587772,-5.5083,-157.551698,-197.006579,-169.94703,-93.435237,-30.927371,75.249477,56.626714,-55.730854,-88.88759,-98.066008,-38.004481,20.902978,149.993414,185.607363,173.658966,158.286573,139.701549,185.141871,242.942441,312.712892,299.094211,229.440634,201.932188,164.794793,119.597222,-5.983596,-15.473804,8.296681,5.152346,-27.694191,-133.106241,-201.288372,-279.878685,-161.632132,-80.019366,7.541219,45.38401,111.12608,82.166512,-58.790528,-105.942093,-131.877381,-83.737793,-35.020961,5.36256,-28.928728,-110.90301,-128.928866,-164.171442,-185.789733,-156.920057,-33.033061,19.237768,22.796485,-12.387873,-106.838524,-160.473899,-195.448323,-102.919378,-71.116487,-77.980555,-76.344245,-36.652094,-28.000615,-94.344525,-184.094611,-173.754904,-87.611237,-42.622653,14.363279,-2.386314,-136.330928,-205.126028,-193.596709,-35.790864,34.376274,121.509001,125.651263,37.859241,-31.055295,-150.321062,-170.516736,-131.04142,27.993002,123.306403,209.341985,168.094701,25.183453,-26.339516,-73.449234,-67.664764,-61.281343,-41.066834,-27.669179,-36.958201,-59.451522,-139.460336,-200.764564,-189.91498,-85.496343,-2.389906,99.943569,79.685066,-24.102609,-71.357421,-131.953161,-94.13384,-38.991145,67.002338,88.033044,37.611643,-14.220488,-90.501633,-22.883113,42.406592,60.847978,15.633855,-44.690989,-49.682923,-127.569501,-218.362999,-341.66383,-257.002873,-176.464224,-62.08727,-79.572058,-238.343483,-309.312966,-372.903754,-362.601062,-340.730533,-289.911189,-238.025572,-97.97526,-69.977707,-158.146078,-243.984366,-359.186839,-298.27375,-230.510021,-130.932579,-133.69628,-233.804717,-287.353703,-333.968996,-286.63522,-255.525607,-225.195049,-197.706323,-134.883473,-128.098466,-174.361442,-223.113139,-261.190253,-149.56467,-78.823605,17.624794,20.409209,-88.75039,-182.190916,-369.633562,-415.571587,-357.455192,-203.487503,-149.68091,-91.938911,-93.088723,-168.18617,-225.153479,-273.956083,-129.554273,-35.980462,-13.820237,-81.11904,-161.853798,-132.742607,-35.00296,-48.713655,-103.142442,-189.726386,-176.483266,-113.348627,-127.767506,-203.996189,-209.218053,-170.074428,-133.11538,-123.148434,-142.690895,-150.575269,-114.794016,-89.231379,-81.289732,-120.245894,-145.788794,-158.536671,-131.533735,-42.752721,-3.974222,-39.645416,-133.622293,-283.388255,-176.616093,-76.23186,95.679479,144.376068,147.184933,129.529481,108.476331,58.564242,27.138361,3.847504,25.015016,68.489371,49.778543,-16.096,-24.11049,7.209811,16.068045,9.495266,54.257882,67.63979,-7.711794,-45.350053,-76.777073,-115.916017,-101.29246,45.143394,122.843198,132.155315,72.513474,-52.602279,-88.15392,-104.561215,-70.163446,-31.142094,49.361072,66.231024,82.944126,99.341548,79.756705,40.434455,67.905881,152.097049,162.270214,110.12701,82.2102,60.170283,52.989963,88.168646,250.460092,339.648156,450.659612,458.238086,371.034824,295.598813,130.244845,75.608954,121.64762,203.302424,202.264551,212.195612,243.009351,279.229931,244.349123,141.738685,172.491085,188.595615,126.434296,87.554301,41.776924,3.091663,-129.712211,-149.14275,-82.699835,60.759733,99.119232,113.530677,94.423403,5.329277,-55.62343,-111.621203,-28.484367,19.334463,82.815493,79.389574,-9.297949,-44.327432,-38.079166,-69.76861,-102.32772,-60.573155,-4.003879,4.292868,-32.021856,-68.959068,-103.062313:-39.216986,-22.846132,14.278628,121.345908,157.339791,125.331365,118.059417,207.04871,242.134572,228.985601,240.615488,254.806624,222.677345,164.520173,23.041348,-16.005358,-17.913627,-14.334035,-32.650611,-65.175773,-51.280748,18.355898,52.086321,64.769441,-19.007615,-51.281526,-40.634298,-25.405943,-17.995805,-26.175473,-71.690699,-101.621734,-117.492414,-40.189695,-19.025253,-104.995643,-147.860766,-93.078293,-39.244618,-16.980877,-30.850844,21.053429,178.764932,191.15673,74.495552,25.332033,-1.459003,-2.410941,-5.689872,9.503288,39.093477,135.40906,173.359171,179.072039,153.87714,36.500976,-106.185352,-121.654587,-67.462773,-43.267603,-16.611491,6.070946,89.201671,117.23974,61.336264,-12.590796,-2.233206,25.99515,-1.53648,-103.105853,-120.968506,-78.354945,-47.7098,-36.566079,27.533049,73.507894,70.084792,4.451599,-96.007011,-102.466672,-134.71449,-180.478631,-160.523401,-63.169539,-32.832699,-38.651712,-24.460608,86.272533,71.410461,-9.956735,-110.090813,-72.068158,61.474409,51.988981,-192.839852,-327.225603,-390.841942,-259.032104,-189.882668,-100.792228,-80.059246,-99.293293,-119.541678,-88.366434,21.704651,67.461865,81.745659,75.021676,88.975744,88.567731,80.055792,80.361769,47.241584,-0.821174,-10.178449,39.540068,97.439671,159.624437,139.02441,74.080531,46.027806,31.170816,15.115533,29.334234,24.206093,-15.085355,-69.047437,-75.357262,-139.093966,-194.247671,-195.576672,-234.169228,-277.152361,-349.180637,-357.170798,-309.58543,-220.519949,-162.870022,-107.375162,-137.272382,-186.950409,-150.979855,-6.229435,27.848674,-68.303726,-138.652549,-97.253545,17.555595,53.75167,77.92335,53.352866,-57.981864,-93.050165,-37.897379,99.875565,121.217398,73.36416,40.89291,26.647773,34.831731,32.615345,28.508482,37.090751,103.01282,157.72749,224.643832,207.459726,96.672169,-10.11808,-19.939749,-7.113287,-37.945518,-86.374276,-39.651311,100.904808,114.269441,46.04075,40.585701,68.415398,131.683636,147.559436,95.554836,31.690935,-112.264732,-144.959041,-89.146581,17.642961,21.184978,-4.05287,-0.758497,17.840119,-4.12565,-125.907434,-189.588875,-181.212818,-153.601794,-145.6195,-153.556568,-159.938702,-162.131488,-183.696005,-176.582685,-80.215996,-21.381654,41.465736,57.45564,88.172933,81.656665,5.018655,-37.052516,-5.206393,100.271212,122.006858,53.257027,2.953802,-11.630096,60.18807,90.071718,106.765382,100.299607,91.126748,83.146943,28.45251,-21.754973,-140.809079,-183.972086,-160.948597,-78.154262,-34.583095,2.131565,-18.732399,-87.981911,-101.460544,-100.189532,-145.749146,-170.60034,-121.84244,-54.280545,27.777641,-0.832272,-151.708587,-233.288603,-210.630967,-135.518326,-133.555581,-191.687639,-211.770802,-193.353554,-138.461214,-116.536445,-91.012442,-60.718033,41.130103,63.762163,10.453509,-23.413459,9.830486,121.674804,141.738334,113.217599,96.556057,55.689185,17.459944,-104.087419,-178.047704,-137.608494,59.837283,153.877221,195.620731,129.407414,-44.385856,-78.505885,-23.239225,69.234735,63.621158,-115.809397,-233.006788,-330.133988,-288.434934,-149.083663,-150.642744,-201.409443,-300.479868,-327.951829,-311.147122,-273.691998,-203.288904,-191.782709,-203.683025,-214.198547,-226.010605,-215.36418,-155.725284,-15.358033,10.3356,-2.532241,-15.719567,-12.016153,-15.597622,-31.268037,-59.190127,-59.994723,-64.241123,-94.174272,-226.256996,-289.754086,-232.665119,-21.954554,59.462183,114.158735,103.206621,38.07975,-34.05255,-74.357541,-162.436769,-166.857867,-51.643375,-0.927982,-29.964152,-65.953026,-91.096302,-94.574599,-78.865166,-8.316918,9.348667,-65.667828,-127.208034,-177.803859,-119.639298,-82.898589,-97.757833,-134.395155,-111.978314,-45.593647,41.309432,-4.081026,-207.819576,-226.374996,-159.754421,-95.8457,-119.135014,-180.971123,-182.063784,-114.569162,-30.825465,4.534009,44.651561,38.705776,20.781606,34.539279,87.470784,105.06456,130.685913,212.914364,265.258203,364.120801,412.782495,430.640247,372.366396,216.573021,179.054922,216.200756,299.852767,304.436727,264.55641,249.985233,235.059425,219.674528,188.95203,155.804156,115.513673,-10.595134,-73.458416,-127.958881,-113.488952,-93.252538,-137.600891,-120.628473,24.693209,89.442543,79.472391,14.225536,-114.631638,-140.676143,-121.233892,-69.68503,-56.633823,-50.63663,-39.327236,-7.517523,-1.42007,-6.554651,0.18561,37.060958,157.662505,195.897277,198.450381,193.726499,166.086523,114.64758:-101.303484,-89.049215,-18.759701,177.362223,225.154396,120.067167,30.378607,-23.999233,87.038524,169.110145,286.153325,296.536191,250.362037,217.370677,145.49488,92.457821,-11.779022,48.414842,121.381203,177.514298,154.364223,99.20422,77.337109,31.066101,28.738949,54.632622,142.947601,196.348676,224.345405,162.591384,-21.185257,-69.267828,-40.629687,35.932664,72.78166,150.516228,185.585886,184.213533,129.92568,20.675587,107.841338,203.36631,356.167769,387.900269,320.398546,221.610954,49.059703,32.831219,80.138022,153.947216,200.560174,285.126839,304.282539,278.718953,239.953078,98.371243,-22.460591,-17.510408,39.861889,51.983712,83.210964,114.797773,117.597995,63.500676,-37.519837,31.88218,112.639157,211.888916,173.184614,-31.106714,-106.767222,-89.863203,17.854114,57.845986,105.175014,120.007284,90.955375,41.606413,-27.939177,-42.815648,-101.807512,-156.499766,-159.266839,-90.197597,-30.823174,52.702913,71.191943,54.631172,-8.725742,-5.241061,76.582404,121.858984,154.395679,126.121719,-29.349336,-144.893385,-308.943515,-212.715387,-112.846812,55.92061,112.491618,95.486836,33.749024,-52.412965,-58.154423,-38.504262,59.726588,133.916592,189.171186,126.96063,-26.683124,-47.872167,-22.750056,-16.40647,-8.507405,71.374351,126.361134,172.42408,156.03459,80.823576,25.258132,40.411699,129.953454,169.18534,163.360772,107.699666,-42.864897,-107.582412,-155.8744,-108.648152,-103.472743,-151.100444,-183.248392,-246.282654,-274.336674,-309.314296,-267.152734,-214.115383,-104.940583,-47.409197,64.809222,82.834309,44.403684,13.07794,-59.099929,-73.17985,-42.297457,30.512355,32.247119,-42.618024,-81.499979,-119.60055,-114.659782,-74.964766,42.541249,76.144833,73.411443,64.721423,68.28704,55.671509,-27.781771,-70.876171,-38.816129,110.135828,168.505328,143.638247,86.915027,-53.793965,-132.071241,-87.186926,43.830662,51.9131,-6.42381,-18.970234,-24.269036,-41.52878,-58.096258,9.38027,45.928376,120.120133,176.569273,173.281616,43.267244,-303.325183,-320.061242,-186.164371,62.824286,114.60487,137.133858,136.470999,109.477247,60.359391,-83.065168,-112.365051,-69.733241,16.728873,26.269321,-16.705481,-48.275415,-108.368495,-97.253824,-53.589025,35.516848,72.397382,124.469771,122.842219,72.010626,38.227369,-8.466677,16.452747,63.52488,199.5344,244.960456,196.438726,125.576445,41.777383,94.540713,139.315179,199.665368,189.109666,102.787906,71.1624,29.203207,-36.06138,-228.915466,-225.41648,-137.487105,-15.693617,-46.733639,-209.068932,-259.140152,-260.111824,-260.853928,-254.422261,-185.175079,-138.338447,-58.345797,-27.257045,-29.057636,-93.285822,-271.676842,-306.964715,-280.131878,-232.566017,-232.127381,-303.388499,-355.017013,-412.401131,-362.085672,-301.798852,-174.741624,-121.214749,-88.040579,-126.158869,-230.575022,-248.587659,-185.84698,-98.135685,-77.745378,-38.557212,-21.002669,-88.01597,-164.357122,-299.804147,-364.799631,-331.243412,-138.491838,-50.782817,-32.940269,-101.383885,-250.690402,-283.25283,-258.877343,-137.438953,-78.738102,-83.238881,-137.754702,-208.54791,-193.546452,-138.625667,-175.321691,-221.003045,-257.140368,-220.46545,-141.90808,-144.990071,-185.642772,-192.535547,-192.53698,-205.410722,-213.315518,-206.832911,-182.758705,-79.834618,-16.667851,14.057978,-101.391699,-150.085421,-137.071736,-87.2581,-21.713881,-32.152976,-73.818244,-87.713759,-124.6144,-120.42991,-84.099187,50.286296,125.216487,164.470895,130.470328,78.73785,46.123725,20.511254,-31.02103,-37.304718,1.132181,6.914004,-68.564237,-124.575623,-184.035436,-130.035689,-86.327565,-31.565376,-29.576269,-112.173764,-185.27028,-280.236112,-227.644732,-158.399324,-50.35194,-38.013152,-53.223209,-67.784941,-95.467736,-115.396374,-199.371646,-210.288556,-154.108265,-20.919887,9.6429,-18.675587,-38.604603,-38.02403,7.723195,49.743367,141.010139,180.190612,218.311662,209.440678,157.041741,126.925016,98.711211,198.506558,300.968997,491.796159,507.867387,313.799221,184.866317,61.930749,58.373524,83.111127,159.310351,191.610746,244.563706,250.042197,180.81651,136.423867,141.72984,171.775091,119.552522,-22.65081,-48.625134,-65.250617,-102.703186,-223.638083,-251.937017,-192.582089,-50.241237,-14.951531,-19.47754,-67.945587,-207.167056,-251.668936,-263.256368,-175.657222,-108.060661,-16.151213,-30.305403,-142.44031,-178.841211,-160.35793,-82.452349,-33.882561,57.928879,92.654755,90.762754,57.235636,-0.535294,-36.813026:15.179665,-11.686102,-3.453687,15.306508,41.295199,119.329491,154.102279,199.963161,258.516789,296.751899,328.600211,317.980604,275.17107,235.853945,107.911165,48.051682,-3.007032,34.454943,56.172653,29.645807,-2.022706,-1.297626,56.571147,206.524174,177.218185,110.48041,56.804948,81.655221,149.751998,162.392925,111.685781,55.092619,-60.055733,-81.932377,-82.143582,-139.066356,-155.92279,-110.015727,-89.26876,-113.566194,-107.728722,-47.73104,86.111311,90.149835,-30.820812,-100.121405,-150.800257,-138.787259,-130.688029,-137.522549,-113.003043,-12.269557,16.399565,-40.368803,-81.922477,-96.801586,-54.010256,-40.455242,-127.985015,-204.000193,-182.351406,-74.969533,80.696562,69.837631,-37.295007,-105.005237,-101.341598,-76.463289,-101.115082,-183.081349,-176.222705,-117.866747,-155.832207,-145.345372,15.62499,98.46883,154.292234,144.255336,121.100257,110.724164,83.194559,99.134873,117.295489,100.965982,63.033674,-21.664447,-17.426291,122.827789,155.21451,94.684758,2.420076,17.994478,130.459563,163.814446,58.915028,-65.926452,-296.000237,-303.676684,-231.958477,-98.513994,-65.602058,-20.567411,5.158597,30.946312,71.051221,140.622112,242.526514,205.241496,76.915062,52.551197,78.815797,100.443453,56.2237,-61.108308,-103.689323,-170.339121,-187.759317,-194.307938,-201.874627,-227.464189,-237.16543,-226.311193,-194.224971,-196.02726,-243.691707,-262.566978,-237.186842,-220.114469,-265.01186,-296.378084,-307.947585,-405.387235,-432.716848,-378.900169,-353.206239,-349.975991,-314.944501,-252.934353,-129.158098,-132.51635,-182.088995,-139.419653,16.786115,40.197897,-14.455848,-3.339143,30.49562,80.084402,92.951241,90.078611,72.897331,52.510423,65.273229,87.270695,183.173893,229.176751,221.603793,187.313316,209.609619,265.890273,302.465379,290.515479,326.39766,383.70472,368.444522,276.40237,223.203898,149.720336,149.355088,159.911761,109.934664,49.149146,-1.687049,49.136768,197.860369,236.346576,238.139768,212.339168,202.097914,200.700572,208.018445,157.083165,81.209527,-72.893791,-131.74134,-122.441463,-56.215058,-13.924292,76.976106,93.03503,16.976034,-32.069394,-101.61726,-118.379008,-84.334713,-16.125039,2.974893,46.444319,44.720673,-23.850549,-34.934379,5.583086,74.940084,82.324756,107.250283,120.041513,71.353995,22.312082,-22.719494,33.01392,78.523628,154.585559,158.558099,67.298677,5.731742,-43.291803,-8.02911,16.022418,14.473324,-5.940905,26.095567,72.590234,100.797828,65.357398,-58.416737,-116.822693,-106.649011,-80.214505,-50.427975,61.394854,116.701278,176.069451,143.586876,110.009947,51.793402,41.822676,80.438025,107.973613,77.557415,15.09006,-100.961423,-98.345496,-60.691288,-33.707429,-63.216452,-112.896886,-91.341059,-0.816552,-22.506856,-61.594884,-65.006869,-15.062194,102.529677,115.928849,52.465924,34.99058,96.230208,156.244437,160.71496,127.560531,90.983894,6.472118,-21.378814,-46.448417,-57.413189,-30.42695,122.462646,214.423276,287.52484,239.426482,94.309083,47.146665,-13.267187,35.442881,64.803946,-53.717537,-158.741777,-216.193904,-167.755709,-98.514107,-167.357391,-227.639756,-326.927538,-355.18128,-362.015367,-335.597134,-213.985539,-152.209632,-129.814358,-167.461457,-177.377147,-192.75788,-183.635202,-72.956412,8.989431,79.761481,-7.913454,-44.123264,-45.802992,-53.814744,-113.996157,-145.162007,-198.559144,-220.126938,-217.204043,-128.561037,-79.173509,-2.919402,31.943413,95.993239,118.734573,115.399519,58.249898,30.826976,8.477539,21.610353,75.268568,83.085021,31.541564,6.292962,32.150246,117.282158,145.458153,126.151019,81.279554,-23.631023,-47.038341,-3.797242,45.139576,49.310915,19.100807,-22.818257,-102.642341,-114.744614,-113.716943,-134.537695,-231.725492,-242.821673,-196.524574,-159.959243,-194.333251,-272.53406,-287.547199,-281.955994,-187.976487,-108.245189,-45.22284,-80.622577,-127.647606,-88.069738,80.68037,152.916473,181.65837,132.551164,133.326146,218.09832,275.656413,318.901874,292.757048,209.021896,117.888189,76.459923,38.954724,42.791469,59.788303,55.374501,27.949304,13.232161,-11.698511,1.365817,2.24885,-40.762826,-56.396223,-46.993724,-37.005749,-18.481719,-16.839608,-10.229007,39.022516,49.887645,-32.937033,-105.309464,-167.842981,-142.500449,-55.067354,22.349453,43.385963,55.895363,67.736121,97.105529,92.729049,39.32011,-4.352857,-0.704186,67.902166,115.179078,206.090815,243.558013,240.142419,182.313962:100.277355,5.233289,-13.182468,68.545653,125.561448,149.106859,149.519696,194.155887,178.041266,170.26006,239.872305,281.131887,290.179635,249.251562,115.444637,47.389795,-68.25157,-74.075956,-53.348858,-74.488973,-98.804711,-83.728841,-32.814849,49.068647,-25.355854,-54.007155,-9.299632,16.66044,29.75281,36.360839,38.565482,2.742472,-124.252977,-154.038409,-148.230749,-209.258608,-235.23192,-209.711014,-196.22085,-178.858317,-84.018235,-14.622765,50.396306,28.307614,-54.056951,-90.130149,-150.556156,-179.008317,-203.28134,-106.376645,-33.520556,55.871332,66.493243,57.844648,39.733392,-71.984721,-190.661225,-189.464351,-182.488103,-213.142727,-162.65328,-61.463124,73.138886,53.933796,-67.314856,-109.420539,-82.895382,-42.7421,-69.313237,-196.042368,-255.143538,-287.170889,-185.584195,-116.463949,-70.181767,-88.530752,-83.806106,-74.888424,-131.765766,-168.664953,-178.018978,-103.409532,-66.309339,-68.759484,-95.060762,-84.287352,-26.473708,78.199718,-26.010335,-121.390979,-222.277971,-212.562283,-95.160295,-29.801171,-78.526309,-205.442063,-432.705863,-369.536299,-300.732171,-260.876454,-241.507921,-139.924113,-85.982645,17.569832,72.621178,58.594406,10.684622,17.133537,66.053036,56.882825,1.45472,7.173936,23.299109,-58.141734,-92.409679,-42.033858,11.744824,54.737435,59.010819,93.596087,95.848571,61.711797,-45.80955,-93.069334,-158.984232,-192.362955,-235.727657,-232.526264,-244.741761,-296.940766,-317.575297,-359.788425,-373.294508,-363.393945,-352.870347,-362.24786,-357.00775,-317.676782,-267.723566,-286.282681,-275.417634,-200.040189,-14.559845,19.229873,-57.554618,-120.683638,-116.735052,-68.757215,-9.447913,110.674522,107.932726,-25.396273,-104.164997,-71.9989,75.993512,158.957838,208.978518,147.842631,48.255024,81.289307,199.123523,202.985595,186.288596,204.040417,225.377915,209.507474,163.745238,50.720401,46.388118,98.845093,135.184624,78.071397,-26.924718,-15.826656,68.835351,96.568336,78.886249,-13.765587,-46.388077,-2.485174,54.207976,83.275791,31.984397,-101.542347,-147.415476,-128.556298,-88.258351,-77.001392,-9.248721,24.797027,-9.193816,-66.88785,-187.156448,-208.989987,-179.524789,-127.403157,-126.786735,-180.586675,-223.379468,-299.438208,-329.121159,-316.254367,-247.709027,-200.104899,-101.77957,-81.374969,-127.588886,-169.459198,-230.776097,-184.101091,-140.632351,-115.374656,-130.143686,-149.696873,-129.942751,-82.746057,-124.104812,-140.569016,-114.412266,-94.343221,-39.296509,-2.215535,-22.857135,-106.775853,-259.032784,-253.662813,-240.450648,-216.916362,-161.171758,-4.894587,24.268488,-31.663761,-42.543652,-3.219753,52.82217,51.751232,19.218149,-25.801247,-143.240599,-176.775789,-224.143947,-282.094367,-281.880921,-230.238189,-209.717698,-231.805745,-252.845062,-226.421558,-201.665043,-203.123489,-149.274338,-95.177729,2.038507,30.888144,60.367036,66.017275,58.879149,45.362626,58.181894,181.319644,249.664699,248.79228,200.353364,102.443133,2.888518,-3.237272,117.948104,197.39679,250.768883,194.984041,28.756102,-11.778977,6.51264,34.043695,3.898468,-140.487315,-213.960625,-269.73304,-255.499497,-260.546296,-353.797075,-393.661387,-448.794825,-451.413346,-349.988724,-281.535811,-200.820407,-178.197915,-145.169484,-116.576172,-98.485956,-66.659534,-50.277127,-5.739774,20.497853,62.483217,49.091196,26.11887,-13.603544,-8.334371,56.224285,63.329882,-38.451847,-114.132861,-233.604663,-209.95864,-131.502747,71.799204,135.916548,124.747024,102.463766,102.826809,54.875612,1.116117,-69.846162,-50.886191,47.041868,72.899821,28.554183,-20.862099,-88.305142,-14.138561,62.882524,183.962798,205.639819,143.995031,84.884512,-6.303477,-98.413176,-117.160085,-62.423349,-17.451597,94.53704,156.879292,182.766311,112.472902,-94.553841,-154.37923,-133.434605,-127.53943,-151.013964,-193.637547,-197.020651,-165.658416,-116.337329,-101.254717,-126.284166,-135.374034,-40.531438,43.698915,185.327221,221.77811,219.13938,173.371479,178.522411,320.148108,407.124427,414.670718,348.187495,264.466533,290.173717,296.009987,227.37329,179.581271,183.077856,213.005406,217.114954,194.250504,115.913352,12.89227,-20.62481,-19.627082,-12.078222,-50.810776,-67.082724,-67.479762,-68.491736,-25.461076,102.229605,115.521319,26.022434,-33.881204,-82.929994,-67.421278,-23.900861,-18.361727,-34.44641,-41.209889,-7.511075,83.37058,104.2316,76.346746,73.440756,105.558201,170.980851,195.621274,282.688311,335.258014,374.40305,356.420423:-57.236103,-22.389263,-15.382161,-22.893254,-3.703247,93.410959,130.02981,129.401842,87.822257,89.693393,173.00963,221.993722,227.446966,185.802641,93.80657,54.952237,-6.56873,-10.015445,6.609562,31.012982,40.110014,72.258933,89.800541,112.972979,115.563114,124.625754,171.293766,194.6845,211.767506,185.169251,71.858164,26.245159,-45.432461,-52.191221,-15.716429,35.351414,37.006352,10.343836,-22.686253,-99.695567,-40.056714,56.726584,236.832957,249.248985,121.460339,48.524751,-7.47451,-3.835355,-20.878087,-40.308834,-6.530117,89.557635,115.272114,98.244831,54.953472,-60.390515,-135.432363,-155.913057,-164.894529,-141.63468,-53.853044,-17.775611,-31.613864,-65.391195,-71.659925,-23.651538,-21.711128,-56.144214,-80.023184,-115.65854,-110.74937,-74.433226,-44.442128,-17.062771,64.19331,109.852651,164.136231,144.607564,93.500355,103.003325,48.626776,-117.84271,-126.680812,23.435802,95.073172,88.523664,51.109447,14.736475,-25.335123,-18.743835,43.488791,42.420863,-49.743085,-111.326479,-211.935608,-244.854928,-280.002312,-270.392423,-249.728418,-161.796214,-109.689454,-97.737463,-131.090354,-120.982693,14.384508,62.23047,12.86772,-33.075531,-4.531281,48.177701,116.289296,102.035811,-21.08309,-109.351449,-109.039432,-65.337794,-49.118728,-45.938427,-43.807542,-52.926552,-60.78869,-25.112593,33.831705,5.563009,-89.430176,-108.594645,-112.987965,-123.713595,-152.221644,-153.725258,-160.206383,-235.110136,-295.255909,-358.135163,-332.393609,-290.516943,-332.52812,-306.00625,-160.258513,-91.892571,-1.039075,18.336233,2.684847,-8.859285,-29.317035,-67.962132,-65.81084,-8.746616,17.659694,23.103079,12.507711,-37.644408,-55.270133,-5.174744,136.836402,180.377611,145.114387,89.342988,82.137145,132.683818,141.381183,34.96286,29.932961,132.81026,191.475465,219.444858,185.332368,97.047885,39.095075,38.148865,75.484796,77.842572,51.188244,58.251366,105.97814,116.781997,119.347412,146.048438,156.1756,166.384346,169.254279,124.261341,55.81478,-115.87548,-143.766267,-83.429028,8.332231,-2.14806,-13.184731,28.768448,89.655044,45.496835,-95.683696,-71.596205,-18.896969,47.343433,62.060881,34.988676,-21.927625,-155.924424,-143.037269,-73.024054,12.565646,13.353469,82.324249,141.919418,177.759943,157.487019,84.022148,55.217378,77.182508,108.757515,105.055648,90.090485,82.449142,54.467404,22.356374,25.001362,67.165647,82.486435,70.463512,59.622573,77.649723,84.097427,27.494591,6.833121,28.552665,42.587143,27.472746,-17.094761,-32.979773,-18.214323,-17.403704,-59.923461,-154.025118,-144.31089,-35.845699,11.234404,21.770469,-24.255194,-164.079682,-230.987933,-219.3875,-169.585644,-156.190916,-149.459641,-142.000483,-106.225625,-107.388571,-121.732864,-135.610175,-117.01921,-14.697581,20.199883,-25.259947,-58.105348,-33.019646,9.648983,-14.324828,-62.48291,-46.745372,-46.402206,-92.453047,-171.195386,-149.677976,-121.49585,-53.074725,-7.236365,49.657776,15.255174,-135.720466,-182.101719,-144.824842,-7.180005,31.209956,-32.737614,-79.630175,-66.598935,-21.100395,23.049501,-57.229935,-123.844411,-247.586129,-271.616559,-230.930367,-200.122669,-142.808683,-105.589516,-81.950248,-113.563651,-114.277045,-127.864126,-143.001378,-124.66932,-76.689642,48.242611,58.528733,28.812692,-10.653745,-15.493287,-8.054123,-7.381568,-10.148403,-10.701869,-31.450017,-35.85729,-10.511158,72.058318,105.620774,132.824531,138.745007,104.424667,-6.130445,-28.34192,28.852097,52.719759,28.755912,1.620848,-12.654403,10.584557,27.259644,-78.219202,-129.087186,-177.832566,-200.24615,-227.749382,-222.577164,-188.649358,-106.378689,-84.420688,-160.848948,-213.601575,-208.252502,-167.969185,-105.715191,-108.161714,-203.424037,-241.182203,-197.925318,-104.866528,-88.175685,-127.698832,-163.697503,-167.174082,-114.405324,-98.929995,-48.171696,-5.423181,31.200036,16.978168,92.697876,198.686656,308.234447,272.959164,311.836179,454.350587,466.567881,343.517584,261.79292,133.101637,68.012358,76.554351,139.30959,163.729416,188.517601,180.048213,130.197621,106.687497,70.461772,23.450377,-18.539338,-69.264921,-47.346294,1.528921,-2.212725,-34.75167,-60.023394,-40.496281,24.041069,21.201803,-20.706855,-33.231411,-58.483851,-71.089528,-48.134596,30.7853,38.340172,-3.027966,0.981116,67.092212,94.054755,55.593613,-47.210778,-25.615564,154.544869,229.742101,236.685282,182.914072,107.930493,114.001979:forward
-55.422329,-172.493724,-245.292625,-331.919106,-326.998986,-299.337511,-298.25887,-271.587274,-242.444508,-261.439946,-331.390421,-328.77051,-225.784762,-185.431429,-204.648069,-214.807735,-146.351962,-76.226274,-84.599746,-171.796084,-209.40597,-179.933067,-113.471181,34.461629,52.96175,9.550866,-61.936411,-72.858029,-124.206584,-182.15131,-237.718042,-205.514431,-141.120799,-145.191602,-137.518834,-122.313433,-132.711266,-152.372273,-146.772729,-144.847278,-192.491775,-181.284618,-57.933663,2.353686,40.162709,19.124641,-4.109878,25.337081,88.498151,81.837445,74.426293,69.528735,76.819436,139.299731,170.779117,146.071291,82.94841,82.566796,83.461433,63.408995,26.775351,20.786812,40.713395,64.959622,98.552498,79.608111,44.874759,-43.982507,-68.056106,-94.453212,-126.035544,-212.898124,-258.341772,-226.932859,-88.175531,-58.250912,-129.834959,-146.265062,-20.869859,55.55612,84.379905,41.618588,15.055929,-76.543067,-104.262539,-82.473748,-72.640752,-82.250051,-96.479238,-121.088023,-207.234618,-233.236074,-171.964963,-114.931129,-70.741051,-74.919862,-106.087532,-173.65565,-193.728923,-168.775478,-131.247021,-47.633925,-15.640424,-4.202931,-21.320305,-11.764145,-7.453356,-38.590135,-107.169977,-92.271465,43.452094,116.714812,147.658709,21.230914,-48.846326,-100.392335,-101.352603,-151.926967,-184.663782,-187.36108,-136.403082,-107.000039,-73.786468,-67.957055,3.13379,62.005582,112.186289,82.314326,-16.0067,-63.00845,-76.482586,-61.900248,-13.498242,80.130658,94.041249,148.862512,263.767449,280.151956,177.487351,89.831263,-49.390104,-58.401911,58.387285,116.159583,67.246754,-98.594246,-179.287991,-268.989709,-244.270128,-160.63463,-167.086388,-261.225688,-310.018851,-270.542925,-161.505991,-138.53142,-95.359067,-58.732773,-21.726545,-22.927726,-3.247115,-2.070033,-36.844692,-61.080405,-5.055358,134.27745,152.589568,77.264461,-4.272793,-2.942124,3.929294,-32.379897,-85.943128,-55.494745,29.805535,31.807449,-10.579819,-33.906877,-74.042773,-209.595573,-237.287302,-172.499184,-127.746828,-85.56687,-115.384913,-156.35841,-275.572781,-314.967952,-261.834608,-200.577702,-143.759888,-151.476477,-160.023396,-189.034571,-232.42549,-248.412511,-180.950378,29.045989,118.743764,173.86469,60.429131,-4.37974,-110.62969,-157.092694,-161.780841,-111.284845,33.083884,114.988028,221.260407,156.71847,98.82098,51.975376,80.464958,155.742029,158.389479,106.198875,15.432371,-26.896563,-79.779595,-91.919646,-69.184702,-40.594246,39.548335,76.322607,39.496733,-54.95941,-69.565167,-104.375393,-126.591308,-112.214216,-72.194078,63.028641,114.177089,55.545292,-116.485387,-155.786402,-109.622758,-84.816222,-160.408055,-232.524917,-253.786789,-89.268468,-24.675752,42.499991,99.656539,238.660455,270.775966,247.861498,160.95671,101.119434,-24.575735,-49.020179,52.387732,145.220446,281.667834,300.009892,256.935841,194.224042,166.124916,95.884171,65.195954,28.280868,16.044464,-16.418695,-69.597278,-79.931422,-20.206264,35.633291,92.035019,70.699781,36.223265,68.465383,140.285065,48.177649,-48.98508,-192.708233,-187.22255,-59.274889,5.506069,38.857746,-73.01556,-134.598142,-145.517,-109.408626,-72.04109,-74.979913,-54.091492,-29.391011,-1.433577,-10.673776,-42.906567,-151.017545,-168.080486,-55.363969,24.810835,90.072002,62.009898,57.128269,58.040933,51.729692,16.792402,-11.437948,-7.651314,55.990395,189.986721,154.78068,92.993377,4.856222,9.238046,52.613213,52.773747,15.544288,-23.966608,-40.600991,-102.744958,-129.217782,-82.237142,-38.905732,9.781669,47.165888,166.383528,227.683617,226.138774,229.02422,249.47922,270.816566,251.754396,176.454976,125.569668,114.97682,40.305652,-25.304798,-69.864934,-19.638679,124.113244,152.379018,79.707718,11.58485,6.031859,20.496027,50.070705,75.724934,36.739019,-35.969304,-7.733555,-1.62094,-65.410312,-110.52301,-139.239671,-122.526796,-85.416229,-83.818747,-106.699721,-76.356342,-61.494906,-114.230748,-137.78673,-68.67425,1.300605,67.089968,-38.46934,-113.499041,-180.511026,-159.577011,-98.075638,-83.412217,-56.724058,-35.119074,-0.591719,35.637405,50.773532,29.112741,4.232137,-14.549849,6.723,87.287419,86.005472,68.143572,60.97054,49.738014,29.810337,56.781556,154.020616,173.502041,113.858289,71.702096,82.821877,92.208569,72.301532,33.714936,66.093208,176.752017,80.169944,-16.693311,-107.591482,-97.732299,-57.664097,-37.016807,47.120219,93.992322:-233.268932,-272.861113,-316.378727,-415.075915,-446.431727,-433.566018,-380.271286,-289.814084,-360.849256,-407.47522,-426.353348,-413.294407,-386.401634,-374.566518,-317.157427,-256.680882,-145.817703,-186.884798,-235.128273,-246.442593,-205.502263,-62.833278,15.905925,57.016043,-3.536179,-9.604456,-56.593254,-137.918935,-336.345759,-382.767287,-298.763685,-219.748088,-133.486136,-150.483196,-180.643025,-233.51897,-237.597558,-173.64483,-111.415989,-20.542821,-38.510301,-47.109045,-18.766565,-2.803411,14.386876,17.86045,20.113283,22.139679,19.992848,-6.564,-25.992678,-44.075004,-22.699444,95.138814,156.530028,180.613912,123.215436,111.93744,107.727002,92.503425,17.652531,-21.136954,18.114233,85.00802,148.238564,52.697375,-18.11706,-73.373493,-58.013841,-65.245729,-84.915634,-73.894864,-72.467139,-97.441041,-124.900427,-106.559904,-44.536316,-22.298061,19.23257,48.87649,63.94529,-1.478206,-22.591116,2.4318,15.171369,-40.524507,-75.775071,-22.222959,83.226819,72.411051,-38.905726,-71.158915,-47.370817,-30.281541,-22.451132,-24.831825,-51.772942,-146.136294,-191.401233,-168.65964,-110.726031,-4.242295,38.20078,111.688833,114.983719,72.945799,-28.591955,-24.874072,120.069953,191.558709,211.130706,190.567013,157.669692,61.901255,-7.991508,-72.580065,-70.39589,-80.14977,-86.714311,-80.530752,-49.866702,-24.640353,11.090116,19.8169,51.57855,70.587218,107.44312,137.149511,174.50925,92.294724,26.457739,-20.00929,38.408322,198.088837,220.837918,169.663995,186.13618,218.272287,215.062962,181.692352,121.409777,126.967566,259.361076,311.033669,167.922703,-102.094408,-177.471303,-188.885847,-158.830649,-115.446011,-115.914246,-187.874386,-273.319337,-272.154337,-214.639075,-170.583766,-46.151648,17.757525,103.596876,104.787533,33.309826,-3.684906,-13.204019,-41.242154,-19.439713,102.373247,135.264301,103.740608,128.5726,143.851906,58.21372,-3.785942,2.627896,69.765632,176.431221,164.326497,46.470934,-55.245533,-118.93481,-241.836843,-228.863755,-86.916593,-38.409647,-42.68648,-106.331289,-165.336995,-305.56805,-322.803227,-177.194456,-80.420181,-31.774607,-71.047127,-174.976,-255.819367,-265.747321,-200.519629,-151.015296,-62.245861,-4.35717,115.803176,91.963624,31.890554,-78.494002,-102.322944,-98.474977,-98.044042,-69.372506,-8.294707,129.504233,142.838624,118.386906,76.983633,57.334415,15.523153,11.833273,30.191714,-0.122089,-51.572592,-181.086904,-196.163664,-97.572436,-54.126323,-61.553528,-76.351832,-70.445768,-64.011917,-82.109846,-149.647755,-162.657761,-56.389843,35.853243,101.764558,-23.02448,-78.23011,-107.901212,-99.254052,-58.647257,-44.968396,-88.864189,-141.813109,-196.232369,-96.391261,-46.439007,0.498783,35.924952,160.157496,229.874288,301.467457,220.8125,156.109262,67.870444,57.750396,100.052741,151.192105,279.651405,312.462503,251.284395,97.465392,22.502217,-16.695444,21.896064,64.203154,53.080406,26.10595,-31.066903,-69.183924,-126.167165,-124.765893,-36.298404,2.657156,2.615763,18.719521,101.044832,25.154123,-84.022654,-209.164672,-167.97545,-41.62956,-11.278382,28.764737,-39.447534,-122.359446,-202.93405,-169.152067,-61.891662,-36.990367,-17.081899,9.135368,36.700396,-43.058733,-94.362996,-122.136735,-102.20837,-36.156259,18.821834,93.959838,-14.827064,-75.38502,-78.698826,-62.813089,-80.405282,-82.855643,12.031131,94.353944,192.857825,70.189992,-24.876057,-63.234556,-14.323125,49.259521,40.619239,-31.611144,-84.839608,-65.404789,20.122561,55.439078,89.219939,100.680868,176.644918,231.937702,286.948904,266.458765,238.038177,198.033538,221.031335,295.236285,300.003148,231.745142,128.283384,78.173348,-17.132554,-40.940125,16.046963,75.676531,157.917935,166.089248,111.152081,-1.166805,-41.345239,-41.942021,-9.61856,62.422184,70.215918,15.257902,-11.144374,4.688158,-16.763547,-68.18047,-118.638339,-96.864106,-49.93182,-41.890326,-79.87045,-210.150226,-269.155381,-263.002925,-192.110425,5.508949,89.72812,120.299884,-56.631215,-156.586955,-232.875339,-207.946714,-103.528461,-47.346877,24.032661,20.455341,-44.888514,-42.205286,-4.431313,8.66003,-23.337995,21.948337,110.07972,158.216021,18.24256,-8.956237,33.690192,65.830431,145.842479,186.288134,217.305149,196.884171,125.74273,112.838771,109.676094,67.118044,38.729601,-11.599575,-12.804963,2.136053,-86.458143,-146.489873,-190.22578,-153.205207,-3.009525,46.402062,68.041767,95.410662:-178.863175,-249.427591,-303.41061,-404.084005,-418.684856,-355.620601,-294.880284,-211.019003,-258.509889,-301.942168,-364.105659,-363.330406,-286.353474,-243.70576,-184.02321,-145.418492,-68.50482,-87.431675,-126.205932,-151.004669,-119.336684,-22.702791,21.394806,40.113869,-51.233416,-108.236641,-180.55837,-195.301173,-239.414974,-276.323489,-262.101963,-190.103615,-87.03332,-138.999859,-176.780545,-183.108154,-157.618601,-91.682804,-48.330614,6.351333,-71.901903,-130.82454,-177.543162,-141.168072,9.278961,70.915202,106.066192,94.11172,54.996753,-13.33176,-59.979992,-111.917162,-88.322879,54.564627,126.341976,151.011425,97.099753,94.597753,101.470845,83.725922,18.320832,-4.754094,-4.091212,7.946929,26.958244,11.483165,-14.33257,-61.348308,-63.626063,-44.844265,-51.123859,-109.38524,-155.115447,-170.075383,-202.900045,-199.152436,-123.981127,-77.751791,-42.627897,-57.545505,-81.465662,-47.179985,-47.016705,-67.302713,-49.106621,34.370824,60.733851,49.160759,29.210787,21.994746,-43.808464,-72.926003,-31.779708,5.841149,25.268978,18.781186,11.824957,-39.431949,-83.471814,-76.938416,-4.058432,148.597945,171.46124,131.612211,109.348499,70.115437,-87.829987,-107.244319,69.849404,189.624617,323.498956,314.490508,203.45524,118.770875,69.944883,-39.839317,-53.450465,5.607718,49.106958,92.74338,74.927606,79.492442,52.956375,4.566888,-10.950662,52.493058,175.779641,187.054379,171.603701,135.839542,99.497514,95.582556,141.132592,217.106743,231.752238,249.283613,229.342516,211.269888,176.216959,164.558466,154.319212,138.790465,98.220759,80.311298,11.999386,-79.817544,-124.354402,-178.36554,-165.033072,-127.763628,-146.656466,-252.974553,-333.391515,-336.575296,-285.153346,-233.366694,-140.970496,-119.656366,-46.506086,19.451175,96.147839,5.411883,-58.891133,-54.386644,18.880477,152.038896,181.410937,201.260932,175.152259,123.193279,-13.612327,-23.043614,89.205722,135.00925,176.386448,185.129486,126.694314,10.776716,-47.040726,-117.542516,-104.596691,-29.587044,-10.092466,-34.592577,-126.373509,-178.763781,-203.915849,-153.201119,-3.246469,48.999044,90.072222,75.395875,-36.526762,-151.727472,-185.522856,-182.543982,-135.54992,-32.43681,-8.402914,24.674406,65.657057,47.048613,-94.675522,-162.203115,-168.396565,-106.151418,93.393234,171.690662,178.879826,80.195647,39.650973,13.2021,19.054757,59.95202,90.526686,71.631316,-54.95737,-104.779092,-160.10174,-165.335195,-123.630943,-92.793059,-41.182171,-36.493354,-71.601095,-107.223149,-146.333095,-219.815958,-192.84195,-38.076335,31.530954,79.368527,-8.172766,-77.534793,-154.4796,-121.244002,18.104489,53.310731,37.257638,11.430418,-73.5336,-114.066492,-80.436939,53.794613,124.540919,252.121909,306.669604,346.278117,280.270005,218.666461,67.809075,27.45749,124.954715,223.921669,319.385693,286.936895,164.422017,44.530224,-25.702264,-94.519196,-58.929174,56.358647,75.736125,7.43459,-88.928337,-117.640213,-131.87486,-114.009698,-44.209545,-14.695769,9.313043,7.400557,-5.471753,-66.001601,-139.987386,-285.425615,-276.310427,-106.139394,-32.160084,-20.633634,-142.930406,-196.944697,-161.712555,-87.34562,-18.588786,-38.831112,-14.467671,34.384895,18.63262,-126.346681,-153.648902,-73.57976,-17.045624,56.15619,73.927803,38.217117,-69.271548,-104.299823,-87.592774,-54.910982,-31.826962,-29.617779,20.739114,40.399021,46.295155,35.356046,17.294355,13.771367,43.309699,98.266531,95.88245,72.341401,62.773797,44.07857,15.995042,18.957281,28.701496,61.965569,207.688758,252.492293,233.319891,264.294393,285.465384,237.072511,218.232876,263.47497,263.054281,120.553742,12.074595,13.60858,-7.096926,-45.542647,-56.238888,-15.059541,65.17665,76.975397,13.970081,-83.540656,-95.729338,-61.320522,-38.379866,12.40496,41.303874,46.031165,-33.52575,-63.796282,-82.991738,-84.049284,-63.635865,-49.598341,-59.090149,-80.379657,-127.908748,-227.7831,-286.798785,-271.682283,-181.073098,45.077421,124.186021,156.881795,55.740492,-9.222885,-84.64009,-77.135868,1.509533,43.788919,102.63659,111.924317,101.159639,92.651721,79.683088,36.562786,25.070204,53.963188,97.473571,162.078671,85.362737,19.173705,-50.887452,-39.316414,23.602642,57.065358,118.586464,125.571017,76.404457,27.039763,-3.724351,-59.613913,-67.756483,-83.197332,-89.677836,-104.392406,-177.514896,-206.408194,-214.152431,-214.734423,-181.018936,-117.544539,88.796838,179.938244:-99.897345,-192.778892,-270.93161,-420.196922,-427.163277,-314.564462,-250.620698,-171.290079,-195.399327,-243.79011,-363.365048,-385.295025,-280.322493,-220.207644,-198.38553,-176.976528,-60.203906,-60.351693,-123.73116,-206.125014,-178.094172,-40.750496,16.994338,32.989091,6.95314,16.688104,-31.416458,-116.680312,-249.083885,-255.245982,-232.247601,-227.809951,-187.921938,-108.235178,-91.75177,-75.692168,-61.659009,-89.162988,-111.376499,-82.591639,-72.492897,-88.772902,-89.755045,-61.55076,24.381947,64.416832,114.935092,112.025367,46.608605,-2.285283,7.070447,47.095587,67.366687,150.960199,199.256486,194.493237,101.492225,85.417181,62.098522,23.252167,-12.525379,12.53475,69.05835,84.959032,96.496594,36.251036,-31.724701,-134.797953,-127.186144,-113.536662,-156.437442,-221.763097,-175.496746,-161.616215,-203.885,-237.625922,-257.142177,-232.688878,-145.294089,-103.665667,-57.932659,-40.874315,-42.993898,-98.210548,-130.82044,-142.756144,-135.994632,-135.631834,-111.858111,-103.558061,-142.128216,-153.636836,-117.413616,-109.942932,-139.551139,-135.193971,-93.074203,-153.478305,-206.481643,-239.150857,-200.564633,-69.906785,-19.680565,-1.236312,-50.755627,-66.327193,-61.754646,-53.557456,-11.595115,30.470948,116.770462,151.548786,172.466204,53.322324,-27.508354,-61.570761,-18.676278,27.896418,18.67756,-3.959453,-3.205757,7.362534,-10.864056,-30.829967,59.353871,153.307087,193.16624,120.531094,-2.847373,16.754517,18.736779,-9.72464,21.21801,147.473563,181.94849,207.897954,295.320459,321.993905,210.487452,111.694041,-5.356233,-11.850931,58.345842,118.068593,116.778492,-71.657061,-139.600648,-150.343018,-121.012662,-82.068168,-92.810958,-157.152221,-233.65994,-257.98664,-240.997143,-202.453963,-123.487909,-95.651372,-13.54376,36.198844,43.323573,-43.250233,-76.24769,-71.804534,-27.377701,78.646366,112.882261,150.1749,136.026362,105.006052,29.673806,-3.842351,-13.620922,23.670972,129.020444,154.14509,108.993486,7.822119,-43.215222,-106.220669,-95.668207,-50.235035,-40.818785,-14.956907,-51.544654,-117.265691,-232.222248,-213.419572,-0.797169,96.089526,78.76106,6.871757,-97.646393,-113.693394,-101.458854,-57.054357,-23.035855,94.374427,178.257642,290.296111,182.566641,82.802083,-59.170216,-86.129148,-56.490742,-1.730594,168.122692,252.144205,292.363202,175.91785,127.659377,98.968757,93.688007,69.532531,65.060806,49.039214,-50.096782,-108.431136,-152.026895,-118.947423,-12.904005,16.801731,37.215306,43.062012,20.55846,-76.175103,-138.647545,-210.544658,-194.656588,-63.023948,15.470117,88.094592,47.466995,22.174264,34.848956,70.309503,115.742074,98.514927,-8.42896,-71.706258,-131.519815,-49.792389,15.879574,102.088703,116.067938,159.961325,213.257197,311.905244,237.120323,152.343055,57.125688,60.676349,110.615221,158.830234,295.742325,329.537814,218.610283,32.157412,-1.592706,53.202995,80.993046,33.459562,6.996418,41.278827,42.048566,10.470449,-29.801703,-11.142749,53.889887,56.177401,25.300759,38.414443,93.050355,38.129387,-25.584754,-112.698862,-116.947111,-78.18852,-42.999165,16.458212,-57.296735,-123.802229,-164.831346,-124.86754,-15.554144,12.046519,-14.15968,-57.21213,-121.003899,-55.900109,-27.684557,-88.318817,-105.880099,-20.454521,10.135309,8.518567,38.59283,41.199589,4.810854,-7.138416,-1.888508,12.745161,81.744981,117.20217,117.973142,93.160931,78.611175,32.574337,32.111702,66.475861,66.35327,31.380691,-24.635459,-49.1889,-67.776648,-69.168748,-35.130714,-14.461364,-4.752865,20.525616,127.805421,189.865724,167.195696,64.500914,63.995088,186.614501,227.769665,165.695639,20.475171,-43.341751,-167.119167,-206.243836,-149.291576,-87.579831,-20.678933,-20.869828,-70.936711,-150.981351,-173.515409,-146.897208,-122.783441,-130.485693,-147.553724,-130.342336,-59.173799,-40.598594,-108.078121,-168.618256,-218.958791,-205.866932,-152.948947,-119.360447,-101.733992,-171.132978,-184.295108,-115.01054,-65.941882,2.005378,41.770575,131.113438,112.585808,67.958541,-53.849746,-115.744033,-117.951119,-66.227703,-33.356713,-47.93462,-7.491199,26.05034,-5.986488,-35.651531,-2.175337,62.790968,72.372159,64.45331,-17.15277,-64.687125,-72.462874,-34.02786,74.401166,127.343664,187.324139,160.766697,-18.236884,-73.561382,-22.883982,-1.58514,-46.899364,-79.68628,-26.408568,117.781448,87.552482,9.316029,-115.706478,-116.449935,-7.922106,59.528217,149.493133,146.255426:-49.354033,-219.497311,-288.424642,-385.252004,-374.459581,-267.434876,-213.330149,-140.017847,-138.723929,-162.58124,-201.248066,-196.491479,-143.115582,-110.101029,-38.028808,5.153375,63.321176,-15.982618,-99.142677,-215.630873,-207.293417,-92.108814,-29.275522,4.985887,-62.261066,-102.575159,-170.993004,-181.432153,-175.522394,-179.697345,-147.483168,-102.782996,-41.321325,-74.551144,-121.70122,-180.986672,-148.786791,1.599872,61.997815,39.134373,-87.608179,-124.739442,-122.003931,-75.137209,48.763153,76.121673,74.185569,70.982218,51.078795,-7.607006,-48.276343,-77.154127,-29.356817,155.308168,239.122222,279.185628,167.133396,106.249947,19.210728,-12.82695,-53.827445,-39.479452,94.456677,152.882296,94.788997,-56.030492,-102.412384,-112.289046,-87.716528,-65.472382,-65.662664,-68.774189,-169.789803,-238.507711,-314.959339,-323.936578,-303.551278,-262.324087,-119.444061,-70.745659,-106.241994,-167.249045,-161.597115,-146.29803,-154.760688,-143.322741,-104.465863,-29.364322,-51.66838,-88.309173,-127.897546,-96.671474,-2.903328,6.998034,-12.269098,-12.36414,-32.201596,-93.23343,-122.204683,-103.005432,-54.870584,-1.167948,-14.31825,-47.44646,-15.331954,-7.029055,-64.269432,-67.848668,93.394323,204.197209,326.551264,310.843196,135.941647,-22.252671,-43.265744,-22.404342,-4.488664,44.109445,90.935332,153.900763,40.170785,-23.296087,-33.963811,-11.413694,32.616812,65.92915,133.011703,141.425964,95.966774,0.057449,-55.036533,-78.800881,-12.601749,181.02536,246.849965,248.266795,137.890778,102.086189,52.29388,9.215041,-43.639116,-20.225343,91.108974,129.476044,62.591787,-121.712784,-200.31349,-259.455011,-225.002655,-119.348918,-105.406304,-177.777669,-279.326213,-300.920116,-281.587018,-254.865193,-176.309719,-133.847709,-35.235519,8.116402,-8.017353,-109.237332,-142.539209,-109.993741,-55.872152,47.963634,95.725602,190.146109,156.600482,70.250396,-68.886003,-62.548385,34.175407,95.826427,249.356362,294.262635,218.38653,46.215446,-19.703801,-48.166388,-0.974098,149.681191,201.412247,167.34843,-6.05935,-78.794839,-112.634873,-80.066282,31.289859,82.548531,105.538998,71.266953,-44.426138,-103.549584,-83.103802,-10.87637,6.812735,56.450952,126.272778,268.986709,221.456723,135.658143,-22.220157,-54.195822,-34.411065,0.790178,156.100983,249.639563,281.091815,127.65288,73.001979,104.885191,148.101589,165.936668,152.347069,87.218582,-16.858957,-30.125395,-10.435234,-20.276429,-48.582743,-29.13839,69.404046,98.927077,65.841495,-7.887786,-56.542872,-134.968389,-122.759416,-4.656834,64.181396,135.325839,88.606914,49.564706,-15.544671,-19.312442,61.938174,114.564463,135.915041,84.882599,-55.020412,-41.29313,5.266461,55.636418,66.895328,144.115043,214.887783,307.025616,230.055395,147.768657,-5.144137,-33.700135,57.961104,163.811523,348.808437,344.451235,161.425226,18.465745,-14.441768,-34.240478,-25.216521,17.378965,49.693963,61.344478,-53.759846,-104.019055,-76.026118,-13.589486,70.631775,63.270478,33.668633,50.383672,88.534392,-26.193766,-134.733082,-258.598988,-225.921888,-73.800981,-12.039987,19.031175,-73.290928,-139.481741,-182.360448,-142.129046,-65.126074,-62.19346,-89.519832,-108.134503,-136.080662,-112.162383,-101.034493,-86.786126,-58.624231,10.9319,12.79988,-57.689186,-97.528596,-99.828364,-138.101574,-162.53063,-158.840295,-122.713126,-8.8709,44.576108,77.823209,15.790205,-5.996355,26.853045,44.432314,29.282506,40.593742,102.775654,70.376274,30.543303,-28.481143,-44.451038,-46.196922,-22.312171,70.475477,103.189002,139.986297,208.802974,184.836807,54.226708,67.412817,240.613688,286.964493,205.914582,49.742757,-10.61972,-139.603094,-207.212935,-216.277379,-147.065029,-4.215531,18.03162,-23.421731,-107.582729,-149.402511,-146.280649,-91.152209,29.967321,60.804189,33.928744,-17.563533,-17.867959,-59.450946,-106.873548,-116.426258,-76.288391,-17.682008,-17.144691,-44.457381,-65.186101,-77.27608,-103.7082,-101.871349,-34.981368,30.833963,165.802107,160.045674,104.076852,-2.99824,-30.780216,-15.442648,31.887337,124.399822,129.007082,80.280397,12.508342,-20.955403,-26.71142,-4.80814,36.272032,65.781004,112.467598,15.509565,-76.005185,-200.699019,-188.025344,-54.846213,15.534708,94.241068,82.279486,-28.258614,-99.918741,-102.758847,-88.064997,-73.78954,-33.194464,-12.791625,-1.486217,-35.894696,-60.077054,-112.744442,-126.293199,-106.871718,-87.626818,-38.87485,-15.912265:52.508356,-61.378731,-134.877771,-204.406289,-177.194421,-74.937409,-36.025638,17.673554,-18.912128,-79.298592,-196.14849,-217.008452,-155.203873,-114.167358,-91.036883,-77.972974,-40.290896,-94.34747,-138.883059,-172.213016,-148.218724,-23.758786,65.068519,163.289694,90.029529,66.355547,73.096761,64.857957,23.624248,-17.905807,-119.584258,-142.609504,-169.4556,-168.254951,-113.75823,27.662805,51.374694,-37.895862,-105.338378,-141.195557,-56.232212,-7.52265,73.498073,102.781333,119.896024,110.650558,98.998723,109.85935,121.133043,76.076756,59.032893,71.148548,102.477286,181.865491,182.143532,79.058742,-10.885677,-24.086237,-46.627578,-71.226519,-123.718472,-133.836586,-89.168138,-49.033483,-6.639016,-48.081095,-83.262478,-98.725585,-72.232409,-57.87393,-87.823919,-141.740339,-125.50095,-95.509096,-75.951682,-112.848674,-207.442293,-196.123984,3.053057,120.382076,188.351664,98.199651,65.910058,52.937701,51.75033,2.632709,-34.833143,-83.681803,-155.356285,-220.969608,-344.866784,-342.544453,-193.78769,-134.687884,-157.826407,-183.739169,-161.817129,-144.217052,-176.348817,-208.711861,-159.186559,-46.237413,-51.428058,-120.827964,-95.632299,-50.252499,30.459744,25.353237,-57.545783,-71.211603,1.205493,40.753415,15.603457,-102.232258,-121.967629,-42.328243,5.6434,-13.045026,-87.440521,-217.04827,-170.423909,-120.689841,-93.550144,-105.190202,-72.26464,-37.510809,-1.631694,4.293477,4.001546,-31.932487,-67.406404,-98.465342,-56.473628,96.194478,158.421654,213.373152,203.69205,186.888503,129.780346,80.660746,-42.042856,-71.729652,26.407985,106.626923,109.67978,-50.694013,-97.818441,-82.734999,-77.499924,-152.840565,-190.022007,-213.305914,-259.331221,-269.328986,-240.331748,-227.614839,-205.080004,-186.546538,-122.934219,-75.074678,-11.036131,-28.996741,-30.929043,39.139644,90.995519,129.842943,118.308516,92.823182,50.458006,33.356595,-33.360725,-105.691837,-182.433597,-145.830987,-7.080493,47.551273,43.265774,-60.231246,-117.01063,-218.566582,-224.510206,-110.955069,-35.559165,55.436738,4.304376,-62.550518,-171.723387,-170.111645,-51.505057,10.992957,26.098107,-19.670316,-141.482564,-205.493586,-205.379177,-123.066372,-40.269583,136.602122,209.392913,285.114744,167.050349,62.187747,-70.174372,-84.953034,-68.432984,-31.582323,124.956126,213.293884,250.350939,84.720436,20.306569,55.013286,117.103903,170.253622,146.010553,97.018214,92.096198,72.554355,7.896448,18.247003,157.247623,226.368466,237.491327,178.240971,27.044443,-13.005893,-10.777357,-89.794053,-133.090049,-96.952544,-48.154683,21.580629,58.241593,56.082637,-26.837202,-80.77153,-54.300508,17.41172,29.56994,-65.106726,-242.521748,-177.906412,-92.899622,33.047715,67.694088,107.544368,109.927916,70.432326,6.161249,-26.551828,-103.018618,-112.637443,-14.866577,57.964238,167.859385,196.60184,200.827151,214.571586,214.995413,126.64405,66.590849,16.108282,29.419179,48.97489,-8.542989,-14.536593,87.498183,148.35889,154.270608,90.490514,-32.432041,-33.706135,15.066108,-71.1614,-178.592153,-362.352974,-367.54618,-220.985746,-139.260985,-129.396278,-252.19416,-260.205588,-142.937941,-84.467905,-79.663799,-115.585302,-137.82059,-103.000086,-31.029728,-44.273569,-80.590316,-140.347196,-111.376857,28.346082,58.047575,7.272216,-30.540485,-30.30494,-13.474633,8.857412,69.518214,89.678121,125.763518,141.988672,90.235493,5.194628,-21.712056,-71.08297,-62.124598,25.009974,57.190551,63.65928,38.486838,18.472749,-63.827285,-110.516142,-110.840493,-84.476405,-73.820141,-65.65323,-2.776482,75.118486,74.829409,25.511354,49.008542,187.392298,223.431084,162.989206,50.808038,7.81805,-80.28734,-124.019435,-149.270836,-124.297865,-45.913214,-24.156888,-84.060293,-221.436673,-251.970408,-174.048926,-102.667351,-87.324612,-149.865822,-195.773974,-70.931349,-41.670339,-146.113867,-205.694648,-171.709347,-108.925658,-23.100304,-11.629191,-24.513243,-33.445078,-40.62293,-94.079012,-110.934716,-24.571847,66.51398,179.101185,75.673446,22.908415,20.007616,19.399244,-33.126046,-67.468673,-95.606996,-69.378209,9.830023,17.794234,-6.111074,-53.957681,-58.767047,-57.344552,-59.835279,-31.049307,-1.917266,-8.156047,-47.174353,-50.678506,78.108963,175.686457,240.938172,190.437753,10.174227,-79.216556,-63.223883,-26.621612,-36.003259,-38.767968,9.559921,149.87173,109.576966,18.738382,-121.350699,-143.903138,-128.791998,-96.662667,-3.214639,19.829014:139.628564,-62.631727,-160.748935,-234.302311,-197.649537,-63.21205,-6.434559,19.329969,-47.724129,-80.666389,-125.541464,-109.758735,-7.775295,4.632521,-56.956563,-57.782418,-11.814692,-112.827353,-203.162201,-245.380469,-159.896239,66.642223,113.926368,55.583577,1.704455,1.211997,-38.455532,-77.819701,-104.874832,-89.319763,-89.528265,-111.775375,-148.107536,-185.588435,-190.978991,-95.51798,-24.253526,14.555707,2.712115,37.847336,28.700866,-18.469139,-91.272421,-82.685868,33.677205,107.930048,192.789471,199.843285,176.905454,111.021201,64.759677,2.096888,13.679959,138.179571,208.040806,226.514045,91.064105,21.150407,-44.649745,-39.694714,-4.583637,-3.116052,9.272778,44.11536,51.68505,-67.465359,-104.984801,-103.969545,-95.018296,-111.719251,-132.922385,-143.776049,-125.770195,-133.157839,-205.010896,-253.153795,-285.126283,-247.79246,-96.08234,-12.206776,91.592079,90.261199,55.513806,-57.404752,-90.429208,-40.923023,16.637082,54.901408,-76.46465,-150.443025,-210.771418,-191.433123,-116.190736,-94.064084,-85.497387,-82.193154,-80.567254,-124.113023,-175.705019,-242.548098,-193.320794,3.627533,68.040303,63.679072,-7.236857,-27.680366,-53.589736,-66.930808,-22.469986,42.731825,134.483099,132.166778,55.437518,-92.523751,-164.788135,-165.492695,-74.762641,128.681064,164.571609,97.96279,11.35406,-10.229565,-33.490015,-23.77148,65.932479,109.186141,118.798547,107.988762,98.849673,11.683605,-66.256759,-115.551858,-47.440545,140.225931,200.425987,222.267696,170.222472,137.670444,23.02571,-45.965907,-99.323872,-65.415007,85.2235,147.914919,106.591864,-75.18566,-125.46472,-60.771882,-7.305676,-35.977033,-93.654818,-169.768788,-202.527069,-211.668141,-233.54786,-233.583643,-146.074757,-78.577202,21.949059,31.71689,-38.271858,-102.065012,-100.512133,-47.597049,-10.605092,42.91787,53.686503,85.343785,104.725672,69.295928,-68.246398,-105.920315,-39.227045,33.627558,169.705002,198.103877,111.398387,-52.037359,-105.48235,-120.256335,-72.478034,87.455239,146.605766,129.290467,3.478106,-45.582064,-71.972691,-37.00446,102.365588,156.844232,174.426753,144.225884,-16.099014,-179.986886,-186.687846,-96.140708,-28.372247,170.088778,284.679074,397.527182,214.78491,62.602886,-107.716654,-86.176998,64.172923,143.040459,283.453054,339.969206,350.224893,159.259738,50.904104,38.130043,119.591911,202.233936,175.376561,121.901579,110.805902,91.336136,31.185796,36.802988,144.444107,200.45846,241.129562,210.715072,63.192737,-45.087874,-49.710699,-23.473173,-11.154694,48.507303,94.936593,135.951428,61.89077,7.285682,-39.7712,-10.029216,81.20108,94.002554,39.583959,-11.043396,-94.186454,-102.079248,-90.468661,-14.476014,37.606446,81.088721,87.056668,119.403087,100.926343,57.77685,-55.342298,-93.466391,-42.699348,33.352201,142.695247,149.833659,119.407236,25.515286,-46.235732,-113.985785,-96.458221,-57.328297,-52.941022,-52.375786,-75.958234,-97.012281,-107.032943,-80.486119,-10.041956,-5.416432,-48.352534,-60.807769,-69.429357,-157.741788,-233.242819,-344.743274,-333.157728,-189.537627,-111.73916,-85.087677,-243.089427,-323.328821,-365.549765,-317.862158,-186.04423,-163.159221,-225.115439,-255.881503,-231.943502,-219.640178,-247.061481,-285.555662,-266.171596,-175.203838,-142.641316,-133.362005,-117.307953,-116.147308,-180.949321,-212.20002,-184.957189,-138.30577,-28.322708,6.717313,-35.864635,-107.179416,-124.123287,-152.443593,-138.873721,-26.771665,39.425013,76.431912,-15.412323,-67.441485,-145.623339,-151.986754,-51.732063,18.284411,81.832176,84.839761,79.124207,70.466189,49.737447,4.619746,34.079846,194.521915,263.990581,262.551969,128.001692,56.536775,-86.052337,-133.171124,-64.165198,32.040445,157.496118,140.101402,-0.253735,-90.889652,-86.333026,-15.751821,39.189059,103.473581,79.864716,20.899886,42.843835,26.81441,-94.310185,-120.402097,-1.913518,76.67425,140.006982,134.060636,91.614627,61.578438,55.899367,17.742034,-5.904998,51.076065,137.87662,231.542782,132.392141,80.621172,-4.456999,-55.366891,-104.418659,-72.563479,17.351626,19.100812,-26.171116,-41.944305,-65.016065,-86.523078,-52.888759,36.924109,69.667055,81.875233,-38.021928,-110.847936,-169.961665,-132.885865,55.618426,139.240523,138.061587,63.894259,-109.316111,-176.078985,-176.699856,-169.505662,-161.016524,-123.941125,-72.616964,64.78012,32.413199,-36.207582,-102.035513,-77.8844,-8.579812,5.248108,21.220148,18.878054:99.437023,17.814772,-18.210731,-64.370235,-54.438999,5.662365,22.043738,-1.308968,-56.795269,-62.16129,-46.771775,-70.608669,-160.713641,-180.73841,-117.825704,-56.103293,-11.841402,-88.832273,-116.64887,-115.439376,-68.137027,134.529582,232.42973,282.505178,205.473378,199.846333,285.478462,318.007061,274.566541,219.028828,88.30047,26.335414,-37.494959,-10.309201,22.391528,111.122143,148.640371,161.237603,165.216928,200.919888,170.31209,152.092389,192.484693,219.362426,215.690761,213.561943,253.65376,266.032215,234.945182,211.281182,201.456758,137.97079,100.991856,52.879544,22.467581,-90.038043,-243.413694,-310.418169,-364.105269,-337.685584,-249.578232,-231.585705,-261.287366,-278.291254,-259.934618,-166.780952,-100.263024,-1.52181,14.478734,1.168701,-5.916748,1.444785,5.709207,28.541662,94.15317,100.440473,86.48242,94.874771,175.937709,253.309007,396.087668,424.702765,431.077739,490.658855,517.107065,461.173747,378.965183,213.963625,75.900515,-2.981081,-164.866661,-220.069009,-226.753088,-198.319263,-143.520019,-113.568086,-84.83739,-105.2391,-105.640193,-79.571149,-48.046119,37.516301,67.737817,65.970389,11.770159,2.180337,45.511437,71.55758,111.517998,139.442643,167.01301,144.033643,86.552865,61.10643,31.749116,-35.53723,-43.806319,-57.028089,-89.557461,-155.012212,-205.792837,-215.176511,-154.044324,-114.178643,-70.10144,-57.269674,-47.657702,-57.833808,-100.458063,-130.437517,-154.623159,-210.368855,-200.718174,-111.489165,-59.352611,32.389902,47.815025,44.100987,53.219158,15.473789,-166.980631,-229.728046,-131.942787,-10.035749,87.587719,-52.061402,-96.702216,-51.096276,-18.600178,-94.506281,-184.52745,-287.180836,-243.857003,-202.062313,-123.657934,-100.150126,-50.927275,-7.396168,53.798759,52.238619,55.61951,145.018855,189.506097,202.234596,178.243057,122.036862,108.761985,100.746507,26.231943,-36.579785,-198.808464,-278.687729,-272.20678,-182.62044,-73.05371,-102.764383,-212.452302,-213.611142,-194.751173,-211.381491,-205.707261,-105.047522,-60.784461,-71.510712,-126.583462,-144.915741,-187.100517,-196.933353,-139.058881,-98.674008,-107.039983,-157.070214,-248.572306,-230.410826,-191.471437,-84.516593,-26.636305,39.937536,56.561257,115.691884,77.635782,14.713467,-58.361606,-76.66501,-124.279895,-122.913316,-33.021958,12.739046,-30.82862,-168.750801,-178.28652,-86.197248,-51.329255,-37.234804,-5.824521,110.841313,80.087426,25.841707,52.807631,129.115945,226.445823,233.66044,264.120809,269.640888,174.541951,85.739237,72.467938,5.461998,-47.075497,-91.949786,-85.074809,-76.356783,-81.938465,-110.048715,-212.34455,-219.939509,-103.518819,-84.256715,-294.104554,-427.597543,-469.161378,-320.255441,-269.125306,-206.96447,-175.411113,-156.414307,-176.622354,-229.39701,-301.043526,-330.04033,-328.79254,-312.979229,-251.088635,-184.565174,28.065949,124.89908,166.240344,144.669587,138.785028,51.853673,-2.615617,-37.71152,-28.181013,0.752597,60.035574,107.338734,150.496803,115.482831,-4.062152,-52.452538,-134.652045,-185.588072,-279.444331,-302.259179,-329.913778,-453.03718,-491.047347,-449.258892,-405.008958,-366.598209,-427.071437,-459.078456,-435.595306,-392.538088,-317.251313,-296.746233,-258.171506,-239.969332,-265.219785,-262.515519,-208.028026,-107.160829,-100.932789,-136.497455,-149.343487,-153.609739,-155.944977,-134.774589,-33.554667,17.954797,45.333007,13.533628,-55.614716,-58.37042,-38.30858,-78.332065,-110.657888,-105.686712,-64.039167,19.052309,42.711613,32.388176,-32.555992,-33.023439,21.147867,30.610868,7.145217,-23.6734,-51.476618,-7.564218,74.434118,70.935325,48.354159,-26.996405,-30.169326,48.284906,77.664355,79.164395,77.232168,78.080625,15.425944,-50.839247,-122.764094,-96.783944,-23.287246,-19.455793,-71.456466,-123.360629,-137.7709,-118.373691,-77.785651,-33.742575,-50.884747,-67.056973,2.662591,47.923458,65.433453,38.361643,-9.165464,-25.220016,-17.971983,36.487995,197.075091,227.385848,178.588519,41.119948,-15.41203,-47.703976,-12.027977,110.114557,185.284005,190.225466,110.206579,53.32147,14.106365,11.122885,-62.813077,-97.558569,-9.046327,175.992199,190.872185,40.311123,-44.27562,-75.965325,-20.541107,101.331737,75.566742,54.005187,111.438977,158.788931,199.440618,194.543303,147.193561,110.980354,69.090351,87.67999,75.51266,-18.657097,-57.397048,-54.951048,-11.095244,74.8291,10.663501,-35.076532,-87.152332,-134.58786,-246.796836,-253.659766,-161.539728,-113.979791:50.498356,43.725444,-6.867581,-135.575401,-145.014656,-87.192347,-73.228863,-66.001567,-17.93647,-5.35237,-78.443458,-129.169654,-140.173483,-112.982217,-71.250806,-54.862951,-1.919398,8.221994,-31.353889,-84.81803,-43.34672,103.603282,164.027056,267.590289,281.107061,240.278591,178.910048,176.581909,150.422837,91.38513,-27.366687,-8.455409,107.96157,54.237574,-20.675255,-83.697322,-42.936983,82.027068,121.878589,109.460822,-11.250011,-37.324539,49.125436,106.417709,151.001713,141.206301,130.116121,157.028046,222.64528,221.180766,192.949879,114.474622,111.153762,172.059241,181.701211,94.117355,-62.057881,-97.662782,-78.199674,-68.076092,-70.179666,-74.026663,-68.335483,-45.033602,17.885209,53.818465,60.76355,39.364243,22.645558,5.297935,0.366984,6.090584,7.335965,7.087903,19.330043,7.195663,-49.144866,-42.707483,97.869473,186.859314,237.933773,147.057268,93.32256,11.110147,-3.178484,9.5761,22.191807,15.994028,-70.299276,-131.119969,-241.742512,-269.71363,-227.20739,-181.082691,-126.356487,-117.034939,-123.687626,-194.849984,-229.521972,-164.088411,-72.317894,27.790675,13.475694,-37.597675,-53.546918,-38.764074,-7.901822,-25.077223,-80.407559,-68.927395,22.721705,57.934108,95.197618,131.759415,117.905518,5.140649,-50.748099,-114.626555,-149.628341,-203.909415,-147.298666,-108.08946,-109.303958,-138.916851,-141.175335,-110.019063,-80.903096,-90.312904,-105.464715,-114.029776,-133.824079,-135.944733,-86.038671,35.87775,79.442678,162.959398,198.512928,190.93238,146.579316,96.959893,-15.704455,-34.538125,8.272149,40.342482,51.488423,-47.069765,-92.70279,-78.673264,-57.498882,-135.75847,-216.386764,-294.753746,-223.540201,-171.580997,-149.127234,-179.825634,-182.593363,-137.618063,-32.785421,9.33425,35.652449,46.999903,77.940956,123.768204,117.432622,59.414516,14.477406,-73.730864,-119.440261,-127.103634,-195.160352,-277.677598,-331.950295,-235.745242,-16.542129,4.149605,-73.685593,-112.144571,-119.28724,-108.917515,-79.312934,-79.34014,-129.702669,-213.720646,-224.136229,-233.442342,-281.42228,-283.43824,-194.867906,-158.516613,-193.587182,-232.183066,-269.022932,-264.120724,-256.407143,-196.516924,-135.870104,3.770457,48.524863,58.035602,2.856189,-38.467582,-130.4721,-179.752459,-259.955645,-258.280985,-100.284762,22.326622,153.973496,98.164121,69.457874,73.404211,83.510918,79.493629,74.067524,72.334684,14.129619,-34.969467,-79.302453,-68.417947,-20.402481,16.116766,108.629795,136.409486,92.547399,43.464445,35.653763,-119.368166,-256.779203,-375.325918,-312.014394,-112.829858,-51.085895,-94.149357,-233.062311,-259.611357,-180.750334,-143.512215,-197.992132,-255.876386,-313.781302,-272.941962,-225.227629,-110.310356,-46.334393,71.728212,94.782827,40.305491,-68.149467,-107.427836,-153.173751,-164.789318,-113.431948,-36.861506,144.852618,204.14922,231.525084,217.090192,187.27469,54.389264,-5.81388,-21.623738,-1.467289,1.539201,-14.367723,-8.513955,41.731556,83.245953,117.722889,89.737374,48.934634,62.868586,46.501623,-70.63577,-133.637514,-236.05838,-251.641563,-181.768849,-124.57428,-59.140685,-89.293384,-117.172432,-131.400662,-121.365058,-149.45624,-165.18291,-72.041504,-12.791611,-31.850759,-48.253658,-30.272432,-76.993849,-105.603935,-64.022627,-17.050997,91.430322,144.146096,127.919371,95.054653,108.235613,132.121131,107.081855,58.419865,85.945122,173.760602,130.811601,63.272559,-51.027761,-56.692864,26.450753,67.259518,62.087688,45.935334,75.520808,97.430068,48.340665,-91.431813,-146.90688,-162.114418,-107.436973,10.528579,43.858801,41.570953,43.799427,73.660193,139.824388,132.029267,64.507941,46.495915,54.150326,16.998104,-32.730902,-82.936036,-54.548351,72.69834,139.726916,158.245715,4.586132,-76.938619,-106.763784,-50.925236,32.8557,21.196128,-10.747964,30.948182,48.166085,-22.110466,-90.286418,-147.960129,-127.152668,-50.032001,-8.006734,91.924744,194.049715,206.038507,113.160652,40.845406,-16.906803,5.765596,37.321859,15.624855,8.434441,-46.211414,-96.711839,-143.71869,-133.800401,-97.523358,-66.412074,52.735288,160.407813,147.3431,16.774497,-20.548283,27.943979,45.668412,-1.961659,6.377859,58.39821,156.000282,153.768621,87.868175,84.109221,158.80019,175.117598,81.962014,55.15447,99.872467,127.161875,84.215499,-8.524408,-5.736303,107.655561,153.682451,89.864486,-161.142325,-278.305511,-349.332471,-306.970838,-128.360557,-35.175286:170.30569,64.016117,-31.511208,-128.080223,-70.851415,118.057251,149.982974,79.236099,26.181346,20.572754,-23.645092,-57.533788,-62.720358,-44.161927,-69.796666,-103.788465,-115.946903,-42.254918,-14.185989,-44.754253,-52.452768,55.162748,138.166372,242.396618,217.995296,196.06487,192.421326,188.226343,146.480581,108.713378,9.242353,-28.079869,-83.832087,-118.816549,-85.804728,31.742149,62.266902,24.209292,-11.223388,41.601276,172.709057,158.500463,28.772905,5.129922,75.465776,116.526648,175.867852,202.26197,182.525675,94.872706,77.647723,99.339963,114.409943,135.25514,139.059155,49.422141,-154.887262,-216.490462,-241.752557,-240.721231,-193.150587,-154.241513,-125.452349,-129.206291,-135.264445,-178.667787,-195.67218,-152.092813,-103.803238,-44.218432,-50.668218,-84.22689,-115.082598,-120.983269,-93.971105,-94.972444,-148.941919,-138.843854,34.523848,127.047751,184.376558,212.211378,229.89548,182.544451,147.649886,155.512085,174.182607,157.233305,16.915209,-82.827032,-250.742502,-293.001393,-264.809208,-222.145757,-135.621496,-105.123332,-115.380147,-137.608717,-108.368433,-6.64227,10.416353,-70.184322,-107.302232,-66.05282,-1.236863,-3.122814,-49.642184,-69.497328,-43.466531,7.205599,83.490208,72.126267,-24.842173,-118.507959,-149.897637,-149.833437,-82.139409,46.057972,9.031462,-189.715563,-264.118241,-216.303031,-34.839682,41.501018,52.004434,-10.396661,-115.400594,-117.544784,-130.52424,-211.166937,-214.175842,-101.662216,-25.770921,49.592931,37.108813,-34.430903,-62.640925,-38.368461,-9.072384,-55.870178,-202.346147,-216.755722,-83.34157,-13.896001,8.920301,0.95724,-1.412387,-62.964518,-113.027372,-182.908866,-184.763587,-184.828141,-263.12404,-282.794412,-187.803672,-114.270085,-7.169198,39.758683,106.329902,100.748579,26.943843,-25.224883,-25.237144,-30.966566,-29.308597,47.819618,78.932958,24.639263,1.252617,30.09205,-27.310014,-119.236768,-167.084133,-85.397583,58.056191,61.300624,-4.098317,-101.907915,-145.230629,-149.920649,-105.088116,-15.380705,10.957755,62.608718,65.915499,38.127794,-35.772004,-54.048832,4.619461,55.823881,78.387634,40.306497,-63.878575,-96.167926,-70.605538,6.985509,39.254585,107.011379,162.783914,257.526607,171.15209,104.92211,51.59812,47.517859,24.705554,23.52106,87.031841,112.571828,51.544404,-10.350169,15.56692,87.220097,97.817564,91.136144,90.82562,80.458615,28.189307,29.874615,116.056157,160.949921,202.460104,211.131632,239.052505,242.566047,198.151818,208.701049,232.267603,176.320658,118.823491,76.267565,82.709642,100.452218,87.220665,57.406362,13.120147,22.008368,42.669093,1.248011,-174.849601,-218.962632,-165.940334,-142.041407,-141.537716,-98.277706,-83.000631,-124.004368,-147.681174,-120.276708,-72.085455,-90.400733,-211.066877,-250.254509,-165.531548,-85.304485,15.755048,36.231031,19.05429,15.318521,37.44405,18.05912,-19.354419,-48.983691,-46.185301,-36.896709,-31.418703,-26.450431,48.581419,111.26334,179.548917,151.45226,23.088889,-26.795189,-61.25569,-132.959634,-228.109243,-424.247568,-451.402946,-378.059913,-337.624391,-300.264482,-309.513274,-319.80029,-300.847916,-277.999332,-257.12789,-261.156577,-260.447779,-241.79852,-201.9387,-229.623731,-245.266551,-224.779119,-198.741114,-162.876704,-145.71398,-106.515715,-137.499211,-146.072828,-101.175472,-76.640601,-80.08243,-113.400544,-153.803955,-134.787874,-110.086922,-115.75621,-110.448114,-100.090834,-84.671814,-15.854491,26.222544,86.017161,19.204708,-57.356949,-152.136698,-125.615868,-6.583515,15.54745,-5.743762,2.979692,27.461827,-0.039567,-12.822401,-25.494777,3.249748,115.127254,144.587452,162.596313,112.807203,35.400707,-105.299118,-112.405265,-22.340443,21.803685,58.239374,58.486403,41.21065,56.095431,50.749522,-1.105762,8.6683,71.279811,45.456655,-133.007744,-163.380878,-74.781424,18.342626,-34.908985,-106.243856,-71.78212,21.676682,58.921539,105.341209,93.171633,93.431657,113.883102,103.7894,61.949341,69.180214,130.0622,95.119682,37.269848,-45.356929,-42.080719,12.132138,23.883863,10.468103,22.90935,84.016492,93.031874,60.971505,-40.738369,-71.664067,-43.195818,0.599584,71.194894,64.757587,57.718404,83.930735,102.914765,104.743653,97.211987,119.708477,143.335721,130.633509,76.578674,60.757765,7.786181,-16.849716,3.010653,34.514309,52.30046,27.241135,13.10142,-64.307048,-120.165383,-179.156612,-157.882361,-56.788793,-34.788883:forward
-178.092081,-70.46973,-28.770313,34.750803,60.681759,89.915908,76.396542,-57.985794,-187.640467,-188.811288,-159.280146,-167.620172,-206.736113,-217.932613,-205.795833,-199.374887,-252.787617,-263.60129,-191.341277,-38.622993,-31.423358,-128.315884,-190.240178,-300.393293,-330.138502,-278.450934,-89.057807,-26.073498,-123.557719,-235.176114,-292.874567,-224.158945,-41.583148,124.943532,186.297149,209.817928,169.280069,55.151442,6.226184,-85.16529,-104.670673,-71.355299,-29.816414,-28.854837,-19.559674,-28.653552,-105.55911,-162.7075,-218.177275,-89.211447,-3.408946,70.876561,54.965386,-37.677095,-89.75528,-170.134299,-197.400446,-170.313828,-38.52693,40.439921,111.578967,74.386706,-52.163093,-79.468238,-52.068844,-1.905064,27.361099,117.036105,143.841183,89.153139,49.405765,52.415078,141.684104,163.270385,138.074487,152.188303,178.541362,102.818754,-162.174087,-246.530303,-225.890576,-127.600366,-97.52192,-52.523612,-25.071397,34.855511,35.075441,-48.509346,-82.275305,-52.201607,68.772641,130.99757,172.890309,146.915017,56.033533,14.171024,-1.361623,151.328286,276.130791,425.506502,372.78488,109.449154,24.628654,40.706277,84.190097,77.937839,84.883048,109.358255,136.447038,132.485347,119.144478,104.810662,41.061085,-13.364604,0.750757,148.711296,232.158525,259.240454,201.395438,30.02321,-41.552836,-4.545522,89.726327,102.314874,71.89911,47.733592,41.819919,57.444834,9.302451,-104.338953,-99.157116,43.715508,105.787767,67.910031,7.972566,-68.355181,-93.483072,-73.310099,-33.988066,-50.819196,-126.723074,-160.902285,-225.523808,-272.826321,-355.14121,-258.249166,-159.132249,-62.116244,-97.957192,-239.404147,-295.629327,-351.412883,-298.628365,-224.08158,-77.700764,-39.880792,-31.126784,-42.816337,-87.408034,-113.666032,-86.591733,48.267137,114.784412,203.134563,206.998601,161.345257,158.74908,199.458757,213.673164,237.296889,361.586792,411.775858,321.545199,217.823464,102.566004,53.718625,-108.244332,-134.180806,-81.336787,39.871516,77.368888,94.737889,72.610472,-46.428644,-114.001782,-79.954579,6.574865,9.250775,-47.858772,-93.354826,-211.813905,-251.006266,-206.202228,-79.924125,-42.654419,-37.407296,-63.412813,-160.314358,-201.365219,-223.744973,-166.201223,-102.823619,20.360009,58.246534,89.533952,78.915042,19.762197,-19.690922,-80.621198,-35.453763,26.700139,146.858299,158.98106,39.169104,-36.600501,-84.400732,-49.738409,-37.729924,-42.117901,-33.750233,15.766784,14.451356,-50.656838,-72.657064,-56.068314,3.944469,49.103648,153.444005,179.82333,154.135288,115.49657,-13.416734,-149.331589,-174.649295,-150.49502,-130.726523,-96.575231,-68.247178,-54.536302,-105.489375,-188.224458,-96.337918,-38.129053,29.790035,31.899452,-33.643249,-71.800747,-102.048535,-36.779975,29.503271,76.58015,34.011557,-46.979655,-54.806949,-54.018294,-67.99923,-41.282516,172.476909,267.929024,279.827802,218.941933,54.66565,-18.950008,-154.474319,-246.470998,-244.605678,-204.777119,-191.256571,-174.646028,-159.392769,-123.075451,-135.215496,-209.413159,-167.619463,-91.784132,30.814105,36.511039,-88.489601,-175.425323,-240.469652,-189.338243,-161.310501,-128.873871,-122.494023,-127.260919,-124.725138,-29.820249,50.019367,99.026186,-3.65503,-10.52007,72.337022,88.541743,45.099467,9.354024,-115.444282,-178.006741,-145.875095,-111.48809,-134.744236,-170.591427,-166.543006,-150.677937,-157.635045,-173.876541,-130.134665,-87.116617,27.077483,74.363513,62.575541,-5.593654,-165.142991,-179.444517,-134.725748,-51.314943,-17.652119,6.156692,-13.808497,-10.668153,12.03282,-1.844128,-29.617535,-26.255895,4.020913,34.158391,97.860201,98.075475,0.202008,-45.613583,0.877771,94.202685,84.81502,23.842953,32.283122,56.870063,7.439585,-107.070763,-26.514332,35.579854,80.777844,70.392718,18.87657,-4.535506,-91.865435,-211.632265,-209.965983,-68.299831,10.168333,89.180311,105.641431,74.096668,11.603032,-115.869405,-92.440347,-33.650896,57.668788,64.494572,14.195299,-24.03696,-115.901752,-174.652586,-158.705666,-104.765513,-91.793107,-48.588874,-24.746954,-45.705961,-88.292714,-103.200917,-11.751607,-1.066387,-5.821733,17.799368,38.583066,15.319055,-31.940852,12.039141,73.942871,189.613117,205.472964,188.182054,187.100778,100.303043,-13.716727,-177.67416,-122.519023,-60.333415,40.023728,51.181749,-7.221097,-50.682428,-69.493971,97.603673,213.448276,311.429408,270.975168,115.125643,32.654586,-95.283506,-119.666077:-272.417934,-52.688604,22.468544,51.432198,54.114932,43.552326,-4.431505,-177.961045,-240.247139,-200.278805,-133.952159,-134.070523,-156.910471,-179.920064,-245.791891,-259.150746,-249.368798,-221.847755,-162.566248,-64.547625,-84.143481,-155.051885,-176.450259,-263.145028,-389.751367,-412.578582,-319.615393,-248.82142,-207.850762,-232.93578,-271.948005,-261.749917,-180.28823,-100.467744,-76.527122,-67.419452,-94.338631,-155.089886,-172.343134,-218.754003,-171.385603,-107.761205,-55.787632,-80.084355,-135.526302,-136.827764,-92.351946,-85.134445,-143.685111,-116.115009,-31.002696,62.21203,27.934348,-65.310711,-112.618615,-228.499045,-171.333712,-63.052866,88.834163,81.790877,-20.181259,-84.065864,-235.597056,-289.544069,-237.030471,-78.170347,-33.333695,-5.822499,-8.38055,-78.394011,-129.39017,-121.115063,40.391111,72.710623,0.283891,-24.111924,-10.35351,-39.776608,-237.240585,-317.875459,-255.251775,-141.736967,-149.831035,-168.051848,-129.742785,-55.803653,-79.279211,-144.766334,-49.213562,28.839586,193.789317,254.017699,237.931728,186.581739,127.861715,133.88671,196.139262,289.833511,332.552016,331.883673,261.989731,76.517574,16.917582,-14.134724,-4.215092,11.142897,100.952213,141.46889,76.27087,-12.930417,-156.985162,-177.694507,-91.38996,41.230868,60.739256,15.797068,-28.068207,-85.023372,-76.717586,-39.278217,8.27588,45.494008,86.526854,76.583763,26.488709,2.236537,1.045386,17.910748,-20.292396,-102.635066,-73.494372,73.477964,99.192483,5.212061,-48.425621,-73.518736,-56.247546,-38.852735,31.964187,64.771747,11.908577,-63.871753,-189.829972,-232.243933,-273.038581,-167.80118,-78.887613,16.728077,3.54081,-124.451642,-223.797762,-337.429111,-215.290754,-127.964819,-3.089329,38.791902,61.801143,33.874572,-80.931512,-133.686325,-99.53286,112.17278,201.445594,244.144235,224.613125,189.934379,173.504729,165.585062,250.384023,280.349102,283.804396,291.468613,245.260071,186.16142,116.874728,76.99569,-83.384035,-153.798147,-123.038801,-19.956687,15.310586,34.169757,22.895473,-53.462446,-105.414159,-79.431978,-25.404655,-51.245536,-177.497661,-232.472279,-302.053976,-313.694317,-205.767327,-36.832622,-36.516657,-126.614211,-152.810307,-172.092872,-171.123949,-177.266399,-142.799733,-67.18702,107.611562,169.01227,230.457976,220.085643,119.487629,48.70688,-23.118776,122.841684,211.809643,209.71,131.999708,-21.391297,-77.61809,-172.885181,-128.929696,-47.462461,40.130104,30.776761,5.039202,-3.738393,-27.592636,-51.489889,-123.31453,-72.219858,33.184852,214.191702,213.707933,71.812769,-13.476279,-148.223687,-225.184908,-209.318592,-83.92503,-53.76169,-95.676597,-107.642747,-139.834969,-182.411416,-213.415168,-111.407492,-35.104083,82.46219,79.081325,-33.289419,-88.805133,-138.622978,-44.451734,49.568323,144.944642,102.870473,-16.761384,-24.342122,3.447558,-15.907323,23.235185,259.532002,322.975946,293.320649,272.302339,164.487334,43.50979,-186.589622,-192.617455,-149.511634,-126.363025,-132.301684,-116.310291,-102.05134,-79.52479,-85.162527,-138.564985,-116.712808,-54.703398,36.075097,26.890685,-80.078376,-139.391814,-160.136359,-108.782722,-72.957569,19.715612,20.616417,-111.757702,-150.728342,-36.11531,40.361319,40.674934,-32.583429,-11.27626,64.587169,56.076526,-13.785564,-31.413997,-77.941654,-130.470349,-100.167475,13.251745,33.106122,-20.257132,-63.605623,-154.191074,-192.209511,-199.723655,-120.886035,-54.875591,87.851983,121.391192,59.493879,-8.615086,-102.163029,-81.16778,-41.785573,33.415031,64.893256,95.364552,64.891997,-43.909705,-77.961873,-32.128607,116.721069,162.483444,169.175796,153.974189,119.241183,105.712277,54.102496,-5.562552,20.128662,159.118052,196.664447,148.817542,109.621235,42.360314,3.863525,-40.765103,1.845872,42.238307,82.306469,57.043772,-31.808614,-51.963061,-64.615005,-68.321145,-32.288131,111.488512,165.445273,165.376063,154.51849,150.744742,104.30421,-82.104794,-74.024831,32.648273,194.808479,207.740538,188.240679,156.460965,2.863956,-82.492308,-58.887002,-21.022249,-31.743356,-75.420815,-107.093091,-134.954748,-125.823437,-99.895568,-56.07039,-36.168002,16.213076,64.199911,136.34017,107.038923,-49.13232,-59.999856,8.993967,130.574024,144.674945,140.354171,146.704641,95.428649,28.33285,-45.116163,-30.438238,-17.283441,36.962299,60.831807,42.26216,1.173695,-83.183573,-28.256421,52.655523,162.812468,174.12488,119.932038,40.123309,-104.818138,-103.361973:-222.730008,-38.307252,25.864407,47.782607,33.296366,26.035367,5.143119,-144.56094,-185.735028,-121.664095,-77.455384,-129.110651,-165.248204,-131.855356,-138.940361,-186.334705,-242.442122,-199.273522,-136.840466,-17.616708,-12.246537,-84.303249,-137.381038,-252.843432,-312.339915,-304.679991,-243.762311,-209.211483,-184.013932,-208.405165,-294.477669,-313.046576,-231.588773,-106.114911,-84.845623,-74.655699,-70.235059,-125.932892,-187.052669,-271.694191,-139.669403,-21.82208,55.036326,-11.923422,-136.325822,-134.26978,-103.252475,-111.773712,-82.67824,10.446086,30.800178,38.260246,44.093722,1.684355,-86.377233,-279.376689,-222.248012,-118.281721,54.391261,95.222359,67.890784,-2.380984,-171.600356,-221.112604,-201.50008,-106.250362,-56.114129,1.882311,-5.167628,-36.987613,-63.77883,-136.685697,-105.329116,-97.900918,-218.343122,-267.838604,-252.906072,-268.387912,-415.505161,-452.413841,-313.67461,-175.940132,-171.369869,-211.178852,-232.252644,-224.530543,-195.660067,-125.601338,3.095767,85.421585,231.553831,276.924775,274.447156,232.845775,110.192614,52.107904,56.692074,256.585812,339.570328,238.540319,87.460737,-93.15355,-91.216236,-47.964807,-21.797166,-0.605334,71.288471,77.569064,-16.886483,-80.977515,-167.948614,-171.223852,-115.989934,-83.308557,-54.033177,21.696064,11.549413,-64.865288,-74.743371,-65.917715,-34.205676,32.840562,192.052323,209.549685,115.115695,72.541738,71.148492,66.905138,-6.435694,-7.214639,44.962783,156.608457,178.112709,131.445129,92.756385,22.816641,-30.801952,-7.562115,134.434076,180.266478,122.165331,45.939371,-131.799878,-207.484389,-254.386166,-163.760073,-100.625206,-64.668227,-109.921695,-243.318403,-327.49044,-508.101354,-437.761841,-277.071462,65.632811,145.941503,71.698251,-35.118753,-223.520752,-237.955462,-73.821721,197.459953,297.588606,308.450422,256.728898,198.045273,171.058979,84.219308,141.010606,194.319353,205.821139,203.104054,207.978614,166.990465,3.633831,-77.672753,-155.978101,-95.97046,-43.062548,-25.930974,-67.002635,-107.777445,-93.009448,-91.461587,-80.655758,-22.763302,93.390084,72.854431,-113.29731,-205.69126,-320.877632,-343.457446,-253.180476,-93.106759,-78.093147,-170.577032,-202.738609,-146.558908,-118.949861,-179.282627,-210.43773,-149.095027,84.799653,180.780238,183.866652,126.636152,45.148269,41.943223,94.381213,192.893395,232.859591,238.449976,205.694255,91.343579,33.751904,-66.178095,-114.803014,-86.399753,25.041917,63.644394,39.415195,4.141546,12.153465,37.79512,-10.151912,-42.672759,32.537973,248.038422,292.933383,184.820668,84.32412,-76.483264,-120.561426,-82.078104,30.757218,7.480282,-137.824821,-138.68282,-90.274199,-102.427872,-62.209229,58.573815,95.660495,99.119146,64.890961,-35.650736,-64.701943,-85.951842,-153.912616,-174.289221,-42.172326,78.296601,170.100157,120.596705,5.589701,-11.966907,96.134401,344.458087,427.540494,442.74789,393.595939,190.732902,72.456744,-68.246866,-21.080375,19.111963,52.605624,57.82364,19.928258,-20.698378,-88.967196,-113.881002,-151.351808,-142.635238,-90.510006,48.716294,61.214174,-14.169153,-57.585726,-156.17898,-115.24155,7.51955,235.617,233.657668,37.091655,-40.590517,0.518955,69.189156,116.099373,20.040415,-3.570124,26.787554,21.279845,-51.756722,-78.687166,-128.737526,-151.271319,-113.101135,7.026934,28.50884,-83.579671,-168.274651,-250.225435,-242.154529,-155.087419,-44.21319,3.837132,79.698931,86.196169,10.280351,-51.691568,-118.465275,-60.767865,-30.37736,-20.092382,-8.44068,15.994589,-18.389479,-138.114091,-162.542893,-83.778176,92.074248,169.983994,224.519359,180.252192,9.535179,-58.055642,-82.54459,-24.671751,5.701717,62.314711,86.013939,104.106946,107.692889,97.999371,65.625203,-19.402606,-33.075893,0.889574,57.009178,30.694738,-58.749998,-56.908085,17.346437,70.58946,93.483544,182.447906,220.632781,190.985447,139.695105,30.759856,-29.9614,-121.700664,-34.327723,55.074817,189.5187,218.959918,205.625005,146.246878,-39.485176,-49.48705,12.712077,42.723402,13.181774,2.929348,14.291758,-36.727211,-103.98601,-176.188888,-105.438214,-53.924221,25.480976,32.220936,-45.801843,-115.568183,-232.303862,-207.73485,-142.568525,1.455659,42.719529,55.13119,64.04189,58.072668,12.097843,-90.259883,-116.188515,-101.295576,-28.339019,13.377916,19.709821,-37.220121,-186.654811,-120.433162,-6.396923,145.58551,168.239356,163.824745,108.992874,-51.953451,-77.162702:-145.583788,-74.535843,-50.224673,-6.976703,44.071306,105.702673,69.798949,-89.675677,-169.661658,-146.564555,-104.413328,-123.728019,-193.147344,-222.372274,-286.71721,-313.47058,-281.222285,-172.571412,-114.800517,-14.407017,4.535528,-17.762081,-45.450442,-135.539465,-194.233393,-185.720439,-137.404892,-121.649273,-135.724799,-157.636979,-193.419532,-184.869472,-62.358099,123.215354,190.752575,227.769674,185.805488,18.876175,-71.741187,-187.346705,-99.023738,-8.066872,79.297104,55.543664,-32.202388,-55.675581,-46.731818,-31.108694,-2.642338,-24.0352,-47.281952,-8.642052,56.568927,107.320564,32.384039,-193.287474,-190.815482,-101.259343,98.184781,179.965049,211.401696,139.446431,-20.061327,-46.874092,-33.019093,0.813773,47.055916,153.498464,140.295922,-18.646809,-84.412214,-120.274229,-104.955314,-89.909058,-41.970498,-7.971009,-2.916042,-74.810402,-298.84861,-372.935062,-385.982215,-304.790224,-249.719526,-139.75542,-97.373563,-50.269752,-54.859298,-99.208905,-71.779744,-5.17098,200.775537,286.139164,317.014298,280.089474,165.019359,88.82065,18.103964,250.120479,406.87156,471.140562,346.569749,44.70368,-25.787335,-46.563143,-72.865896,-71.163983,6.88889,43.887702,-9.000973,-66.87248,-107.312947,-103.998916,-107.580591,-75.774743,-22.152451,137.293457,188.648828,144.447185,80.62218,-19.569034,-11.205484,43.195843,156.212669,178.284353,173.338827,162.749894,120.016863,81.156447,9.919051,-5.34305,-1.619733,80.690155,151.695302,165.708416,96.326826,-34.13774,-23.015533,27.108629,97.812732,88.649228,-25.884365,-114.122049,-262.26887,-300.005654,-285.942026,-211.923213,-192.444422,-223.821117,-271.247009,-395.516718,-454.041506,-505.911825,-404.162119,-296.447879,-50.557831,36.726222,74.710298,38.210194,-101.001969,-159.57122,-75.25819,218.67071,308.263673,309.609102,284.378529,271.07203,291.907434,368.07983,403.450963,386.073862,365.212386,403.440757,449.408226,382.820271,140.125267,24.090096,-115.893115,-80.206875,-37.0483,-36.50016,-66.489056,-73.453137,-66.705911,-134.897387,-159.416598,-99.388432,16.770775,7.939527,-137.750212,-234.754068,-369.722915,-370.485415,-251.515643,-174.93958,-198.528304,-248.434538,-245.799483,-238.34664,-234.724777,-241.253001,-209.3373,-139.146106,16.624093,66.586029,107.943051,102.628612,65.079242,31.31593,-48.915971,40.104727,149.287148,260.688134,218.197756,53.964389,4.058053,10.467773,45.542103,39.142186,-23.553773,-35.825534,7.390161,13.403099,-24.832342,-27.057052,23.517158,99.251536,145.711923,229.417185,234.667814,152.729123,101.599242,34.814749,-8.594666,-11.955551,15.510251,16.619794,-6.436147,-3.128608,-18.297512,-67.879601,-142.298691,-50.331906,33.454555,141.950175,108.748305,-48.756426,-93.195628,-135.046588,-181.656296,-183.663668,-149.762867,-124.754567,-75.008593,-60.197931,-84.474825,-118.934009,-95.157218,149.252368,279.662496,402.12513,385.295611,225.161149,128.517311,1.399648,-26.975023,-34.129555,-77.067268,-81.768634,-62.448831,-78.755949,-132.265884,-131.577467,-75.295276,-2.507275,28.543567,77.554481,79.102388,-22.779745,-94.607717,-143.699348,-78.976957,-32.535219,33.862576,47.694261,30.304453,9.796717,66.542222,145.645351,185.010109,39.85943,37.847916,192.958081,226.088129,91.703613,0.18421,-98.511116,-71.403024,-16.198431,51.878096,17.769815,-102.071303,-125.939858,-116.673591,-112.510001,-64.261895,25.497344,52.240741,102.412648,137.135456,100.096997,9.630013,-151.42695,-136.228435,-84.446373,-23.653943,-22.623152,-56.737918,-95.997489,-177.761107,-193.370916,-134.273422,-20.752601,31.971399,103.365273,90.226078,-11.293231,-53.27297,-108.908712,-143.84637,-125.306126,-11.342638,50.776779,104.241229,100.094381,53.188711,-5.573817,-153.242268,-153.526306,-98.3227,-10.551945,-3.10264,-30.03852,-44.424453,-91.0884,-136.922876,-124.330629,-2.610203,73.309133,122.147433,83.53027,-54.305185,-131.955074,-229.765539,-143.007652,-46.209381,91.575563,87.150663,16.994084,-12.125742,-125.141531,-225.663837,-209.234238,-92.038897,-28.416181,-8.400942,-66.387172,-174.84086,-201.709898,-232.551998,-175.4685,-124.914683,-53.839957,-47.06808,-56.952253,-51.640829,-67.373847,-99.717347,-72.369714,30.198537,55.897558,33.008589,20.269941,6.950796,-18.956994,-91.842606,-126.600116,-97.45025,29.818717,55.414326,-29.640939,-85.792547,-110.338558,16.745246,105.962075,182.432721,165.327419,75.894496,-5.083854,-153.841946,-161.045605:-84.560034,-9.279222,-3.147359,-21.065589,-16.973016,25.223685,20.032062,-92.449901,-74.961912,-10.915366,-21.166946,-87.280944,-156.520161,-167.295315,-290.387064,-389.75901,-456.914682,-314.059845,-218.613033,-61.601586,-28.394741,-92.825811,-186.172007,-340.456387,-222.023911,-112.867242,-26.679481,-52.626849,-141.299835,-183.653166,-229.683768,-217.029362,-90.974286,116.931946,208.432174,315.304367,290.663917,48.504465,-102.022143,-267.208839,-196.581369,-111.472746,38.790429,70.27973,52.3191,19.381714,-88.724735,-138.268432,-113.248964,9.414966,50.339182,93.946655,97.912523,27.588494,-44.223831,-178.324616,-161.912004,-74.544441,159.688456,241.376118,230.915049,155.094097,17.450394,-10.603432,-4.392183,41.839548,82.356478,161.198612,146.877868,-8.05507,-101.913103,-182.465029,-109.328873,-97.07829,-136.266885,-129.64874,-136.99597,-224.516104,-485.530402,-551.67391,-475.066758,-302.980979,-220.677103,-136.975571,-156.923248,-211.678862,-204.850483,-122.09378,19.192321,90.487889,233.072997,301.267918,352.397748,323.46901,151.849352,34.785666,-13.413931,279.113286,397.915248,334.527137,207.484517,-0.934035,-67.529232,-189.969308,-212.241555,-164.855866,-40.902151,-0.050414,-13.750805,-61.219226,-171.96486,-205.816886,-215.59175,-179.418601,-129.99839,21.251798,76.573343,66.642297,24.53153,-37.751206,-19.523416,36.864231,200.318385,245.73998,215.138813,186.611413,167.20189,155.35237,121.758852,165.155411,207.833594,242.190365,234.771999,210.488944,181.296847,48.730902,2.039097,66.378067,203.991186,195.675868,31.551006,-62.826402,-211.907726,-281.963486,-354.692702,-270.418475,-226.216081,-274.340892,-363.665317,-542.053146,-603.299897,-658.848612,-533.555445,-398.953891,-100.833563,8.579786,65.88713,7.428004,-202.226664,-272.032802,-165.463907,164.855153,292.232817,345.182023,317.196158,293.332891,276.598362,191.116549,176.297768,188.969877,229.772364,268.604571,282.233793,220.938473,29.011482,-56.435603,-133.057505,-79.121527,-31.132998,10.897381,-18.685808,-144.2828,-224.324873,-336.724083,-241.054283,-132.860457,25.657266,24.869581,-108.256732,-199.941619,-362.723351,-402.317343,-341.477641,-213.768941,-163.546939,-120.704861,-149.246488,-239.986654,-273.773991,-307.86466,-196.337178,-103.767259,63.129034,131.331441,162.793661,109.487273,-24.833785,-51.238354,-16.082889,39.864682,77.947217,184.349455,201.513165,85.516729,2.152827,-80.426337,-94.163174,-96.76748,-56.604553,-16.376623,28.620606,18.095068,-64.286789,-105.528266,-77.97819,26.73502,69.578817,161.220167,197.942031,158.141977,77.666437,-81.557801,-76.879819,-13.438294,108.997093,93.92026,-40.571942,-63.009105,-34.266877,-40.262169,-61.422147,-14.970342,46.829631,173.253882,173.025479,70.506222,14.772914,-110.953003,-242.929625,-260.994226,-134.595478,-24.237022,111.664673,94.960313,-69.3329,-137.215902,-47.642012,225.974456,327.172297,380.360565,331.761655,142.293665,64.027874,-4.873104,-7.08072,1.923653,30.912977,54.801921,54.266715,4.263181,-111.344334,-134.145481,-108.194985,-59.271616,-37.372919,13.160415,17.485659,-40.107675,-87.095661,-171.388239,-143.23902,-74.263925,77.824993,106.632044,33.627269,-27.440916,-56.868612,-6.790704,103.214077,113.542765,136.784048,230.348809,218.289078,48.979396,-31.473811,-97.474437,-31.961356,28.75812,79.250276,59.691153,-23.60851,-73.070565,-151.775465,-172.276654,-135.771182,1.221187,72.759621,152.509087,130.999602,-17.570119,-84.740265,-126.709474,-89.532822,-53.877029,49.847082,97.202086,71.726162,-1.869845,-135.454919,-149.348036,-67.583473,59.631595,124.625682,183.379704,129.029711,-35.561845,-74.571877,-114.974399,-107.164887,-42.738792,138.872527,202.36071,220.412629,191.648497,87.901844,17.753274,-62.655898,-8.41611,43.312209,141.604761,152.333465,68.147339,13.270475,-40.362817,-26.075714,-11.768107,89.687986,175.420656,250.242485,206.101145,41.908173,-34.58245,-100.25137,0.519174,94.646065,272.068397,307.851339,230.438368,141.530007,-20.710768,19.610343,100.37724,199.229456,198.542919,160.46075,126.859174,9.048356,-58.592875,-107.849057,-4.873039,74.761806,190.587657,179.245126,40.226369,-23.76533,-80.488384,-57.296892,-12.750999,122.047931,192.020213,253.618263,231.079501,118.123422,61.25517,20.727714,36.012995,48.707427,117.485571,148.022326,83.881755,13.795714,-53.1245,69.924031,163.609621,248.398278,244.626583,204.077159,159.6957,57.609033,35.530672:-225.913974,-98.37912,-64.782778,10.249714,62.30547,120.357604,107.802991,62.550542,33.044749,10.422228,-50.623221,-83.677091,-157.116554,-198.923913,-297.681333,-353.73838,-413.189563,-315.672335,-242.978054,-178.040381,-186.60453,-191.222527,-177.792739,-219.137853,-312.298353,-310.022019,-213.065649,-166.961297,-190.312547,-240.560074,-243.263264,-178.970196,-34.012712,131.090802,220.272594,270.193385,201.6555,-5.972182,-69.768941,-116.425082,-139.955018,-107.387274,16.841065,55.562813,49.112962,11.996104,-98.736407,-151.942604,-178.885909,-56.040249,11.842766,47.631097,27.667701,-37.646115,-82.167851,-149.409356,-103.130655,-39.062873,85.33521,120.728629,140.18435,129.892538,67.468526,26.479019,-0.666565,56.770289,90.484656,135.687418,138.029328,80.803444,39.708833,0.287019,38.210119,71.435983,108.18132,104.423787,39.993063,-40.845315,-259.362461,-331.946333,-328.20787,-227.512187,-167.699511,-73.172573,-55.130718,-23.705266,-7.618586,-64.988893,-147.29452,-130.100825,24.893772,117.73432,212.989747,224.5601,184.808735,103.833068,-22.005433,172.086506,311.188273,405.50365,337.713991,86.684238,-16.717556,-78.939332,-50.845375,-37.863867,-9.93966,10.153382,22.079501,-10.390204,-102.682734,-133.207375,-148.701909,-39.897073,61.729536,264.118589,319.911722,278.42024,198.974376,42.625671,71.046194,150.087365,236.021699,216.865374,149.263871,139.774904,189.728325,198.510659,118.730375,57.684374,44.250884,45.828915,70.93427,96.176202,59.584846,-93.40753,-106.416108,-17.274306,89.715962,32.029666,-174.64,-251.504378,-310.564152,-316.742382,-302.459191,-211.195797,-158.796019,-101.500286,-120.388126,-266.760198,-342.245843,-384.691851,-289.411176,-212.771184,-61.151042,-2.395485,32.66251,-0.084603,-100.899983,-129.621465,-64.120967,132.768799,206.117429,191.790153,130.055228,85.836586,144.404988,278.776021,289.31868,288.21079,334.262808,359.297403,305.742716,219.521506,-1.643415,-110.45276,-212.245623,-110.6773,-37.319207,68.972161,78.645559,18.919028,-22.909607,-112.499246,-120.256441,-76.899835,-28.629187,-50.088898,-143.281562,-207.056558,-336.292826,-355.130235,-220.530881,-42.302205,-30.769696,-131.473228,-195.465166,-270.593302,-262.754948,-257.097369,-256.938371,-186.365397,-16.049277,17.583337,24.930214,26.122585,-11.626098,-63.157239,-150.21736,-50.566545,52.54091,188.094512,200.137774,122.882901,45.034264,-56.953573,-49.166833,-44.101733,-41.269784,-27.275359,-5.41819,-14.269824,-15.156583,-1.268702,38.386629,146.490116,210.961532,267.683966,228.721923,83.92381,43.714894,20.930915,-21.842303,-44.368997,-119.203868,-163.724027,-178.104664,-154.731039,-156.564449,-197.629958,-260.197053,-178.677976,-100.341388,7.746479,2.205155,-75.010082,-105.879358,-134.233431,-154.623485,-142.397253,-36.95622,24.669088,34.239854,-15.30086,-85.255635,-95.040686,-66.401397,85.727079,175.08777,251.076435,213.843756,47.578308,-27.096529,-111.842571,-167.118757,-187.061136,-157.124732,-112.075076,-60.436076,-60.294369,-38.559022,-41.74205,-111.785079,-60.623098,9.565548,73.755928,40.32584,-83.983033,-132.313947,-208.370664,-271.264745,-263.665302,-173.925326,-119.359401,-60.117209,-66.791248,-60.224836,-11.285909,64.351188,29.975881,72.065909,295.987618,347.860318,218.015799,135.977855,48.149073,-22.406587,-38.921826,-43.985188,-60.746982,-120.929592,-120.83909,-48.41135,-24.822685,-11.273988,67.307359,107.018339,110.770998,91.966317,52.443797,15.25153,-118.550794,-217.465748,-217.924321,-132.372021,-68.7564,-23.686987,-62.762646,-144.473977,-152.327848,-112.43088,-14.168343,22.304813,22.570739,0.465565,-43.778528,-51.0533,-28.540267,-11.783738,-10.258606,41.273862,80.508665,88.384421,59.875162,1.698537,-25.933758,-45.930862,35.380388,78.358754,116.668321,112.532123,54.629313,25.777938,-34.712516,-131.690476,-153.106301,-96.642208,-54.864151,0.558961,21.696605,8.679488,-39.455112,-141.818254,-85.405332,-4.718742,104.2905,91.064078,-1.349572,-14.467118,3.730883,8.991725,50.281301,194.172287,235.613113,172.981493,95.207789,9.37275,24.190061,62.457591,68.542195,81.579489,139.8629,173.83843,226.734812,240.251566,214.584867,208.278008,261.030263,388.890847,408.614576,349.240028,285.840587,120.013114,28.206837,-85.632244,6.727583,87.515158,150.374459,114.953189,20.666883,21.090453,104.772618,218.843785,288.569187,335.571651,281.572171,114.69461,28.985722,-108.667777,-131.122121:-124.999863,61.744436,84.757061,30.40535,21.131862,49.936599,42.657723,-28.710324,-35.363271,-11.207447,-36.774071,-93.698847,-215.147188,-269.299185,-395.755043,-450.696299,-424.599077,-239.843615,-136.618202,-8.020024,-31.727364,-189.601173,-245.53381,-251.380333,-143.419355,-82.47996,-62.496721,-88.804532,-125.545446,-148.934055,-243.923417,-270.342662,-94.124737,276.937628,383.406808,326.634254,203.705935,-95.756431,-212.046981,-271.706286,-155.417672,-83.3434,41.486203,76.189795,42.964036,-13.866647,-140.112185,-169.835828,-68.406913,111.474655,162.765429,199.112196,196.082021,131.859424,57.448175,-100.304623,-42.234485,67.280674,266.874744,308.438191,240.528652,162.314557,41.835744,18.160248,29.991538,98.266395,155.592385,236.204907,184.899821,-62.566638,-159.583922,-198.133789,-94.859831,-35.525083,19.697641,21.345663,-55.4461,-169.450477,-475.917293,-574.564441,-508.038192,-211.888488,-81.472608,-5.582502,-55.8509,-160.699291,-162.480205,-128.678482,-61.728139,25.705391,271.300709,365.397564,391.446035,336.868698,170.022298,89.936879,97.027258,342.397053,432.63417,377.165989,267.354667,48.301797,-50.609675,-212.446854,-200.074086,-130.168302,34.920441,77.282638,-18.980436,-117.827883,-258.298362,-298.995544,-317.097782,-150.233723,-29.367132,144.000706,169.486586,92.748457,25.53162,-37.141463,26.58893,82.676518,215.666524,263.848753,242.701439,190.325597,81.593699,30.380632,-22.257186,85.054578,156.397231,203.881427,176.578012,61.239134,-0.693886,-60.425665,22.489565,93.054189,141.333184,95.761477,-88.196755,-190.773151,-321.153739,-350.844425,-370.427838,-243.638827,-148.368152,-152.416027,-281.317795,-549.376827,-605.878906,-579.960351,-439.943307,-337.100815,-97.842247,7.857813,89.914042,44.753543,-132.588303,-183.153704,-67.104639,180.38836,252.252883,285.426241,282.586965,263.100974,233.714103,180.899356,262.829964,332.204797,412.761078,407.218334,279.701019,160.511522,-94.95739,-191.977869,-246.069515,-78.006056,17.534291,41.162693,-23.750707,-176.948543,-245.153988,-339.671457,-286.995586,-199.25142,-37.952669,-37.085795,-213.507486,-318.988236,-395.697051,-372.602311,-270.745688,-135.930558,-94.901816,-120.70554,-185.395271,-304.767457,-306.472041,-257.617955,-190.464384,-123.726281,8.861236,38.350101,-22.21389,-95.789993,-199.181069,-196.995592,-93.970771,57.662484,132.10541,238.306585,237.598213,122.259072,44.484076,-53.982955,-28.550915,2.130555,11.289323,6.508396,-0.758025,-22.159809,-67.133317,-81.989996,-57.184783,122.63457,217.797045,269.548255,227.423739,83.420945,9.223655,-75.107319,-40.13104,2.320304,79.77175,88.874346,2.210567,-78.265158,-219.583707,-248.787611,-230.90987,-158.391001,-72.244334,132.542437,144.045448,-32.211871,-108.172599,-121.380455,-126.114214,-140.049696,-82.598846,-23.921118,-21.110908,-93.343279,-212.879735,-218.192998,-127.505858,63.497085,148.271795,255.153893,255.468851,106.713036,17.135223,-72.892288,-56.128872,-15.858205,58.736335,66.748744,34.526916,8.536869,-58.315505,-89.885565,-97.241869,-24.023212,20.629536,76.416901,53.881373,-103.867692,-190.333701,-278.271992,-188.97117,-117.364014,-54.834915,-48.226072,-31.715779,-25.76692,-21.571316,-24.232069,-33.002375,64.378712,186.932732,357.78141,308.764447,88.599389,17.016722,-82.78281,-113.292051,-52.746158,129.087576,180.530095,96.834494,4.193132,-97.303443,-96.414987,-3.54398,170.184431,240.291698,308.66318,296.595161,147.059642,25.022452,-173.605593,-141.028668,-72.261914,-16.044239,-32.669044,-75.050975,-103.193837,-181.561619,-201.354353,-122.817704,86.037058,193.145802,286.605742,236.119586,-8.547271,-124.73532,-193.564417,-72.144673,20.201324,198.27813,246.596058,172.259285,77.482145,-41.554688,-55.814102,-84.98449,-16.042703,71.760388,189.966728,184.277168,124.523005,108.008374,59.87207,-39.075701,-53.674511,59.657781,142.306505,166.190516,91.680225,-85.069693,-126.241365,-94.21279,43.834763,139.483188,259.577924,228.898145,50.30527,-28.009381,-112.258785,-50.035766,45.011016,251.394092,304.592119,256.080492,193.173665,88.477054,45.2182,10.915766,119.14721,195.141103,288.367689,276.071747,164.092656,119.611065,89.681576,145.686314,219.71087,365.161985,391.599555,326.715069,253.421825,105.194394,54.125186,22.290924,86.780535,138.41713,186.002802,147.07263,-20.956954,-80.473271,-36.342425,156.068482,255.109914,319.532647,274.931145,130.080245,51.389994,-88.053316,-115.181511:-80.478741,87.363008,177.029166,248.192783,227.865462,198.435186,221.779755,218.832273,58.662135,-1.162744,-44.171237,-83.312517,-193.663006,-212.174485,-156.147877,-135.303051,-203.945146,-296.170321,-296.931961,-264.7994,-266.596757,-328.179892,-369.932651,-400.735048,-361.43556,-339.676726,-278.493087,-221.054486,-113.309476,-92.936882,-58.431666,-17.943356,96.097446,201.440603,221.791533,184.604031,140.235363,7.06516,-61.62646,-101.936197,-70.004746,-81.143858,-99.872404,-65.423748,5.160748,-31.605451,-218.936246,-287.905465,-278.030654,-186.319843,-178.409213,-219.644902,-242.117248,-298.154506,-325.569896,-392.190551,-407.276351,-330.606634,-78.098308,21.734875,62.848655,27.519437,16.786836,74.077724,233.270756,319.340602,319.742373,266.069415,216.724188,114.175018,97.646902,165.930704,294.128957,324.190507,308.363278,302.620967,250.272333,169.298133,24.701899,27.656857,85.5943,53.298037,53.630998,141.200409,183.972729,193.013399,174.405494,130.920522,76.916697,50.573342,59.912293,118.546777,252.030538,269.570658,182.073797,109.653948,70.603607,254.801241,359.629534,452.864289,424.252565,254.776495,167.731887,80.673205,69.167653,68.889663,44.049518,26.98008,11.991591,2.620795,-37.835271,-69.136955,-120.380498,-27.456597,78.57239,293.452152,357.381303,339.577698,281.152079,171.753234,115.618316,99.421148,73.68758,76.833842,132.591764,156.062161,137.452509,104.806226,16.292885,-21.008319,-0.788103,31.965752,38.430686,54.790584,27.838687,-135.942957,-218.009091,-179.969355,-125.939333,-151.682342,-226.762437,-250.297791,-273.742466,-290.389518,-287.214907,-105.243119,15.744833,163.293812,159.608091,81.839396,70.404593,90.285179,126.325319,159.36763,178.838723,171.407071,203.932704,223.754898,196.524836,144.841682,49.935114,127.422612,185.135841,142.683648,58.126451,-41.217651,-20.667982,54.122039,47.90247,32.873615,35.201134,46.682816,-18.100257,-98.452733,-227.849308,-270.098324,-302.156848,-177.105944,-107.217235,-84.031878,-109.13863,-105.915979,-61.107836,7.004821,0.734903,9.52171,44.574834,42.653028,-43.085278,-106.782838,-156.91075,-108.427789,83.360616,184.572825,171.999981,116.894222,81.406279,-41.079681,-97.827606,-148.97984,-157.040728,-168.973226,-183.931528,-156.161271,-84.473848,-70.482905,-52.058389,-44.741475,-54.651107,-31.284856,14.884844,170.039581,245.021533,241.822382,173.566247,93.243728,83.540452,60.901943,34.595621,54.80363,89.672282,88.079983,114.245797,131.796437,97.041962,31.532786,44.701397,165.614692,194.490689,105.193305,54.122769,25.204975,17.823898,17.319613,-4.42387,-41.320198,-125.096483,-153.596713,-219.945359,-274.963096,-380.023588,-324.370006,-218.802487,-15.63238,9.141558,-67.652982,-105.692674,-158.591811,-163.658585,-102.73611,52.938349,91.02602,89.794072,72.54404,34.164586,22.513571,25.960857,61.410833,94.10125,137.750981,106.456325,-20.082651,-47.974362,-21.441695,-39.909696,-58.546038,-50.528697,-26.657579,18.428273,29.895099,61.911284,72.472635,33.472235,21.58097,46.904648,60.639713,20.376417,-129.455257,-210.817116,-330.33594,-313.762402,-254.483674,-154.490918,-148.2116,-202.566457,-223.066019,-159.237245,-97.638236,-48.500286,-53.07182,-9.470361,133.284449,160.156405,84.836573,31.804209,-5.864762,56.612574,81.996022,30.877637,-22.2251,-69.586465,-55.310431,6.665902,36.300887,113.512169,205.472927,217.591649,200.364727,187.3154,104.665878,33.861851,-144.78611,-228.181356,-169.374168,-11.675448,2.012099,-117.337199,-183.44677,-190.076931,-148.151813,-70.14316,-33.568782,-36.331096,-68.689588,-80.997699,-55.078626,-11.316774,38.376533,2.743781,10.627386,77.505718,101.232854,100.185677,80.481618,61.917688,76.31213,111.946247,122.573745,120.527125,140.257383,151.392007,125.449772,107.839124,63.838956,-57.511013,-126.73073,-219.943703,-230.247407,-188.94919,-168.497303,-176.064416,-190.053234,-223.293525,-240.501702,-206.696178,-108.906697,-111.666842,-202.523023,-214.534185,-110.987029,-3.944609,25.679369,95.396882,113.229234,54.941624,5.501804,-24.962209,8.99861,101.543273,81.566983,16.639368,-68.089155,-26.39623,166.156077,238.076533,240.119399,201.285011,218.870841,265.241208,265.368324,213.02459,163.283112,38.811333,-18.274662,-73.940129,-31.433692,8.094499,68.301367,66.802166,7.617453,-9.229585,80.732775,279.815386,353.399644,338.353566,250.449012,35.695286,-46.27122,-154.825609,-184.372287:-161.919486,-11.308844,81.359138,253.873841,288.737201,263.076229,240.904227,169.339648,40.812724,-9.346533,-65.942185,-77.721341,-108.59201,-146.22587,-174.564475,-137.568173,-104.417008,-204.347162,-235.524155,-228.673352,-222.949726,-241.267047,-268.524107,-367.754824,-407.163356,-340.870757,-89.107942,-1.992601,-65.916924,-154.071979,-173.567839,-106.652129,19.257548,150.447518,222.140666,237.497748,158.56197,-23.453924,-53.458094,-27.59868,-66.411707,-105.371321,-122.259753,-100.175956,-96.001617,-133.479119,-243.980381,-287.321931,-278.758289,-113.118961,-34.67279,-19.254353,-57.814129,-129.14753,-161.619371,-254.425421,-281.006504,-222.970234,-32.730103,40.413469,48.930814,-7.529528,-90.26569,-55.172784,113.362577,183.070065,158.895441,105.727831,95.936758,89.794624,108.321133,177.626677,237.800539,250.102673,224.090995,195.305025,85.119022,14.61988,-62.33813,-68.442379,-68.491334,-31.161016,3.42663,50.033322,54.187571,91.754281,119.090272,68.935057,-59.905893,-97.061677,-65.411322,6.493262,144.003418,154.808372,71.832345,24.853534,25.282374,146.107027,226.841938,369.96988,372.05749,187.44814,93.270911,53.317816,78.5554,70.88402,59.142664,99.753169,219.347852,222.292501,107.322867,55.798254,28.609645,54.186972,102.278443,309.388709,406.156572,371.431689,249.397529,40.112248,72.665146,133.425234,173.069669,157.395997,152.640772,156.707153,153.64375,150.974979,105.415931,19.136764,-7.170441,21.682216,72.819152,111.550853,49.621746,-170.803489,-236.742266,-160.287061,0.52992,9.841384,-92.160797,-164.437071,-277.527383,-310.929017,-282.073896,-128.897233,-53.626264,40.146724,44.498347,-8.570087,-36.992771,-75.007077,-79.464805,-63.164025,-29.555386,-2.93173,67.03235,72.294271,7.879306,-43.597763,-108.15164,-52.870831,-19.709547,-8.359883,-28.079827,-45.93742,0.464182,130.098487,98.329419,66.428973,128.753247,187.164332,150.348127,52.936227,-125.93907,-182.972377,-212.757367,-125.169289,-87.699941,-50.295583,-37.790994,-29.642456,-37.29322,-111.739219,-165.982468,-119.606298,43.872642,78.691655,-22.737151,-115.788485,-228.277852,-213.582378,-81.046566,46.174754,67.762449,54.971996,29.938572,-101.260728,-183.946257,-260.003769,-207.211006,-155.236097,-83.011747,-78.939935,-68.991063,-51.01476,-71.444168,-123.171901,-165.7798,-31.787632,35.99871,93.14843,112.840467,116.502344,70.294233,-58.169777,-49.73794,5.982432,32.050945,4.210826,18.626207,46.643835,40.837949,12.88307,-29.006131,19.518615,65.936987,119.991896,116.542484,110.603308,121.591356,57.983103,-62.649751,-66.473466,-22.035308,-9.488449,-5.147248,-15.586768,-70.976039,-118.697067,-174.87849,-105.137833,-58.455088,38.239941,62.356601,-13.021028,-79.454672,-170.572876,-81.811747,48.526288,214.765394,181.397473,88.161906,92.733193,114.051617,89.755483,66.804673,192.503173,226.030443,138.258017,70.52496,-18.134872,-36.424514,-77.637434,-168.723615,-196.09303,-153.82302,-93.834496,12.59672,36.385217,34.396363,-7.36784,-165.166675,-204.112334,-135.764146,26.719637,45.785051,-55.319005,-118.294623,-192.772922,-230.124046,-218.361275,-148.797173,-126.142262,-131.991917,-135.714623,-58.203436,16.236183,90.458179,7.034573,-12.671255,103.546112,177.525789,186.720989,124.723839,-13.792671,-48.509506,-37.994867,-42.512601,-67.617149,-123.079297,-121.222554,-62.237632,-56.1856,-94.746313,-71.18359,-17.248651,121.674769,145.759638,34.98758,-52.386568,-163.571822,-162.200152,-144.51161,-129.655891,-119.620278,-104.458906,-115.9512,-105.873948,-79.559166,-54.921901,-80.005903,-105.43298,-113.869429,-84.934395,-14.798987,1.671499,1.307418,49.345141,79.772856,53.386611,8.392298,-37.94482,-34.762299,-38.442544,-51.066133,-45.453171,48.31117,99.83428,129.092329,95.916441,-54.183843,-129.661736,-229.355976,-257.224416,-239.72573,-244.455572,-257.279861,-189.102287,-151.334853,-193.810369,-233.965715,-256.685175,-215.889624,-176.134581,-107.639148,-118.895954,-242.474678,-295.074919,-283.936471,-230.595824,-213.468167,-197.43679,-198.740806,-149.544506,-104.363496,-48.858121,-26.270331,44.362711,33.352491,-20.22962,-49.722049,11.711561,148.676175,169.844157,140.630735,169.041112,215.467125,264.390993,249.984847,168.262449,116.282629,-0.071124,-70.841043,-153.917983,-100.228997,-70.280856,-41.315482,-18.281924,56.29804,86.812274,139.169578,271.093572,356.048502,424.343614,366.875593,122.70106,5.977719,-76.525477,-49.325127:-32.464489,83.293321,102.281956,80.712853,86.912719,124.446267,152.040747,207.192769,169.018452,130.403264,32.374634,-40.85812,-180.027358,-218.034014,-264.148633,-298.152133,-360.196723,-301.251339,-222.533674,-134.411362,-182.904349,-324.062888,-321.128261,-206.930122,-141.587487,-126.962384,-106.030345,-108.317657,-144.317026,-169.121114,-153.011157,-90.668851,59.676274,172.055311,211.048222,224.043563,175.242153,0.775104,-51.673734,-21.17792,11.187775,0.05874,-21.509778,-23.112758,-30.078129,-50.639434,-102.310033,-99.666606,-44.580923,-3.747064,15.271087,62.318363,63.436702,-25.489592,-91.050853,-170.235363,-87.244784,-3.858986,104.617045,112.529269,80.768882,66.264026,103.20301,141.316018,159.733103,137.517782,142.999186,183.594386,187.85643,101.1716,53.096015,26.959081,4.598712,3.508853,66.656157,108.886021,77.832979,-20.001995,-225.53129,-261.084508,-194.675551,-63.188668,7.648883,97.406478,91.509506,65.099718,70.125647,51.318186,32.900439,48.695408,113.986183,168.787335,261.718803,252.40385,134.375629,76.758193,85.199164,265.5893,343.809421,340.203497,254.677143,32.384247,-31.123654,-33.254186,-39.66675,-66.877777,-79.584631,-51.115618,-48.213374,-112.256258,-236.093068,-241.670652,-173.308252,-44.379274,32.233338,184.489994,246.674988,254.318634,193.241462,47.540205,48.890829,117.909144,209.652964,197.650231,133.192657,102.635942,79.673413,86.591785,75.152481,24.935709,8.984594,6.140385,-3.859133,-68.876717,-110.039474,-186.897835,-165.238326,-112.056907,-48.563244,-37.82483,-43.408774,-107.472747,-326.560731,-416.518527,-457.339634,-268.897786,-146.419615,-57.957563,-116.915086,-260.941448,-254.715199,-143.610782,-148.976556,-152.164541,-5.910407,102.456544,204.1448,178.779227,64.41649,14.30975,46.782814,224.351573,239.297043,104.361228,72.185806,124.744182,147.433519,189.1015,255.867173,266.271626,211.599356,172.943154,105.962202,53.863602,-85.477348,-139.88007,-159.227968,-33.33263,36.780642,35.751182,-40.742866,-190.163147,-208.774258,-162.264646,-109.156102,-98.906403,-121.958688,-129.160435,-93.865554,-89.383217,-144.634168,-154.9352,-43.114085,98.890673,99.203436,-25.513447,-97.976734,-176.665677,-188.661926,-191.921803,-101.044426,-34.813044,2.411723,-29.081706,-100.500534,-116.661929,-86.679546,-62.181357,-30.171835,72.735044,138.180923,173.263924,144.274551,57.072296,9.915991,-21.387187,50.306599,56.604497,-20.253679,-22.454238,66.862584,84.362035,77.288914,77.716873,52.026493,75.368094,135.342846,254.650278,250.96284,102.463503,27.4936,-5.376445,24.256239,17.877405,-19.995574,-48.328032,-157.619019,-223.110053,-316.166479,-330.755014,-269.497936,-126.382873,-59.107212,36.064801,50.041273,-14.271381,-59.129758,-86.356369,-3.381079,49.170248,65.347471,47.42639,23.582526,14.505025,11.323895,18.408543,92.792057,206.957632,233.865892,232.021373,211.608062,147.156807,104.586697,-2.298264,-41.440339,-17.878458,23.319505,24.419645,13.457639,17.506356,65.129162,84.057235,58.68986,21.476452,20.689474,26.249765,2.383181,-129.905456,-194.864724,-269.892079,-306.571429,-286.645045,-207.858694,-200.053999,-222.041381,-191.004028,-51.857406,-1.185271,26.315868,0.20221,23.006342,169.38591,195.574363,73.61071,7.280051,-43.734132,-12.621993,23.771511,47.772046,28.069488,-47.858173,-95.186907,-159.144367,-152.343648,-10.831266,205.203668,266.220444,285.568757,268.709604,162.856022,75.785504,-111.102029,-178.279535,-133.046531,-7.7395,17.864799,-37.32861,-102.705437,-216.512529,-232.337999,-144.807189,24.357481,75.686762,111.864409,110.42022,31.316201,-16.91708,-24.190326,18.260039,49.795002,162.426652,203.414026,178.03376,137.061584,70.100375,35.954847,-15.44874,77.087203,155.943128,227.354966,206.355828,131.723275,111.47688,61.691271,-38.634284,-70.171549,-30.935923,24.247574,47.004195,-23.428963,-195.199194,-215.970008,-117.048224,-14.333871,-1.240144,15.81819,20.821258,-39.338706,-91.605143,-155.798228,-77.483495,14.066231,176.532481,198.336406,135.516364,84.845504,14.905767,14.184738,54.348968,81.302847,80.399808,79.185239,94.172118,122.475537,124.488345,120.825453,149.421873,184.947809,258.563071,282.409349,255.750468,193.049919,47.625539,1.073869,-39.571022,-34.532146,5.014213,106.766821,92.398585,-92.854499,-158.691783,-57.273975,179.142324,255.309226,208.047113,102.246638,-118.314091,-196.324478,-236.217201,-209.356326:forward
92.270198,108.755185,141.077788,270.962031,308.267819,303.907384,289.511967,202.290989,5.65116,-94.431875,-183.985691,-181.39897,-135.055196,-78.652882,43.923967,54.873206,-44.409472,-124.321478,-104.348291,-40.53194,-28.572804,-5.936151,-13.711337,-165.315646,-412.191687,-488.105868,-445.968468,-376.364118,-285.541315,-255.122861,-223.90144,-242.787759,-301.866468,-308.409233,-274.783907,-143.273424,-62.583878,64.799775,54.430576,-117.236326,-262.400499,-300.957867,-320.955323,-310.121683,-282.17609,-265.645382,-240.385348,-235.877635,-260.254424,-306.435892,-281.328441,-177.995234,-154.011431,-137.479844,-147.123737,-270.019799,-391.57015,-391.130631,-287.715069,-226.01918,-151.232764,-124.506164,-83.354467,-83.34524,-132.897261,-180.627955,-159.867133,-69.649865,-53.856552,-110.462786,-155.890067,-225.138609,-249.471537,-245.257547,-192.014959,-162.794879,-112.430453,-81.888722,-95.874108,-151.535834,-229.332704,-159.694487,-92.429857,17.179589,40.193582,59.157548,63.632792,42.763774,26.82888,36.539887,89.540879,107.605794,89.700287,83.657271,91.0662,82.877704,56.950577,23.432441,20.819686,58.207383,66.288091,81.83137,106.997226,120.682671,23.125378,-35.888562,-56.388897,-12.387844,128.70941,213.828473,333.668495,348.173491,306.354983,162.269653,95.11167,83.22564,115.838552,166.765642,167.630194,106.457323,-22.474843,-84.964527,-119.080216,-90.470668,4.36752,49.805753,60.065969,23.485888,-61.338266,-143.859235,-159.136178,-79.594032,-16.566225,47.026092,35.111559,-34.278851,-93.885866,-96.481976,-38.831308,-21.209004,-55.212751,-67.650792,-76.42541,-98.548977,-166.512879,-274.714213,-325.166382,-325.82319,-288.321416,-227.407874,-215.349634,-214.633961,-242.980845,-267.18493,-262.60761,-210.138486,-65.507715,-23.279754,-30.122501,-61.054745,-145.037643,-139.959379,-91.354751,-21.960126,-13.3026,14.105537,32.432878,39.772298,12.230357,-8.430843,8.679138,57.620061,144.104681,162.406445,161.70003,144.102783,101.172282,99.469133,115.06241,71.749219,12.105925,-49.087103,-51.352629,-30.731146,86.022496,143.608711,165.671949,147.244102,162.642093,224.060799,396.829884,453.19074,392.543426,199.326169,142.714222,133.690802,140.989723,142.320214,147.43672,148.326617,89.226485,42.783853,6.863133,23.44335,42.495528,38.052351,-0.299041,-38.136223,-98.807418,-140.627737,-154.482418,-106.334728,-58.578011,30.964684,77.792232,146.298721,126.346963,94.801968,50.552789,40.329037,-24.578226,-65.614484,-79.933822,-67.146047,-95.623669,-154.562543,-149.797969,-143.310903,-167.118475,-140.974508,-72.629455,2.737454,-164.976815,-284.134134,-347.951578,-266.214477,-65.508017,-26.698801,-51.236308,-53.927705,0.08756,39.284302,53.398344,18.766377,-43.659703,-98.216563,-63.097827,-16.014393,-41.393207,-61.110251,-138.681324,-194.291119,-279.688298,-291.061005,-269.039173,-252.043965,-243.805271,-247.364822,-209.045187,-80.161564,-35.488892,19.179272,51.008508,159.025494,266.242335,261.993367,194.410395,179.257884,195.539916,216.047845,255.994313,248.437825,128.91799,-16.059947,-33.098618,12.790199,41.014499,101.329492,129.405096,165.74606,143.129823,109.96397,86.049308,83.970786,55.982381,52.920477,37.579094,-13.797518,-145.374294,-151.626674,-119.188601,-99.498429,-115.491157,-128.433593,-130.348211,-157.621525,-161.133222,-142.641876,-80.469109,-62.542876,-75.616581,-73.028865,-63.030271,-93.612287,-198.647814,-206.970613,-151.071971,-1.500669,55.417929,98.667834,96.092848,125.753702,197.304453,184.976082,75.696629,45.884033,76.658467,96.653284,92.336918,80.449347,12.644103,-148.417545,-197.827109,-169.229824,-139.086751,-80.236941,-30.33265,51.799129,-9.938065,-49.397534,7.186111,59.900931,83.984212,93.613745,166.199156,195.434657,172.753635,62.064088,31.636111,114.292616,191.445884,291.110479,302.350582,291.503514,263.639891,219.655163,78.680033,24.082302,45.863552,115.797464,216.485664,204.533527,126.853778,100.421166,119.916479,197.808567,227.269253,208.768866,164.14917,121.033819,178.224689,184.131627,164.25514,172.075781,187.809131,175.65597,123.933634,94.88482,59.943623,82.813979,111.848749,166.334383,173.480727,146.815325,127.194648,106.86957,111.42647,121.468572,144.061395,135.285535,65.036024,43.322371,55.710323,52.374646,-7.49573,-55.81289,-44.188058,15.649001,23.550858,-11.447147,-23.324761,-9.753067,-62.122209,-134.679423,-158.159545,-57.65402,180.154225,245.908956,291.919891,292.605465:86.495198,169.770269,223.400827,297.366486,312.208097,317.261734,294.393029,148.209405,-24.368136,-67.163801,-63.292474,-47.877146,-21.906199,20.906809,139.706903,132.731755,-66.5506,-145.111075,-56.009477,178.489794,239.684608,209.086127,137.050861,-57.263656,-259.842049,-335.003924,-352.627931,-311.822276,-213.111459,-164.664568,-157.29833,-203.824591,-254.579628,-199.214882,-158.141463,-60.094223,-2.917164,80.107913,70.109751,-25.098779,-116.04262,-171.661513,-225.464853,-188.879124,-103.68788,-110.239208,-189.148084,-212.178113,-187.273941,-161.321106,-151.059431,-125.335377,-116.622726,-91.241922,-89.508156,-191.475511,-379.845214,-438.322191,-359.436081,-248.535119,-88.18961,-64.404387,-106.258461,-165.157875,-235.502249,-114.59941,-27.75173,43.436289,18.595673,-62.490689,-100.771707,-204.312548,-316.539376,-322.008945,-168.31757,-64.319531,-5.511941,-58.383046,-171.986357,-184.195968,-176.310151,-198.578994,-186.777867,-89.924027,-31.906335,21.069821,-4.617839,-97.339732,-172.608087,-189.813197,-96.458746,-24.617347,36.991953,40.304454,36.940842,35.015355,26.649141,-0.18049,9.686922,105.60129,171.064935,271.52554,274.319986,168.086911,37.537602,12.685469,59.461061,99.966233,194.957893,245.359477,259.193254,221.845611,134.494162,51.574326,21.124308,47.959027,118.866777,241.586624,223.183135,72.109771,-39.945097,-69.002729,-131.123027,-150.921714,-86.958927,-21.581745,14.672531,-30.248331,-123.747725,-181.805719,-198.744588,-130.494248,-49.835316,54.813464,44.115204,-32.042235,-92.615076,-102.312969,-97.216276,-103.430787,-107.799649,-102.467293,-153.980078,-197.861819,-246.796853,-295.688917,-321.818774,-341.302007,-337.015849,-339.075813,-344.591908,-324.4454,-295.386155,-280.378945,-192.891933,-138.807621,-64.155853,-37.378843,-6.486412,-9.629194,-37.667096,-58.453258,-61.301114,-37.909829,-15.223148,14.56846,16.167265,-21.778659,-76.557795,-58.705427,73.454197,134.129087,180.75268,194.911733,205.046811,171.070391,46.41558,27.432434,85.427223,143.70834,97.304148,-31.349465,-70.999185,-114.757957,-83.378143,-33.86095,18.451447,30.462261,155.812996,247.53961,335.792413,333.767744,265.877656,125.503797,80.99122,65.528126,56.809594,1.740933,-24.960512,-15.331135,42.264185,41.497856,-4.144939,-15.49118,6.340842,26.535636,24.879583,-10.314242,-140.736828,-248.0497,-237.792564,-123.966442,-57.731649,41.246278,63.412196,90.76955,96.134594,86.729512,94.928775,104.884867,103.535233,99.179503,88.218486,62.591394,-84.554913,-232.222733,-227.319075,-133.724926,-110.71271,-96.603444,-70.359707,-16.701039,-46.971245,-94.958259,-160.910873,-139.106042,-21.93225,28.108057,48.722422,32.499117,-0.598871,-20.781539,-10.082033,28.933024,39.667651,44.051865,36.253256,27.12649,31.046721,7.58466,-88.714055,-129.10447,-150.157487,-133.244445,-75.490154,-48.807591,-28.136258,-31.977355,-25.028826,21.833249,65.337112,148.699671,144.04262,96.408083,161.388193,192.295447,162.135865,133.361959,112.073177,115.981539,131.562899,132.855612,83.603103,20.547314,38.727272,117.493502,120.038901,91.310287,104.259831,153.572295,141.904988,125.805443,97.073686,71.260147,63.048867,88.894627,92.935766,61.682981,6.754566,-18.880296,-38.792563,-73.6897,-54.397769,32.133611,44.023947,9.13637,-39.536385,-73.996232,-69.410521,-19.050783,59.166337,55.296021,-12.971028,-50.371665,-73.385018,-21.898643,4.952379,38.664248,63.424104,101.917049,104.8486,136.045321,155.394006,133.26162,80.914652,69.649689,86.852979,105.667152,127.22212,118.235048,26.184478,-118.204158,-157.213355,-131.49841,-90.845166,-32.019282,-47.902274,-147.146301,-178.497168,-157.17381,-76.225641,-17.758113,108.967987,142.226746,113.069879,92.439047,86.368843,13.521168,-32.470386,17.110402,106.3693,235.357861,242.78795,185.01253,67.219494,13.573143,18.104127,60.534394,132.868365,162.344755,213.743428,222.038519,199.131534,153.906134,140.930637,187.160243,225.830974,234.28396,197.836417,130.908151,135.829343,154.77898,181.978567,164.999859,110.100703,122.25464,183.061427,172.43961,52.192079,10.838194,70.942375,209.247266,223.071334,77.001415,-40.347211,-134.269473,-33.560645,10.74663,31.96136,37.926424,82.468966,99.499753,70.087811,40.717969,33.048829,59.372988,67.961335,119.054927,160.165129,156.662593,96.976017,24.01088,71.201512,71.097072,51.883958,98.348972,271.701442,337.817844,363.712592,337.611497:112.394754,102.92554,139.477823,240.30127,241.109544,186.632228,165.475459,118.054992,13.103231,-58.801686,-163.091107,-155.480378,2.757022,105.251029,168.693747,111.29108,-61.828721,-118.841082,-64.60316,96.252609,134.429969,82.438167,11.672486,-121.09122,-199.34729,-238.309104,-278.791149,-274.900076,-244.208178,-204.434611,-116.110779,-115.896003,-197.742934,-239.128625,-211.044364,-75.595354,-0.303098,62.391877,41.512586,-59.878948,-225.321537,-295.915772,-310.562285,-264.485914,-185.027932,-185.677712,-221.035799,-215.493579,-180.343976,-194.256361,-194.251232,-116.180817,-44.89783,14.876389,-52.085374,-243.385792,-272.965704,-251.827246,-203.264864,-172.73084,-124.690871,-106.147208,-79.044839,-91.661703,-188.233032,-255.457834,-218.819719,-69.615225,-31.870283,-90.343426,-157.889889,-290.419561,-373.140971,-374.650927,-248.88021,-146.686161,5.890451,24.890591,-76.421606,-172.517889,-316.916299,-306.315228,-270.344974,-210.084351,-170.002359,-102.818244,-134.953424,-283.22462,-330.176898,-305.267241,-189.309808,-119.152507,-51.863093,-71.198654,-152.127464,-166.268012,-132.116521,-140.299508,-129.473408,-11.870338,47.035306,84.587961,70.64722,-27.022626,-182.642125,-203.761468,-82.012085,-15.300559,27.770194,14.34716,-61.397968,-93.43774,-109.055175,-148.273171,-165.10362,-95.846383,-21.629027,60.007451,29.210985,-118.054067,-237.743741,-256.433242,-209.262884,-176.97665,-152.90601,-153.016017,-154.894125,-151.177235,-183.578897,-267.917363,-246.706783,-57.289942,14.208693,-1.184949,-34.130294,-66.272145,-84.479298,-95.672115,-131.448128,-141.177995,-106.816782,-92.467076,-143.041931,-172.653837,-162.8747,-179.769791,-221.036854,-272.283175,-238.944691,-107.933201,-91.567977,-195.003115,-279.993148,-258.045455,-102.048581,-31.856625,29.509362,51.125625,80.867279,68.089805,5.942718,-32.222095,-37.941126,-7.511895,43.170846,138.350859,129.710952,16.360625,-25.742586,16.947571,127.251573,149.309296,156.858645,158.259476,115.631468,72.86169,22.427814,79.510278,119.321815,131.152155,109.781212,54.150068,28.064107,-2.857586,18.743515,59.680967,174.921576,221.611517,278.745165,296.651984,279.885893,242.179911,138.764547,49.709979,37.481195,54.423221,45.261105,-32.724777,-54.949034,-23.890592,-17.130679,-30.167826,-29.08347,-9.483975,36.023995,46.100793,-1.003127,-62.767838,-217.419383,-300.652201,-284.001455,-166.544255,-89.839829,29.160163,49.541001,68.716403,113.405683,131.328783,148.934307,146.60899,163.545751,197.986549,248.976639,223.90698,40.036141,-112.694316,-103.279021,-24.188993,-9.575277,17.203917,58.056096,100.102386,-9.179971,-67.135401,-81.539111,-47.424271,67.119575,128.49312,183.84116,188.543123,198.083284,168.192034,155.896852,171.213306,198.125819,261.522507,252.939051,166.399079,114.552686,102.4422,109.39245,124.386117,161.471136,182.504264,183.876677,154.457715,61.554853,11.598766,37.534666,158.168202,236.546512,352.166223,333.740578,204.428585,193.302871,232.364227,266.933152,247.553869,203.921013,206.124421,287.851882,341.746014,357.081389,267.252513,237.901248,248.558054,258.02192,204.745046,158.208004,174.545124,256.93889,221.263459,91.750701,76.410087,149.913112,197.841344,245.384562,226.498732,77.956715,-9.080945,42.614839,192.744648,226.210277,236.856824,243.320306,241.878498,223.177749,236.093358,291.698852,312.657456,334.304409,314.578482,212.041643,173.518797,139.144205,128.772637,156.814611,247.488755,273.355625,279.154641,273.059455,272.720056,264.168002,258.698793,278.998775,288.546776,276.323195,241.271319,132.97393,95.617319,32.987636,-39.851614,-47.271422,25.523108,89.839445,161.813092,138.270871,31.03649,-29.759574,-50.38823,-63.470788,-16.535299,140.957032,177.17892,128.870843,97.020491,47.836576,-30.078503,-55.332825,-5.720807,68.066838,204.137457,202.44991,76.607883,35.909321,66.084338,126.558707,132.438752,129.681455,142.207222,171.483781,189.390901,209.97178,163.289617,151.572552,177.068217,187.994853,147.285593,104.455649,74.284207,124.35881,146.478264,163.874649,159.398444,151.891286,157.113344,137.491166,108.728507,54.479966,13.797734,31.759284,130.576478,148.33461,53.195973,-18.291803,-100.407848,-114.394624,-89.507393,47.87709,118.869064,122.00637,51.9952,-83.456989,-91.356889,-7.190398,92.68436,138.813375,189.912842,182.610944,132.933834,105.672562,76.195893,83.641506,87.255355,108.198824,130.818598,209.249495,256.663923,268.485331,213.6385:71.151643,91.449377,136.399798,222.688275,233.326377,205.611354,174.677573,64.928662,-137.958321,-240.915648,-333.922732,-335.917313,-274.163837,-190.178998,-50.394375,-83.981484,-310.099441,-380.86374,-302.082527,-132.826326,-103.637518,-98.511187,-112.337528,-202.361202,-349.727654,-409.437135,-393.943651,-321.90586,-167.879529,-129.556924,-157.908301,-201.439243,-298.665076,-342.752379,-307.823253,-183.469535,-117.793696,8.148304,18.214394,-113.318748,-238.482226,-260.336502,-265.222088,-260.971272,-242.164101,-229.118649,-207.753556,-200.597278,-184.830889,-144.177095,-124.012886,-138.192513,-144.314921,-104.622491,-118.215564,-250.174975,-296.786562,-261.299318,-136.751534,-84.134395,-69.757324,-74.11029,-20.199315,-8.565372,-104.343729,-188.793037,-183.808062,-168.415202,-163.890945,-133.482595,-148.272565,-266.788559,-360.489756,-362.02143,-254.512213,-168.986624,-37.459131,-5.087837,-34.795178,-113.032009,-299.846714,-298.946474,-225.377406,-119.014846,-114.049211,-109.216821,-97.677394,-126.951024,-257.242252,-281.04556,-128.15858,-44.08486,-38.620908,-55.801328,-25.050333,-11.988055,-58.886472,-117.314832,-99.957504,-18.433816,8.01661,54.053626,85.89277,70.398453,-138.330242,-248.517653,-267.337541,-181.512994,10.096078,73.480743,108.45473,94.069973,28.07435,-128.656502,-184.642168,-141.167757,-71.469569,35.384987,25.585611,-95.223996,-194.133219,-216.746802,-207.064797,-178.968875,-69.226196,-0.929823,24.707031,-32.992512,-185.586063,-300.421768,-308.470295,-192.747139,-106.106809,-10.39045,-22.122506,-76.485404,-122.455385,-157.398033,-180.854521,-157.436931,-117.948141,-119.019308,-145.12235,-150.86314,-141.030894,-162.111984,-194.827495,-251.494016,-229.193112,-96.106315,-57.72082,-96.065611,-144.896873,-157.460987,-144.947108,-106.110162,11.424455,52.876154,19.703865,-47.373668,-160.224628,-134.435279,-83.586308,-0.209949,16.707943,48.917684,81.682602,131.02647,48.925155,-8.816755,9.646196,81.761192,213.49615,243.986765,236.624276,214.03779,155.583422,106.90484,120.521513,149.822157,115.68535,22.036721,2.244445,11.020452,72.797164,114.459158,163.911098,173.025056,258.271463,344.923508,453.136348,425.125356,256.16957,118.084762,119.757286,201.187058,209.149731,126.336771,97.178742,161.329112,194.590833,136.871664,77.324265,134.286311,238.418178,217.19243,112.550215,73.779439,-1.877524,-73.173579,-78.548856,-25.406732,18.842302,95.700529,117.591429,140.608775,115.555969,86.963518,72.710354,86.290013,105.681735,122.258249,163.542915,152.518433,38.012296,-81.269751,-109.546306,-124.309581,-115.888368,-22.429796,62.778821,188.946299,71.71625,-46.436192,-120.874195,-52.078529,92.938372,115.830113,136.884288,166.941026,201.494532,192.957921,209.761927,205.908596,161.792238,115.505138,142.091506,198.747621,138.670294,91.627311,37.672532,8.508306,-80.205512,-103.837178,-64.260681,-35.299226,-42.375391,-88.301823,-76.59544,29.691538,89.87177,185.869947,227.517821,302.322986,354.283455,362.611582,334.390821,310.53668,280.844607,286.480851,342.181829,365.012815,306.049858,189.764404,195.873123,319.398441,359.912358,326.736235,294.715824,291.654558,304.094097,291.648176,275.287367,272.073903,282.561546,308.850351,338.53888,310.490325,177.616275,90.531291,107.611692,145.419662,130.880355,106.991654,119.526697,153.949397,135.235501,114.429013,117.855038,145.06924,221.248239,243.079084,148.492734,60.592916,0.463132,77.941135,121.431138,197.311942,228.111316,272.633837,279.568662,282.594003,290.277762,285.579992,265.099577,241.034345,201.064593,205.733986,210.497274,191.291647,134.522848,75.940483,43.998101,22.372906,51.18829,148.050585,188.633424,210.048218,93.902378,6.836402,-47.556002,2.120789,158.139537,216.252482,198.955764,134.731352,0.338843,-71.560163,-61.831572,60.968898,142.028841,259.819129,276.750409,241.661375,166.593658,128.939977,94.638325,106.945782,193.508949,242.322965,247.442018,210.884139,137.507875,84.672647,88.339,132.969823,143.129333,142.210015,135.774486,88.521999,25.168539,21.551913,58.522492,78.914382,156.458551,201.63523,188.591921,141.187432,61.101595,6.72755,6.797411,76.584958,99.413401,41.312141,-20.150552,-113.042861,-94.280945,-53.032606,40.486609,84.259549,144.639571,138.050926,31.844955,-18.404875,-26.421323,-17.661676,-9.085867,30.174028,39.649466,50.840835,70.607909,117.511128,36.947655,-38.955434,-45.034802,41.312464,192.833539,209.537413,205.581095,216.753213:212.816277,194.650644,237.208968,357.058323,397.394101,364.346895,282.056526,101.028796,-35.580948,-91.522515,-169.264225,-195.123345,-165.149757,-105.071709,-42.410867,-81.202702,-239.273301,-287.000724,-228.758437,-77.519396,-24.933237,13.849812,-25.022742,-162.733053,-215.478899,-206.582827,-145.019012,-107.443012,-26.656892,11.75395,3.25159,-54.393659,-198.883423,-202.112026,-138.941274,-36.485803,-7.451917,82.07523,119.607902,60.381663,-108.07122,-159.090616,-167.897308,-155.261057,-77.917215,-14.921681,23.136638,-4.714851,-38.993997,-20.553866,-19.671046,-47.077597,-23.929815,92.727383,82.654541,-123.325528,-213.537064,-162.136535,-36.432416,-14.060883,24.90586,77.993158,148.157966,122.794719,-11.287183,-128.802549,-140.674486,-92.457986,-48.13395,-1.864906,-54.171302,-249.693492,-385.80523,-394.889301,-249.887827,-135.939361,29.241315,52.213537,-18.63515,-85.29033,-226.190121,-287.824152,-251.914155,-67.448894,38.314274,83.481504,-4.072468,-194.847922,-212.074599,-171.042809,-34.549356,23.661353,59.75263,53.636407,-5.467558,-42.83735,-55.890596,-30.943169,-9.754944,40.501561,58.106986,85.146521,91.247292,41.264276,-140.352403,-218.533286,-173.784307,-98.864424,-3.70657,29.607143,61.65945,39.115346,-89.100825,-299.825682,-350.789863,-188.934052,-39.055853,100.267026,41.780112,-151.743991,-247.37414,-267.420544,-233.688973,-176.816089,-55.43859,-26.923686,-68.893459,-119.567787,-239.309477,-342.137918,-345.855324,-254.922419,-188.289764,-74.540211,-53.098014,-89.961548,-176.761127,-206.23456,-195.441788,-168.228623,-95.87251,-54.575648,-27.521205,-66.099299,-201.527722,-229.03246,-200.682044,-145.684293,-102.680298,-21.080431,-29.179346,-112.778443,-172.606876,-173.904639,-103.850716,-47.39325,60.740294,86.248057,35.042552,-26.641923,-159.344484,-183.86722,-138.296455,-10.723531,56.109302,167.422707,180.689351,111.078345,16.095486,1.896042,64.956959,115.026951,199.463062,232.672366,227.834405,169.002893,-12.322982,-79.552448,-35.921583,93.615445,146.548199,192.45268,154.932536,8.356705,9.404672,57.591918,123.393643,150.205838,254.452092,309.163402,325.505619,285.109635,162.563641,112.181535,132.282647,136.929998,106.048384,53.426995,55.155596,96.692539,59.666629,41.212273,153.512737,229.501097,263.343023,243.149159,154.918494,81.158976,-86.145033,-184.9342,-168.343469,-39.543603,37.117359,154.002291,167.515514,100.411164,-5.068983,-22.266671,81.044212,149.579799,187.04117,193.227016,242.99352,228.291769,37.629993,-94.815763,-70.99035,13.543873,62.445972,189.078648,220.785056,145.75846,-19.060414,-63.466032,8.518445,87.424435,187.645084,197.627444,218.279373,246.048285,225.669092,101.299441,87.079378,162.652555,192.498785,189.846035,179.984009,196.299725,196.580976,176.811528,95.046426,35.679737,-19.442887,3.443143,65.950667,70.172241,-2.040853,-118.473403,-130.570467,-22.649101,55.02537,145.916017,135.80414,73.336899,84.450434,93.33812,65.67521,52.946448,85.58322,111.090068,98.804695,74.363636,36.864131,-7.989485,2.521795,127.838588,194.853371,232.778689,204.47067,134.541278,106.121582,92.195885,67.800502,71.707831,137.561273,186.431747,212.939466,166.049352,11.651234,-59.627841,-36.756438,67.681717,116.315525,133.414759,95.217948,31.502765,115.40207,187.54453,265.907581,267.037652,282.099754,282.185488,162.355213,76.400697,2.282282,45.435613,80.312167,162.396573,201.064413,249.319628,264.865327,278.068668,196.202696,168.181154,269.343334,320.77116,294.325595,263.593167,199.132625,158.524437,100.866206,108.118932,137.042415,184.99013,184.209832,187.287811,202.71291,197.727854,95.94598,31.419155,-7.654356,44.247802,218.424448,267.986677,201.607403,120.215813,-31.517529,-65.494831,-31.151647,68.928113,121.236271,210.130381,208.061769,98.63274,48.307848,66.970914,80.093982,75.709322,145.795067,185.438826,132.876645,90.218792,107.182425,133.368371,127.842707,151.678597,181.785454,185.344506,152.952833,107.781252,69.276899,47.948642,61.22618,88.675452,156.952724,178.510951,136.600144,90.0002,-6.569531,-12.538071,34.502707,95.620827,77.615069,4.501619,-31.384142,-121.607768,-189.036677,-166.850364,-39.922889,-4.573052,-27.709295,-45.076005,-82.020003,-110.638196,-161.085101,-149.465627,-115.795114,-39.563886,-0.096266,77.764534,99.466999,109.851935,75.809654,29.371246,-41.96237,-13.157512,173.923856,267.835195,296.104228,232.797985:81.599474,189.158156,283.278025,395.762052,368.898362,213.308279,138.435916,52.51483,17.428348,-15.419107,-126.74003,-167.811647,-116.285283,-30.235944,92.494753,81.843557,-14.26082,-73.093467,-51.482943,26.201477,32.680694,15.176101,16.895292,-28.717137,-171.793796,-230.640857,-223.017756,-163.306365,-65.551186,-65.750329,-146.975358,-194.544427,-237.160282,-177.400466,-122.409008,-46.759326,-22.367833,62.589237,99.919793,72.210571,-53.851786,-122.430047,-183.245128,-163.837966,-91.102835,-60.574123,-39.891468,-49.286044,-78.147306,-85.482559,-81.331404,-116.47751,-132.660565,-72.502861,-48.904826,-110.810253,-150.513084,-128.165807,-21.960668,27.214663,54.746514,66.654813,132.523979,143.301466,53.221001,-11.591122,25.888022,86.74815,39.325747,-116.917928,-154.996672,-155.769429,-209.516404,-256.184904,-256.012625,-198.228786,-61.906865,-20.192871,-45.16042,-106.302458,-218.847508,-180.571414,-106.086174,32.883672,74.727861,148.791273,154.558377,57.04593,48.59104,111.461983,218.44652,210.714508,120.607511,96.37645,116.950012,132.209323,119.969686,50.872749,59.478328,227.432218,309.70695,291.491266,209.862731,45.527493,-49.076972,-77.858435,-81.749604,-38.766655,126.537267,217.712273,288.932758,265.470078,207.825939,106.314756,37.372494,-21.76837,-3.616086,35.218744,26.539842,-55.818391,-154.656564,-174.863146,-117.862932,-58.989313,39.571495,77.790094,101.215229,66.244541,-38.278661,-127.238078,-147.521039,-106.768163,-71.538939,-23.405296,-15.253026,-62.198635,-154.371068,-173.505041,-132.048487,-114.237139,-88.273943,-41.844237,9.451232,-23.460305,-86.830557,-133.194096,-163.40398,-207.814054,-232.333485,-245.281294,-208.170088,-147.356112,-240.75432,-314.41871,-336.334329,-266.279093,-106.527925,-66.790055,-71.336359,-96.023072,-146.036531,-121.861364,-81.675921,-23.60353,-2.813572,72.615741,107.456658,94.979466,5.333882,-19.088723,14.746043,46.661622,84.180879,83.905751,47.266233,27.201735,33.543768,75.282256,62.041514,-71.589533,-125.417612,-77.09661,-26.801325,7.762984,48.320568,86.197571,155.158472,174.014811,213.660056,265.707855,411.250369,448.687826,357.027591,199.250058,169.773939,168.588084,171.027973,203.404662,235.080851,265.076386,224.29986,192.325522,153.836322,146.790448,93.166203,51.807714,16.451866,24.686994,16.715356,-48.799265,-72.160309,-71.03205,-57.515292,-26.300459,-1.138125,67.703113,51.609854,9.03863,-12.103417,18.156549,26.07503,-15.551883,-76.440413,-62.590057,-33.093991,-76.184008,-111.224735,-213.606839,-237.803454,-116.471675,-22.218476,37.82147,-115.1816,-220.89323,-238.150003,-126.137556,54.905738,44.389897,-23.153712,9.469015,157.056883,188.302881,159.019784,71.455736,23.314472,-24.09815,-14.385789,12.794502,-9.617354,-36.509698,-97.166048,-149.593652,-330.125387,-417.63337,-504.927767,-500.344122,-445.019437,-450.708479,-436.415174,-261.88344,-155.749138,-58.65369,-53.3856,17.566106,200.779386,252.734656,227.271783,198.776236,168.247108,154.213152,76.453027,0.565569,-136.152246,-118.348875,-79.064042,-51.466912,-52.470996,1.931054,44.95755,55.883116,-21.538101,-56.279709,-83.274999,-83.768131,-63.661575,-39.679949,-20.745247,-46.126087,-111.67709,-125.320562,-125.602542,-171.098772,-205.05874,-215.533241,-208.405564,-224.617633,-224.515435,-204.378499,-135.513564,-94.899201,-13.766694,11.126007,-47.569989,-104.917741,-122.372733,-43.709445,-19.557804,-28.739385,-33.946253,3.053331,36.018962,123.926172,159.440433,111.563311,-26.727379,-59.349779,-21.9677,28.150481,81.806015,67.025637,-7.579077,-92.651099,-98.232719,-19.884961,21.237463,56.251214,69.33519,113.294004,93.425286,62.169211,76.112366,121.565514,175.803191,182.592201,207.906537,211.266275,140.005797,43.859028,56.603484,212.874044,288.900239,308.919572,273.967354,240.949551,253.94297,223.332701,107.041399,79.733891,145.698658,211.284341,296.91377,281.408736,129.958616,8.896579,24.096428,98.369368,107.116635,120.702635,137.287,120.703375,41.217187,11.877341,33.040259,84.665579,193.503591,203.250581,96.582825,33.091597,24.725661,135.688133,188.476078,182.661967,133.945645,101.192074,114.331309,80.581978,24.966093,38.198652,121.870904,163.972481,198.412226,179.671312,62.124662,-2.401071,-47.771622,-72.409548,-84.641973,-77.046989,-84.350839,-147.403936,-163.142621,-127.404434,-149.08585,-191.468202,-174.773048,-107.435477,-29.007967,-22.77701,29.531802,64.384812:232.173272,195.158002,198.495743,283.938271,332.408841,358.480088,311.408102,121.415053,-60.695727,-122.516532,-154.901068,-130.828811,-53.525098,-11.574264,42.105185,35.386621,-70.403528,-159.371736,-123.551924,22.909051,70.277555,115.974509,123.10905,48.034381,-110.23411,-148.847544,-92.115178,-36.04613,68.974456,98.026011,25.181148,-48.969192,-133.836216,-148.696469,-125.08441,12.342217,101.662933,217.327993,208.902178,94.792111,-16.310473,-62.235295,-149.848681,-174.08427,-110.91826,-32.068014,85.51773,89.345041,16.901458,-10.187583,24.178135,71.909826,63.877115,37.128715,4.787482,-97.127614,-115.710262,-79.333228,32.619631,82.571677,149.767377,177.52904,191.99095,160.587944,22.078723,-120.125052,-119.693494,-50.514796,-48.424662,-69.043249,-79.460234,-158.196602,-271.333843,-302.906629,-254.042254,-175.860587,-9.184002,29.32772,-12.015011,-64.266505,-216.461189,-314.472905,-260.02023,-32.572655,56.029478,108.833531,77.22907,-66.597559,-163.656825,-134.612931,47.975225,141.712825,202.416987,169.515356,80.232988,52.280742,19.454625,-8.153055,10.171522,129.856585,185.938521,211.177388,180.941066,53.8617,-117.04313,-185.609523,-212.617505,-163.598735,5.499381,78.571496,75.071152,19.162283,-69.716438,-160.699859,-189.100819,-133.028038,-77.090499,-16.379278,-29.85737,-140.027205,-242.64904,-242.031297,-175.021154,-141.493853,-93.60437,-76.218841,-91.846664,-131.633308,-247.707432,-350.939919,-361.953671,-312.596751,-263.996401,-146.763002,-123.965733,-185.569742,-300.647379,-357.029894,-369.878326,-321.296402,-207.640449,-161.840624,-151.749274,-185.175766,-237.291272,-262.270286,-270.403659,-255.697302,-211.306285,-75.745998,-49.903078,-143.93671,-290.692372,-318.303218,-270.448996,-226.89967,-103.42698,-40.058567,-29.092404,-88.497852,-213.904358,-202.935601,-149.812116,-44.615414,-0.255724,115.917294,167.880328,161.333791,37.984887,-3.877991,0.919977,22.587032,79.800905,107.202812,78.151588,20.913876,-75.222994,-49.100554,-2.844651,60.861715,63.116786,45.588708,25.914553,-26.308614,-7.194615,43.883303,186.273955,238.259942,282.769575,317.506729,420.730986,435.863059,324.323072,183.284371,179.509188,265.793126,311.844616,326.222019,290.035051,237.293073,228.856716,213.577044,226.846913,252.87138,245.93287,218.19973,155.860983,119.724241,43.572358,-18.255141,-19.912314,18.643608,26.014995,18.845805,23.039469,48.667453,92.020403,122.517548,166.746382,165.87564,145.586517,138.934749,93.969905,53.156549,5.342636,1.842183,-20.582028,-64.422658,-19.815929,174.257126,234.438294,202.365462,15.809552,-98.068303,-142.377929,-47.154142,144.003879,166.760949,122.162552,115.558437,140.114746,147.576531,180.138584,239.092343,222.780954,140.254249,105.311117,84.424419,93.438367,88.540557,71.29379,47.572813,-51.528339,-92.388952,-123.775536,-141.946522,-214.840885,-294.852842,-292.318992,-146.996178,-43.513401,54.816112,31.592571,-20.553516,60.127843,123.65319,193.855599,165.530557,32.04338,-1.281795,41.271722,50.992379,-65.529874,-143.872651,-91.891882,69.675998,108.43191,86.961914,60.671268,-9.530246,-98.654437,-109.652405,-26.18388,32.228937,87.742778,87.627033,66.666274,48.577253,-18.430408,-96.928043,-108.112021,-104.79629,-103.986967,-98.191145,-103.954932,-119.03338,-99.529456,-91.82833,-65.995908,-20.878927,102.408739,130.16983,30.580361,-58.376044,-138.677382,-57.710951,16.870533,131.825246,147.468768,138.940476,139.889217,157.144508,121.953358,93.127878,97.206638,117.782413,124.943199,123.103866,135.037434,131.888468,65.045362,10.586437,44.641708,173.259224,210.84464,198.514297,173.780861,136.549904,41.478802,-16.415478,8.921948,92.628352,262.11617,297.516933,193.831376,80.609941,-99.184984,-90.883641,-27.063277,113.023978,166.992815,227.330714,211.569611,129.088838,125.684178,132.204162,116.079585,115.237156,175.307084,219.600013,231.897766,192.706214,79.725977,3.976846,4.533301,67.498183,118.8542,219.636319,226.025482,94.967488,-57.820907,-63.5804,16.815212,44.921554,101.991862,147.284977,146.811081,86.218286,-18.701957,16.180068,72.325592,126.038591,94.942933,-17.609607,-80.074676,-191.688012,-211.221658,-177.254737,-41.16527,42.663548,164.020459,166.498938,22.595997,-78.950961,-170.378424,-120.935888,-91.051148,-74.466792,-87.975367,-110.565401,-99.270019,-27.250251,-4.452493,-43.300732,-94.231389,-46.393238,126.822086,166.215972,108.07832,75.604811:79.455218,180.608859,243.822108,284.84246,255.650842,185.046539,181.763307,195.584413,134.545258,81.84484,38.748455,82.172874,201.956206,214.305353,159.031642,147.513888,168.279915,145.875648,130.727549,111.87856,97.958041,84.425749,71.567891,-25.022521,-74.294654,-55.324989,-39.616945,-70.970962,-120.953889,-100.189668,-58.543503,-68.872386,-97.333234,-105.83145,-111.384828,-108.993009,-76.329301,60.387785,97.901709,4.312175,-90.448828,-76.811447,-1.272944,9.029309,-60.539779,-88.811558,-83.931141,-94.599214,-165.288497,-174.195728,-152.476869,-139.447444,-140.77498,-98.535908,-68.891032,-49.991546,-29.987716,6.029376,88.66648,89.205595,33.285978,39.404566,130.681329,155.430143,78.910523,-19.663262,-11.705833,33.28412,25.512517,-8.448754,-15.940002,-30.158325,-67.082732,-96.346397,-137.307848,-132.141727,-87.925442,-72.548406,-92.779382,-111.610082,-111.587835,-63.338267,-27.806406,25.863057,35.695123,80.403685,109.505478,141.461812,256.480542,315.915797,338.166726,337.949963,339.015313,321.117778,309.155123,329.182885,309.18238,203.389666,195.683623,285.558991,329.238603,341.309106,316.366045,255.199647,180.814872,117.239488,27.59118,51.378653,143.518034,156.087515,152.783399,173.037968,190.614708,39.262057,-45.962357,-72.064258,-34.254855,41.439748,59.276054,20.328486,-57.44264,-66.898942,23.34283,91.127268,136.208672,117.161639,69.510055,44.502066,-1.651203,-60.58318,-102.364097,-160.391335,-164.064963,-145.8817,-138.760165,-122.761127,-96.112652,-89.81623,-63.509273,-39.326853,-1.210182,4.119123,-36.082501,-73.585026,-100.625111,-93.609635,-108.515842,-147.578917,-154.385575,-117.269895,-88.317862,-102.648915,-216.67596,-260.294379,-213.229614,-149.61371,-79.767673,-70.448406,-73.777231,-94.571325,-121.703013,-99.794956,-85.443948,-32.60331,4.187696,63.368482,86.101331,124.874667,53.183445,-21.655867,-71.553134,-36.735491,1.259763,-12.586693,-25.636671,-20.549141,-4.210948,21.549966,2.066805,-122.401358,-171.538725,-140.350963,-104.391643,-78.993472,1.419128,38.472196,35.121111,15.111929,-2.827759,33.752649,184.556636,228.683412,193.520548,136.518752,97.957895,-11.232728,-28.969545,24.514725,51.935115,105.163002,155.725637,145.417113,106.592182,95.856312,23.09354,-24.216875,-42.974986,-32.716906,-67.878093,-150.588651,-176.428117,-212.943523,-231.350344,-177.448355,-104.439844,-61.466697,-193.672133,-245.654051,-263.134654,-262.735182,-289.793434,-296.771952,-299.711785,-314.703181,-329.595075,-291.783696,-308.179129,-427.927741,-442.96584,-252.985457,-130.560978,-63.143,-214.149454,-307.856988,-369.252609,-326.831979,-229.368741,-202.5629,-132.253206,-78.480587,14.764888,95.491803,125.461393,71.187611,-10.444336,-134.415397,-127.35035,-3.612321,91.444506,74.201192,-47.203227,-128.227393,-307.765224,-372.155253,-405.43067,-401.558425,-384.528451,-364.466885,-361.003421,-296.002123,-227.826505,-109.274135,-79.830073,10.110367,185.166474,240.780184,222.303987,180.021515,127.97216,119.620413,57.394046,-0.685966,-119.598035,-215.255746,-250.346056,-301.083971,-283.292237,-101.284892,-9.834704,-13.071892,-164.525838,-228.643172,-277.924712,-269.400335,-223.384173,-202.01381,-182.470194,-175.665834,-194.035413,-258.560761,-261.945901,-244.12807,-241.151434,-193.418835,-168.730514,-214.689104,-322.803901,-348.573991,-291.033535,-231.584884,-179.920049,-200.069182,-230.403002,-205.817855,-128.474904,-139.696303,-145.68339,-96.841562,-79.607252,-87.27698,-86.445186,-30.93907,41.508462,34.222562,-34.06132,-60.228635,-98.778865,-96.308874,3.140978,79.340973,149.886596,34.996202,-21.103314,-24.993303,0.650716,50.797811,75.584517,132.426002,154.490428,127.002971,50.534473,50.14099,142.17836,196.703957,226.40046,203.005475,186.249092,226.806993,230.651705,192.458847,174.495947,184.96778,189.604546,142.924488,135.264677,152.336699,141.088819,106.367138,51.547218,64.508415,132.76811,150.787816,85.505645,-75.390495,-128.221985,-133.179771,-75.518994,139.821768,199.029388,58.756506,-99.152176,-71.721209,36.651596,27.723461,-43.800408,-35.892161,43.675,57.095785,21.772213,41.220863,63.376397,44.005525,24.019578,65.172043,91.793851,36.877868,-8.886528,31.817735,117.820098,96.855586,-7.380351,-28.296276,-49.404238,-93.922401,-191.285201,-203.676306,-194.447833,-204.81967,-225.221166,-223.618616,-195.565015,-151.632823,-192.520233,-216.628543,-126.988475,-45.399429,-2.587033,-27.65963,-38.106491,-14.893708:30.850738,109.857542,179.710659,291.527068,308.077669,290.942863,290.842776,281.729774,129.009935,19.389873,-66.25873,-14.891936,154.663887,206.845706,158.990508,103.322581,109.245129,166.169047,151.580855,98.452628,72.841086,24.009101,0.039954,-126.042903,-313.648568,-361.460534,-344.132654,-313.850416,-263.31433,-243.192416,-235.456325,-243.300835,-225.928203,-124.615735,-62.713616,-9.337022,-5.830857,34.479799,50.28652,4.779893,-105.760881,-161.818357,-186.598611,-148.164235,-85.487888,-89.14218,-146.309538,-182.787337,-267.137199,-353.385426,-335.291941,-197.36475,-141.253148,-73.959535,-66.298775,-139.992435,-188.576323,-174.645693,-125.396511,-112.004029,-106.246331,-80.909944,-10.00239,-13.824968,-73.13763,-68.861343,-31.335887,42.690295,43.456256,-18.470121,-73.494215,-192.280455,-190.479234,-172.808542,-232.96366,-290.342356,-323.523063,-283.306769,-200.99956,-182.358369,-133.848191,-86.675652,-68.612966,-11.313145,20.302263,73.274581,99.679082,151.966203,204.105298,228.141253,265.234413,278.385283,273.432999,243.490074,183.915409,201.173614,255.655441,149.445905,100.526833,143.475528,188.887143,240.24908,243.995918,211.955521,145.349864,84.037847,-36.325754,-34.605761,104.829207,186.096698,249.46865,232.882955,136.232816,-40.139423,-100.501041,-64.449063,-17.435665,31.342595,37.976321,14.672349,-68.064797,-123.424837,-153.054948,-108.838912,-16.302962,6.800037,13.942845,-0.259147,-48.54414,-158.231503,-203.676123,-180.859014,-146.058889,-109.217586,-102.340509,-94.990575,-55.665655,-16.4196,100.599692,145.944359,118.373812,73.86014,-2.891421,-43.233392,-118.510445,-164.533348,-189.584712,-244.212013,-250.937729,-210.651445,-199.131028,-246.622479,-276.775909,-254.853604,-171.107658,-132.968201,-80.896749,-60.256145,-95.018643,-154.828839,-190.708144,-76.024781,-37.572827,-52.675667,-57.23053,33.860925,94.045802,97.765694,-34.225568,-88.141944,-90.972854,-75.941982,-119.739149,-137.369838,-96.854183,-82.677225,-92.228335,-114.827916,-142.567544,-221.401866,-251.870625,-237.80512,-201.3462,-129.790425,-95.866631,-120.071378,-181.071619,-179.912225,-108.571508,-32.12579,158.84882,226.967194,206.406815,22.590063,-64.440841,-164.74022,-165.590316,-58.129508,13.476384,55.680708,-16.48707,-39.497306,9.682878,47.373446,-4.000691,-81.319091,-194.193967,-215.998875,-238.479103,-257.422669,-245.747387,-220.496256,-243.437314,-260.737613,-206.642283,-89.334994,-151.891467,-229.279446,-310.189913,-308.058224,-316.894851,-342.050634,-413.533482,-428.05014,-359.582488,-313.179361,-341.073752,-402.251501,-396.758826,-325.829418,-274.997342,-191.381766,-298.601371,-406.984649,-467.482803,-394.848951,-244.575639,-215.236435,-221.869024,-219.085261,-125.615704,-32.349833,-28.360566,-85.208083,-129.579733,-158.878385,-132.059042,-82.517608,-77.828656,-88.863242,-172.425425,-246.765043,-367.922385,-376.926162,-342.707756,-340.158262,-358.384909,-345.104524,-312.425839,-182.614524,-91.610187,65.667466,92.972584,115.349139,225.492699,265.964886,261.686515,228.489356,160.20566,161.425622,191.003094,162.116923,0.354609,-127.012985,-130.722771,-91.898088,-77.896566,-21.342631,34.152736,165.209336,174.117006,120.319695,18.454867,-10.488249,-12.394546,13.061638,23.321993,-21.435184,-180.155034,-264.951466,-234.609196,-130.204715,-113.040166,-138.159843,-164.101711,-211.94062,-203.162815,-200.859488,-156.18959,-79.280773,86.913944,102.920198,-32.22633,-114.512989,-152.191214,-100.275106,-77.916201,-7.843722,26.684764,34.602992,29.836617,88.364153,190.028481,183.144024,43.047624,-9.733808,24.849366,74.6357,144.58058,156.441018,84.060163,-57.611043,-65.568508,4.593765,19.665463,45.698636,81.717107,170.828312,227.543881,224.261497,170.765127,158.048961,198.908893,227.755577,272.517269,284.222817,237.396726,141.646703,142.552976,273.339739,340.077921,361.358224,334.405273,277.952598,233.604805,201.665481,129.912269,104.609536,64.263867,63.221228,125.99699,164.279625,181.204748,104.542677,77.365313,96.522376,113.684134,146.934508,158.429237,128.061489,80.861794,78.277257,109.737897,120.852015,117.04439,105.457647,56.569712,48.804475,133.816983,232.354221,242.988345,182.918605,137.34903,129.453578,159.234407,159.797411,121.176216,129.900643,138.001726,98.486495,-32.102557,-70.907309,-51.418551,-35.302314,-93.607698,-200.715393,-203.720559,-136.537102,-129.142416,-182.594619,-208.632744,-216.0034,-189.976131,-178.384333,-139.997859,-99.359315,37.39607,109.14446,139.614785,106.548986:201.777463,182.982626,207.24512,235.429501,213.838759,193.979111,204.934729,191.619005,117.25679,47.51625,-71.032323,-57.998951,83.795133,153.229163,154.918158,83.82863,-57.033497,-63.565384,-8.174595,117.360924,134.931234,121.847076,120.579545,75.497692,24.724854,25.599975,5.133705,-24.795257,-54.050855,-50.737588,-60.777777,-67.477522,-48.591528,-59.020591,-93.390113,-73.124127,15.189306,152.443614,146.25625,70.915938,25.221596,21.050475,-6.781766,-48.000832,-122.173779,-103.375118,-3.221258,3.422057,-101.480647,-203.272384,-194.534657,-123.686532,-93.291132,-7.781162,23.357157,1.757117,-31.287754,-23.859068,28.850101,54.528036,108.319129,160.752047,251.079384,230.98668,86.269551,-27.049876,-36.76399,-4.901992,1.613215,-9.595149,-12.749446,-16.671491,-100.074778,-163.135935,-179.44638,-129.801722,-62.788713,-63.382129,-98.073045,-122.75018,-176.077723,-206.469134,-169.585499,-42.992493,-5.963755,53.96924,84.573212,92.833748,109.231324,127.970289,144.617865,148.985773,185.175164,215.947355,265.716394,287.680545,293.738732,154.872173,103.417873,172.497786,235.617916,300.085002,304.292373,218.354605,2.980999,-94.62991,-141.419296,-100.03511,19.048343,85.84098,165.966433,148.759229,62.284837,-22.839531,-64.740634,-90.234637,-59.749691,61.252761,99.249125,41.027469,-46.875293,-67.209476,-67.065283,-50.853995,-47.059497,-61.819917,-76.073895,-88.326751,-149.38063,-172.487559,-152.217325,-118.190023,-136.263173,-189.198911,-191.02023,-176.79609,-211.346634,-241.751615,-226.741376,-178.554246,-140.936423,-159.588172,-194.904273,-200.122337,-184.992245,-202.92074,-230.259854,-241.57722,-211.107634,-133.369268,-121.78148,-187.273477,-268.473292,-290.124378,-306.489555,-304.311905,-247.056423,-197.342236,-172.942315,-209.915588,-265.663436,-240.734889,-221.153772,-163.389534,-106.061314,58.372442,143.057782,195.359698,13.015428,-82.757723,-88.087971,-24.534461,18.897334,-26.842849,-109.92195,-102.945665,-33.202022,-2.63308,-28.414575,-94.091541,-98.598814,-91.174097,-108.327387,-110.281054,-0.813081,31.908068,10.095764,-2.0188,18.22904,71.68665,250.573707,282.933618,153.495973,54.285272,52.895366,19.860162,-6.618076,30.437852,83.862436,145.976778,149.432034,151.291205,110.184489,58.201124,17.539228,50.509949,59.997491,5.123341,-125.111053,-188.390258,-175.938433,-119.509679,-106.559555,-63.885324,-29.660004,-29.484696,-100.233035,-134.666781,-177.056213,-186.883315,-213.944545,-220.041756,-191.362129,-169.619184,-167.347914,-292.546675,-366.395876,-356.584158,-256.846237,-24.454558,20.244251,-56.080444,-141.456306,-176.824388,-206.483192,-164.894557,-89.521886,-109.081398,-156.052182,-125.111942,-12.576015,45.73012,64.15301,103.724673,114.165842,86.308669,53.634836,14.300499,30.624372,23.001308,-49.169462,-83.825408,-143.900511,-185.671671,-258.164084,-275.315591,-287.661538,-317.703152,-310.765001,-205.631129,-140.659106,-59.414919,-44.295178,-14.413801,80.816955,131.989901,160.431282,132.639732,53.145193,37.735577,29.138199,-17.466796,-169.613447,-235.716918,-216.832179,-137.437536,-101.72212,-16.584535,16.837746,-14.704097,-114.898393,-138.012477,-91.218138,-48.116057,-14.020724,-31.975211,-96.737947,-116.574664,-108.72002,-126.266711,-154.104899,-180.910968,-151.953059,-52.978928,-54.006963,-178.607986,-225.074733,-205.262859,-165.73559,-155.091613,-137.95662,-121.899517,-134.623271,-178.034365,-223.077845,-170.260248,-132.541458,-48.134045,-34.131447,-56.777388,-36.292446,78.369185,136.629061,118.22974,-10.73964,-90.399999,-117.542456,-49.119638,75.328021,87.010114,65.552174,27.966023,13.440121,31.53295,61.794943,143.685142,169.185211,142.463798,109.365313,99.209074,93.607941,125.237989,214.315727,222.157434,148.92443,100.228745,56.707525,71.899107,87.62041,173.622178,229.557135,241.437529,205.040533,163.991232,175.89819,187.912988,173.94618,134.053418,83.423504,107.056814,172.496761,174.806718,100.83862,0.172962,-12.693004,50.934752,97.787974,195.137828,234.137688,198.920663,72.747659,45.349392,32.362012,4.351877,-31.783923,-4.369973,53.827884,55.482436,59.250345,58.554221,64.345689,117.797496,128.12067,96.377616,76.576625,41.498668,56.296508,92.343124,181.658539,217.007608,227.226349,194.376237,102.211719,69.231142,39.331071,-23.128646,-81.520546,-162.672469,-149.821742,-57.171384,-12.294753,44.072688,57.371044,31.400616,-9.285763,25.202516,127.34432,125.406834,51.262614,54.018179:forward
-140.52958,-187.807989,-186.306302,-144.993943,-114.677093,-99.374133,-118.552987,-150.668712,-208.582422,-249.575233,-249.483646,-180.527716,6.232288,55.11975,41.483255,18.1477,-22.550964,-18.542484,-11.982887,-37.419072,-55.926958,-98.595691,-127.992307,-193.753964,-251.162227,-251.03854,-177.522387,-142.041542,-147.793411,-176.156681,-238.002657,-266.594581,-288.318333,-245.069795,-237.247278,-271.114006,-291.104789,-344.323715,-384.557476,-424.335168,-313.323502,-224.324463,-145.646535,-178.412205,-231.876864,-215.253517,-202.154201,-243.103227,-355.041214,-368.851825,-333.083125,-246.213747,-228.038205,-232.70267,-214.988156,-157.602616,-213.541722,-258.018601,-264.857723,-213.919735,-61.733554,-10.821704,-14.937413,-39.779765,-71.65791,-28.906735,32.588428,163.046171,198.983346,186.493517,160.306916,111.583854,75.597181,91.937618,179.606633,216.04428,234.251784,216.258718,149.982606,116.513407,49.03707,50.266496,110.853396,256.022609,280.596633,221.185961,180.640047,117.466112,5.204948,-13.436021,158.040743,275.747635,355.714855,312.240467,193.98025,170.04386,171.327616,161.09598,141.630105,88.859738,73.641878,61.474254,60.935214,47.747349,-12.377396,-26.201998,-30.770265,-34.035014,28.255903,88.718571,160.364163,142.879112,62.243292,108.000942,171.515567,269.918313,307.430497,358.053282,346.130916,242.346495,199.062969,238.554832,324.904115,336.78341,330.648156,312.791449,228.70183,181.937023,125.48849,105.88766,83.205749,0.99521,-40.559712,-50.862421,-26.48009,-48.473327,-146.157856,-159.357423,-97.985986,-45.437036,45.721954,58.045818,20.224216,1.05574,-3.420435,46.826491,88.70995,124.714391,96.06537,9.082843,-7.384081,-24.271074,-64.255578,-48.03244,42.651352,72.987911,69.055514,32.365561,-87.81687,-132.362732,-112.832202,6.368874,59.295282,94.446564,71.682641,12.248115,11.381357,19.768263,-49.522938,-72.308922,-63.539245,-52.002005,-45.284891,-78.76452,-177.75045,-173.520548,-36.072344,57.021179,65.655086,143.553318,215.779419,283.727655,260.24759,184.374703,144.773162,154.048312,237.675674,291.371421,309.284822,252.136868,80.125615,-11.594719,-167.650933,-154.364227,-89.270178,27.38683,61.69335,22.902555,-54.348323,-195.525931,-192.35932,-127.239651,29.681347,72.218993,51.835838,12.83438,-31.251952,-34.351436,-39.889045,40.411584,110.348464,125.353859,53.836143,-58.406684,-62.329736,-94.397229,-133.854534,-82.14434,68.837406,101.527829,99.654751,72.064786,-42.512973,-91.666558,-126.371652,-76.569236,-12.978857,116.363356,128.671012,19.766789,-34.535922,-50.421339,-91.895979,-119.785316,-133.809016,-138.419844,-157.897574,-164.860131,-182.383074,-206.251135,-265.570062,-195.691483,-116.633398,-11.74117,8.516091,25.298819,22.876018,38.150396,94.252878,117.869842,118.766268,89.038085,24.389385,10.87729,16.149164,21.544617,19.243332,23.723912,32.687224,71.307751,104.117056,134.814055,115.931281,92.274725,117.462896,110.510822,73.967586,54.830577,-1.412096,-20.64969,-16.678839,-22.418786,-89.944438,-80.86172,-24.591602,36.763796,19.272455,3.934285,18.51708,10.944222,-3.261254,24.741122,110.15965,143.548181,165.664785,158.470592,161.958676,157.798114,52.107017,-31.399038,-21.004575,19.024413,26.831443,6.731468,-24.475785,-109.129189,-130.898334,-82.719101,54.372985,67.498597,-41.506866,-91.582577,-66.277167,-18.176503,41.758314,58.369551,63.251526,86.339972,120.92753,215.536692,245.93402,226.744452,185.191655,206.585293,285.807357,301.384058,246.95404,170.877871,30.133816,32.656551,130.360954,123.863844,80.67341,59.886709,99.833069,185.030572,197.673721,151.09079,33.369108,-7.01529,-29.638045,-44.410821,-123.013918,-185.087809,-253.796584,-218.20914,-87.362697,-50.315398,-95.142464,-220.13411,-238.320627,-242.48795,-269.887794,-287.75065,-217.020824,-184.968996,-177.279175,-199.912982,-233.40531,-232.841905,-256.560451,-292.127499,-322.764868,-197.952795,-132.074509,-111.052057,-127.3648,-136.978177,-122.684144,-92.947733,-100.330053,-75.510561,42.320268,85.753464,82.406535,52.758845,23.624343,38.554352,53.580864,10.468587,-5.075388,7.74201,28.12286,45.396462,21.951998,-99.523633,-257.270704,-316.634527,-366.566844,-363.9663,-332.225698,-302.422681,-225.34333,-208.511367,-228.264336,-146.064233,-59.440376,41.933771,26.115052,-46.581293,-54.299873,-35.972825,-99.029242,-127.543945,-56.539777,19.935919,103.505975,94.565992,51.361301,40.428899:-158.535158,-188.148372,-161.295245,-86.79405,-64.136873,-74.109439,-91.38579,-137.741388,-208.697361,-207.805713,-97.939699,-41.411879,-22.970652,-48.576222,-99.426926,-109.780888,-63.997724,38.366004,67.774559,57.6028,33.252917,-24.320819,-66.720976,-196.611548,-288.621858,-273.811724,-155.987607,-99.846585,-74.042516,-110.017187,-226.190927,-278.682579,-325.301988,-239.86786,-180.423851,-137.772374,-156.071508,-232.532756,-274.640181,-355.445948,-312.343235,-215.358254,-48.943396,-28.461074,-62.829388,-101.465709,-213.043781,-279.237649,-397.474747,-364.280343,-285.582143,-123.406535,-82.148697,-127.292694,-178.102095,-230.745687,-256.288353,-272.228548,-250.450382,-200.961809,-71.939001,-16.915479,72.430137,98.251126,67.60714,68.09846,113.944194,181.390231,173.425582,127.711811,114.898252,136.333883,246.974897,307.959756,364.743339,371.450666,393.384131,386.592386,253.427188,151.891621,31.58208,86.807131,155.123309,281.453457,314.191783,316.544949,281.710268,144.179934,109.253602,181.988337,352.534895,387.960081,373.597039,343.640258,260.028035,209.476946,135.066219,153.457965,176.527458,212.497597,212.639259,140.272768,85.220093,12.886642,1.526351,32.747262,167.623873,219.059923,220.191515,205.418883,188.887746,155.904249,69.83216,130.175314,193.056332,259.348149,254.474169,187.321428,159.226159,166.962734,179.284182,187.966356,225.214136,233.891947,218.90129,213.324682,193.895418,147.187034,31.669673,32.304553,43.282981,29.795668,14.525939,-46.747502,-94.012198,-214.965789,-250.995953,-196.431359,-66.077668,-42.503798,-49.510096,-24.554844,76.668776,72.068078,-56.425626,-80.534716,-39.051374,26.250535,27.6566,-33.287473,-74.223272,-109.658234,-75.053482,-36.318784,57.917766,101.300782,129.633398,92.588509,-39.024794,-102.836093,-166.47785,-91.908466,-27.129083,107.44351,161.768521,174.301155,143.721014,64.60042,1.839741,20.069537,97.439016,102.547108,43.100325,-9.19484,-126.657136,-144.069475,-14.973051,131.874277,124.694271,87.550527,125.546991,187.342833,166.156909,124.69285,168.531169,208.011952,278.326774,303.421491,307.667885,265.458679,98.635303,7.529683,-140.051841,-193.37094,-142.940295,74.434758,153.285606,65.515441,-69.064186,-261.140726,-217.031761,-154.637167,-73.86212,-53.929612,2.983359,17.471161,-76.067441,-168.539875,-254.526368,-86.687032,2.092966,42.680215,14.484935,-65.388296,-104.825257,-208.53716,-277.688352,-240.878419,-22.440307,89.847339,145.921031,87.491732,-74.582351,-133.596251,-181.818974,-107.106913,-16.027768,143.063184,139.49515,-1.176741,-65.066846,-120.914661,-163.837653,-159.645654,-68.320849,-32.233515,-35.145312,-51.892349,-127.209939,-193.001904,-264.671809,-184.795907,-153.21033,-148.235651,-138.442565,-106.338747,-93.239968,-80.062793,-64.063095,-17.153643,103.051752,130.78297,86.075846,27.867191,-51.601309,-47.094006,4.154638,47.532835,56.250556,84.540555,106.897584,98.14165,75.563344,83.331019,167.935236,208.624474,200.574281,148.268891,8.883853,-46.44051,-96.872195,-121.833006,-201.756296,-161.97529,-86.381193,22.536156,16.015576,-76.260886,-121.656709,-122.773385,12.169275,76.910746,157.324905,198.938176,244.780489,223.885798,148.817832,113.739469,42.975781,29.645194,44.319102,27.542282,-3.008541,-60.614414,-107.289253,-270.517188,-346.815576,-270.598434,36.958079,145.3767,96.770842,21.712032,-13.648402,-9.634293,-29.486102,75.653923,165.715415,251.992621,229.249247,174.352896,187.605365,238.744727,216.090508,202.342568,222.22374,238.226369,204.195848,138.417476,-7.604357,-47.928871,-13.644524,169.004024,239.460537,225.145237,184.688883,145.153026,134.654976,66.647787,-37.559962,-64.268076,-58.853955,-43.993674,-66.263846,-115.883895,-146.98214,-104.748246,-61.295243,-77.78771,-71.222377,-91.937017,-130.792536,-189.595399,-194.860579,-258.350596,-387.643419,-393.949615,-305.009346,-286.235449,-311.781092,-298.196357,-257.717469,-282.343553,-353.066631,-296.818393,-238.244937,-155.451861,-148.715669,-212.745573,-256.126104,-264.882754,-166.14689,-109.525786,-34.308579,-38.917977,-127.502942,-156.817007,-141.842268,-144.842281,-204.754099,-206.883879,-171.662305,-112.244473,-115.555133,-149.338882,-150.264054,-165.764844,-248.207966,-269.059633,-264.460257,-268.488682,-279.368226,-278.769559,-296.765213,-316.949395,-259.883073,-13.856613,73.102525,53.034599,8.097735,-47.112974,-66.207627,-134.572754,-198.258217,-170.666473,-10.871555,75.222859,158.752141,132.059816,31.234131,11.840876:-228.367303,-204.523671,-206.072551,-118.636004,-51.522103,-70.157358,-164.114201,-324.068986,-328.268871,-312.203025,-275.560621,-249.26508,-213.267473,-203.614275,-157.158164,-130.191678,-129.131851,-160.824134,-154.208082,-112.302871,-106.322555,-148.600605,-186.226932,-271.734271,-254.19599,-186.499842,-70.964298,-47.715674,-50.027058,-82.314848,-176.371712,-227.712413,-301.368051,-217.543927,-143.806054,-104.486987,-154.207451,-251.982462,-248.649412,-221.890457,-207.032491,-145.370844,43.557955,101.398521,53.05093,-28.586918,-168.708824,-217.339721,-313.389196,-304.707065,-241.929931,-90.464657,-56.580293,-139.248103,-207.93037,-252.55404,-188.132774,-162.791565,-152.301829,-140.665794,-71.331897,-16.522056,109.553559,133.898572,59.443484,69.560713,135.803498,236.27968,241.311097,208.133262,201.93569,196.061173,200.628999,255.813924,434.493459,484.220257,408.902072,332.132723,251.693863,228.294822,138.011096,160.417478,233.117903,340.831686,338.605289,257.221872,211.805315,155.616969,157.905477,191.379159,289.375654,324.12524,332.978652,326.166446,296.404699,236.245629,109.449242,167.990918,214.936244,233.957046,214.291559,128.333426,83.305082,58.111168,51.132533,44.940574,115.980807,198.263901,315.278823,301.413324,162.625956,86.752161,53.756884,176.567247,238.378177,258.982952,205.692416,45.278414,2.596829,55.793322,111.625534,107.455807,127.784026,145.648228,112.984179,67.230555,-9.098155,-25.541748,-31.016616,-55.682506,-54.888314,20.011278,41.909032,-44.398617,-118.535468,-203.082821,-184.839729,-163.53903,-73.906946,-0.104213,89.857637,71.555114,-31.718453,-76.632624,-81.64969,-9.177463,8.710354,20.304537,24.872626,-18.977209,-56.859304,-68.872144,-3.660594,25.554787,31.61328,23.136552,38.514129,50.827681,47.835994,23.328131,-48.164185,-42.686997,-6.687908,79.373266,87.277798,12.125911,-16.032308,-30.182903,-36.092432,-7.777759,112.039142,170.765006,162.446779,79.396633,-90.597167,-104.96075,13.816242,121.288789,115.45833,102.034124,130.250845,175.522299,176.190834,173.277981,194.662878,231.347475,315.167463,320.390624,252.09049,206.440395,99.835204,32.671833,-54.955327,5.087422,58.016935,97.317367,72.721935,-15.571282,-70.225559,-207.211508,-239.492691,-170.176028,12.483015,60.944945,34.970228,-11.484794,-76.276385,-101.034137,-142.101673,-39.871103,50.534843,117.24134,55.00931,-120.261466,-169.724377,-230.537398,-265.448799,-243.163445,-116.711891,-32.449229,92.860987,111.592954,65.661535,8.368296,-82.079818,20.03376,116.795834,193.741636,137.22227,-36.448433,-77.216994,-56.085064,-53.538544,-48.893596,46.618041,110.594314,152.660969,111.591261,-45.42112,-115.185925,-154.247672,-112.432092,-94.299597,-56.22423,-29.438732,-6.30146,-25.060303,-64.410367,19.05871,97.29902,179.022864,152.460473,20.479764,-35.729434,-43.9674,-10.982186,45.535912,85.30515,109.38088,204.413587,255.434831,217.360952,141.503625,63.077398,88.182491,99.397169,88.541187,53.523366,-55.168475,-88.855404,-75.565616,-59.11631,-60.899392,-68.820001,-62.703962,1.454231,37.903746,15.853754,-31.347648,-83.56555,48.473668,151.390591,268.851186,279.78545,245.073913,204.525076,166.341565,170.187732,97.756027,-30.956848,-50.688491,19.95694,65.459161,19.033527,-84.665537,-280.732954,-236.506588,-133.947463,48.627353,70.182993,-18.788075,-61.301773,-22.584315,14.297207,4.352857,-18.307877,8.361932,95.946301,109.770554,57.872668,42.015955,68.808354,76.628645,73.747093,97.38534,120.432342,110.218833,61.224111,-43.932982,-64.1486,-34.752618,65.638629,129.954892,216.310002,222.105866,169.864548,129.128739,27.441569,-114.075473,-155.404168,-116.092921,-66.926841,-58.752236,-118.589626,-204.130919,-185.529869,-121.933363,-45.367878,0.123877,1.327397,-55.128151,-168.570722,-188.596391,-219.059728,-255.463524,-245.330588,-185.342243,-165.659542,-193.415704,-224.548375,-251.695394,-245.986448,-217.514699,-184.513379,-176.441455,-176.803128,-180.350933,-174.109111,-168.562706,-183.486708,-159.559082,-123.584438,-66.829377,-43.187117,-31.60215,-66.335767,-163.164685,-187.914813,-148.508371,-77.567268,-71.309534,-72.73067,-70.151767,-106.637409,-130.169463,-121.165238,-114.166205,-142.212556,-232.756702,-269.581013,-292.524605,-272.794053,-215.275021,-221.446016,-253.489016,-121.464201,-13.792961,120.956749,123.547378,45.313563,-7.042885,-117.335082,-175.731753,-141.733815,-1.260905,44.759625,10.857069,-31.133652,-12.968095,30.289731:-211.404662,-315.165415,-346.962434,-293.401835,-223.99359,-186.814067,-237.981309,-316.268367,-335.005188,-352.981597,-314.978717,-250.426841,-164.815623,-170.45146,-236.102581,-270.062337,-269.798956,-175.293766,-129.145266,-88.617304,-80.507075,-86.411027,-116.966676,-199.914454,-226.181968,-198.454075,-93.110048,-60.971741,-128.026758,-207.785478,-296.486021,-293.139152,-312.989929,-335.279635,-305.006936,-206.821452,-180.559039,-220.163783,-258.322384,-292.51327,-269.687211,-226.088577,-120.035069,-105.134214,-154.740276,-183.534498,-218.141264,-251.653489,-381.623688,-433.783568,-384.463155,-231.981368,-190.567397,-220.898724,-255.968414,-299.406592,-304.509124,-287.738747,-235.593028,-204.762029,-123.312199,-72.960977,24.288906,38.422848,16.110503,73.735437,102.464347,110.34312,120.603125,131.220539,111.87184,90.600385,157.660404,201.865379,283.294616,319.385179,321.647548,281.938156,207.254143,183.92078,131.100431,184.55224,258.617941,322.601269,299.005974,257.365021,254.446291,221.204961,117.200641,86.335253,171.089512,256.102927,319.133731,275.6388,166.011645,131.592368,105.097107,142.067395,152.48566,125.509726,95.51053,21.34627,8.491492,50.049096,88.009748,103.808901,137.409423,130.561492,72.335311,58.823641,90.193886,109.731875,128.453912,139.21987,139.84957,131.232038,124.67233,110.151895,116.782421,190.496145,280.380085,303.627092,290.582491,267.282125,217.693669,192.460436,158.424211,143.162239,94.23173,46.664685,25.756894,18.136091,35.516228,36.587438,-1.596823,-102.007925,-110.437924,-75.442015,-19.8838,-15.939743,23.518446,79.484118,152.294752,126.731594,21.123997,-22.923383,-16.082214,44.549703,74.331517,30.165673,-22.288412,-31.614318,34.895588,34.529454,0.893928,6.838474,38.353955,34.720064,-10.26136,-46.082363,-106.88924,-89.43961,-58.068753,46.760076,97.122062,78.252085,30.8192,-9.934928,-22.21705,-32.598241,-2.298541,32.190273,38.517968,0.440377,-84.228794,-112.66373,-103.662878,11.012247,71.53899,156.437732,180.385679,208.290825,235.342074,294.355526,269.619837,243.041129,249.859289,293.209367,374.072543,365.966409,257.158093,186.320965,31.191383,-71.686559,-61.735445,35.977903,79.307021,79.612394,30.76199,-114.956548,-137.678096,-77.994249,-4.174244,-18.168552,-16.983178,12.978785,37.853312,14.624045,-20.588166,83.306664,146.892061,136.677314,77.21842,-6.86074,-23.81965,-95.009417,-159.032978,-115.272372,86.829396,152.007012,130.852229,89.776707,24.391425,6.808227,8.456625,92.506404,171.468519,303.656696,294.274558,128.453139,44.810418,-30.050806,-73.337782,-79.884042,-29.746195,1.833429,2.591403,-30.685887,-92.959845,-119.23742,-180.294165,-98.498357,-16.867907,59.77826,53.574535,-0.493702,-29.42319,-6.236936,92.869349,132.839931,115.849794,76.110639,58.134587,70.662594,69.418348,59.466955,35.673462,17.067041,22.576849,119.231925,198.512512,262.68151,231.756442,170.351315,145.454499,119.100693,27.199617,-26.316607,-87.035328,-97.298832,-126.759234,-130.375293,-85.252693,13.311682,62.895597,65.836366,33.699867,15.675578,24.384177,25.317146,59.370297,101.463853,210.175819,277.746185,378.487649,376.608129,334.622674,313.407353,180.931642,2.515042,-27.060974,59.859861,120.891242,96.664878,2.687794,-176.13907,-184.169251,-132.208448,-1.535581,28.42188,-31.442161,-69.372336,-26.972502,13.997383,-4.664405,-24.018111,1.639038,58.609479,91.161427,171.338221,188.330581,144.326106,92.366867,96.559275,125.449457,107.221505,1.303968,-48.93476,-97.340708,-97.752588,-46.966137,36.749829,48.229255,-3.793731,-22.222063,10.39324,26.415396,-8.455502,-108.471399,-147.329648,-159.093182,-145.441137,-156.594683,-198.617597,-235.469682,-204.578662,-160.053609,-167.948977,-176.027733,-188.376188,-187.512188,-177.341551,-157.493358,-145.671975,-230.809487,-229.79616,-140.322988,-127.180608,-152.227175,-149.922998,-154.266157,-186.943951,-268.048218,-223.594887,-154.635307,-62.164798,-79.715784,-180.696417,-189.740473,-95.845146,-57.161141,-54.564134,25.52058,77.65444,80.798651,34.778647,-52.515395,-86.872789,-138.301108,-80.918012,-29.425132,31.291624,54.669146,77.498499,60.595847,7.879379,-75.470735,-125.001861,-173.089169,-172.413943,-164.695644,-154.841216,-96.017141,-52.783147,5.026576,51.390594,97.34657,179.59742,175.533804,76.489263,19.992522,-33.23036,-6.107924,17.52249,40.650683,53.680745,105.617243,120.43786,99.815075,75.819494:-185.327344,-263.984323,-310.898435,-276.802872,-214.747411,-186.246733,-240.248776,-360.146806,-374.705841,-360.617376,-356.674167,-350.430439,-271.250518,-214.96925,-185.633357,-239.97377,-358.371606,-286.784928,-223.102743,-139.847441,-117.77133,-127.187876,-155.19239,-223.486112,-212.495256,-170.627599,-111.699222,-101.492759,-138.578577,-195.235426,-291.513632,-310.629282,-326.116623,-299.976291,-258.028384,-143.044659,-104.92004,-109.519417,-137.046208,-205.180651,-215.469533,-170.53164,-39.414014,9.089417,1.677269,-57.398877,-195.032533,-251.866804,-314.817659,-228.925666,-143.205039,-5.914161,-14.188651,-189.5764,-269.304718,-278.575467,-194.76426,-153.336312,-95.756228,-84.91672,-74.411036,-55.293409,17.900828,52.926191,89.341792,99.826487,110.785409,183.299788,225.008925,186.365819,123.588494,62.495858,152.290813,233.949544,350.381605,379.421891,390.692148,353.93064,204.389587,119.960557,37.859497,125.526882,179.861785,211.900546,195.673347,168.571567,177.110908,177.701176,133.678066,139.200163,224.131793,286.272377,360.275636,329.103462,193.914125,144.284091,117.929145,153.966393,174.910342,211.355746,202.132944,94.063155,34.294546,-8.252882,36.2104,69.086569,129.484352,162.913912,224.281226,214.253282,103.995835,62.046833,91.003654,134.754954,129.421532,107.755711,89.474132,52.380347,42.127769,31.534522,88.255701,134.024307,185.626229,184.335322,148.714661,129.975298,119.174751,113.689479,73.490888,31.866456,15.231086,-7.290593,-8.104547,-0.797426,-6.791911,-49.380832,-63.279679,-51.704187,-29.305317,-8.398885,73.17877,120.708475,151.369722,102.11553,-34.295314,2.003658,53.342878,81.786401,77.168207,84.96853,81.406516,15.193091,-44.672102,-32.392996,13.567883,25.849958,31.222701,16.586028,-56.135004,-104.24691,-142.662521,-55.884125,-4.14446,86.948017,102.822156,25.54397,-25.198103,-90.159269,-58.590535,12.536927,130.162039,140.917855,83.829993,5.835869,-145.677052,-160.132831,-83.263901,71.559953,129.810849,174.17918,185.13846,193.532516,185.680935,161.742089,167.06425,201.423634,336.270364,399.021061,392.223721,321.42956,187.695066,150.542165,76.897103,46.066698,55.43607,95.641917,117.577749,109.19994,71.886638,-36.941311,-111.0455,-83.829673,76.66958,133.046731,97.405766,40.236022,-19.655244,-21.708249,-31.575973,40.256649,105.49437,162.222539,139.628062,55.580241,15.270028,-76.588513,-138.421173,-98.243696,69.803075,122.24412,133.788129,124.68106,77.58358,32.877713,32.668766,248.972278,366.522948,488.03621,471.610629,297.230893,204.389711,112.515519,39.927173,24.097919,109.332302,181.590333,226.567928,167.83816,2.885133,-54.115973,-108.259519,-61.734499,-10.481811,89.910412,109.946781,11.556484,-70.293607,-116.081199,-13.585458,48.585316,101.939019,83.532477,31.440518,21.48392,14.182273,-3.164451,-31.021514,45.758058,111.638147,219.289804,254.839644,284.740623,264.5239,158.573521,95.226467,96.224832,82.826794,59.733523,11.176435,-12.311257,-74.036769,-103.738449,-80.496596,23.111398,55.884574,97.086022,115.787191,116.224847,101.610662,76.719513,79.335489,106.041197,199.883489,263.17827,339.99271,309.861524,217.837115,198.967186,134.976416,33.970176,13.161108,58.389049,81.833176,-19.835548,-134.089541,-299.320261,-210.063424,-106.00151,35.719533,61.387915,56.894851,15.940079,-75.949604,-87.577709,-79.839429,-80.849958,-75.704898,-10.035447,43.427695,88.795797,66.391338,-8.946466,-40.429353,-28.649576,26.352244,51.155418,39.587255,3.081808,-75.473016,-106.528946,-110.408141,6.521913,58.480255,70.172103,62.211913,59.261325,49.028539,-18.359799,-109.970129,-127.178968,-102.146104,-83.086689,-87.120392,-115.153344,-126.636108,-98.275371,-78.648522,-116.751193,-122.081206,-74.993687,-47.782632,-102.198164,-179.51691,-308.387349,-289.904275,-220.405648,-66.439855,-24.294281,-33.655603,-73.317825,-157.916914,-185.352156,-222.590547,-247.896981,-226.422486,-99.921531,-45.685747,-44.123943,-71.238595,-111.424291,-147.223388,-151.922243,-90.74727,-38.895234,14.909667,-4.333914,-106.834053,-171.914232,-226.433527,-68.09652,24.547576,97.32629,105.328146,92.574294,51.727026,-65.372215,-156.08989,-179.370145,-146.468722,-97.162198,-18.44155,-1.117992,23.023514,19.632866,-32.758527,-9.25006,58.662612,189.268339,204.654159,142.80786,83.596934,-49.029298,-114.604576,-100.675215,0.123475,56.575565,122.134337,136.789429,119.280872,68.142144:-177.12877,-252.12732,-256.970487,-173.335391,-103.653117,1.827105,-0.506629,-136.405973,-254.547936,-241.259765,-146.26068,-112.084089,-78.547096,-73.80638,-64.463109,-47.698878,-64.981863,-165.120138,-173.863772,-49.184748,16.134141,-53.595977,-158.543998,-265.521733,-257.494313,-261.066098,-229.350068,-177.695637,-103.340278,-131.256669,-274.273297,-325.079815,-337.644111,-272.36745,-231.229421,-208.031608,-241.260642,-370.279484,-427.808729,-414.917721,-271.171561,-218.016409,-202.66881,-219.394473,-246.439852,-254.005572,-239.926536,-227.10682,-276.535429,-352.784471,-339.596241,-246.463967,-233.044352,-324.10439,-359.076076,-288.67137,-234.332621,-269.04435,-316.284088,-286.999814,-200.210802,-166.582258,-89.453228,-61.62005,-89.981326,-65.907608,7.341182,155.982527,195.28484,180.958652,131.90525,7.857301,-8.111237,53.244337,173.646087,178.332733,129.930073,120.131653,107.486971,75.790112,14.375685,123.158219,228.742328,356.038688,328.057619,159.398188,93.327549,74.196021,80.155378,91.478662,200.536393,256.326109,259.902289,220.0859,175.706197,196.835163,214.236075,127.813195,92.682217,95.132629,107.737925,55.674746,4.650288,-80.945883,-133.034459,-112.859875,-12.132351,11.059789,-19.322646,-37.620844,-2.105832,43.372333,80.160808,76.101019,88.442462,122.276207,164.438297,275.141123,298.177016,274.222464,288.790391,332.975393,402.531376,385.634712,263.279315,202.185949,154.775191,156.96604,142.47196,64.744227,3.927818,-53.533048,-11.543458,77.375266,62.611346,-31.197563,-56.787097,-40.101583,-31.036463,-32.217036,-9.522459,-11.844057,-38.9879,-24.280287,24.204885,11.123025,-5.055397,-31.745762,-33.493619,21.598742,54.732634,27.492536,-73.462759,-84.131964,-9.050111,27.28231,53.579895,62.491602,61.579038,13.870399,-142.546611,-121.085027,-23.270374,160.399647,164.724863,-13.972539,-104.49177,-154.639769,-185.154814,-201.89914,-137.280438,-79.086536,-51.60962,-87.126201,-126.335029,-105.642519,-45.74191,14.048444,66.766573,210.423338,248.190249,183.806166,150.644964,198.745416,226.188959,239.230303,303.732636,299.876036,197.918914,145.394467,79.520541,50.929913,-29.917358,-104.469296,-101.226234,-44.03716,-24.185256,-15.698612,-16.174346,-24.841306,-7.753561,28.066519,137.872869,196.346567,231.365465,184.318457,62.077293,34.410224,74.209831,237.030957,291.238815,221.048806,156.663443,111.695765,99.073639,23.884336,24.97157,72.387159,142.688103,150.633505,163.281128,153.43956,54.828137,5.039845,5.288291,57.236153,77.517382,196.907391,265.986677,204.436642,110.481459,31.123817,-20.164418,-72.303002,-115.423051,-98.523346,-58.285866,-36.927812,-5.447103,-37.2904,-182.499865,-175.315391,-95.776497,21.305642,35.694801,57.867512,71.039233,61.449242,58.355258,92.436482,134.627925,94.866135,-9.406459,-11.762984,41.132033,51.505552,40.953703,37.802821,41.371305,64.635315,81.47748,104.260159,118.755048,175.288529,142.991383,70.434823,-53.479321,-66.782798,-45.57499,-51.882782,-47.502781,8.588177,140.119177,142.182953,112.014652,69.336523,55.628454,16.687312,7.23329,30.282799,42.225303,44.892743,79.731641,112.205424,191.840811,224.596175,222.740839,182.649818,111.476632,107.336693,93.124563,66.818616,77.27037,43.539483,-36.745565,-214.761682,-163.535496,-51.724074,41.738039,-36.622251,-195.895199,-181.74032,-54.055536,-26.31508,-44.232993,24.161245,59.267784,46.370024,28.933235,24.941602,48.718136,114.220558,131.435648,147.962955,178.019044,169.578618,115.978726,61.632918,-74.995902,-98.806717,-14.477417,36.31517,21.812452,34.056895,43.835741,-12.042771,-31.419346,-8.243067,-41.331437,-73.610603,-128.747973,-146.880095,-155.719941,-171.739122,-225.068899,-214.95924,-139.702656,-138.285268,-161.295316,-151.249445,-118.064087,-121.924783,-158.426927,-171.649928,-101.488884,-73.747428,-52.836013,-44.854383,-15.202878,-8.161496,-54.326132,-105.192868,-199.313679,-147.2196,-75.256011,20.15257,22.879859,-19.824548,-26.634199,7.746426,17.624572,14.796392,16.306079,40.099384,117.917157,121.62374,90.307369,84.553555,39.019554,-7.968457,-5.262219,45.825233,90.294177,156.293512,150.802483,22.601817,-170.041284,-219.828046,-207.543629,-161.462334,-61.712078,-47.020828,-44.727951,-24.726318,10.847731,34.574388,58.590804,74.085728,43.718629,-39.802577,-49.731526,-1.20008,30.051371,31.389677,-4.089066,-23.788088,22.789816,66.702023,84.264966,65.125107:-270.993248,-292.699472,-292.436466,-249.032211,-194.562005,-125.588213,-167.565308,-331.454172,-375.354272,-338.257443,-226.604267,-182.939687,-175.201626,-203.923083,-224.261831,-210.789931,-237.334562,-254.871167,-206.974433,-63.557439,-24.562714,-95.596899,-167.395924,-256.167963,-297.177917,-298.25924,-262.58578,-232.554919,-178.817054,-188.001807,-264.97784,-290.413618,-273.921247,-200.682206,-175.680031,-223.511401,-276.193145,-306.618534,-279.873872,-242.755804,-190.740053,-126.37374,-15.925224,-6.819902,-67.741066,-121.295093,-222.124422,-253.253962,-261.98096,-235.243492,-228.093798,-226.24538,-237.880271,-269.769993,-258.13258,-205.328893,-241.36867,-251.971117,-157.270772,-99.820399,-69.251245,-68.294928,-50.928008,-63.040627,-100.047996,0.06505,73.986805,148.550896,149.143907,90.999604,45.942506,-19.147954,-1.684381,53.027181,178.701439,223.974801,256.919257,241.267237,179.084829,133.852167,58.722219,133.132241,207.738395,335.827788,352.974923,226.014979,140.88887,70.63703,34.15381,34.127709,136.188457,201.913788,260.102333,259.685481,245.923882,220.403727,129.766345,129.805274,164.847018,183.073683,151.875067,28.011922,-40.247507,-95.343578,-13.200726,53.172833,127.462212,104.97959,-30.211619,-76.021736,2.782975,66.83358,66.455814,28.934885,42.549613,81.030626,84.177014,52.458008,36.63649,72.488676,237.088141,313.944284,295.898015,230.8622,179.523631,189.180513,173.734331,140.697993,71.761322,64.728968,67.902869,48.021753,50.416272,89.05688,86.347092,14.698001,-36.915536,-34.554494,-3.389185,11.29945,33.929333,28.871904,-31.152794,-50.801887,1.813428,82.072129,81.665147,46.361022,34.660123,-8.021077,-32.92179,-55.724699,-13.502234,33.066995,64.425407,30.627989,-37.874149,-42.892642,-68.518103,-123.930105,-182.309797,-29.055714,47.011471,75.236358,45.738778,-58.360006,-113.750214,-179.404871,-165.863673,-119.90936,25.604423,76.831647,26.063147,-51.868508,-140.237243,-123.716511,-35.644832,52.995158,91.818504,136.824999,137.427678,150.213969,176.815382,204.245544,211.108952,250.380692,358.735373,381.443265,319.284873,256.072261,164.022298,140.213304,89.100283,56.02586,63.051889,113.08959,124.582468,68.804649,37.135889,30.560619,66.044612,103.358991,215.364938,264.728199,283.216498,256.961845,191.527654,162.753933,130.855404,186.754418,232.283104,279.084213,266.135776,155.118446,82.702049,-6.676803,4.198711,43.382571,159.497903,198.954368,150.965785,82.877928,-2.127953,5.395513,99.612736,247.955786,327.596877,456.049793,469.618633,321.054189,197.571319,35.620758,-1.464157,-3.875571,18.074281,42.034899,31.378643,-25.397545,-142.504744,-166.402731,-143.622909,-29.915966,33.755762,73.62332,41.909257,-45.090556,-68.209554,-66.602403,-9.31447,53.228067,168.8371,167.12237,21.336066,-72.675351,-141.210507,-98.243566,24.554655,63.518783,73.991621,143.158484,178.096484,186.460012,175.563897,148.819429,92.300341,72.446066,85.354669,81.403719,-11.364844,-63.641945,-136.46838,-162.486733,-128.013009,-12.298709,27.580466,49.813487,34.990504,-15.545267,-30.7348,-30.314787,-0.839455,30.433034,122.143849,173.577243,252.253075,253.305593,153.539741,73.918547,-43.73464,-46.754829,-34.699592,-22.822405,-26.979792,-98.293204,-178.94362,-323.852084,-295.361462,-229.146202,-108.237516,-94.066619,-123.929295,-139.389478,-184.539145,-209.746898,-198.883678,-109.171515,-81.774693,-87.041089,-79.753511,-1.222375,37.468758,50.743886,55.650752,89.055745,161.442653,175.823328,142.557254,85.347794,-47.471479,-77.856895,-45.576714,43.737001,74.35846,67.116892,41.475982,-11.413842,-36.674799,-105.629173,-158.879853,-145.79033,-96.547747,-95.014375,-130.972354,-154.261956,-154.01209,-122.402684,-51.101615,-18.983737,-34.791214,-89.348318,-89.141884,-75.906698,-98.817303,-153.129304,-100.143842,-41.506905,30.43112,29.891695,-5.260535,-39.517097,-120.09699,-140.267631,-144.649165,-126.883234,-85.234192,28.265431,38.708947,-40.931052,-66.440874,-69.146541,-62.153522,-31.394596,43.91497,62.670914,85.925738,86.918635,24.371589,-31.477514,-136.188067,-143.976266,-98.735917,27.968859,75.621153,84.097617,37.334051,-87.71197,-117.77688,-104.694853,-72.843686,-34.005385,62.288203,54.402236,-69.228216,-108.842794,-76.608932,16.322135,70.978899,147.739235,128.013238,-12.830955,-74.950558,-120.997864,-102.234873,-64.067126,18.162083,39.75261,63.352556,50.243818,-23.355795,-42.726881:21.961164,-48.559143,-61.074271,-72.258415,-64.006021,13.607693,56.471793,75.755869,58.341302,69.908589,122.282626,152.203777,200.247873,202.13231,192.369328,186.623156,95.205184,-39.463766,-62.634657,8.264509,84.396213,165.819275,136.134497,26.802586,-125.416638,-215.983416,-284.311621,-245.447226,-180.314935,-191.742641,-205.95619,-192.406561,-174.788395,-119.199989,-86.541112,-150.730167,-247.326965,-390.768515,-392.885788,-332.825713,-258.024629,-200.886244,-84.063577,-47.997269,-20.799872,-29.944958,-79.998548,-103.574281,-149.899878,-145.092051,-120.25795,-120.067707,-138.673204,-126.74056,-86.991138,-6.10185,-42.715267,-87.186414,-149.710909,-160.137942,-123.654585,-87.86265,18.527846,81.98221,97.590013,22.513767,35.467117,134.188197,164.366725,126.91393,85.802806,57.36579,65.940728,54.065489,20.815182,10.897416,-1.391772,-3.561753,20.336725,31.970769,-7.450597,-0.505239,73.252324,237.331534,251.929194,130.27296,51.147658,-49.030725,-95.467829,-72.613806,50.234145,80.469253,62.190026,54.03625,59.823469,74.923188,75.864677,-75.608599,-146.303151,-64.769115,44.246227,102.022496,32.5815,-133.214003,-220.13907,-212.842213,-140.915316,-128.754056,-162.400891,-155.842457,-67.285948,-26.443353,-23.277889,-57.114825,-39.27988,89.22713,173.579898,282.421084,288.233682,248.822921,253.757955,280.044971,270.455613,201.257237,24.341135,-19.427146,-8.804416,2.646833,-28.157045,-106.721791,-143.7284,-171.964255,-145.06976,-28.548828,26.408693,87.651335,85.99762,55.933843,-49.978656,-89.777737,-76.140122,-53.248264,-55.771812,-65.296791,-69.728441,-70.453408,-71.097467,-87.314844,-92.409642,-71.68535,-62.227801,-56.689402,-29.749953,1.577813,69.401228,84.150965,95.92035,99.267551,73.897974,26.510446,-136.546558,-183.563079,-124.192773,0.729778,-4.757854,-129.599614,-175.739929,-177.344019,-150.370709,-131.505176,-93.923792,-93.214009,-125.869496,-157.653372,-236.105569,-244.048447,-121.280357,85.372322,150.898863,169.206297,145.603447,96.607313,94.490426,141.07801,148.743825,122.621092,44.440038,2.377957,-83.745411,-119.957813,-118.478471,-101.50403,-151.121073,-141.095552,-69.464411,14.235598,2.109774,-27.407779,-33.209881,-50.864122,-18.893852,39.655725,161.520308,188.84841,181.073435,152.339504,87.982202,85.098472,155.729886,273.171488,302.415927,255.886181,208.262249,103.087562,64.563602,93.633218,205.459117,237.841735,231.805937,236.161857,236.402878,172.902812,35.71337,42.893425,113.117386,73.614048,53.299879,148.111554,222.028767,152.222312,26.654085,-86.631015,13.620093,67.724651,98.994164,64.20491,-48.761072,-72.24477,-33.162642,-5.692091,28.842366,35.202976,46.957911,131.629791,184.357158,217.848709,189.138589,142.547125,193.137194,214.030758,172.883295,123.887703,36.190031,7.101298,-11.013482,2.245088,6.735896,-33.377714,-33.605715,-14.604019,-15.649678,-38.399207,-44.758858,-22.137541,-46.08909,-68.554475,-37.790077,-8.150228,-4.342293,-5.539218,72.076832,133.621547,182.971369,133.183197,101.16987,26.839688,-1.726549,-30.298956,-48.696684,-75.799661,0.590764,87.119238,208.479175,198.157757,175.905841,197.069575,191.723053,144.378592,24.037151,-25.058778,1.934962,59.627624,38.596017,-45.100665,-67.135277,-93.807273,-80.1151,-32.705198,37.211059,9.333575,-75.449587,-69.672406,20.442486,62.972734,97.42892,122.298599,134.60343,77.391667,27.854426,30.550363,80.812796,134.31306,130.941548,172.152305,285.954865,299.27128,228.687661,165.16355,62.521922,60.307579,104.737012,53.984532,-22.024105,-109.164837,-70.244023,42.225446,60.383487,22.898929,-52.655187,-71.546171,-84.000177,-106.004989,-149.368002,-151.181735,-135.12012,-119.389515,-74.566276,-98.190197,-148.535013,-159.239616,-91.880855,45.410259,85.786272,115.293032,18.888722,-27.873208,22.671078,65.508385,39.868045,5.364148,-9.777002,-6.203767,-37.805318,-16.582211,27.781662,36.486554,-17.107521,-107.166646,-87.470723,23.757221,40.180766,20.9903,-2.057126,15.284576,101.151683,121.903215,107.19596,100.388436,56.258106,-26.326776,-34.957704,8.782094,33.128324,44.239698,32.09263,16.907457,5.998407,-26.502039,-132.472258,-151.107742,-59.36667,-10.217392,-39.393464,-74.424239,-59.011528,31.549866,61.031888,-13.919235,-102.345699,-164.66378,-89.696214,132.365234,218.848854,197.643132,126.518352,109.013058,105.336245,104.351337,107.341819,106.669701:5.924861,-120.556262,-146.161457,-98.398098,-57.88729,-13.919818,-24.323717,-90.590034,-175.919927,-192.713809,-105.478656,-9.691839,192.317754,245.023036,219.230919,170.40531,27.513872,-91.292696,-82.800361,28.586745,71.239341,43.798178,-8.018771,-113.863226,-222.125078,-259.415959,-242.090355,-204.665462,-144.724409,-143.150633,-217.652673,-258.721518,-241.832074,-154.126727,-155.400082,-262.322909,-304.556653,-318.504279,-336.720067,-398.017211,-374.582084,-343.514146,-267.500669,-220.40575,-146.879271,-142.686094,-230.125395,-299.727539,-362.468732,-307.223518,-271.32249,-236.405866,-251.598507,-270.851184,-227.326962,-81.650422,-54.384931,-108.4931,-260.962764,-292.346448,-174.736181,-82.721606,-32.590016,-53.755719,-48.057114,-36.442892,-38.440034,26.894704,85.566328,116.641416,79.695513,13.81671,2.360493,18.384751,99.248915,129.620111,113.643962,96.559866,99.179593,89.755213,-34.955714,-89.028037,5.286744,237.727126,268.119999,183.039532,132.773848,49.329916,-54.283599,-59.447356,54.719917,105.693076,111.515258,84.98865,78.707613,105.917519,70.485488,-25.320095,-21.097575,56.506895,92.092125,80.622772,35.365562,-21.956203,-38.342797,-63.236465,-103.520859,-108.568551,-109.846148,-89.01262,19.449389,63.666358,48.664143,33.517384,79.600522,248.07425,339.386328,463.496608,471.797933,373.222841,262.846393,252.170136,293.12412,293.275896,204.165386,162.092486,149.694796,136.931888,62.389681,21.294575,-14.293523,-133.726851,-161.453059,-92.409805,-52.110658,-91.078662,-177.025329,-181.429323,-122.735362,-78.092368,-5.690817,0.445268,-33.936854,-51.262749,-82.749119,-105.022988,-96.460152,-62.881358,-53.991436,-44.9992,-20.012652,41.958464,0.536963,-4.742497,89.023482,105.630763,12.532918,-27.24959,-52.398376,-81.562278,-154.424094,-89.886482,-27.286807,37.198076,25.310508,-75.856787,-123.867545,-102.725413,-60.990607,-96.018431,-201.17301,-219.059972,-189.470042,-160.29789,-68.027605,-29.134694,-21.661785,-26.691259,1.335489,122.788461,168.445605,116.687151,43.487317,-60.259813,-32.710481,30.119237,141.482062,140.600277,49.806035,0.568551,-80.874851,-115.234494,-141.157473,-99.159535,-55.69024,28.73178,40.46047,-12.420212,-47.877065,-72.321767,3.602995,91.170216,226.084558,221.257027,158.664682,133.820975,92.898441,89.186156,125.301607,227.915793,275.297097,233.769956,164.336075,31.180548,-18.161485,-54.640151,0.220764,49.088313,150.549892,189.841775,169.278363,96.260004,-43.742331,-70.935086,-80.681573,-44.886382,-9.83317,82.637925,113.799584,70.039366,34.967582,13.89924,-61.792644,-91.772852,-58.340295,-61.382803,-168.245242,-194.570602,-136.105646,-113.072881,-124.137519,-65.751946,-0.943394,116.550509,159.01657,176.96086,142.855002,87.808414,149.081065,191.971248,174.60569,121.690836,53.893717,43.977256,37.903887,34.77303,-17.729266,-87.124879,-99.940106,-82.316692,-60.290016,12.434399,61.015267,109.634201,35.674212,-2.040433,8.676079,39.650898,87.285442,102.044662,123.845266,118.086023,82.225895,115.187859,135.607407,98.72032,61.197458,43.452717,65.938263,84.451361,-4.155976,-45.784225,-11.067211,71.273395,270.144403,314.000417,211.66629,105.026196,-69.017999,-63.172399,-16.414208,32.211635,26.318398,2.436435,-14.285763,-51.844719,-26.328736,22.041653,69.207193,26.191711,-72.816684,-79.385237,-45.473007,-18.894781,68.086466,116.819408,84.89116,15.899133,41.290642,136.971087,145.588797,81.819572,43.457044,87.562731,233.494014,273.085543,266.83178,239.941297,171.080359,144.265473,125.459881,130.583572,120.365909,68.754414,47.695067,60.141321,105.799345,175.599768,45.312751,-48.096277,-146.284078,-153.572657,-142.964054,-159.629496,-230.660308,-221.998492,-82.297432,14.46695,-3.881207,-103.112723,-131.368025,-135.0209,-134.805921,-115.904463,-87.536158,-81.680112,-45.805656,-19.983882,9.885135,1.470129,-85.161738,-136.675509,-172.470825,-116.035094,-79.563809,-57.324543,-58.420159,-20.63167,15.942441,64.003404,39.280447,50.224713,139.806866,166.224228,159.705963,159.747461,199.196811,221.628407,189.485073,146.559458,166.896153,171.822346,146.295897,165.119509,198.041577,131.396383,-98.063889,-169.055647,-137.805124,-87.000609,-75.951102,-111.718946,-113.791188,-72.724699,-15.823751,24.775598,55.195562,76.46654,55.99417,-4.816634,-7.870882,46.999119,102.622161,124.300108,118.471707,98.412201,82.641549,92.680192,145.49327,171.0451:-101.605753,-72.983022,-95.034382,-172.221565,-155.741609,-12.281905,47.050331,50.694507,-36.224935,-43.527557,34.595083,65.711375,68.223713,64.427375,65.773939,41.602582,-112.024683,-207.207326,-168.256526,-54.321888,-33.773756,-68.114466,-102.640776,-169.903517,-257.987632,-283.934395,-260.774343,-238.421506,-212.782007,-204.976516,-201.851879,-210.989999,-229.130526,-217.327251,-204.081032,-184.553326,-191.054896,-244.538112,-256.109867,-220.607661,-167.718708,-113.791921,3.728296,10.643069,-57.849006,-81.826005,-78.33333,-80.099882,-147.831101,-203.16567,-178.534488,-124.018968,-135.478089,-157.383008,-124.744867,-10.358451,-32.595003,-92.345419,-166.178427,-173.074474,-94.034985,5.88816,169.092,168.103886,43.016844,-59.287958,-56.741217,31.152319,69.867473,46.7526,19.15104,29.627845,53.447717,60.249292,92.861611,106.468963,100.949248,85.266098,48.839524,35.204683,18.839248,72.864583,124.370942,195.209453,214.535393,217.458703,180.319405,86.395652,46.76646,44.967958,79.795436,118.843215,178.172276,166.194013,93.069846,78.489945,135.357749,180.481606,162.480266,96.484787,84.351664,77.341699,32.6164,-120.70168,-123.635335,-57.328967,-0.881293,-56.402821,-164.124691,-133.164677,40.658432,103.577918,83.865612,-26.024712,-46.909847,6.760383,57.778784,125.400553,136.917956,192.150882,294.417092,330.459046,322.392223,274.59593,152.332007,112.684568,101.409357,96.396744,25.28777,-32.525673,-30.272316,35.983936,80.434349,106.663359,97.357048,112.317848,123.578548,116.108004,118.84925,121.313512,75.604472,29.217553,-18.009526,-0.647572,-5.928544,-86.918176,-78.391949,39.45168,85.04521,61.096821,8.439267,-87.222306,-58.726385,-9.449733,11.453542,-15.316747,3.073074,46.647101,58.328551,1.199734,-130.43412,-140.928559,-111.079625,-43.080385,-34.692527,-116.900879,-166.521102,-168.280339,-157.134944,-166.426806,-121.381771,-84.314067,-89.461931,-127.355735,-172.648274,-173.322454,-158.051327,-22.289928,82.874075,205.684102,198.444537,124.461451,103.048192,110.236117,115.364699,128.733681,172.756583,175.514365,138.565772,108.768247,41.622374,5.862318,-69.285983,-45.508653,3.190868,16.958919,-24.255588,-83.242643,-87.572704,-96.810279,-60.111216,19.136066,209.843537,234.755103,123.384822,58.618188,38.574168,71.574799,137.46454,194.089366,202.676652,140.810187,105.502507,131.755727,189.408242,262.045464,201.217244,185.216335,223.312722,216.476072,92.20529,22.948903,-15.627361,11.884458,100.978257,212.948959,267.02166,335.813553,329.760259,198.44207,118.329546,60.712695,9.563004,-45.836277,-81.13851,-31.994167,48.734687,11.172846,-121.469834,-143.729437,-99.042632,-7.541643,40.798101,110.500019,115.910042,28.68951,-37.373623,-79.780815,22.783672,92.031047,121.545488,63.34184,-48.27611,-65.029483,-61.843394,-63.729913,-113.197081,-92.135441,-16.264056,112.470449,107.784055,24.663392,15.896413,72.507055,30.406354,-7.164779,19.036332,38.726047,-33.439833,-89.636358,-111.663241,-86.886643,-16.507018,74.609745,97.576631,81.381639,49.609868,-42.917554,-65.864042,-30.501616,16.672727,41.02286,59.800859,51.528378,121.028478,190.64569,217.799868,165.102024,46.883103,-4.330563,-16.59992,-21.865893,-20.79224,-76.967119,-125.518778,-150.002735,-61.811353,-23.133117,-44.333223,-92.974552,-150.126357,-139.75542,-89.340227,-61.378821,-2.534323,35.771416,38.361867,-2.579827,-20.792984,-3.012518,18.159837,66.150233,136.368602,173.779034,199.451029,188.707727,134.125207,72.403965,-49.094951,-56.518269,-13.869715,40.805022,62.350511,49.615224,35.979062,4.689556,-8.961554,2.625968,-78.431744,-147.318032,-155.195547,-106.355167,-68.395087,-79.695732,-87.453416,-72.103994,-11.637049,-43.142122,-97.515451,-132.385284,-105.852863,-42.543443,-8.838429,51.494235,24.589564,-5.045199,-10.477547,10.965822,13.917939,-21.477272,-80.414497,-70.981947,-20.356629,-1.956995,4.417742,14.476392,-1.193543,-75.568833,-89.516203,-79.555415,-111.951232,-104.858056,-46.070183,-13.592729,56.315878,67.053917,57.636505,66.285543,51.63644,-22.653639,-50.31239,-41.411944,-3.62636,35.472592,13.340507,-25.972478,10.218608,21.648383,-64.136561,-123.820637,-98.901912,-20.194877,95.292102,93.712025,26.70567,-40.010324,-56.065623,-30.191603,-8.100863,-17.752756,-25.789486,23.683387,96.959084,109.675667,51.193409,21.84743,48.053636,56.5558,29.724341,27.600758:forward
55.780666,110.217782,138.64673,154.210133,157.928373,105.392251,29.419432,-155.430497,-250.876507,-235.89729,-129.801248,-62.687505,61.61963,81.876272,-17.423292,-106.294725,-206.304925,-140.378204,-114.131104,-104.827977,-91.507377,-93.316677,-116.583303,-160.590633,-148.084591,-115.929324,-48.128371,-20.264062,14.21977,8.976982,-47.983547,-95.331471,-190.858856,-178.289133,-116.116054,16.690316,42.151269,45.637939,54.250894,29.71518,-75.772594,-98.171532,-26.001328,33.365358,79.75216,55.030851,-11.822033,-40.562702,-93.880873,-53.408883,-5.537789,87.016346,117.700281,86.546785,36.238473,-59.887254,-109.376655,-80.532589,95.192635,188.400719,239.339551,201.244239,127.317168,108.177987,53.363767,11.605415,30.946494,146.420539,203.157672,192.746578,123.668943,1.375971,52.797411,108.084502,159.463685,173.653336,263.973515,330.82705,391.600985,346.915841,177.981175,139.315404,184.249023,312.496706,349.255426,256.362863,168.625528,93.126655,119.221224,129.505301,127.095553,124.917589,134.712137,144.852904,120.851217,57.376855,-110.028201,-128.322654,-101.37261,-105.009079,-123.220411,-139.435267,-153.46138,-246.937033,-244.086932,-142.583126,54.362067,64.416645,-28.859049,-76.205605,-157.175906,-209.427574,-283.181338,-176.128628,-74.176152,101.98384,154.847316,162.753312,130.765436,55.060693,-21.222628,-35.515173,52.763221,138.741586,219.764456,180.813862,65.234298,22.492116,-10.636917,93.531432,156.51476,218.818144,245.163264,254.315396,201.770925,59.041254,79.855876,161.078742,267.485511,253.476616,183.500209,156.161254,115.69596,85.802165,-2.128334,4.159614,52.670706,119.451406,118.211216,44.949198,-35.640476,-227.085866,-297.208371,-277.342449,-200.224139,-156.981182,-90.860158,-81.351462,-121.272516,-156.571172,-202.84294,-215.303256,-219.765479,-218.97974,-213.262297,-208.788835,-204.631282,-155.52603,-101.196132,-110.051708,-129.453786,-81.505342,66.47166,91.049215,40.112665,4.575199,-47.57453,-31.845271,-23.593241,-73.931404,-104.949579,-91.767874,-59.10521,-55.114531,-88.500982,-68.064046,-19.70873,-33.705525,-117.395548,-134.558886,-79.178524,-70.085527,-156.570183,-186.938398,-140.146301,-0.156334,50.817804,71.604401,44.080799,-63.222225,-115.973396,-104.870753,-84.89116,-71.882639,-0.600326,45.867595,76.915349,35.594021,-40.986509,98.609702,202.63091,287.049537,273.096566,269.961234,274.564871,173.846284,94.086338,145.414145,335.886546,404.450521,408.719466,340.62764,132.328281,48.245013,-0.197039,43.475406,59.126026,103.388547,128.186762,32.610525,-102.185763,-317.382238,-237.331239,-166.479238,-161.204968,-190.937282,-184.025228,-164.459489,-183.922951,-226.189729,-307.305169,-305.128151,-290.156757,-269.368367,-262.135672,-281.122747,-319.285708,-419.867504,-423.133936,-371.918494,-219.411106,-138.511428,-80.189695,-127.17584,-250.57298,-291.702396,-342.300898,-312.612818,-252.358569,-57.267874,35.420874,107.396027,104.885949,116.825396,179.293339,190.577639,101.422366,59.755128,100.408966,129.256479,55.906072,-21.145771,-66.750399,65.007257,130.207667,178.209697,167.27032,136.259324,133.721132,118.265913,103.440881,141.603187,270.71386,310.006562,272.118564,216.333259,150.445981,123.886915,-6.318423,-49.244023,1.780023,139.561397,176.756529,86.077472,-15.803635,-141.709571,-28.936973,65.69194,139.691,132.95749,179.061966,239.652759,332.37203,312.541389,159.347192,88.309507,128.293691,298.831385,369.760388,368.259615,310.816151,155.393969,104.150636,173.184107,368.90957,419.949869,386.616897,343.370627,295.654004,265.810069,161.933565,167.702871,213.945113,245.961696,208.785045,95.321999,51.852033,-18.243394,-82.707554,-95.441821,-76.216539,-46.096544,45.018877,75.377351,56.966308,25.424701,-13.99845,-47.620037,-76.095941,-67.724073,-41.530795,-54.13156,-79.882155,-124.126396,-155.975198,-158.011261,-155.585936,-138.558058,-50.264447,-4.795396,42.425335,29.618044,-55.582831,-54.462944,18.616465,228.696688,302.959328,337.769996,316.720822,236.259333,145.103291,118.395081,118.994042,128.650168,119.367057,96.803897,6.052955,-51.501809,-99.652729,-63.2704,-40.672698,1.103347,-9.843946,-127.479485,-177.005146,-171.772713,-174.367885,-204.054584,-221.663217,-177.184535,-61.695657,-48.317232,-61.838088,-41.891147,-2.748012,-44.21716,-53.309746,50.923733,117.610837,149.901422,135.384098,50.612037,-14.233597,40.197472,232.178276,307.290057,397.633627,409.706604,365.20904,307.969152:115.377137,93.852341,93.793605,150.899442,166.388286,95.574775,34.570839,-65.818629,-57.79358,-24.772925,17.406364,39.731992,82.963981,67.095839,-32.760931,-85.17548,-144.031307,-100.21534,-58.123392,16.986732,45.263236,44.026636,14.676836,-25.829267,29.192784,86.69225,197.138277,239.303832,262.473971,221.568735,75.95212,4.359069,-97.095158,-102.40594,-54.135933,61.866912,82.437712,106.948062,145.793356,179.089106,100.159922,74.358707,110.353246,161.730453,240.348438,234.946724,131.196908,56.704117,-4.66077,110.971652,161.26171,158.701579,142.89783,121.911709,95.613887,7.800301,2.903824,45.193249,117.884722,142.996542,228.291253,278.334568,343.578159,348.117408,290.484807,224.233596,229.300165,295.183873,316.384198,288.701529,225.278429,53.640141,80.887973,160.125994,250.406701,266.784856,350.253552,405.350344,483.777524,491.813413,394.843539,312.845212,328.071886,348.918529,319.435295,209.79674,146.197782,22.839174,1.080692,52.1896,203.591444,246.427228,193.008352,138.934004,83.233596,75.201402,63.082487,16.322895,-4.128362,23.028386,38.467354,-64.23815,-153.772763,-203.130724,-72.41266,1.916173,95.942458,96.885904,-17.69114,-118.586227,-292.242405,-323.185917,-270.551448,-126.544611,-52.404359,17.703266,-3.238999,-37.232592,-7.533698,9.527512,-31.558444,-1.06906,131.726219,186.658875,200.743102,165.774052,74.522219,48.065839,98.408724,191.432397,206.701942,235.000194,264.275758,247.80811,173.857954,8.849304,43.419744,124.47802,212.63653,188.973687,86.442308,42.18833,-9.618099,-26.43385,-46.752072,-12.625115,3.914823,-9.471259,-41.397105,-134.764258,-185.127598,-260.642037,-247.128625,-225.635392,-185.456955,-156.968234,-118.234956,-121.295915,-145.086605,-146.084343,-119.916809,-134.910669,-148.776714,-128.834788,-110.128472,-123.870304,-154.236346,-185.460884,-122.277451,-79.094702,-20.460792,2.241399,54.327269,66.662991,7.432816,-48.837928,-99.762834,-37.051419,-24.956746,-138.927919,-212.360498,-231.85373,-205.02278,-197.133347,-211.159725,-191.70937,-116.831852,-95.883561,-142.866401,-179.811913,-180.902727,-171.759403,-210.482626,-198.319543,-147.783262,-35.683481,-9.019767,8.328328,35.443922,57.869181,-71.828746,-143.385274,-146.269412,-81.115731,-1.756022,-21.868203,-45.459351,-22.347153,51.174687,185.929716,246.13534,254.166836,220.425075,177.544569,169.959975,134.599225,167.230449,231.932332,379.685463,424.071266,381.440072,299.321709,103.623847,26.644149,-40.647824,-35.198887,-11.865795,29.494049,7.45671,-120.48261,-195.105836,-342.735621,-389.336898,-333.797705,-202.582349,-181.300268,-200.427723,-232.750522,-343.324156,-382.006051,-354.277478,-284.362952,-270.185487,-256.930737,-265.520014,-353.350573,-404.960242,-427.460142,-334.821495,-300.720326,-306.738254,-299.297395,-262.409978,-271.749351,-325.800867,-339.199792,-305.795979,-255.597068,-226.985391,-104.641537,-22.202983,101.423319,108.736325,26.8772,20.361757,77.771039,185.930012,200.71608,184.267731,168.727036,101.625765,54.272562,43.69083,161.452002,204.609266,213.466342,213.357011,240.967463,238.769276,153.880647,114.463077,155.21099,250.755069,261.269284,177.821101,114.93794,66.208308,64.145532,14.007009,-7.433242,24.554926,104.288078,112.216195,25.583666,-54.263782,-181.351709,-149.614615,-99.302959,-19.418493,16.330094,103.330143,138.52027,138.859405,98.085248,-8.825577,24.396156,111.199028,250.368741,247.709913,162.655139,119.260032,35.939637,8.17019,47.967649,212.083473,276.870679,219.733662,139.271345,105.024219,138.919786,171.439996,179.595092,185.199095,164.394548,115.153077,-16.542412,-56.424421,-80.994057,-73.883765,-53.776181,-6.278449,13.11099,84.26572,132.010192,142.678227,93.555009,26.994128,50.574267,40.642442,2.511896,-2.829257,-46.80692,-88.577256,-132.598425,-70.664199,-18.840376,37.80788,33.658897,50.756918,86.0059,113.750859,93.316648,125.195192,271.111461,310.593618,315.944373,316.00919,315.239498,305.783296,262.79675,234.875185,236.454014,203.707429,180.60516,195.95514,206.385827,138.497006,73.708436,-10.159887,16.029104,45.94683,59.820996,15.868242,-113.854857,-143.919441,-146.458503,-179.753638,-177.463229,-50.985702,31.163461,46.781277,-11.423601,-56.58775,-23.797739,16.887541,-19.023215,0.684948,144.660102,197.79855,180.370038,134.171366,-4.577829,-45.803781,19.836196,202.732123,271.153834,321.61958,306.325366,221.004281,161.913093:100.699795,185.104638,180.305425,91.16607,51.644531,24.687242,12.476877,-9.298644,49.705482,79.961055,78.681643,74.189283,73.394078,62.210013,18.131227,-20.60719,-87.151258,-48.415477,1.145221,134.054292,193.812005,201.186828,149.738414,69.051443,121.110585,163.807351,245.111244,285.502264,288.772398,244.016893,139.131686,93.032349,28.81754,27.291859,43.668379,69.011308,67.83674,82.146009,115.50405,153.35443,113.633415,119.743611,218.939017,275.545745,277.474147,212.247977,74.498376,40.944774,40.252069,78.220628,105.044478,176.208778,187.754608,113.64476,70.947402,84.007123,178.142781,199.259865,188.08011,199.049539,242.601825,247.197094,264.525386,268.639031,240.913849,277.800461,312.096758,313.409612,274.830381,202.922644,177.023143,114.395226,111.044819,151.284882,290.429059,353.109282,382.301123,356.912728,272.781511,227.409479,191.496744,219.764297,225.995199,235.309629,251.191399,273.08203,260.683116,170.382989,80.224953,78.958207,167.672835,223.550187,228.589742,175.696849,70.078072,32.069161,-19.403067,8.455008,45.886637,70.783567,46.270228,-30.296074,-56.998572,-40.27934,40.723694,73.772011,131.208396,138.126726,-34.531371,-192.915651,-383.309993,-368.947882,-234.305111,-110.33848,-67.246314,-28.230304,-29.870819,-3.589059,25.083574,19.459887,12.869631,63.163841,227.847956,290.744403,275.986836,211.181603,71.612597,39.043399,97.479273,175.504877,202.397535,312.651861,365.089339,305.673488,183.751714,-50.078219,-3.15293,71.024057,99.467292,59.398919,-25.038377,-34.52274,-19.471478,-46.303576,-123.185337,-49.822083,30.875822,107.500435,55.294097,-107.049947,-153.092072,-207.410279,-242.046962,-216.205822,-76.693951,-24.26689,-57.922551,-118.706391,-229.890697,-246.426584,-190.97451,-184.022287,-207.813754,-180.556568,-141.351836,-155.904298,-203.15497,-193.160475,-69.568966,-48.928668,-37.225013,6.330845,90.283488,74.024563,-56.127627,-121.099789,-138.303015,-18.737982,30.792336,33.717445,-5.471811,-125.030056,-181.540327,-235.50899,-175.120013,-105.829562,34.627816,51.709467,-78.601681,-170.026052,-240.555889,-218.810475,-112.735242,-69.214009,-116.763374,-184.446679,-146.205063,-34.188446,-29.391847,-145.540905,-251.142626,-239.551359,-122.670013,-65.161504,-32.80047,-41.761203,-39.178331,-32.435714,7.489866,98.813081,114.914441,84.61848,84.871855,99.520434,50.047866,-126.452506,-56.552488,65.107006,217.941861,211.693022,108.451419,58.476693,-22.768729,-72.167486,-139.675932,-111.858467,-84.77251,-79.654308,-118.993512,-227.898209,-270.027396,-342.478619,-352.888995,-315.160747,-249.916003,-242.955385,-233.792122,-236.385478,-330.794461,-397.597079,-409.680628,-330.850575,-306.773022,-283.393987,-299.394879,-374.475801,-392.052722,-397.272167,-383.053683,-347.576362,-253.427882,-236.963838,-339.323619,-403.819967,-427.553459,-417.000769,-375.005239,-265.846786,-211.018646,-144.201506,-137.08136,-130.289715,-116.596961,-86.074764,-23.568092,12.068581,48.183305,55.680627,48.885449,37.19448,10.957734,-13.578212,-21.011728,82.07257,129.889849,181.181717,201.725733,262.821177,275.243413,178.133419,102.446344,150.774273,291.731241,319.8299,283.832252,241.517155,145.63431,96.765048,52.748912,112.301396,140.173761,131.56084,97.652208,-5.534883,-72.005194,-186.702659,-120.580026,-34.101379,95.069251,123.585914,131.279138,125.952026,105.23442,66.794365,-34.902256,-13.495492,50.731059,185.834489,221.361445,203.001035,144.438365,-12.944204,-15.903777,58.69527,185.916705,168.521104,9.880908,-46.729564,-15.58032,4.229295,-53.421295,-49.329,-2.256956,47.336113,14.098738,-138.090287,-207.141002,-237.884629,-162.016197,-99.033813,15.875767,29.533112,9.156549,27.653995,110.143347,105.147327,-30.198438,-94.798309,-72.151143,-31.167089,-33.515595,-46.350679,-58.306326,-100.338227,-40.782582,28.127952,108.156815,108.739098,92.952025,91.476546,80.981396,68.819442,95.612675,151.068033,156.843862,214.221802,268.216573,305.245618,289.833454,270.588777,243.141468,206.756449,107.143263,89.089046,168.391672,215.130066,204.583228,153.814605,45.530323,33.575171,62.58817,88.234872,58.389527,-17.048465,-29.109275,-33.783122,-51.037733,-55.128483,-2.311605,53.431316,106.536875,95.214783,84.598805,77.656864,27.544488,22.040571,53.873948,138.795525,171.279202,189.619944,166.695661,75.00489,63.383199,128.110242,318.327711,372.239965,335.497635,295.300385,253.372747,224.222317:98.986696,79.728878,79.473375,93.921183,71.983856,-9.024214,-21.604707,-42.540024,-149.965975,-197.029608,-160.513771,-79.718322,53.188657,66.939315,15.723049,-38.945824,-142.670439,-131.746444,-87.237643,29.532589,66.426539,42.486899,15.33962,-2.437114,43.344614,87.631434,133.992615,138.584523,153.002735,130.449051,-11.494145,-99.253052,-191.339983,-111.098594,-35.860635,73.537592,66.972924,2.465055,18.845969,126.789107,134.128458,106.038622,125.269932,184.558712,270.320939,251.626887,127.160912,46.677008,-103.696086,-123.302233,-77.609778,59.969038,123.220855,171.864051,162.868682,97.921772,37.240618,67.976508,226.224082,296.456583,308.279009,256.563507,115.441482,40.555272,-32.754237,28.209801,56.596853,87.840832,107.469843,107.475142,66.975091,-44.838265,-58.557813,-19.133223,64.057259,88.550803,102.811705,110.103183,140.248297,132.736571,51.533276,24.242817,63.733738,182.270228,207.356961,130.814201,76.176305,47.908749,74.65105,83.809691,114.937434,137.318371,99.803224,27.703155,-120.180988,-165.726809,-211.836453,-196.374602,-152.074943,-33.942556,-1.303774,-8.487329,-20.709179,-46.391892,-39.809512,-8.151232,65.230497,77.172045,-18.833978,-123.517984,-288.69973,-297.283135,-235.856506,-122.9976,-30.094357,164.120074,227.691623,254.677867,230.64722,132.902378,16.534293,17.698144,177.119054,269.617873,314.6509,267.759702,149.741927,95.338121,39.348931,150.44912,230.868735,319.882388,321.534464,222.580821,127.23829,-41.480402,-26.921807,44.686654,143.76576,141.55746,92.82011,57.372875,-16.529493,-42.546305,-18.922085,122.880348,175.010085,164.757194,131.047792,55.068941,-4.848207,-168.279346,-243.470341,-222.753713,-111.600598,-37.658491,38.886232,7.218103,-94.902837,-125.85903,-187.229907,-235.598998,-235.143448,-189.785625,-153.350327,-121.107747,-142.260851,-185.576571,-96.818811,-27.11669,30.670382,41.218541,99.188565,108.644806,72.275247,68.061701,118.30063,127.751382,72.66021,-46.71701,-54.067398,-25.998604,-33.601999,-61.168235,-38.753457,-26.064854,-18.98988,-9.372435,10.721126,-4.268305,-64.11127,-83.061335,-97.888045,-101.907052,-79.046075,31.306159,89.063887,141.923066,125.244565,-54.240041,-268.209185,-266.823202,-70.851405,32.198298,79.716671,32.8582,-54.299268,-62.698767,-11.642684,101.824335,154.414627,233.839189,251.949149,195.886631,134.587613,28.21312,38.383318,82.624886,165.27931,192.128846,201.594727,175.621631,95.061457,63.664213,29.578406,19.75861,22.758824,6.407758,-24.627782,-127.913247,-200.846636,-377.875688,-411.630138,-336.994232,-210.469408,-210.335023,-232.368899,-221.63976,-234.97126,-283.97225,-372.407967,-336.168562,-291.913827,-271.931294,-318.827655,-457.156562,-492.801143,-447.412786,-347.588423,-315.290299,-270.500582,-238.274982,-223.712098,-267.449205,-364.058933,-376.173392,-336.329645,-269.752573,-247.821188,-187.26066,-145.346488,-94.968646,-86.284984,-67.21687,10.154443,68.382628,153.017198,166.769613,128.993203,73.002761,-74.227572,-123.936831,-89.123888,60.644653,110.095869,123.336118,107.15659,84.903241,88.405909,79.85071,111.391433,174.958355,268.418937,254.985648,190.463111,176.834207,154.452842,118.998357,22.247724,-8.38327,22.598571,117.874222,120.111397,-5.810292,-77.891684,-158.425273,-102.002834,-8.524769,169.65899,214.181585,281.250755,312.038335,268.353481,180.303303,20.046097,71.179106,157.446569,293.92047,289.858339,178.959017,130.35993,81.356068,85.180747,106.084503,164.153341,193.225788,191.514789,152.602354,71.112923,34.040113,-51.087428,-53.945551,-23.690168,24.640304,25.823769,8.972455,6.426849,-43.117441,-100.5471,-82.284537,16.072083,69.721787,128.58645,118.17908,75.3394,60.840056,6.332141,-111.756656,-153.933632,-105.985252,-67.626793,-93.691398,-120.96383,-154.129483,-176.738799,-165.447331,-116.721857,-74.776998,48.987366,84.731038,18.925113,-45.371666,-87.012217,-9.080967,32.287425,112.382697,149.257726,196.440528,204.329117,156.441286,87.933112,82.666545,90.716045,88.325682,93.449833,106.650694,92.839331,40.261614,-62.000244,-31.514482,-5.164405,-20.256057,-62.842528,-152.513484,-168.950813,-176.767839,-197.435808,-188.508169,-98.874195,-25.596216,99.789902,127.674197,123.511717,85.357666,-53.224467,-104.754539,-61.177228,119.391438,200.951085,245.348872,228.581027,164.039747,149.75624,203.375958,353.852509,424.684923,548.978935,565.853577,457.691775,369.115027:54.179189,53.723385,54.068263,77.100265,86.338734,60.638953,18.18112,-101.899817,-129.749598,-104.428869,-38.673481,4.265827,66.309595,58.171694,-32.619379,-100.378008,-195.621065,-143.862137,-57.679922,144.912744,190.270464,125.617396,60.500414,-46.141336,7.25583,95.33271,223.432196,238.587309,200.122995,151.344292,6.081922,-64.905864,-110.526136,-70.475957,-52.121599,-6.780753,16.766885,25.469714,18.34658,21.087811,61.017151,79.74705,110.012325,150.620487,253.838109,267.070416,145.29875,34.763045,-111.927275,-54.514386,28.750197,204.145634,256.357413,242.786642,190.070842,109.687956,176.70559,239.804185,353.968248,380.475873,295.975846,203.676141,87.810988,85.119301,113.520826,142.961105,164.208724,198.441176,189.180939,129.383441,90.501472,-1.346482,25.949477,111.464678,276.965822,307.698139,272.360393,227.913681,104.481902,27.155658,-57.188212,12.87801,62.415588,136.82979,159.945875,219.980976,254.30745,205.677968,103.590399,126.218246,251.379757,267.191383,145.076211,73.94962,-9.38314,-54.50516,-133.339002,-110.786618,-68.261173,47.955568,94.831618,104.966711,77.034614,24.197498,38.459932,71.936958,132.804119,111.036961,-79.922989,-182.121208,-246.692281,-223.583991,-122.138883,10.983594,80.272759,233.438647,284.061976,250.970932,180.490542,17.87578,-22.374651,41.896324,287.204582,387.798125,370.772247,282.943288,105.382223,41.637969,39.931276,159.598129,205.767759,269.048617,274.967658,163.21967,63.14306,-105.753678,-106.498083,-26.217047,171.292683,213.727254,113.510444,20.269088,-71.9391,-68.140934,-15.893199,131.879673,209.228895,244.07615,189.051912,-4.639914,-111.291385,-270.882889,-241.142461,-176.439029,-73.220802,-28.8822,45.701851,47.704727,-35.969045,-106.96236,-216.093991,-178.225931,-129.542018,-63.674656,-71.985954,-163.745696,-198.528024,-187.313021,-130.602071,-81.968732,86.577448,176.000103,238.618958,195.155807,32.433511,-35.143571,-35.227224,80.141091,129.874862,192.26211,179.517672,29.765177,-62.964241,-154.938048,-103.44509,-56.013694,36.622894,67.580255,40.686002,-11.785478,-86.581496,-89.147137,-67.36472,-45.33549,-29.692119,9.328942,4.256212,-76.346463,-114.688592,-164.545588,-210.291535,-200.938588,-84.00567,-5.655977,50.695626,-3.996829,-156.917592,-179.380163,-69.328108,61.82551,84.261684,92.745186,78.223438,-31.535358,-113.418998,-206.867128,-90.320228,1.703876,88.934884,71.906925,15.213798,19.429874,34.042124,0.599684,-60.650711,-33.485471,-24.559477,-21.648091,-20.995532,-63.10651,-127.007231,-327.70405,-360.045975,-264.775709,-87.046039,-64.707907,-107.313538,-152.880132,-307.040197,-383.688898,-350.943914,-156.387698,-107.393927,-169.777727,-241.96011,-362.617083,-400.243998,-404.095342,-268.108647,-185.010663,-113.431145,-142.892801,-275.758452,-335.17174,-406.410218,-429.742819,-399.426076,-245.217396,-174.523569,-115.666326,-124.298454,-161.809036,-179.649185,-201.19891,-103.163347,-26.097124,58.61608,71.603178,70.093984,39.62077,-97.68596,-171.156781,-167.501912,18.968544,76.241128,51.635964,20.472771,8.359287,2.581261,-97.355808,-151.282242,-99.399039,56.717294,104.338568,100.816205,66.870156,-48.244134,-129.290448,-198.780349,-54.026307,17.300764,33.055056,-17.022183,-160.192937,-231.904721,-351.184545,-275.393171,-157.890931,64.609773,143.300315,203.834209,186.330265,116.364325,49.599619,-113.683251,-92.583292,-2.879252,148.162678,149.467684,43.819969,-30.0544,-168.934163,-119.840055,-17.561473,144.789649,134.674479,-41.391528,-121.653461,-145.419072,-127.522478,-108.451421,-66.943196,-37.131579,-12.35869,-39.027056,-153.102487,-203.265136,-222.466226,-132.661867,-62.80405,60.097842,87.740483,48.839973,19.902572,51.132545,79.228587,43.64292,-54.877801,-60.185997,20.514927,48.983906,31.015698,7.230709,-43.403376,-75.20925,-65.077751,51.692725,133.340075,205.167329,187.278955,95.106723,50.137127,64.438929,167.605898,204.252883,258.779052,284.038579,307.89543,291.28895,191.229738,127.388679,137.027832,224.094438,285.678038,351.435644,330.407085,208.026118,146.001118,135.44067,219.612461,246.837242,263.941575,225.468996,17.248498,-91.471209,-165.656885,-86.163337,-40.817723,27.056641,52.297178,34.58212,-3.707803,-55.603116,-70.378175,-92.448116,-36.665211,38.664934,213.946627,256.178596,205.46556,154.32526,77.494332,74.890474,123.951345,272.875716,339.457251,407.538325,398.144376,294.219773,209.233535:41.135298,24.240669,14.895528,40.199356,82.965385,106.229553,52.534219,-93.961944,-195.802876,-212.988692,-160.879046,-105.763551,-5.136129,15.983024,-46.965134,-125.319155,-246.088772,-175.2007,-90.844692,39.450178,41.954148,-50.691103,-88.336724,-138.738748,-194.485462,-168.448441,-30.273347,13.066307,-30.093696,-104.540911,-294.586642,-367.678569,-338.719956,-132.077315,-61.206187,-32.10273,-34.950237,-58.852411,-75.551411,-70.865577,-75.955223,-96.144682,-87.000509,-32.982247,96.127637,108.205219,-27.101396,-127.438037,-228.003006,-153.865912,-77.080188,123.072067,207.362295,208.211703,129.940633,-27.76386,16.959279,118.190792,292.915163,324.725046,316.32178,276.744231,94.98182,-28.095359,-162.164267,-49.620626,20.858886,78.337219,66.583489,-39.088571,-106.526069,-150.018602,-90.311021,-44.375864,29.115746,34.924594,5.982629,-4.591758,11.136485,19.152741,44.670457,100.080376,107.239253,117.618841,148.313529,177.677107,166.951151,163.593542,128.049088,103.42803,120.772974,155.582673,182.067463,145.213068,-32.297706,-141.300426,-272.655151,-212.576931,-153.846047,-88.128193,-62.311261,38.855901,77.897745,-1.394229,-98.653703,-61.466537,65.108514,91.117353,25.204572,-43.470549,-108.851879,-93.735116,-49.898938,16.486528,80.777189,256.439742,321.362899,324.114039,287.94669,210.748124,114.104628,87.617245,145.26236,194.336659,198.252106,151.427212,22.506337,-53.219021,-96.999423,132.654708,239.719054,253.0038,208.67438,118.322133,68.478536,-15.933911,20.854188,77.762505,132.115697,125.334786,102.113517,87.659186,81.382167,92.733406,125.853537,215.689951,267.360164,317.7904,307.124275,195.251478,110.424068,-38.270665,-162.357737,-200.807939,-146.802175,-60.191418,67.492006,52.889606,-82.354979,-140.788223,-201.735866,-222.43039,-207.641393,-164.520368,-183.12787,-288.990822,-297.685615,-225.640987,-214.053157,-201.176646,-77.074891,4.410102,85.748049,86.869388,109.613972,118.520415,55.568747,21.489588,29.737405,-1.288894,-33.093235,-31.148297,9.905165,75.686107,132.420048,183.036159,169.953636,76.769663,-119.953646,-174.82724,-198.737699,-178.38684,-112.843199,-63.476622,-33.785198,49.027954,78.768607,114.217619,121.662329,21.138729,-147.07847,-152.040475,22.158844,123.276665,165.787389,110.889741,38.142724,49.533762,85.821469,182.76899,260.373991,365.973533,365.452757,273.137783,191.45824,23.099837,21.90008,82.081724,172.450779,176.777162,166.562294,169.785831,139.27112,104.194808,84.037937,139.469923,166.116809,202.518794,201.821168,93.020734,-21.330367,-253.269377,-278.870965,-207.329966,-53.274648,-23.634256,-105.501918,-188.369405,-276.396961,-257.406402,-193.548411,-174.206366,-150.142631,-104.917802,-137.351889,-264.171191,-300.45362,-301.979824,-278.14775,-257.339854,-174.270034,-122.07163,-122.013116,-192.73721,-334.064077,-373.436284,-409.839892,-319.393979,-237.223925,-95.981537,-46.78145,-4.720093,-4.744138,-5.344317,41.146929,81.102743,60.717519,-11.007413,-117.369904,-129.611395,-168.138593,-203.130105,-235.793601,-153.550546,-94.093368,-23.124125,-20.933482,-73.14008,-106.978723,-133.169768,-41.981348,37.798209,116.442698,91.218249,-8.763803,-51.627714,-101.059079,-129.85573,-202.394119,-186.755851,-146.5102,-71.145792,-67.96788,-162.230903,-237.757899,-346.232321,-247.115564,-136.711402,9.536353,32.376353,115.802274,185.356525,220.701043,163.312667,63.066728,66.993732,67.853274,86.173065,103.945376,84.829617,51.867597,-18.371482,20.933201,92.536384,192.74064,195.623706,157.758298,132.220509,76.577457,35.09876,-42.222127,32.614241,95.513139,87.78684,23.682191,-43.463541,-17.412709,21.679688,-36.46938,-44.702626,34.911763,83.776705,87.316449,49.107561,-10.822535,-19.304083,-27.969603,-64.030851,-84.779396,-74.731957,-64.407155,-98.442969,-108.208774,-70.920017,-54.475419,-63.678693,-87.349673,-86.396831,-36.679707,4.834411,40.134153,1.310515,-105.21359,-31.861605,76.895742,285.156028,322.147591,278.772351,255.759787,219.414036,177.565032,170.141599,164.029373,169.938385,201.252185,207.637454,163.350634,117.200057,34.907373,-15.787528,-21.482708,26.293641,28.376366,-118.778865,-195.264677,-165.469667,-44.863089,-14.019784,6.582203,24.249691,67.578544,71.515886,26.09965,-20.961684,-67.829209,-40.468391,-48.259379,-26.611039,16.56139,69.353773,85.731938,123.028992,111.494564,115.940374,222.298917,307.816846,428.768664,429.466445,350.252268,303.534194:0.156944,33.800016,58.611632,80.701496,60.066747,-28.174515,-75.761082,-147.928419,-178.169726,-175.259897,-108.182176,-38.711086,75.8599,68.970942,-91.594977,-206.618604,-323.052431,-175.246985,-57.135313,74.350951,49.616598,-74.645697,-115.21693,-166.86691,-162.914298,-103.579023,52.881659,94.539849,54.33362,-18.664658,-203.416647,-263.784909,-206.87006,-57.074751,-23.099992,42.135869,84.48334,71.770563,21.650679,-32.766147,10.478565,42.472577,131.269466,198.458717,290.43861,266.139786,84.166525,-34.276244,-156.129175,19.377934,148.774617,308.417705,338.340357,303.984995,237.256475,101.684743,115.228935,195.106793,397.370511,445.320003,333.956708,212.247869,7.005647,-54.12326,-83.057286,17.637018,75.61428,133.74208,135.867903,87.679758,21.325828,-139.022343,-128.110688,-51.720619,95.63533,124.479842,111.957277,89.583483,-11.617015,-77.246251,-107.648427,29.540959,103.206414,195.295257,217.105988,193.275477,146.564401,46.195082,49.625712,102.439884,243.840293,285.347828,223.654051,135.440335,-52.249274,-137.306285,-243.356432,-153.021198,-65.645332,50.47417,71.541966,89.622207,87.162656,38.607445,16.479446,51.353818,179.20168,204.039483,69.80731,-32.855202,-133.249742,-129.135083,-74.63884,49.223179,151.540519,377.889002,428.153799,332.943084,239.646067,90.62563,54.328249,95.084146,241.975567,300.725552,321.823307,289.171825,164.760666,73.120588,-42.614794,96.895123,200.051702,307.171222,291.83221,129.512529,10.721754,-164.859958,-94.614601,2.875748,156.091276,197.131926,191.571409,141.588388,23.389224,-30.303911,-51.382395,149.969506,266.497829,327.865158,260.522447,55.521913,-35.8944,-166.211448,-181.643424,-144.517307,-15.918983,74.826498,193.237698,152.800366,-85.527652,-193.339168,-252.795107,-199.883506,-163.365131,-69.228763,-45.623906,-122.528373,-180.038953,-211.541782,-172.807725,-137.378578,8.649397,97.398006,133.920028,68.356369,-22.006217,-1.053763,77.724172,116.662718,117.558391,126.596943,138.782546,91.42339,26.013544,-64.002312,-14.647648,32.715442,104.991565,115.931798,77.885354,29.418768,-98.842078,-140.469245,-101.080862,-5.267279,17.33593,45.461608,59.716687,51.760024,5.750452,-187.952464,-292.118167,-242.442081,-14.231772,98.358292,147.132464,71.550799,-127.586385,-177.341672,-90.257609,129.265213,214.209458,295.297424,283.423638,110.216445,-29.949757,-242.013102,-181.278366,-88.571115,56.505747,80.517024,33.633308,2.881273,-17.722885,-31.81749,-72.457539,-64.685686,-19.835044,116.122563,142.36885,-16.635538,-182.303079,-444.253987,-347.996749,-227.228166,-97.973735,-97.402911,-105.569796,-96.419849,-117.582938,-172.251044,-277.50773,-206.827162,-134.907424,-90.948543,-146.934846,-308.627607,-358.902126,-383.900872,-294.979975,-209.042458,-49.320001,-13.180119,-92.255809,-193.632243,-370.11812,-401.542365,-347.673526,-185.021781,-101.425459,1.49095,-4.55592,-151.712554,-238.917158,-262.110929,-42.779091,65.397565,100.150451,65.897758,6.38607,-39.132744,-186.567355,-243.413568,-230.888395,-103.285928,-37.011447,47.786317,38.997768,-89.464959,-151.458925,-148.950076,-27.141396,12.865848,17.445925,5.626565,-17.701679,-27.882107,-79.610771,-143.222187,-241.081121,-150.626607,-94.004512,-55.203632,-74.292923,-202.31016,-281.490369,-352.33027,-216.900695,-112.184012,42.631429,94.974639,175.386524,182.966311,85.812436,0.558214,-77.78227,55.829242,130.978649,189.936899,163.61887,6.160871,-78.06512,-156.061851,-116.353068,-56.442461,105.227692,166.063856,150.70119,80.162836,-67.32896,-119.258145,-163.681473,-98.40656,-36.722891,92.84062,115.737008,43.916358,-14.596529,-105.142457,-63.5069,8.217916,140.089556,171.858346,138.502652,85.412454,23.872324,23.479882,10.564604,-14.175654,-3.261007,82.854739,99.467751,-17.601942,-93.915479,-154.283314,-76.367201,-3.515781,62.825958,45.985442,38.192386,51.871932,34.819215,4.331172,-12.246471,76.234023,137.269991,249.762344,279.055291,269.44346,256.608902,217.019177,149.498628,151.038874,239.431705,279.404693,283.841573,271.444839,240.576061,199.957815,110.302843,124.577986,146.520024,154.003672,124.49781,-22.381182,-98.680988,-134.43757,-65.470831,-36.936949,6.848347,36.802126,77.513449,62.457893,-28.194075,-76.187432,-107.137489,-52.045537,-2.707015,119.748425,142.440444,66.808802,22.350087,3.64471,45.353824,77.399335,167.918811,223.303426,326.444933,348.334175,259.341729,160.087953:80.173525,54.78121,30.751274,2.719446,1.480821,13.020579,7.025609,-42.406813,-62.379141,-49.122445,1.266934,43.672399,129.054,146.62535,122.09662,76.225011,-40.336853,-38.132118,13.37343,86.346328,70.758622,-48.292548,-96.659839,-117.400485,-196.716122,-247.213321,-240.138131,-191.631381,-147.895562,-195.85712,-331.549048,-342.935653,-240.018457,-178.189492,-197.423927,-220.306177,-206.592476,-212.279543,-235.592685,-250.611467,-243.417848,-254.146664,-283.691752,-280.419256,-231.369307,-213.629329,-227.072291,-243.832189,-269.159437,-249.490299,-194.644174,-3.99104,75.438872,42.49499,-50.953126,-177.826245,-114.937336,-53.767914,67.568132,136.211421,222.810386,188.560296,22.624845,-37.444667,-87.924933,-95.472394,-61.008566,25.294369,13.934684,-121.789591,-176.965286,-165.568058,-112.824456,-104.529744,-125.493698,-139.56066,-101.021875,-43.311132,49.573857,39.920832,-9.774236,85.397121,156.578522,256.653886,278.619553,189.953445,110.677008,72.711765,97.967946,77.328298,39.829978,46.311713,76.794553,69.387667,-31.436949,-100.122315,-205.383319,-221.137393,-181.204175,-54.334026,-7.804919,-33.040605,-90.595652,-174.032677,-116.134286,-43.437976,103.779502,151.949199,126.697273,75.8892,33.31552,29.531293,23.154509,107.807457,157.460561,223.258571,264.131675,317.265086,295.600562,180.527328,70.879477,50.077529,40.418007,43.590555,51.468267,30.508357,-60.782736,-113.016954,-162.506737,-93.7627,-36.89653,77.799465,100.553386,37.692783,-10.734941,-51.697387,3.277436,29.000532,29.317989,55.87017,196.426239,246.962235,254.747997,247.684965,250.152672,248.027622,250.728125,271.328805,284.597857,265.657501,210.166714,20.389048,-126.598586,-139.864099,-122.776876,-130.564418,-138.46663,-109.934712,-50.311492,-63.748164,-167.536885,-215.593212,-203.120284,-165.691973,-146.249641,-148.379506,-160.775088,-165.141414,-204.393566,-216.151645,-168.91686,-127.428222,-76.848846,-70.242623,2.118822,72.86659,137.51167,32.037884,-29.987151,-86.296923,-82.052022,-1.231875,63.207395,154.728543,174.320945,147.716009,33.847469,-3.291281,-11.750872,-34.959334,-142.987961,-187.027142,-191.869641,-105.97539,-58.73473,42.970559,89.592593,92.896637,58.940905,6.657319,-13.407773,-16.641055,15.828467,64.768308,164.228913,172.283591,154.802427,166.47699,211.615366,299.297611,365.897344,493.375033,513.035311,394.640407,279.632979,54.537368,15.087068,81.928405,207.908466,223.131074,188.878836,140.469836,16.854509,-14.017204,18.911438,115.537018,165.53554,226.707474,237.781025,202.491696,135.715819,-33.77553,-79.232418,-52.299437,15.656711,25.823921,-32.331977,-66.92855,-49.747637,-21.62823,-33.293044,-64.909195,-45.704787,8.209316,17.594854,-8.812356,-43.684474,-151.325761,-213.879101,-192.758779,-125.248476,-109.290292,-99.309224,-103.93639,-155.545031,-194.941975,-216.371339,-95.746364,-16.161489,99.021859,120.395293,61.294914,17.830669,14.917038,77.640753,98.361847,29.683695,-36.580919,-99.755508,-115.994669,-184.995858,-211.635635,-173.988459,-53.654626,-29.140664,-94.819724,-140.612246,-199.637641,-197.913859,-122.851927,-49.569688,-14.585883,35.406128,41.140249,54.419749,47.969751,-39.180955,-95.259148,-124.02825,-44.925626,-29.066792,-68.753336,-91.802049,-118.790662,-128.786253,-145.401931,-88.381019,-23.563087,64.325739,71.131572,78.323872,86.474369,90.509517,79.34316,76.607395,152.652521,178.880177,166.146019,157.666421,165.511168,159.680927,98.94586,91.977531,131.528289,159.114421,133.682175,146.372255,194.032091,243.182767,233.115719,212.485379,203.058004,217.969226,294.905555,300.75595,177.577461,113.171322,80.590038,56.006971,46.354894,48.489292,36.332932,-27.724009,-62.065136,-81.880153,-80.613472,-155.221898,-286.642196,-323.117697,-309.262469,-278.109414,-187.386648,-116.71951,-16.433075,-111.489874,-160.293459,-150.634697,-132.407284,-128.339903,-145.323203,-201.447729,-217.10932,-200.834304,-72.643045,21.34839,148.519175,160.431533,126.259271,119.034467,140.209902,162.641499,165.978112,126.051637,76.623542,-32.670933,-57.68331,-27.648662,-11.577912,-76.120589,-173.956891,-190.237265,-167.009609,-133.884314,-71.940248,-60.641224,-63.151511,-115.393187,-155.877369,-145.8532,-86.424342,-14.54381,-25.420004,-70.752609,-95.35076,-145.257702,-214.488948,-244.908886,-203.294566,-147.978959,-90.52563,-90.156688,-71.359803,14.421521,69.584348,133.736745,144.813142,185.347966,208.248676,170.135178,95.405068:73.552152,120.469623,102.23541,44.880343,23.363034,-26.515834,-51.764643,-136.924423,-222.9097,-218.662469,-145.74416,-72.862923,100.318661,136.149872,70.795395,-1.301428,-137.319959,-87.729538,-7.563306,70.760319,43.113138,-84.30124,-149.629304,-231.574957,-230.165705,-209.908988,-168.426515,-155.408687,-147.85385,-154.146823,-187.697045,-216.950491,-275.602777,-257.552656,-216.147881,-111.113389,-80.91936,-95.477179,-97.558719,-107.83273,-244.725358,-289.877003,-234.739305,-185.024477,-164.009145,-184.442556,-200.789317,-199.87347,-244.250263,-277.880287,-242.269142,-74.451365,4.53019,0.345188,-80.888872,-251.004952,-235.915284,-149.425655,37.857863,114.863269,240.745436,252.524888,133.399786,60.528822,39.460496,72.706257,59.779692,82.875109,119.21528,88.215446,28.521323,-31.114466,21.932751,50.393138,57.199341,47.031009,11.44084,-1.815395,25.884714,53.385894,105.571562,161.460687,177.013004,208.031553,229.887451,190.120912,137.997864,77.613046,41.533442,17.785903,-5.877794,11.897006,110.278446,153.220989,108.696431,17.789867,-182.780276,-230.949781,-192.231772,-98.603803,-83.630873,-134.813538,-170.937935,-207.322257,-189.809125,-127.571765,67.976775,125.740146,74.513345,17.189857,-20.937708,-32.041257,-121.567699,-121.045978,-43.211995,161.292664,230.778997,273.769193,270.718342,199.002748,30.854274,-25.614662,-19.484387,5.433876,-15.585013,-57.529718,-131.131851,-157.019333,-107.169618,80.625486,135.120303,130.589504,123.79397,99.623535,59.388075,-10.506007,25.517372,61.485207,107.071559,122.318505,166.340674,193.837266,215.694189,192.38281,124.960248,104.627518,113.187186,177.498538,207.025407,131.865601,17.796852,-216.348348,-223.861705,-180.15566,-207.265042,-238.901547,-182.965493,-136.616212,-124.744875,-137.40702,-140.210417,-142.219558,-152.079794,-169.06118,-185.404744,-232.692658,-229.170812,-146.679169,-106.876757,-133.817061,-174.320296,-152.405763,-93.37483,-86.431296,-85.332475,-94.753778,-190.661673,-252.766466,-230.729396,-186.899004,-187.756652,-144.756206,-79.190364,47.281279,56.510426,7.601497,-136.128303,-173.993707,-151.532232,-143.403422,-239.779312,-320.574827,-331.270173,-136.520583,-74.356146,-52.385071,-34.89934,38.78625,55.774712,-31.824756,-158.104092,-174.608029,-148.479469,-112.005355,-19.780822,2.849691,17.951375,25.20572,39.618004,136.042552,210.881695,328.490105,357.641697,340.617195,272.799058,28.386518,-97.089984,-37.238525,212.788498,314.944454,360.874734,317.371872,162.670626,77.081534,-4.254281,55.931516,73.51118,53.76287,48.912377,31.799305,-8.25027,-131.355136,-206.967809,-210.649169,-162.617829,-129.251036,-124.772394,-153.627536,-189.55737,-206.24037,-272.50528,-266.55054,-245.283538,-186.130487,-132.374656,-69.032905,-91.602321,-196.967754,-269.324523,-249.944117,-123.081974,-60.852091,-8.244135,-27.760438,-136.58275,-196.703543,-235.95962,-117.344674,-23.665019,170.311543,239.929935,249.187653,215.221828,201.103624,316.736629,372.759009,303.433246,203.511119,60.863037,33.103632,33.79152,37.499243,20.228821,70.244885,118.500314,183.963025,179.53395,114.205318,98.311266,138.500583,192.213243,221.725568,293.170321,321.286523,334.423267,320.027267,241.825253,176.395299,82.466717,136.797136,189.419879,253.335181,231.670493,94.009344,42.819572,45.739385,114.757278,154.620552,196.18094,210.116847,306.611076,372.647993,434.315584,407.822524,273.751612,213.007035,235.059858,320.89053,352.935276,345.170474,321.731191,277.849459,316.421813,390.924397,528.496263,547.548837,556.370294,574.74265,562.949758,507.861989,416.96437,465.617856,492.056765,475.736559,439.529045,332.414972,277.63607,196.838941,139.040536,114.745362,83.481939,91.498215,150.595781,156.525392,46.318867,-38.261148,-149.168611,-171.517522,-167.634993,-122.486417,-85.456108,-27.664718,-10.913727,-7.909757,-87.238392,-124.87233,-109.21921,-78.039424,-48.92608,-55.844344,-67.495583,-63.501716,-61.627296,6.761996,86.248439,255.155422,290.389692,250.013723,223.500395,156.54471,61.378331,73.918362,175.414445,169.142597,15.803577,-36.104871,-33.624148,-67.171059,-201.142663,-174.296328,-116.957568,-47.01838,-57.809417,-127.225159,-129.140271,-78.766135,-151.87233,-205.351181,-200.551585,-163.140077,-120.716368,-110.321565,-55.639133,-26.641784,-44.774584,-130.648662,-145.987527,-70.43962,-37.677806,-84.509482,-101.267855,-31.124777,65.937482,108.099926,184.762816,207.993836,183.55836,153.970897,132.089208,109.206305:-17.392681,-30.849074,-54.419,-89.551368,-97.553463,-108.588053,-107.460871,-94.545573,-90.693146,-91.564978,-97.20003,-88.594415,-39.730839,-25.422845,-79.14775,-150.456689,-282.425963,-217.773775,-122.177533,15.746427,-9.407427,-178.806812,-232.118093,-252.125345,-259.780244,-238.382575,-156.378343,-131.308804,-141.954743,-165.45273,-202.991309,-215.481522,-245.984879,-241.442867,-214.358536,-134.630061,-115.159481,-170.760967,-189.879313,-125.058837,-29.560059,20.201762,84.498754,80.198936,58.480821,52.102035,-32.085674,-123.830791,-261.471875,-133.356192,-8.191215,167.73643,169.50163,41.682536,-1.203106,8.750686,-0.090842,34.751182,241.956543,327.980015,257.109039,134.412066,-17.0845,-13.737236,16.974063,7.12887,-14.232256,-22.186601,14.5757,13.865268,-74.855611,-247.672938,-215.515395,-171.165104,-128.133399,-127.420665,-117.572095,-100.425059,-45.245158,-25.230278,-20.642727,-0.496596,8.697566,50.302388,106.034038,171.966447,138.141202,26.556236,31.392505,82.603125,142.547538,114.054281,-12.029291,-81.788978,-180.419397,-202.842113,-232.180477,-251.861287,-238.895887,-127.962298,-54.455132,6.434754,-22.129113,-127.18234,-157.657837,-117.636976,4.860513,30.460896,-23.284795,-51.363024,-36.001334,-30.040892,-80.480309,-2.996576,118.82869,288.387003,289.328184,257.628862,261.12128,236.655745,125.363272,102.671115,166.746835,189.479993,112.391227,57.677628,35.156361,36.689511,-17.298988,-63.50013,-53.904216,6.424291,24.611291,-8.532433,-42.148992,-104.178971,-103.06252,-82.247448,-13.154711,42.250918,123.45297,116.38707,28.236519,-22.522958,-19.877601,172.816813,252.734277,276.682524,239.659556,94.769333,8.594297,-130.905654,-172.799788,-141.618227,-49.92837,-28.957462,-36.988912,-50.790128,-125.459804,-198.580046,-308.370599,-248.524057,-203.385784,-162.573756,-163.218839,-167.63859,-165.315584,-213.972568,-242.125392,-194.503559,-59.414646,-9.661382,10.755042,-2.832363,52.514363,97.283666,43.22841,-30.873976,22.486791,174.993752,160.688808,-33.410659,-88.51703,-11.197635,82.791695,91.795264,14.587875,-53.457001,-127.019367,-143.938559,-189.949519,-190.398687,-134.476009,-56.932036,-18.226058,33.357321,40.136788,23.879502,9.843301,-25.883991,-38.260204,-17.055095,56.875353,96.903197,166.998745,171.660127,87.274299,45.058672,80.334395,233.615284,304.531286,361.520196,341.970685,227.174322,153.764177,18.523807,-61.827128,-63.8052,17.84146,70.733928,81.711509,33.704067,-52.776503,-62.577435,-53.258757,-10.476844,50.225989,214.466991,258.607605,153.060946,30.624369,-146.322037,-103.235102,-27.15311,38.873868,-6.913015,-94.917818,-94.287498,-41.230071,-6.777299,12.341881,-19.691162,-20.640559,31.302472,42.54233,-78.980814,-166.65017,-203.040866,-110.260798,-75.084368,-46.269168,-31.984714,-44.121265,-97.567682,-193.618277,-209.385532,-217.535881,-119.693699,-62.878294,-27.720476,-17.661886,-0.185193,-4.305556,-6.741182,5.296979,23.955808,75.519933,91.684916,67.781554,4.577735,-142.598165,-163.350942,-90.630234,18.256564,48.492686,63.644334,44.120028,-50.567894,-68.756717,2.831854,46.925486,33.223472,10.139668,25.61575,78.997275,92.02192,72.229687,29.742608,-65.225991,-37.404151,-3.942461,-24.078296,-81.936054,-206.758759,-231.310192,-157.379312,-15.38286,39.407427,112.917168,163.393807,270.544756,258.980368,151.185936,137.304871,215.015372,265.930698,249.377704,213.48671,217.497858,219.568918,185.655782,75.317537,124.015477,209.936223,286.088777,257.514969,230.842208,249.916181,272.098258,255.616822,191.495804,188.736183,211.156519,262.458618,274.058818,225.193336,173.329005,107.709766,180.38332,226.047352,196.735597,137.811758,53.603839,32.650385,15.236193,20.118245,-13.242092,-135.478261,-183.028637,-167.158712,-130.389011,-101.412096,-113.435852,-150.969871,-135.910952,-113.252574,-97.935705,-92.743305,-84.922413,-95.154251,-103.67082,-116.104594,-209.935848,-225.846964,-149.209391,115.661137,218.564679,197.907534,135.800601,109.951969,128.54048,114.067249,71.316859,61.459539,85.4354,111.380129,125.174738,83.516236,-85.632619,-162.837026,-131.184929,-14.310145,34.588208,71.921477,67.136992,22.69662,-20.102507,-13.79397,-0.776033,-11.762136,-50.841381,-57.307876,-17.072329,-6.066967,-53.086194,-130.076965,-150.479946,-107.037316,-66.688824,-28.761706,-26.699777,-22.037645,1.859733,23.979608,75.58621,109.751379,187.930415,219.942198,235.634615,198.463039:forward
-201.876607,-203.441639,-213.516508,-243.199292,-263.08206,-292.767138,-271.393953,-186.662455,-123.946631,-98.077963,-47.8884,-39.650207,-91.726953,-123.163493,-94.063474,-28.507305,120.10725,157.229414,140.50505,57.99326,-20.655022,-93.838448,-23.031913,151.488655,161.671059,155.540853,178.965519,177.401728,118.342812,93.670484,102.394499,117.002531,117.094964,20.933194,-57.512558,-149.437327,-129.160689,9.133955,80.016515,109.1271,18.930838,-27.750874,-127.046157,-186.921096,-245.798983,-212.826112,-84.958123,-38.433329,-24.980218,-126.404243,-173.337283,-156.396836,-121.950945,-89.254696,-83.800007,-70.675943,-76.265186,-110.719464,-261.015037,-344.790679,-387.51662,-309.838557,-107.671066,-81.360295,-117.530013,-78.526366,-65.178079,-64.602569,-47.633007,44.48046,107.26865,182.621378,206.963115,217.076098,161.617783,99.281894,28.504696,31.574586,10.156106,-14.624559,25.035048,94.482706,73.375663,-20.6954,-41.818388,23.641451,81.668315,164.833702,204.713687,190.114553,84.746549,36.005501,-6.889975,-21.766253,-43.970707,-21.956335,118.325301,194.96945,173.27217,138.116872,152.082182,237.73647,293.211115,368.720589,401.986987,391.683484,282.929877,218.626748,157.450758,165.94921,209.073728,203.041471,136.126748,79.46879,59.978668,-1.101474,-57.83031,-133.243782,-118.567343,-53.551072,-72.12057,-121.016677,-196.300876,-191.322772,-141.142927,-125.044602,-139.21805,-174.779296,-235.237308,-154.183079,-100.495007,-112.583722,-185.489413,-337.028663,-351.629463,-258.686763,-192.980081,-207.61259,-198.695943,-154.448443,-138.420324,-179.862618,-205.115374,-158.911306,-18.620276,14.478681,-30.170454,-93.086858,-71.811957,-13.38196,-9.512677,-28.761856,-64.475247,-105.426669,-203.267056,-232.702859,-275.52762,-288.499459,-229.752402,-165.379396,-81.667333,-97.371774,-103.143714,-88.763172,-87.008625,-80.124487,-67.056218,-32.110324,5.670419,-15.542488,-137.459416,-170.942365,-87.448669,-8.796902,94.109666,115.777439,152.398011,150.16795,128.409405,94.739627,89.100256,127.126752,157.184574,179.795482,193.209333,162.182364,-25.1525,-123.354248,-256.278609,-298.021657,-276.668827,-214.721323,-122.085727,-161.452523,-200.678017,-246.924433,-249.30766,-149.924818,-39.404683,122.189324,57.865473,-22.954057,-181.709053,-239.400349,-331.938791,-365.751813,-387.585553,-351.963144,-174.589421,-115.434382,-167.959282,-244.500931,-218.164791,-98.529837,-41.834118,44.924846,74.554227,57.376008,-44.358242,-121.393047,-293.141741,-339.320356,-238.257973,-121.658345,91.009445,131.081706,80.076836,-95.713351,-187.506597,-211.477605,-123.989074,16.053391,-101.775414,-185.623009,-218.032176,-190.279864,-190.646639,-214.872647,-220.840037,-199.192008,-170.845243,-171.631033,-147.683169,-111.643851,-160.281437,-268.965074,-246.527441,-166.758037,-181.350767,-176.051839,-137.10957,-135.318923,-157.372756,-150.048321,-129.791095,-148.959901,-197.088217,-215.239929,-235.110573,-308.042309,-338.490617,-309.777659,-257.060707,-163.650572,-60.171862,-6.879142,30.088644,5.169106,-95.149139,-120.549183,-50.354494,16.32179,113.011508,115.514609,107.032291,111.474624,91.252227,-9.742168,-37.247633,12.033757,84.454377,77.453639,-31.859971,-97.245322,-185.366526,-192.082739,-94.427511,-26.298877,37.034848,83.357107,107.892009,57.551069,-6.905661,-36.911943,22.445411,147.868526,138.257548,99.129679,65.033279,73.477964,57.796027,53.989812,140.388919,196.540905,237.640263,223.980547,205.914562,133.489553,97.526597,64.382523,41.181946,-17.347888,27.311963,59.367511,57.693601,31.039586,-26.130954,-19.885856,60.059551,89.468529,130.004836,139.594713,103.272796,1.531466,-35.971641,-27.607649,14.249435,91.332459,93.388472,68.639021,33.361813,33.098387,-19.747575,-82.207218,-116.505188,-47.703145,118.16166,115.465471,91.981773,93.520809,69.542115,-40.276322,-76.453428,-59.302365,66.158136,126.00823,172.305225,170.014561,97.683337,39.819783,-5.210292,19.20826,84.864408,19.282766,-47.943244,-26.190813,64.820253,190.306155,192.505073,164.484956,157.632614,146.117395,106.173762,77.938927,-26.790444,-72.483656,-40.766228,20.67344,110.105162,42.694283,-14.347243,-66.048864,-82.280341,-102.74699,-77.129166,12.392179,60.0423,57.889497,0.508612,-63.231171,-227.267277,-271.220088,-188.880365,-90.824372,72.776067,95.584502,62.404147,-28.430112,-50.975801,26.529447,123.519532,309.969348,290.617427,206.593245,39.459354,-3.705547,-8.454569,18.168417,101.175891,129.100341:-181.417251,-209.559856,-220.2937,-292.387873,-343.517712,-342.037377,-266.709518,-98.62229,-43.999412,-48.323812,-52.671292,-56.61867,-116.223683,-142.924585,-89.629212,-14.651609,120.280135,73.237703,18.324987,-1.512316,23.824752,55.688488,44.660422,31.625363,155.557002,220.895826,180.288857,96.015301,-7.576623,20.63811,132.122235,134.147333,33.097127,-44.498117,-60.184353,-54.975346,-33.815245,73.578867,145.963745,178.871703,86.151883,50.958128,-17.277475,-45.935984,-55.549019,-36.543513,50.390225,96.10793,123.443174,42.239325,-5.004705,-56.974836,-76.32819,-76.589883,-40.187962,47.351226,24.574085,-46.774884,-190.45099,-222.571379,-232.969768,-219.627919,-150.464232,-98.618854,10.313991,-6.58922,-66.85143,-116.042992,-63.300795,121.620442,202.32989,249.762578,181.15599,145.372427,86.796269,56.027616,12.52119,27.663823,120.033618,161.628259,198.338541,167.291285,131.647537,37.098755,-10.175137,-17.895684,41.368612,207.587688,246.847887,183.904344,11.510791,-51.968063,-134.229027,-158.405063,-130.002491,-63.055226,93.153059,125.326353,100.737742,49.887622,54.570542,161.689523,226.466953,296.223776,345.550665,343.693783,264.712903,221.454264,160.448305,150.191296,191.656435,214.512974,153.754237,17.86029,-4.824799,-44.216136,-114.354665,-196.634896,-142.36182,22.675221,32.177698,-14.8087,-68.398998,-57.781252,-84.820814,-147.759492,-225.903145,-176.836732,6.426439,-9.645764,-89.944789,-198.190129,-209.985054,-228.28996,-242.630313,-190.628171,-83.142873,-85.65147,-141.178267,-141.534532,-119.24787,-119.967336,-143.3345,-128.602467,16.880868,101.298688,54.93618,-75.67667,-88.573489,-7.44132,40.272305,94.98159,78.901914,29.068839,-75.962887,-103.776357,-163.182944,-183.612504,-130.771225,-81.741486,-35.896396,-66.08929,-95.342752,-145.368592,-146.825166,-95.682232,-66.969859,-24.459007,13.359753,14.99447,15.454662,31.406505,53.55848,58.241785,82.17042,97.300538,133.107464,104.18607,57.426066,23.108722,65.898897,196.496361,230.862185,214.72002,195.50944,182.006168,88.693686,8.418855,-131.847029,-133.66458,-11.038609,51.290143,103.113052,23.060635,-62.2119,-157.336755,-125.83398,-30.31573,-17.171305,36.591934,110.890356,67.013975,-133.920952,-219.037002,-337.852499,-364.82311,-309.916362,-268.191714,-246.257266,-264.441505,-271.842512,-314.761828,-336.862277,-263.03419,-171.720318,-13.823392,-7.271131,-52.487876,-129.919655,-149.797071,-215.503222,-248.184826,-201.394251,-126.663698,10.906675,53.768498,45.752266,-67.194947,-181.070434,-327.221587,-292.40072,-163.059687,-167.590078,-207.139609,-269.283268,-278.451827,-272.829092,-246.758569,-156.436751,-116.778447,-97.779255,-202.888886,-262.578746,-317.809691,-323.237748,-289.930784,-256.796205,-188.65008,-140.380932,-140.687729,-193.412057,-246.511945,-317.064639,-277.82949,-140.961348,-134.207618,-251.982245,-306.263162,-287.700945,-299.96024,-345.811704,-371.65735,-315.362815,-128.067691,11.332611,22.338471,-11.457545,-36.185773,-148.451109,-202.790336,-141.638292,-21.629154,203.417016,153.654912,68.891445,-9.693288,8.084838,75.921618,85.336696,46.908533,50.293171,52.539354,-1.156202,-33.353091,-80.172581,-78.457615,44.622608,132.771414,205.809771,150.044973,121.230512,65.557383,29.050383,-21.247899,-1.676757,133.555003,214.110926,191.040783,156.584293,175.366545,168.883663,140.184034,162.639881,207.478433,227.242757,131.414205,84.73257,31.756466,6.947386,-42.942843,-35.911822,58.805742,132.09956,128.620585,66.143942,23.825992,-17.082438,4.505931,74.821026,86.124053,67.65217,59.700171,48.905663,-35.864886,-77.040153,-30.958469,31.187494,98.681985,103.573158,101.426317,47.5905,-14.637451,-101.150598,-87.071395,2.446823,59.366167,173.522626,111.982781,34.420235,-42.174542,-60.405133,-108.043878,-115.501258,-67.687025,36.668356,71.890067,77.491738,52.502973,-48.74431,-86.448649,-57.743354,-16.085069,29.580767,-22.65206,-59.204986,-62.969945,-35.691667,57.974918,110.082287,146.490839,104.200271,82.438212,58.400316,38.826045,-38.292002,-70.365567,-51.267596,-2.575913,74.928993,-3.331691,-61.428758,-86.885201,-82.791839,-130.089529,-149.833771,-66.204275,75.791843,78.961996,-45.421535,-120.150771,-222.97869,-238.699754,-182.535006,-125.01769,-39.984504,-75.371552,-118.925799,-154.645641,-130.837927,-42.921073,4.230782,130.803449,190.97991,132.091299,-32.643496,-73.316001,-100.061925,-103.193976,-46.931258,21.148031:-171.286166,-174.5752,-191.288558,-270.063298,-313.828259,-349.523993,-320.313826,-152.677534,5.466837,14.015569,-43.91941,-59.104337,-32.970616,-1.330301,66.199069,92.842834,122.374491,85.921682,45.139308,-44.438522,-58.832319,3.285115,44.465148,110.531026,147.193495,138.673034,89.511866,59.97682,20.9552,39.38127,142.177992,187.402689,191.137495,39.266391,-43.557819,-99.013352,-89.797927,-14.244768,68.700486,207.348039,147.903634,99.918085,91.491257,88.642877,38.391398,52.891643,164.588158,196.58794,167.956471,67.360748,9.171663,-74.336335,-86.522516,-58.611972,-32.532639,6.99269,-28.413847,-72.330641,-136.326047,-155.875773,-188.530265,-177.098691,-89.395506,-46.808291,-27.562816,-52.16821,-42.80344,19.852245,53.461409,91.088895,100.894966,167.2489,250.188229,237.935387,136.318724,92.082411,84.468534,124.090585,204.500072,224.013838,221.428802,130.854005,70.953989,-31.727343,-62.167301,-11.537323,63.926705,183.298315,150.524739,91.606966,-39.093968,-105.162028,-205.179291,-196.12394,-70.123879,-7.875454,70.790947,72.833523,54.874094,55.847447,84.574346,195.844306,252.631503,316.606412,356.830544,348.426954,262.031969,219.78562,168.995698,152.933918,134.665926,129.702118,106.238196,57.110983,47.382057,26.086477,-6.572005,-22.764611,18.810319,79.164962,-15.058526,-81.146627,-138.458727,-144.557462,-186.075524,-199.154927,-137.388006,-75.960281,21.605974,16.536749,-20.187706,-152.051625,-221.514123,-244.024679,-191.301491,-69.915991,-23.136361,-33.959303,-77.882652,-86.27586,-74.100086,-50.502738,49.970087,100.508925,132.561103,89.794299,52.07889,4.117202,23.926175,115.34249,146.70353,165.598495,139.519266,94.866817,3.932414,-16.240781,-30.894387,-22.086452,72.986649,145.230123,201.416139,46.409104,-47.351779,-167.422458,-176.46412,-57.012782,20.241723,105.945156,175.845808,190.584939,129.532429,100.092966,133.522332,182.94884,302.700863,340.01625,284.495128,132.236435,86.866464,75.947205,87.373299,166.277081,228.876447,319.857491,294.34214,216.660685,29.563841,-28.562471,-62.839698,-45.956442,23.948656,51.804529,38.394261,-23.915547,-54.061317,-143.037412,-179.242017,-117.58304,-31.042293,106.883679,71.5734,-15.799527,-210.818928,-279.127606,-356.361251,-362.930505,-311.140023,-287.684254,-314.493579,-347.341883,-349.252294,-373.716618,-377.119624,-285.861162,-196.351579,-0.642319,55.411953,13.933382,-88.501546,-135.453557,-259.166404,-311.098344,-270.374504,-165.596118,72.008509,120.899938,77.596814,-71.083981,-155.481386,-235.353921,-222.465198,-182.096036,-190.015886,-212.119077,-271.577295,-308.832261,-347.291639,-314.921563,-209.923199,-186.144148,-206.776306,-257.635527,-279.871872,-334.027214,-356.343477,-315.992767,-262.598488,-180.963234,-159.216831,-168.591139,-212.844628,-236.797289,-261.058925,-250.011893,-196.133227,-174.397281,-145.508238,-151.938045,-190.156985,-279.974647,-308.265553,-306.215057,-258.619945,-82.168236,41.594248,38.194381,-34.780891,-83.863335,-172.002099,-164.622818,-11.307267,81.359134,162.474029,96.450354,54.855786,-11.661912,-48.43988,-46.87386,9.347968,104.398731,95.400994,75.369003,60.205715,53.144278,-11.850694,-25.307236,106.349017,201.313416,226.352316,78.36972,34.076074,38.703485,45.459905,47.020757,83.103355,231.528259,278.80906,235.524935,117.825426,55.77299,-79.089848,-100.587308,9.763473,92.248128,152.119231,26.075853,-39.060285,-84.840497,-98.926907,-146.087921,-148.18132,-54.467615,30.72449,22.734539,-29.435989,-60.910183,-141.408143,-163.892241,-116.322141,-57.405541,32.392415,-44.652324,-119.662833,-231.359508,-246.964048,-153.865378,-77.446814,20.722882,49.494781,29.589424,-59.416336,-101.954822,-117.833207,-76.392593,55.533006,108.91307,127.984897,59.114795,36.666862,29.312274,7.585185,-63.188235,-78.164352,-29.373471,80.596983,99.157401,36.244429,-19.642934,-97.405872,-80.260963,22.883826,45.200603,-6.566016,-89.505814,-101.040678,-25.946748,22.326383,69.966379,76.071231,78.002892,63.115073,27.41409,-68.373636,-90.614568,-56.975496,-24.985067,13.680549,29.566863,82.268556,63.401728,21.027635,-45.418713,-54.433875,-41.54293,-27.705002,60.878478,155.710042,128.363179,-9.711759,-46.492573,-62.285455,-77.643496,-94.928557,-69.664366,-4.879269,-22.314635,-48.603209,-82.585085,-73.920286,8.318407,62.707526,144.480004,158.546602,121.59538,-15.331422,-79.600697,-102.245934,-58.075865,29.612984,49.538463:-96.912997,-161.754876,-182.797653,-226.328856,-270.080434,-307.61534,-277.615146,-199.521722,-118.01356,-74.560972,-55.141231,-77.596409,-98.629767,-80.55615,-16.092622,30.68976,145.061213,160.826829,140.115864,151.029573,175.910003,211.592261,228.753513,273.4415,264.195248,225.462973,149.218525,125.554587,73.296358,72.280843,180.444623,240.88212,220.856658,32.936332,-32.991194,-20.078671,7.103871,66.842579,125.388976,232.296772,206.022724,159.049214,54.074205,6.303249,-40.295623,-30.549675,-17.61198,-30.382554,-27.480508,-65.343622,-125.306731,-230.989012,-245.131627,-172.057625,-108.360739,-58.652527,-131.442039,-174.680509,-258.079623,-299.165413,-347.316806,-333.286485,-228.281769,-167.784301,-82.103301,-65.614853,-80.056233,-78.075182,-42.880368,87.939076,170.742515,297.537166,304.778706,264.480406,144.974341,100.904483,60.356383,45.467088,30.169431,42.763613,91.593947,103.427582,87.673833,8.075216,-45.366711,-53.563578,14.427576,182.834429,237.026746,208.516379,45.186387,-61.532546,-180.727353,-174.083116,-104.208637,-62.502553,32.425876,91.504166,106.631231,171.981494,226.701676,318.459,333.514831,346.874191,385.320841,381.653982,296.20302,241.09405,192.27729,206.585356,242.097709,226.037719,138.22919,96.026201,94.793781,47.74146,-5.052931,-52.271603,-16.523433,56.916185,-2.171064,-50.17202,-78.420271,-62.129615,-72.197833,-107.888092,-143.233557,-121.783985,-39.793574,8.523699,-13.954366,-133.68482,-197.000167,-236.507102,-195.047746,-75.523468,-41.055263,-45.469033,-37.348854,-38.546381,-57.112479,-44.610296,36.83827,85.842198,164.137024,137.726813,78.041841,-33.418713,-47.16424,23.088595,71.539954,107.660273,103.070346,82.947007,-25.677747,-84.82283,-122.509178,-84.607131,42.492113,60.541517,-33.349389,-68.457853,-51.041851,-82.642003,-117.802835,-145.409762,-132.963951,-17.188106,142.506394,153.587552,24.78735,-33.670578,-1.907175,75.687596,273.293403,348.655777,369.203394,261.511802,217.840887,187.856761,165.528316,119.104574,133.46789,225.933449,243.114554,178.48457,3.455315,-58.970487,-128.622789,-131.375647,-83.553186,-62.572835,-53.576005,-84.122344,-125.941113,-212.217044,-218.595593,-115.432793,-42.65287,15.881956,-8.393966,-19.47139,-55.32578,-108.61819,-283.317277,-347.55602,-360.730865,-336.983883,-249.017903,-160.090135,-159.233484,-202.461205,-203.019167,-134.222615,-71.419643,77.421288,120.71523,80.141336,-45.163916,-107.275626,-193.239586,-193.020177,-104.676537,-44.2116,52.126064,78.379438,54.466444,-79.940491,-157.017362,-190.925281,-149.162382,-102.43823,-157.711195,-190.116135,-243.305609,-269.582384,-311.123864,-303.13427,-193.025946,-112.529038,-58.61099,-183.908285,-225.071499,-204.189117,-197.467083,-219.533501,-211.0639,-130.810437,-16.936762,11.210451,-73.88474,-157.777543,-211.74264,-164.250601,-76.861554,-86.270944,-147.234221,-139.500525,-142.671936,-231.868587,-297.236345,-353.011808,-313.279841,-165.490928,-78.935822,-77.612973,-107.095125,-128.719908,-178.823881,-171.760958,-78.573491,-17.978493,139.134975,208.932207,162.293341,19.863783,-29.827183,-62.651954,-38.23813,73.756476,117.824475,70.81928,-51.107247,-69.45235,-72.673523,-73.051726,4.500313,71.097751,140.37748,82.859979,44.334595,7.235812,-1.854383,2.704119,29.034736,87.219331,78.287693,65.660003,73.673579,66.870714,-38.011129,-91.537194,-95.001361,-62.365542,17.676871,43.86345,4.481908,-131.768019,-187.375595,-233.639448,-233.084181,-205.053919,-125.723707,-77.316637,-56.941398,-87.718946,-142.543943,-142.023496,-87.233648,-56.046223,-6.771307,-7.371266,-71.658307,-244.227805,-254.209243,-92.930275,-27.77545,-47.513532,-78.937552,-83.373528,-119.093554,-129.781601,-83.251011,-48.312038,-51.945379,-71.681341,-38.52467,14.043903,17.034742,19.713823,5.743625,-80.605634,-122.885473,-104.539205,55.674749,106.741837,36.615043,-43.320617,-153.693937,-162.929105,-111.210791,-66.104088,-0.913448,-74.563346,-126.950722,-117.550886,-77.161902,1.158047,44.719133,103.756123,113.348751,118.358765,93.824197,53.877332,-34.201484,-52.616661,-24.016277,2.525483,28.756482,-12.389573,-28.840475,-3.686093,5.465793,-9.945552,-5.164549,63.911617,155.442679,171.197858,107.460217,38.622214,-113.838765,-139.903535,-18.099556,71.932129,169.162145,158.865764,126.631077,59.831531,50.284046,126.160922,195.92628,265.236329,207.820143,180.97349,163.365627,151.189131,88.414689,64.616623,117.271551,173.495592:20.518784,-94.07882,-138.383222,-190.467136,-223.554634,-226.550039,-182.755652,-94.884199,-19.365885,11.560419,3.410843,-25.256543,-24.31274,19.435019,91.287265,102.893442,141.261462,184.531841,186.605118,141.995953,110.170887,94.399384,123.083024,227.478812,288.005687,279.860949,200.743163,140.356627,51.399577,62.029054,160.316984,197.962292,193.923178,59.460563,-16.894121,-100.076642,-112.341262,-33.814131,50.42311,178.708202,195.033765,174.885891,94.252166,37.421102,-41.332538,-23.901956,97.251687,140.559455,99.315347,-39.177592,-99.975619,-196.306394,-227.181125,-176.687537,-108.68089,-50.852481,-140.950947,-198.967252,-253.098008,-255.027174,-264.344655,-251.934581,-152.122011,-95.731328,-63.626804,-89.200985,-85.205852,-72.108329,-60.661964,62.224569,153.213848,249.794085,214.853125,176.728087,114.271457,95.085528,83.871771,93.964043,96.311721,85.942851,104.48378,127.808539,108.904855,-19.125842,-93.845293,-109.219284,-59.750261,51.151067,141.475025,139.457219,-21.141697,-142.761199,-277.437183,-236.854896,-55.993942,2.04591,35.893841,50.037146,78.54227,165.530975,198.224517,262.686306,301.279641,370.37636,392.617686,362.309517,233.584849,153.408553,51.941308,67.567596,130.218633,120.418805,64.875794,25.463749,24.470431,12.05737,-29.475039,-73.143207,-36.338225,45.846222,-12.283748,-75.398321,-149.768047,-169.625347,-233.232966,-239.868232,-145.302179,-71.020744,80.385978,150.05775,116.830992,-64.109142,-141.164908,-120.41525,-58.09519,8.649593,-20.725434,-27.419043,0.099624,-9.186536,-51.330705,-16.431686,132.824965,183.327219,222.292874,171.659676,108.692835,4.070142,-9.344414,61.663965,139.263077,295.320374,291.7492,218.42401,75.354778,32.200823,-42.047544,-37.047856,110.113795,182.323089,202.026117,78.194358,-4.288572,-109.19042,-112.074708,-40.530048,5.560253,76.467165,144.302733,149.294364,37.33592,-28.799255,-15.503623,72.602476,302.265636,386.970931,386.40871,243.315741,202.664713,148.648893,104.801392,90.993831,138.95757,224.023964,187.968356,118.842932,-40.086681,-83.521873,-68.933488,-36.272713,-13.006391,-34.098171,-99.292659,-146.503593,-163.154248,-191.00099,-201.262955,-174.528308,-124.703882,-12.616206,-3.233759,-58.329426,-201.124896,-265.278539,-384.836073,-402.664665,-350.517891,-328.082665,-308.637104,-295.105482,-300.146937,-333.690058,-329.971892,-190.827758,-76.817099,128.655773,196.166169,156.848951,27.491764,-39.391386,-185.538082,-226.500113,-126.838541,-6.578552,176.169882,111.319021,21.278384,-130.655923,-156.247603,-114.849323,-86.995221,-79.485066,-119.741675,-139.606985,-193.993088,-244.86231,-323.658316,-308.588517,-200.415587,-147.396046,-95.499831,-136.891812,-176.844575,-233.917456,-246.629169,-228.421452,-190.764255,-91.727882,-39.628606,-43.194877,-73.399311,-96.108433,-124.622064,-109.573568,-56.141256,-33.695229,8.830344,-1.820663,-47.082299,-212.971681,-286.266851,-271.418268,-203.68004,-75.854646,-17.094552,-28.551397,-87.315782,-114.987015,-166.198164,-158.095962,-13.035347,89.458053,227.495281,233.395323,182.400216,17.881686,-35.191955,-10.858039,16.027497,47.037233,148.678157,175.651793,65.157368,-29.947476,-128.052119,-86.88692,121.820661,202.770054,220.606186,176.26128,169.759945,134.585597,98.61883,87.898587,121.681925,206.168491,220.693296,173.341881,48.639868,-5.537264,-114.248232,-139.057813,-94.50564,-62.48585,-40.037165,-80.242248,-119.560564,-218.281497,-265.204188,-302.604376,-270.797816,-132.000593,-38.503935,-36.396462,-97.102917,-133.173181,-182.750976,-191.833156,-131.481054,-66.436016,22.207203,-54.769692,-144.377203,-305.242229,-317.784763,-194.306087,-112.773126,-5.297934,-15.995797,-57.299174,-96.586211,-84.870154,-47.817509,-27.600839,-6.447909,11.567632,102.706374,120.331345,80.05889,1.674825,-22.97584,-27.61316,2.570725,86.568657,139.200637,131.686824,48.378313,-14.055433,-122.894184,-130.007779,-43.834098,16.213877,96.463002,20.177794,-36.893601,-35.667944,6.837822,48.981966,37.363927,41.586647,83.409952,65.684326,-26.565792,-66.727441,-84.619402,-61.592622,-32.593836,-39.460873,-36.639482,-35.738159,-41.515002,-28.535672,-34.694745,-58.697778,-22.598538,164.583206,257.615316,212.886492,61.27762,-1.906006,-80.611661,-79.545382,15.276059,79.379315,146.923892,122.802308,105.966066,85.942087,79.794507,119.6177,160.828153,233.295354,279.591536,262.119597,118.784266,23.764567,-74.743758,-45.63032,62.199054,76.028257:-57.630663,-90.600525,-145.060525,-202.352096,-205.835638,-192.31011,-167.730842,-129.0558,-119.720269,-107.18623,-48.792801,-18.882399,-41.24942,-68.622477,-9.752027,59.658516,147.250822,131.399904,118.569791,111.876363,107.279872,134.530986,171.857505,243.02198,279.247317,258.816762,177.176885,166.546949,178.393078,159.426472,130.730766,157.02622,197.675569,84.699474,-1.934622,-119.594235,-114.947468,29.062017,114.810583,188.007397,138.602749,64.286255,-121.082027,-163.177113,-123.363376,-87.432169,-49.609928,-51.289724,-74.521279,-159.24092,-214.244053,-230.799048,-188.655551,-84.937092,-48.933498,-48.62618,-155.72765,-210.785149,-281.333312,-326.593331,-402.832457,-366.869137,-163.224449,-87.499103,-78.223818,-139.537331,-155.954066,-81.587224,-7.031579,115.885267,158.967123,221.117348,248.612389,226.528106,61.353033,-23.750767,-65.468368,-69.132495,-161.621037,-201.89997,-117.999008,45.91067,88.806505,94.06853,57.601751,-4.48423,26.973157,181.686941,263.644428,240.750039,129.517202,80.682683,18.071259,-1.717915,23.416293,71.993063,167.374495,185.529664,198.183688,281.571311,321.953312,368.308601,371.726411,349.808162,369.035308,366.180023,257.518693,196.684376,142.527626,123.545297,73.367703,57.830268,52.074978,2.645896,-28.410295,-36.849675,-46.367977,-100.944198,-96.165217,-35.048627,-64.927829,-102.731947,-121.969218,-105.118668,-86.109341,-75.868654,-23.885638,-15.173611,-93.510302,-131.928488,-92.312053,-52.328293,-104.990733,-232.011539,-238.270321,-158.591348,-114.57666,-128.198207,-132.072551,-113.682802,-78.488346,-41.557704,61.497049,90.841776,100.849249,45.567613,-2.452869,-37.957772,-7.290767,72.25663,91.367677,91.144094,64.294521,28.851906,-99.453762,-153.797427,-136.938398,-78.630193,4.053762,-10.425902,-110.239265,-145.660229,-127.418088,-90.811853,-88.335535,-91.198671,-74.540116,1.473311,35.731144,-2.913749,-133.334237,-160.695431,-82.992745,12.996985,224.950537,277.168202,273.458101,244.723917,218.443651,123.875823,79.130433,41.77393,38.453261,62.150995,124.783193,105.192555,-71.651078,-158.224533,-235.909911,-241.878546,-248.999414,-253.20175,-186.11746,-165.294449,-224.652891,-294.945374,-275.827751,-233.809483,-219.018184,-169.815657,-63.229953,-5.805324,-36.139114,-130.16351,-289.389255,-288.509102,-202.65935,-181.694083,-148.362075,-59.451047,-26.259459,-24.378215,-35.032602,20.906498,87.540716,191.884225,202.802076,163.445198,18.108997,-37.557876,-111.38909,-150.6281,-149.766029,-89.536715,51.359008,64.667326,22.44798,-82.55076,-117.63578,-87.563716,-44.659123,-61.809602,-166.866051,-167.222363,-86.659218,-72.59013,-113.486313,-140.694072,-168.250787,-148.686917,-95.608887,-121.094149,-123.864913,-75.458388,-68.878318,-61.276576,-23.719393,29.917604,9.501218,11.60675,0.619544,-39.720798,-153.547496,-194.403164,-174.817818,-119.726563,-20.673766,-90.091531,-191.23839,-351.910997,-354.509545,-248.974174,-189.828187,-103.34313,-11.40792,31.329127,67.870816,51.481738,-46.632742,-82.064685,-1.779791,94.13656,218.749317,184.322067,171.598181,192.856267,174.011703,39.172586,-27.897735,-37.829676,51.191684,40.244875,-108.530527,-169.271716,-205.528262,-200.936018,-119.384539,-54.68853,50.31344,83.270554,54.068682,-12.497755,-27.821062,-63.223313,-54.689353,36.439111,58.803276,31.238092,-14.407487,-32.118861,-112.801675,-130.833609,-20.478449,42.586742,59.087745,5.657792,-22.736849,-56.101167,-59.713586,-73.189284,-102.707903,-191.882474,-217.781674,-215.031032,-192.531651,-166.287106,-137.344063,-138.120831,-75.358903,-2.844453,103.536075,32.42693,-40.50214,-99.29644,-78.659486,-18.836222,4.298922,14.327245,-31.856588,-51.188014,-30.573451,-11.632381,-15.080328,-15.950594,37.385019,77.551841,119.077935,84.517599,59.461567,40.458229,43.978193,70.88704,95.391692,135.764182,120.940336,93.270798,35.320328,16.642507,3.089332,12.111324,91.480706,155.157027,218.607703,87.090219,3.794003,-28.240269,15.02431,121.216378,153.484756,145.296644,139.001806,159.467432,161.434399,113.298654,-16.361377,-61.531646,-94.927605,-88.068255,-53.622483,-102.209833,-150.380821,-127.984458,-70.99593,-2.360036,12.656519,77.69833,185.290779,202.8492,131.374767,67.572476,-123.375237,-205.9565,-116.435621,16.863766,149.78563,91.658609,80.752013,154.088065,206.282741,300.886618,341.199262,349.872018,274.042201,229.705638,144.721096,118.467834,113.380084,127.806003,182.184869,217.669622:27.271366,-41.225203,-121.239417,-255.750354,-283.026958,-243.148511,-189.849218,-86.718517,-36.012011,-34.542639,-22.694016,0.879148,9.886738,-8.435866,18.952401,85.637744,242.321256,227.458739,166.024022,103.194832,117.892193,204.286937,256.399447,327.671577,334.021054,296.17828,167.688665,121.229077,105.668867,124.964918,194.739009,223.340815,188.957914,62.209086,24.492343,3.81508,-11.025846,31.009425,104.381954,209.856496,203.664876,166.873001,15.46786,-45.854151,-26.436688,13.625365,-2.614111,-50.377891,-100.146995,-143.968291,-187.1916,-244.629264,-251.729889,-194.226361,-128.073265,-47.327975,-122.124968,-184.658789,-263.611185,-279.745,-314.317455,-307.005312,-189.399482,-122.737848,-79.94694,-148.862082,-186.020171,-175.400088,-119.293295,69.282521,166.568783,281.417031,269.739532,209.724397,33.337263,-22.975191,-7.702422,6.841781,-75.861587,-132.433431,-105.258369,11.028851,24.93199,-32.414888,-63.068455,-67.04663,-46.483891,52.208763,156.800196,145.304078,0.044484,-91.089096,-184.95472,-169.770707,-89.734531,-39.349005,39.379473,4.073396,1.67153,131.582423,221.161088,364.234608,418.283133,455.813889,386.804925,326.666332,156.823248,78.105062,42.327713,82.815224,156.627777,136.291793,-10.287317,-91.832292,-72.232244,-50.489998,-82.09953,-105.574092,-61.313744,40.971062,0.852081,-75.128886,-189.450891,-179.98767,-109.388719,-90.091991,-45.150126,-4.298973,56.684049,-7.029011,-63.3148,-134.376241,-145.194395,-102.896556,-60.181458,-8.986114,-7.025299,-17.889985,-46.443353,-59.868365,-85.998492,-64.559236,102.227559,201.147536,279.622656,188.586384,116.658923,9.093666,6.797547,92.73474,140.963835,200.993994,203.114177,150.249156,-38.94577,-107.559529,-101.293233,-42.507106,90.104087,110.005633,27.323176,-84.595275,-132.582922,-196.023566,-196.424892,-144.579001,-96.820803,24.099223,79.941463,43.370691,-116.482195,-177.448062,-126.573905,-5.385346,297.31683,396.136257,398.661748,282.866877,224.719836,102.538406,62.813805,83.638565,121.432047,187.60815,218.35259,194.028647,55.314166,-29.345543,-142.658201,-148.068323,-103.211465,-84.794226,-71.386426,-162.025901,-254.901346,-370.678295,-358.636855,-257.405037,-191.059495,-75.926706,-44.734972,-73.387535,-189.782028,-256.546191,-367.813839,-371.19646,-281.954408,-258.459509,-254.311752,-195.845449,-187.117373,-234.81948,-226.459156,-46.904363,80.345622,237.169279,220.2583,176.952296,41.934446,-42.417897,-194.283039,-222.264393,-110.523556,-9.545246,106.792691,13.653976,-72.799653,-169.437109,-152.400767,-69.714844,-55.324686,-84.162811,-118.627949,-148.499483,-234.447473,-249.374895,-195.44373,-173.154093,-167.083911,-137.591015,-40.009269,-81.94655,-136.540578,-163.146527,-141.547661,-76.822799,-29.186279,53.706982,18.773934,-35.573637,-124.396612,-137.590779,-117.200585,-94.162396,-27.148388,0.392703,-12.324391,-105.906246,-163.980367,-236.955718,-231.374532,-130.650936,-72.227549,-43.594069,-33.619177,-13.368061,-36.184795,-99.368399,-218.005469,-206.846116,-33.49315,85.160663,259.800603,246.917384,187.549388,47.028258,-11.459339,-72.416872,-66.245873,17.592653,108.485828,104.503085,7.14385,-38.562048,-74.071957,-54.716321,68.906987,130.699965,179.010295,145.202753,91.009197,-43.103285,-74.599971,-2.05006,73.115519,169.330454,160.558,131.237962,49.147532,-3.793138,-105.677035,-106.454616,18.175629,75.263518,57.18275,-36.261903,-73.91608,-129.057877,-136.520924,-118.585324,-119.333008,-132.477096,-103.804748,-97.158751,-148.683626,-186.218721,-218.648847,-210.602308,-138.571921,-70.883867,59.604919,42.728577,-38.560018,-203.561095,-203.397517,-42.192184,18.789983,-3.959315,-56.147254,-72.299155,-86.24152,-69.493348,-13.148618,11.626061,72.132084,113.010186,183.048239,155.378717,122.593215,107.928973,110.538434,107.615226,118.431762,160.046391,205.58181,189.462115,16.31116,-79.197418,-107.212388,-41.239084,152.617634,240.454464,262.106099,43.420379,-50.086945,-17.165069,60.870626,133.49618,108.30539,21.423185,24.24883,49.302886,57.068086,42.604142,12.661282,0.411482,3.878602,11.17931,-6.432129,-43.080287,-53.312822,-54.509609,-60.608376,-60.690205,-27.40964,93.235643,167.139626,149.692699,29.664833,-47.354522,-166.301852,-169.273691,-72.713834,-18.783653,61.963344,65.066156,41.31025,39.017007,70.913599,186.86357,251.025654,302.517908,260.112759,222.933658,108.674917,45.840872,23.222062,73.085108,175.731103,203.164427:-156.949208,-132.115567,-112.638709,-98.27018,-115.314079,-137.00763,-108.80982,-47.373563,-34.824519,-11.078048,87.941428,129.379323,130.371262,109.7448,80.254443,68.841917,59.196293,55.843085,46.700824,31.325343,42.55948,116.272836,158.581236,202.416821,180.167384,149.505668,96.72799,82.119345,48.74116,32.055735,35.916524,41.328434,-22.324827,-155.617549,-205.654326,-218.29026,-187.109374,-102.020486,-62.789278,-35.569013,-88.697085,-123.682463,-144.300528,-119.802578,-76.556177,-80.243417,-76.424343,-46.696381,9.877578,-35.340955,-65.992803,-57.206141,-37.956566,-19.231779,-20.529451,-27.528389,-1.154804,-5.545466,-122.644024,-192.657973,-208.763551,-159.688256,-36.233141,4.265614,5.98102,-39.292894,-50.637665,10.981423,66.904009,173.534268,231.628932,329.431355,307.449615,230.583693,34.215503,-19.571482,-40.951709,-61.556293,-118.376973,-117.836517,-62.569788,-40.366488,-46.620889,-30.492981,-11.69478,11.246881,42.258159,173.791093,249.67605,237.970909,159.405198,111.310733,45.781011,36.316518,52.650687,76.840869,144.807328,173.232886,175.226029,194.430703,188.126458,111.588513,78.09872,87.212578,95.971126,57.515692,-47.699856,-75.111319,-66.303209,-47.155384,-48.427904,-90.704539,-175.494443,-131.631361,-84.661838,-85.960562,-151.233859,-240.870305,-211.97223,-108.87539,-61.403352,-50.726692,-36.361571,-26.532396,-12.143638,-9.81215,18.316357,49.100507,93.288575,75.311996,55.325802,3.643084,-29.250041,-51.311429,-15.636919,81.515938,97.366986,77.658741,27.921445,18.862395,49.090441,75.8002,117.248513,125.892623,118.343259,50.774999,1.459095,2.983395,73.802251,218.74902,236.918675,200.166422,196.106185,180.981777,70.801722,32.71142,58.578363,69.53681,24.412718,14.308488,63.130961,-4.273465,-81.758632,-137.792276,-125.08901,-113.235016,-88.91869,-14.048094,-61.955982,-117.150134,-210.912349,-231.108776,-195.290379,-149.35588,-45.499897,1.545038,67.304595,25.331455,-22.453339,-70.124326,-77.890812,-136.90996,-176.366021,-181.245566,-137.480318,-149.647496,-222.673155,-263.046951,-365.493179,-394.947661,-318.567895,-256.539562,-217.419329,-292.148676,-341.346162,-380.669805,-374.927365,-336.264023,-273.940654,-106.153243,-10.770824,7.704533,-6.342192,-24.436068,-47.61335,-49.34745,-33.274361,-34.399194,-49.846886,-16.680834,5.818935,45.555618,76.766298,188.570882,240.279902,239.441527,187.415848,168.591876,89.261173,30.276986,-71.435343,-98.425003,-82.933368,-39.64174,54.179657,69.538999,46.105408,-47.205486,-88.916097,-41.142373,13.685593,4.636514,-35.640209,-1.962907,46.338153,4.062461,-106.165798,-114.96087,-97.33863,-113.807829,-131.668579,-64.578702,-31.734492,17.525888,28.432671,44.311499,70.387889,87.135453,-24.421437,-66.482677,-40.724031,-23.35687,-71.481637,-103.825205,-95.163825,-72.272293,-73.997057,-130.468173,-160.11115,-202.78713,-201.857323,-123.603013,-64.634066,42.35264,179.001975,239.480986,265.924433,231.802533,148.561937,136.225433,193.940527,243.629829,265.982529,208.695731,220.214395,281.180235,263.680189,112.235058,32.542787,-29.853187,5.779162,11.167689,-34.721172,-61.003369,-115.305559,-132.117726,-66.062922,-11.410002,42.75857,76.865155,92.824165,65.895509,25.3908,-26.444991,-19.217512,-1.397354,14.331913,32.912049,46.156776,48.375324,72.365318,91.32024,130.273362,121.727176,47.603525,7.765106,-0.927896,-28.410266,-60.292799,-171.883737,-225.311489,-249.72561,-187.998912,-162.546203,-150.224883,-158.033981,-184.26395,-176.565987,-72.078562,-2.771308,58.812168,28.870206,14.294586,-5.911047,-17.652957,-20.634673,-13.522355,-20.013533,-37.816068,-51.393021,-74.695505,-66.795419,-8.468335,18.207836,57.147728,86.676894,156.659373,205.194236,222.314031,254.547718,252.149675,194.202336,174.575405,208.870336,236.437779,220.612581,186.702123,180.975355,131.080924,100.418621,184.48747,292.383838,399.19198,233.107482,136.133821,98.765481,126.662281,140.553136,140.595672,179.706885,201.433199,194.994706,210.061762,227.81165,189.767501,131.853926,55.7919,43.926623,-9.910263,-86.627153,-92.896347,-28.745132,-13.003863,-73.653856,-112.181193,-144.528998,-73.31091,-27.795881,-39.866501,-94.514105,-218.606339,-238.980404,-147.045153,-82.514447,-11.111534,-31.800514,-64.715086,-63.487446,-15.092829,89.875987,126.48223,190.006986,209.111624,163.535909,35.165502,-1.098274,-43.100215,-48.73412,28.116464,102.625338:-126.694633,-98.241804,-112.010782,-151.388483,-174.66837,-189.562737,-163.171624,-81.336089,-8.13556,7.039848,-9.406045,-12.372168,-18.841944,-36.023637,-29.817339,8.442619,90.604523,80.76038,45.090021,-11.892205,-24.612154,-42.956634,-44.265965,5.384269,48.241619,28.88464,14.626775,57.264279,95.081857,47.646927,-10.586751,32.636499,116.725191,13.759552,-66.648971,-147.621045,-140.462464,-85.742411,-58.388397,-41.668126,-92.959782,-128.501226,-151.217099,-120.432191,-38.923783,-37.855688,-87.402082,-89.788239,-58.018718,-77.750891,-91.862082,-59.40748,-29.927449,-15.353059,-25.37347,-48.897857,-45.867873,-42.029514,-135.628978,-220.358506,-290.59587,-253.806568,-143.99489,-99.056633,-4.667397,46.288108,57.401535,105.508073,124.318948,157.820199,197.868442,293.298859,301.831827,244.635008,42.8796,-33.868447,-14.629961,36.003468,41.909181,9.786089,20.530409,87.470434,93.783434,89.453861,90.999999,85.671285,85.441671,117.32252,185.261234,202.324602,126.370706,61.943585,30.907246,62.284554,96.897554,108.960083,197.592996,226.558515,197.89102,198.162543,225.36803,242.127558,224.308045,152.499405,173.4951,227.720783,265.305968,234.836084,134.539737,82.647328,15.820532,2.262972,4.046832,25.236146,17.747058,-81.25429,-144.940495,-169.393542,-128.725532,-44.408295,-20.53767,-34.144408,-46.112387,-29.648663,-33.24697,-52.340536,-31.710629,-3.459422,10.037456,-7.368166,-10.105917,-24.101355,-61.534788,-168.070193,-177.807409,-84.362754,-42.904055,-75.224673,-67.68398,-3.188357,33.553616,-16.465675,-66.234278,-27.010649,93.922902,70.606277,4.441601,-39.777176,2.111681,68.69769,58.587882,-9.960835,-46.846805,-50.140424,-73.298478,-85.523723,-113.888109,-140.571088,-148.834542,-107.119222,-21.111906,-72.240237,-138.327092,-215.104917,-202.045902,-131.977565,-100.132308,-66.482469,-72.304934,-105.468116,-235.123767,-275.993018,-167.992124,-48.831968,96.368221,102.170959,103.228782,75.626208,34.010344,-48.507586,-74.288693,-50.678999,-12.733016,18.378467,9.730725,4.289818,-97.602562,-190.240427,-329.603828,-359.304862,-368.935517,-355.108573,-292.49256,-257.045113,-283.18174,-316.147218,-286.793056,-205.311725,-170.795126,-91.697882,20.847137,56.398175,1.498498,-76.651317,-265.226404,-334.008731,-321.811169,-266.531933,-179.388762,-155.338557,-149.48835,-111.915167,-81.456465,-13.877504,23.810331,122.349346,164.673433,112.035938,-36.952097,-66.383643,-91.154716,-132.0785,-176.376639,-119.451082,96.6704,179.425549,125.785864,-27.222725,-60.676708,-13.886156,31.98237,45.923607,-76.812793,-122.791479,-74.325902,-30.494337,-58.982056,-104.385714,-138.682373,-131.905759,-97.956394,-55.34283,-39.038965,-35.985664,-53.595483,-86.002353,-95.376237,-125.581205,-102.352897,-71.295342,-54.281787,-63.948551,-70.724264,-56.733904,-34.662624,-54.411646,-123.070957,-198.565013,-248.210208,-310.684745,-296.214344,-178.720281,-100.760177,27.73484,144.593582,202.892514,266.64997,247.515727,98.783732,26.373699,29.856298,72.272863,85.263299,91.761135,141.215446,213.835894,174.225194,-1.294362,-63.227372,-67.176462,-30.73516,-50.591873,-122.888204,-141.643132,-184.103316,-221.659026,-218.360106,-155.677527,6.280588,98.033682,84.5962,-2.004438,-29.972595,-25.832256,4.928082,89.827088,103.007249,86.700938,106.987712,130.722492,86.836602,52.2145,141.520198,236.520476,290.502381,155.370646,108.16831,127.909095,133.0954,19.173729,-59.331793,-136.376936,-54.887018,16.113823,86.374776,73.864229,6.190349,-21.278555,6.147879,56.189764,148.822482,164.052878,153.485528,136.466736,122.004364,98.724585,100.370058,114.503825,149.056505,167.241252,174.031636,162.944369,115.520109,91.112877,81.890692,96.00597,156.373413,246.625858,279.43976,247.990653,175.634501,66.396327,76.952189,166.392087,274.854599,302.224441,294.652184,292.520349,262.746693,224.600668,194.982167,218.292117,265.490353,178.223466,106.146984,85.427403,137.600639,237.364354,260.85756,246.893083,222.152957,225.335571,206.048838,184.553468,145.485666,135.514672,138.646313,134.260519,97.880332,7.412057,-35.241812,-45.982604,-46.622414,-87.983508,-110.380229,-134.490465,-91.566108,-63.592021,-79.640324,-128.040796,-248.081631,-279.326973,-230.09863,-158.241546,15.895722,27.159259,-31.683445,-52.280201,0.229526,102.377256,150.936534,253.213239,195.730461,112.140845,13.646364,23.722125,90.705767,135.35914,247.824222,285.605112:-76.653328,-149.482659,-182.032903,-195.812437,-201.189301,-204.053553,-179.313217,-97.264953,-7.345638,8.380103,-43.224734,-59.351946,-41.315255,-10.641174,120.375542,176.896922,168.782327,50.606094,5.089604,55.644142,131.723187,231.796978,241.064177,240.801961,289.13187,317.986719,317.121773,293.645819,213.738124,165.288304,98.139959,73.451817,-23.045434,-128.008806,-140.10069,-115.054595,-98.533101,-88.586421,-85.582381,-48.500079,19.914891,28.70479,-61.600073,-108.749574,-116.871387,-101.528622,-81.904066,-82.184843,-93.267744,-138.750702,-186.744171,-219.481465,-171.30012,-32.348928,7.659792,-45.670091,-156.199463,-175.239506,-182.633669,-187.596747,-180.859247,-150.411364,-53.523282,-31.740779,-54.591796,-90.673811,-101.989258,-65.156376,-39.328449,-8.469344,30.224355,144.55064,147.526394,90.283221,-62.25533,-114.236283,-103.453883,-72.119575,-112.626824,-173.034237,-192.681217,-65.049102,-16.164016,-27.410344,-62.860918,-80.546697,-43.431931,55.510287,112.853191,134.126971,118.263076,61.231364,-84.410433,-119.997864,-81.353248,-29.961767,98.136821,128.542511,89.530536,58.593904,99.017201,217.131562,243.296799,189.792391,130.928176,123.697576,107.342488,86.600483,47.579502,52.6086,69.559037,49.026308,-29.260827,-116.547532,-148.252765,-166.92606,-180.924645,-200.734376,-161.533422,-4.495662,-4.188134,-96.01907,-203.402655,-167.908833,-112.904598,-130.528541,-104.998065,-27.895882,119.793253,77.732167,31.124955,24.978345,21.847876,-50.029914,-79.38587,-74.205609,24.429845,61.601343,21.190077,-14.818293,5.525078,50.543095,107.597642,121.372178,148.605926,77.553141,-6.579201,-65.269769,6.485181,192.007428,247.499147,270.026131,189.024499,121.536383,37.518558,37.619188,26.72344,13.406494,33.340359,30.229399,-57.049763,-96.360951,-76.083147,-21.013959,-13.558629,-74.785987,-100.979495,-37.252896,-0.32744,-65.714826,-223.200947,-239.150308,-146.046117,-44.238807,203.223001,258.460318,177.208801,67.760636,49.524651,38.282383,8.748949,-58.36345,-36.072108,107.902718,142.939598,54.584502,-182.678987,-233.978066,-252.394458,-264.411142,-225.978359,-180.786629,-167.176248,-260.69782,-311.783602,-371.300086,-362.390281,-230.225427,-120.613345,42.888988,71.206043,61.720785,40.386278,13.668267,-104.94456,-144.551459,-97.559984,-52.063317,28.136837,71.025028,31.745661,-41.49396,14.772895,246.038615,316.38875,277.41996,218.518004,217.770553,131.964123,52.152746,-39.924868,-45.894489,-42.726,-42.530168,10.458982,105.903692,93.097668,-60.40503,-117.007939,-56.983639,9.286997,53.383864,14.507146,-22.5156,-111.584223,-133.977066,-120.531177,-95.033452,-42.00947,-38.762303,-60.898108,-14.0387,12.36901,-25.865488,-57.489342,22.654818,121.446671,168.12134,17.257594,-18.948343,-49.822117,-70.885971,-69.567508,-53.649483,-37.891028,-51.046321,-114.181079,-140.409102,-144.707224,-193.781422,-221.008067,-193.476328,-146.797664,-65.935235,-32.696752,-39.212489,-74.345326,-84.740127,-81.310856,-59.508685,71.661877,172.798249,275.29563,153.922857,95.359636,87.987364,91.053373,23.104325,-32.56905,-88.257407,-44.618369,-35.154189,-29.604602,-29.292622,-103.793778,-122.671109,-2.216162,65.808824,111.34849,109.455312,88.614147,50.587511,52.301782,57.592892,53.873503,65.727723,99.899227,97.953914,35.785155,4.011809,-33.232589,-46.10828,-50.317933,-39.464606,-18.183536,-51.923305,-74.746678,-76.638285,-65.191561,-85.47137,-122.885409,-189.5504,-213.323826,-221.170857,-190.702409,-139.961701,-76.00954,-77.052623,-41.521361,-12.844807,-28.652823,-84.620038,-102.044378,-92.058584,-68.045855,-74.702628,-105.116421,-114.814645,-65.878106,-59.559978,-86.8181,-88.916419,-30.181942,15.882087,99.998329,131.574193,175.792485,156.00596,127.70589,140.357365,187.971358,244.7855,229.033604,208.747223,252.139709,230.814494,38.710935,-66.187841,-87.197224,4.554236,211.146987,259.997128,246.934897,131.980671,76.352293,62.649524,77.498694,60.66473,44.226885,20.615744,13.24627,29.431055,64.711315,69.592965,25.256601,-10.892359,-29.864459,-38.363841,-158.280698,-261.167654,-215.317041,-15.145176,23.738358,-56.350579,-79.021399,-8.744377,69.762406,88.876058,36.197541,-55.135138,-212.95446,-198.41305,-47.916104,13.904479,53.554401,40.296188,38.597658,60.111216,60.760658,52.301572,84.927828,181.500853,173.137534,147.291702,115.539935,110.098968,90.427752,74.4997,94.808857,142.689537:forward
154.7901,8.396726,-124.057823,-236.891157,-194.681772,-114.854172,-125.620987,-196.41138,-201.638645,-163.451036,-31.631597,16.418207,-3.48069,-18.060763,7.967327,5.344213,1.320749,41.906077,33.359311,37.021751,90.901637,165.758036,133.932497,34.022908,24.518718,36.189784,-4.695884,-45.630276,-17.736796,49.464493,104.236736,74.729486,-16.84287,-107.996783,-135.790271,-138.092343,-121.365152,-92.924435,-98.389764,-159.672845,-242.010247,-277.24369,-318.9951,-333.652377,-381.583166,-393.259431,-404.252012,-440.144999,-523.277944,-536.075726,-509.439117,-361.870876,-276.021489,-211.703508,-239.841609,-323.52345,-295.116837,-264.707037,-241.325242,-210.550172,-71.8923,19.352575,165.062894,178.959827,131.420116,134.572799,140.585072,59.227078,-23.124607,-151.056087,-163.083243,-140.238801,-205.470247,-252.581641,-253.31679,-237.19449,-294.794123,-327.381494,-304.517775,-285.429107,-283.731756,-319.196978,-348.03041,-365.294491,-350.318279,-308.767834,-295.622307,-315.563723,-364.73143,-369.404293,-309.074721,-249.415846,-66.064336,37.43832,139.409861,123.591352,4.996005,-170.690879,-229.124891,-239.022434,-228.258989,-279.090419,-332.711158,-344.559946,-226.075203,-219.275197,-337.467203,-373.417766,-329.774429,-286.783871,-169.75477,-108.717625,-76.821178,-196.760071,-261.041845,-264.801145,-220.581132,-142.24197,-104.559658,-4.806317,-47.698921,-162.942509,-344.636925,-315.673168,-123.16013,-59.331468,-79.644174,-140.220252,-256.69124,-325.733534,-341.183791,-309.319977,-287.227432,-269.351979,-252.55862,-197.743268,-204.35647,-237.258391,-252.941652,-222.85137,-157.764456,-120.252072,-45.986494,-62.319606,-192.189002,-238.881162,-218.387055,-152.437837,-110.914209,-25.015425,3.116141,4.791906,-52.149174,-88.109631,-126.776858,-124.897656,-87.388112,-53.298325,-6.426167,-10.771817,-61.114132,-135.659039,-148.974524,-83.139789,-49.211849,-26.52696,-16.739612,-69.87921,-183.372084,-208.213208,-203.066071,-162.762166,-33.66511,-0.139841,-52.031293,-112.115541,-205.122208,-224.596547,-204.186202,-117.793006,-92.456388,-144.156142,-186.784331,-203.124535,-184.029958,-189.023377,-153.333,-95.326512,-5.674051,-5.900728,-59.019022,-79.243515,-84.542314,-197.203228,-283.724094,-265.310155,-160.747199,-53.395592,-107.194667,-283.637311,-388.231082,-400.065648,-280.603345,-164.918562,-6.718867,-4.814712,-53.622343,-47.230225,27.700197,94.726346,128.409176,222.499152,265.617181,316.021542,302.791923,129.845539,-40.440779,-46.387724,10.950851,41.758712,108.404422,142.310165,216.281436,247.562066,229.83993,135.502148,90.674538,25.285279,32.468186,176.60333,249.636828,197.067879,14.559472,-33.923199,-41.632656,-23.805694,15.708007,32.11836,27.15748,-5.093346,-72.33266,-123.30219,-133.664172,-67.43432,-32.23456,-20.781909,-8.548057,42.313039,-8.68827,-67.363034,-80.788943,-22.059237,64.149491,65.023963,70.404456,71.255386,27.27881,-45.924806,-87.924694,-122.946378,-95.538758,-1.268821,18.904578,-51.389767,-159.940196,-192.427101,-215.288766,-212.697654,-229.367044,-253.50692,-260.831118,-233.076,-224.27042,-322.220636,-313.062842,-99.400189,19.760348,109.767126,87.065563,0.798765,-1.598283,27.914711,116.149465,187.797976,287.364003,276.701806,227.374044,215.29435,174.41431,107.313528,80.827062,26.505796,-5.699108,-20.214662,11.322247,97.71344,106.143922,66.037977,40.568457,103.524887,232.955652,224.487056,94.848617,40.926053,61.19758,130.865021,137.991776,194.110891,242.588962,229.726849,161.192114,41.999529,38.882055,41.379136,-20.440335,-78.473218,-209.067491,-252.146557,-242.541449,-222.948321,-259.314323,-330.119156,-317.739189,-179.758685,-100.92209,-22.895088,-31.73937,-75.071629,-2.188249,42.614218,32.543865,9.904983,20.237619,51.247371,73.320887,36.673616,-33.365247,-4.943436,26.010079,88.763193,119.297673,192.053845,215.376334,238.296993,278.190427,281.287444,271.958292,263.31395,196.310882,161.679152,150.555017,153.872873,133.306248,87.940791,69.868348,75.830456,105.360563,172.971108,176.366334,140.016457,194.523706,242.344045,307.206356,339.910461,407.841131,417.099563,356.62518,311.784624,308.768656,366.170741,343.532693,239.639443,237.278888,300.579714,271.968874,82.01209,-11.249525,4.811779,42.514059,43.383397,49.364455,72.711455,141.2068,161.691682,148.888806,84.841534,65.173466,134.1612,213.373005,343.203068,342.060484,158.250318,-37.763061,-48.217205,68.295536,141.66188,210.623174,206.566471,154.408928,96.000758:215.169098,239.820315,155.784902,1.996058,-9.635219,-3.935268,-40.446501,-173.311366,-224.315515,-177.943064,23.025599,103.712548,139.689443,131.930718,134.760908,155.755786,212.335991,167.10974,107.916481,87.694923,156.587786,282.973426,266.017048,123.460457,69.814673,91.08542,81.175916,45.486448,38.663595,58.887392,64.714663,59.258864,-17.796057,-190.895736,-222.430902,-166.530922,-135.69341,-98.566621,-100.820041,-200.580619,-341.206845,-359.43204,-285.515654,-247.242732,-249.049871,-282.370654,-359.297378,-373.77915,-326.615812,-278.260804,-276.401512,-250.056117,-201.335992,-115.532218,-128.97733,-220.035256,-229.837176,-205.760101,-98.166331,8.989444,217.322258,248.78857,170.556376,107.752837,9.664457,-4.473554,-1.636184,-87.217454,-147.877583,-138.217018,-97.452982,-154.626668,-364.458814,-416.395649,-272.812319,-172.760974,-189.177664,-261.166558,-327.807168,-329.112814,-372.693765,-436.601973,-440.243377,-404.966893,-365.208012,-245.534589,-206.350539,-194.816774,-222.44577,-240.77921,-185.552046,-100.776849,75.798546,129.705178,139.557895,89.463123,-75.865203,-197.285124,-214.057558,-192.670901,-172.438852,-158.228553,-193.486652,-285.145,-303.392771,-329.946612,-400.498015,-385.436589,-300.256866,-283.738106,-272.120899,-246.652381,-197.358993,-295.632887,-361.799578,-315.220386,-197.201336,-3.396087,-2.076556,-107.350397,-224.999972,-271.665154,-278.954982,-263.651782,-253.441869,-233.042259,-184.557813,-189.116612,-249.718527,-348.366534,-364.350824,-269.34181,-216.479396,-197.451284,-211.322132,-249.455801,-280.808897,-301.067922,-323.541711,-300.296293,-195.536303,-128.479322,-56.997345,-81.26986,-191.857001,-312.090992,-338.48095,-226.332338,-122.119047,3.177117,8.622381,-44.920833,-147.055427,-175.372145,-124.628463,-78.446081,-0.777644,34.750785,51.49035,23.120089,-56.459493,-136.183948,-158.493297,-98.046456,-24.007377,70.204182,43.009655,-97.726116,-120.003365,-80.557738,-28.502911,-12.734815,39.57897,57.646168,12.241622,-48.542876,-172.882421,-273.117653,-290.828207,-191.566523,-124.350434,-92.41146,-117.195583,-174.003109,-180.583684,-176.929937,-148.920242,-99.64902,21.143296,35.504957,-83.023611,-164.294185,-216.136099,-204.82581,-219.049333,-210.748698,-165.533383,-89.988167,-118.249583,-278.494687,-389.584648,-401.224565,-343.650636,-283.154466,-168.236139,-135.904327,-124.149675,-122.87982,-73.786405,-36.721097,-39.491715,-23.635657,3.059767,68.749045,71.141194,-31.062324,-104.821262,-109.743774,-111.813184,-101.018229,-24.856996,27.31292,76.022545,55.677511,-23.349731,-58.074819,-46.996404,24.878742,75.248117,143.103061,142.187558,80.967482,-25.41893,-58.104753,-39.322887,-15.312289,26.569361,42.888382,40.243925,20.530617,-43.39087,-149.204547,-184.086765,-137.339324,-74.022173,52.034222,74.897205,-31.238807,-190.73791,-227.248341,-168.180034,-73.441905,92.616206,111.159732,51.606107,-2.457683,-83.868415,-63.536796,-46.214966,-43.783064,-34.086155,14.936148,18.802018,-70.095261,-205.126711,-237.810085,-186.257913,-139.121169,-145.453166,-187.432618,-184.146512,-143.614255,-157.356206,-253.830438,-233.400453,-41.649584,53.78684,118.532386,90.789136,-39.290861,-119.714462,-98.444837,43.400455,141.308281,274.518035,278.249339,199.533788,157.838719,126.057619,80.48154,42.353965,-3.891088,-0.249877,26.284786,25.568214,1.761129,-38.3547,-45.65108,59.274137,137.995672,170.759793,144.233571,97.079209,69.468315,44.870633,120.928454,177.962743,225.330164,204.252199,178.754401,185.397863,138.856909,32.375647,-5.377719,-72.881094,-107.21285,-108.336593,-75.341793,-66.473612,-104.646471,-174.596441,-219.177532,-199.475326,-32.595274,46.057272,88.095721,73.720164,52.799289,69.49811,63.481197,26.2998,22.883923,77.194627,114.705738,102.897056,55.414589,-8.820991,8.594734,37.22293,116.090356,164.072805,295.810111,340.203752,302.19976,218.112783,178.445941,135.164416,149.017892,219.830086,236.762168,159.646944,91.900587,8.287148,6.65285,40.534561,175.36358,233.929612,264.879988,267.671859,313.848525,317.495916,280.941558,228.680237,248.738521,344.370961,382.796394,378.539946,332.588365,264.938219,315.046874,329.638229,275.022749,260.144631,321.541913,329.792609,233.447507,141.143172,104.774891,30.815547,25.622704,139.26252,221.111316,274.232313,231.142877,128.996289,128.087667,163.271588,270.53963,320.673027,347.546666,309.146425,158.607627,77.255909,83.083898,82.194859,69.421491,73.697935,106.906117,160.72655,127.945158:325.409515,300.695015,229.445892,150.331147,170.022053,202.738416,167.384882,-4.620517,-157.587864,-144.4436,57.620943,152.981245,249.938281,259.687471,203.404974,175.375056,152.573478,142.597618,150.470155,185.149788,218.046898,262.868515,223.727122,115.039261,100.371668,74.562317,7.771079,5.146538,7.51213,6.658641,63.757746,93.514321,19.002608,-193.960799,-252.20122,-160.745424,-77.324409,-48.084071,-95.164695,-175.943866,-272.055523,-320.653221,-300.495276,-245.142093,-148.880259,-117.653563,-121.884837,-149.378036,-191.572917,-222.384764,-188.949718,-52.724589,-24.548115,-52.918474,-66.658308,-62.758092,-35.89733,-21.022364,4.154313,9.811265,18.378538,43.432571,103.53445,96.250961,8.431822,-110.049193,-136.663547,-102.88307,-88.828773,-121.461042,-159.995617,-298.369969,-427.173871,-411.985682,-280.908143,-244.061876,-259.017179,-293.391684,-368.659767,-378.207596,-375.385072,-380.542758,-369.743741,-355.775109,-348.731985,-270.890311,-218.108025,-165.666453,-204.202937,-222.540258,-106.4045,8.929857,167.943829,188.849579,135.523842,70.402953,-59.634056,-109.37977,-111.02439,-84.782683,-57.251119,-65.704507,-136.944793,-305.847008,-382.814142,-383.15458,-346.076537,-330.87803,-286.302379,-267.00967,-278.071956,-285.965075,-305.991515,-372.084878,-379.210468,-290.908763,-230.100532,-127.986582,-92.472845,-111.175335,-248.947543,-330.168704,-430.639277,-426.734371,-331.021022,-274.488906,-250.813283,-280.158692,-317.936048,-379.205141,-415.952032,-368.611387,-296.92458,-229.686811,-264.370179,-391.857864,-444.013369,-429.126311,-374.709776,-346.873877,-236.704217,-155.808859,-102.149485,-157.652257,-334.55928,-479.676672,-471.862761,-227.641882,-84.442328,-12.311411,-62.930463,-115.751359,-104.39092,-119.09181,-127.147542,-102.881733,-18.375193,22.693507,16.97893,-30.088515,-102.052464,-99.393423,-86.755887,-16.619334,48.983573,137.467245,113.815675,6.735866,-27.463675,-24.002287,24.864588,70.891026,182.565769,236.192706,211.408016,114.216307,-81.866006,-111.015821,-77.583025,-11.423214,-4.211095,-46.534687,-96.513105,-203.329078,-204.708113,-182.110384,-148.492376,-122.005485,-18.168957,29.457368,31.628107,-3.407822,-104.183537,-233.39016,-268.156138,-255.952313,-222.086505,-117.2871,-117.98977,-306.442885,-468.843083,-470.799604,-351.490057,-274.45289,-176.427138,-154.220772,-116.204648,-90.979322,-93.23069,-182.013648,-197.648356,-135.250344,-90.51373,-25.831559,-3.969075,18.977353,-55.807043,-115.152852,-127.836103,-60.852304,85.228819,98.786279,14.053263,-21.102553,12.320512,90.332127,117.082837,131.546948,140.960461,187.253442,181.784303,71.490787,-55.005432,-63.103465,46.565814,101.613622,128.946668,122.411309,105.16087,87.33589,17.108131,-94.696145,-130.69374,-43.863453,55.178439,141.909574,95.92604,-40.485744,-85.978534,-81.535739,-36.61153,15.377682,133.109223,158.452423,70.774913,-23.096888,-126.266323,-54.817323,-17.801189,1.827203,3.787886,13.119818,7.586434,-86.606797,-289.187484,-347.200675,-211.365501,-76.737539,69.59182,75.581722,54.181742,22.683285,-98.142017,-164.882178,-128.11534,53.331524,155.077359,251.75336,215.601587,43.748574,-50.08081,-11.570786,164.631726,231.038928,268.875642,262.817631,199.881254,150.278554,90.960631,90.856918,103.049271,136.640714,128.154274,39.54706,-19.095201,-117.540564,-121.572503,-66.968753,82.766102,132.819091,158.341756,147.635219,99.189782,75.662704,63.961458,118.931304,172.771735,269.241357,289.409474,254.195696,185.640065,16.725163,1.510693,15.144326,-44.337072,-73.989295,-16.197045,38.134325,24.768129,-66.12967,-272.614317,-274.395865,-196.434382,-23.883466,40.169416,84.528332,28.493854,-166.401227,-158.232206,-92.536798,-0.858281,26.784161,65.347511,64.007373,21.608809,-0.538089,-22.790539,-39.086816,-25.304718,85.556613,162.250814,307.46061,333.404458,213.716312,105.166156,129.360165,201.38229,204.840176,171.668485,147.27157,46.34337,-38.499163,-111.04837,36.62477,101.321244,162.751553,206.61264,302.31591,302.822528,224.099709,208.878615,224.072715,217.137668,201.713348,199.6659,213.863703,231.502383,220.341892,188.61972,233.916329,271.139532,259.552907,232.260207,246.146225,249.273411,168.294552,93.664617,76.508106,47.860814,31.775472,78.672755,146.283769,222.180943,198.966911,116.914868,139.63148,166.706661,188.692974,213.064559,263.814828,236.857098,82.880807,11.002137,42.633546,123.531974,132.845201,119.031405,127.919509,182.273354,187.109905:336.96163,292.308454,204.135569,33.965423,24.641161,94.227372,82.156576,-91.964198,-231.772165,-218.975132,-40.311146,61.136744,151.833145,147.255107,122.901627,119.249432,81.131457,-19.433993,-60.969745,-40.258192,33.945338,144.529004,95.567956,-75.336212,-31.428971,14.981056,-25.475714,-61.798596,-15.349269,56.071107,167.805361,167.365239,73.610857,-52.731516,-95.007189,-96.240126,-68.982238,-35.142023,-36.373076,-47.344834,-132.224123,-212.621148,-311.234859,-293.549586,-207.797466,-185.069045,-230.209642,-286.755342,-381.052921,-395.35482,-365.145051,-251.545981,-193.404876,-146.275119,-177.720681,-286.652331,-284.345911,-239.77432,-156.398468,-121.900125,-31.366605,35.549042,169.42385,195.462468,160.072224,90.948716,58.717691,-7.38577,-38.870595,-73.471581,-96.639183,-240.278572,-430.696705,-458.726195,-359.51981,-323.219848,-427.118732,-502.327491,-507.851341,-457.59961,-402.805403,-438.551249,-445.771992,-400.39573,-366.319951,-311.770404,-303.395988,-293.222572,-253.169704,-218.945959,-82.998185,4.815211,158.640962,235.212211,332.002991,297.199121,92.575713,-97.717695,-144.592895,-140.416211,-122.053921,-144.436739,-201.17855,-333.748858,-385.513694,-393.548137,-411.755984,-408.836131,-363.03427,-341.789881,-322.475495,-309.957317,-265.985875,-283.59594,-316.388594,-338.860744,-324.121747,-252.165101,-210.925139,-190.377367,-253.820066,-304.363805,-379.936588,-377.422717,-296.003847,-238.420378,-202.684773,-254.752795,-351.101022,-334.773219,-318.601941,-280.301577,-259.102072,-251.097447,-278.25698,-356.480025,-388.103459,-398.25171,-426.894478,-414.261047,-272.768257,-168.24893,-61.550406,-103.008312,-267.646496,-371.385893,-380.599946,-255.947483,-144.53457,-12.816025,-24.29445,-82.301365,-92.300777,-103.731127,-138.580816,-141.632176,-65.054616,-1.893988,2.967894,-78.814698,-239.869969,-207.749575,-138.627995,-21.768806,5.7888,51.09441,59.568555,-47.258942,-200.205818,-229.243259,-185.167323,-132.943412,-29.78089,3.942963,10.213379,-12.253121,-54.825428,-111.968252,-146.191186,-132.683503,-89.818151,-45.860203,-78.300234,-200.285489,-233.153573,-235.851878,-238.88491,-197.57194,-56.12517,-17.327345,-58.128038,-100.60471,-168.158201,-262.599945,-316.671715,-321.072515,-253.756371,-136.694586,-169.671038,-362.844229,-409.683714,-361.8645,-248.562854,-202.080639,-130.503349,-105.843345,-60.039544,-27.968057,35.080917,10.759991,-26.771872,-21.862263,38.914247,167.635764,176.736597,73.515807,-13.647004,-13.30535,34.478249,72.886696,168.983268,203.145211,185.046423,163.871418,196.082849,171.811458,116.992165,98.351178,146.691092,210.42135,191.279587,114.756627,90.199432,97.583991,124.822823,144.646723,178.41412,179.527303,153.099174,136.408351,129.968847,101.856962,75.800814,82.130859,100.086279,86.751306,65.170269,26.617601,-64.721844,-129.553437,-124.788328,-33.881107,85.523999,71.715316,33.11754,20.815297,-23.407343,-54.73237,-56.549694,-2.434572,41.347682,67.655217,34.196458,-88.164989,-167.695188,-160.580029,-84.030188,-48.514279,-28.08173,-35.161544,-59.072991,-64.568241,-43.668089,-13.12023,16.232327,121.816863,166.288946,194.240843,194.839768,190.263667,179.342805,176.860281,228.055199,305.369519,468.938833,501.151559,460.215034,427.040365,396.935572,319.364794,259.886701,179.803954,156.40723,123.523806,116.930733,127.09182,143.017531,128.704204,119.267839,156.576491,232.81102,239.750283,205.567249,174.907279,150.585741,175.741777,178.725106,184.031706,190.286429,166.818167,124.287365,-1.967083,-79.571118,-98.949878,-127.466223,-118.975234,-73.238387,-61.853967,-108.282241,-172.213075,-312.373807,-346.299994,-292.965712,-110.701694,-36.250274,16.253993,-16.88275,-120.324612,-86.385458,-50.89405,-59.618512,-63.674773,50.02896,128.638165,120.897698,27.640707,-117.335049,-119.2023,-114.581261,-53.793337,29.953179,227.416787,268.47026,179.093568,55.087186,40.146601,71.095122,76.312088,27.147009,3.082342,9.266249,13.615383,-9.172734,-18.914749,-9.346447,68.026819,126.676186,226.146309,264.335311,284.209139,198.917082,160.057431,168.759727,209.224342,277.407363,269.137449,171.752784,125.402637,144.356366,289.797046,342.021269,318.337128,283.906827,262.199068,251.868818,191.927304,102.908747,59.987651,19.048708,23.177195,67.870878,114.869439,202.960625,194.358015,86.131893,33.404325,50.771993,120.534904,162.661636,281.786694,311.526109,185.175421,27.690556,24.219589,123.474018,179.647251,236.365383,241.459262,218.114989,169.071641:257.802201,246.67299,266.0542,247.862445,226.814317,238.344502,225.854351,67.190047,-157.026504,-199.209984,-73.697361,10.125712,125.612545,174.365099,202.890976,169.494723,32.725246,-101.088781,-107.75381,-29.745048,23.942279,95.836788,66.828877,-61.109122,-69.967107,-46.923394,19.746666,62.964389,81.809959,55.427978,0.787112,-11.676897,21.126108,59.689243,50.824334,16.781777,21.465163,65.165006,55.718752,-56.021867,-202.884448,-252.056143,-224.053802,-162.05051,-49.595244,-26.426054,-94.917866,-172.50273,-287.163236,-288.930362,-245.430787,-110.107205,-56.915373,-37.589778,-67.396339,-137.697408,-162.778731,-154.855886,-108.099118,-74.112847,27.245418,78.234184,121.006683,123.945197,121.744959,29.532364,-31.700044,-61.431068,-25.847294,22.178999,-17.265382,-198.079924,-356.297187,-382.641088,-342.346023,-332.887946,-402.393198,-439.162841,-415.441316,-353.34744,-262.574256,-345.86615,-393.675198,-377.967484,-336.222614,-264.970046,-247.521827,-224.13452,-193.963225,-169.196513,-31.026171,63.5282,227.716667,303.000088,350.947469,293.267202,117.432052,-77.101434,-161.16879,-171.587903,-109.448403,-63.628909,-123.956113,-321.960277,-452.514523,-447.32071,-361.394676,-343.109254,-317.662003,-282.034919,-256.3764,-283.553135,-345.283869,-351.372034,-336.609964,-292.508084,-249.445479,-94.719632,-34.020125,-97.060451,-314.764344,-396.434757,-399.319445,-349.435189,-259.970394,-216.74641,-166.926152,-192.214493,-286.740442,-320.27787,-302.251452,-221.095388,-184.08333,-172.092801,-205.342737,-323.279479,-447.542259,-483.97797,-464.781,-424.657499,-302.153901,-204.856301,-65.431633,-103.728105,-299.709856,-410.40813,-399.33301,-236.983549,-120.481469,38.215562,49.297257,-7.706658,-90.454643,-129.838253,-149.695485,-129.046208,-40.330044,14.024578,20.061722,-41.250509,-180.359689,-243.90589,-220.267984,-63.145828,25.19279,110.549646,104.655974,34.882404,-67.869027,-105.130285,-67.955846,-6.28919,63.365956,62.344604,50.216984,51.988747,45.231887,-33.176768,-60.780177,-36.927273,-8.997066,34.284465,20.951324,-111.820491,-213.962433,-211.468525,-108.993284,-39.556882,41.493957,64.522046,72.878825,30.182594,-90.940587,-169.842696,-210.213269,-266.228663,-239.010996,-105.446705,-86.954363,-208.464948,-314.041023,-335.857592,-333.474408,-283.074821,-78.916357,14.634043,45.45529,13.173657,-30.312122,-46.694671,-28.318341,52.757173,79.870737,110.599208,127.07315,138.273214,66.467216,10.297558,-21.43544,23.904082,148.870643,183.113009,158.80348,137.761483,168.595343,158.688435,107.923336,57.302301,103.945869,219.599434,208.488561,80.046686,-27.920556,-48.773272,8.817777,67.212992,168.471873,206.64644,223.689494,204.790161,165.436519,115.92479,101.325063,125.279735,141.455565,127.692044,91.783887,-35.747167,-143.337346,-155.322143,-117.328882,-89.910533,-33.44186,-6.134521,-3.11746,-31.330513,-103.27433,-137.515586,-109.802936,37.70344,103.787542,105.297697,59.232286,-20.132989,-94.024145,-137.400543,-129.573148,-74.977066,32.391975,63.480881,63.524635,23.943063,-110.230186,-146.201239,-92.857108,55.509474,120.258639,192.915408,184.402962,91.430763,2.759715,13.997037,174.609313,264.928288,343.750622,349.557149,355.579211,343.510581,245.083673,150.816659,160.940404,213.712609,206.854789,147.392158,107.759499,27.506417,-40.339009,-66.836069,-4.756343,80.356014,212.757681,231.751665,214.248683,189.024686,112.9749,71.034706,78.804717,147.854168,195.246814,232.217494,193.906811,28.485003,-128.039167,-168.516709,-159.875079,-131.36837,-58.380276,-12.820969,-4.630864,-72.07229,-222.759131,-233.828121,-171.717396,12.391748,75.166384,91.302808,47.285877,-81.588095,-92.421559,-74.793943,-67.249731,-44.674003,41.322356,68.794982,63.922675,31.615709,-92.059752,-195.460212,-168.984667,43.406063,157.946762,251.4939,221.501134,121.969589,89.857447,79.729631,77.614135,92.710783,77.139284,39.618305,-25.077092,-50.094506,-123.278128,-149.424005,-95.186475,112.572671,190.434573,190.516939,162.39332,172.313627,150.777934,93.449004,31.644433,66.42951,159.902732,168.857733,111.290892,80.025233,83.921354,180.24792,226.822468,223.316786,198.331577,190.656076,174.992956,55.626776,-57.746977,-76.599627,-30.315437,11.163201,30.174534,17.312897,44.244918,72.291171,52.014027,-13.548132,-14.44898,62.075853,116.468718,167.971941,144.009596,36.991977,-36.214785,-42.906908,-12.686122,11.226463,69.278633,102.894566,139.017036,116.588399:250.945907,118.304359,9.894564,-114.412979,-90.572712,-25.254543,-44.010888,-156.662737,-204.644723,-171.370469,-70.696283,-68.578236,-142.739332,-135.477054,-28.029499,-11.382372,-80.643684,-136.763084,-157.426033,-161.167327,-124.520968,-43.528455,-53.316383,-138.965898,-150.151893,-147.801799,-187.776737,-203.266391,-142.32676,-70.994728,34.689894,32.171894,-20.392736,-47.937278,-52.92475,-16.194579,11.207745,-2.007102,-35.456994,-102.27899,-190.03017,-225.549087,-217.182769,-196.725496,-210.074773,-239.178228,-323.744182,-386.781192,-473.450464,-442.994861,-412.158212,-317.720136,-253.813452,-178.195951,-200.502888,-319.482478,-336.894309,-300.752556,-231.867734,-191.257796,-57.436417,21.534121,104.004534,96.505641,84.743602,136.662609,162.677864,131.456444,74.14552,-32.901534,-76.786461,-203.58803,-328.912081,-336.738739,-277.203419,-272.258827,-351.834925,-395.472648,-399.002621,-370.643769,-325.629158,-291.784766,-283.351444,-334.667918,-379.857101,-414.078823,-395.104638,-360.928442,-377.908804,-357.724758,-191.429889,-96.142637,-15.526362,-18.349332,-28.934652,-15.956329,14.754153,-80.313854,-157.16241,-215.877095,-204.470357,-266.345896,-344.32458,-367.896008,-185.60674,-148.626317,-238.308266,-272.53367,-246.895572,-232.696597,-225.402747,-216.056103,-177.659712,-174.286987,-181.375184,-158.066902,-149.83005,-159.806301,-153.226098,-113.843374,-107.488689,-143.359548,-217.189701,-191.753462,-68.816533,-38.666251,-99.819325,-171.568022,-287.681295,-297.421915,-259.887145,-182.721902,-180.590897,-189.112798,-184.518615,-232.289529,-296.482872,-311.695268,-333.064634,-323.58299,-230.275772,-160.630284,-69.650832,-94.208263,-227.492685,-242.698444,-208.517692,-126.079492,-78.551211,-33.793416,-60.3833,-97.108124,26.186468,79.192059,8.988926,-71.206993,-98.81764,-33.609771,37.202997,-13.833438,-131.47245,-111.354932,-83.383391,-34.942942,-14.83912,4.130133,-11.503961,-135.596024,-268.301848,-285.556519,-217.855065,-140.678182,4.466897,28.236176,-18.808685,-67.654394,-127.667147,-78.318001,-41.957222,-15.378282,-36.239748,-107.169988,-124.434245,-125.966479,-151.464249,-156.231486,-92.948193,-37.912076,8.936792,-21.126044,-100.89495,-113.653791,-111.841235,-154.031796,-186.962832,-175.591124,-140.241928,-129.232573,-177.177546,-356.802046,-466.245838,-440.597484,-278.90852,-196.466453,-103.555909,-83.426456,-45.835944,-9.988981,82.840348,101.675687,82.218917,81.348295,129.367599,261.776598,273.716864,130.318114,26.733356,46.068997,138.515098,186.079632,248.978426,267.876503,285.479847,288.448987,325.697147,333.461379,297.794865,262.085487,305.839736,411.211045,387.706561,193.875851,123.394342,171.508817,246.637135,226.454401,143.98564,134.502066,199.75036,246.946095,256.944699,104.475644,54.418368,108.931452,146.847242,144.289076,121.219778,67.778806,30.180336,15.034722,35.207088,66.657194,89.170375,90.50746,128.897308,139.608562,70.531885,-93.464368,-151.911037,-98.801676,-13.256423,107.871452,107.159362,-1.631264,-127.358479,-141.630836,-54.539279,-23.352299,-122.292974,-181.807354,-149.652038,-105.131652,-109.841867,-177.316368,-143.895972,82.938273,184.313964,237.078085,224.107473,166.1045,108.234911,112.811795,201.895898,280.432809,413.975672,422.882586,336.450395,295.285649,282.917348,211.113276,152.643336,126.075959,144.0582,155.277966,160.100789,178.961812,135.143595,100.141328,103.983658,145.619682,198.499954,170.067321,73.551952,68.094595,133.27084,154.337306,156.204495,166.75023,151.899716,81.90299,39.185729,-67.440855,-134.909358,-127.61651,-98.750556,-103.104339,-183.695831,-257.328018,-342.020868,-321.654212,-257.753092,-243.553459,-221.681131,-117.918392,-67.663217,-3.570464,3.812507,-40.94151,-42.301954,-23.714322,-2.315934,31.343792,130.991739,149.290434,70.353979,-17.792568,-170.367285,-136.61054,-55.897068,87.906791,125.168202,198.479104,227.425854,194.86194,136.448102,130.890435,116.641137,96.697201,60.130748,62.056231,79.037444,67.252284,29.587957,-10.042146,-29.512242,0.466548,43.085504,101.862828,96.635794,26.821254,-1.844702,10.828233,42.564026,57.620599,84.163645,97.54856,134.719977,146.471635,163.123333,216.564626,224.081504,144.439254,111.773713,145.988163,142.198174,-20.201135,-169.219816,-163.086728,-63.762489,-33.21286,-27.767633,-11.59526,59.748373,68.767725,12.793682,-34.403789,-34.845176,3.620627,38.577841,175.699703,241.044133,158.112397,-58.056482,-73.316573,89.655628,178.896218,230.360738,207.981689,135.087808,91.05225:254.047063,161.495159,102.785277,32.486627,45.396473,66.533968,27.793148,-115.320748,-208.222071,-201.105402,-89.771905,-31.468786,42.944505,70.573949,90.095563,68.844477,-42.306575,-162.338774,-168.042691,-70.31958,-15.870656,-17.928856,-81.678949,-143.246354,-26.912698,-11.710627,-115.794711,-157.246352,-96.182319,-11.495367,99.637378,92.470992,28.136454,-41.331746,-55.101056,19.445252,85.006374,170.055907,170.454178,90.845287,-59.103402,-130.259617,-167.056841,-124.014391,-26.589326,-20.451547,-119.497491,-189.505267,-293.310536,-383.408024,-399.579325,-259.82912,-127.569297,21.761513,-21.9919,-207.863749,-268.390883,-248.515908,-164.22174,-107.094766,8.792389,59.5545,114.192571,99.757219,7.34757,-3.042585,55.642255,141.549752,114.897877,19.694346,-9.18785,-120.226935,-317.25507,-369.025766,-307.243941,-263.683285,-323.36708,-390.477612,-419.739078,-386.801798,-356.873867,-377.606312,-371.580202,-305.653121,-278.54339,-333.871013,-389.658617,-373.719378,-244.339461,-217.263787,-169.015647,-104.165703,82.134472,168.793499,224.15488,173.938706,-25.736983,-194.603096,-214.00608,-159.140221,-129.04974,-148.261794,-208.254441,-346.797373,-366.725135,-335.349602,-263.335838,-234.15608,-217.117092,-243.880175,-312.067777,-314.634528,-270.82832,-283.2832,-294.43375,-262.294544,-241.723093,-185.942708,-146.112171,-138.28825,-213.699469,-226.473248,-158.435616,-106.924119,-68.988582,-94.096613,-213.740487,-268.331527,-251.094657,-187.287155,-185.057103,-152.532624,-107.121005,-65.084999,-104.662527,-251.340053,-348.741904,-364.610804,-340.400629,-300.307245,-204.818342,-167.188569,-144.898576,-172.916275,-299.967963,-394.564551,-362.073035,-194.867328,-126.282043,-49.114462,-35.901837,-57.983937,-84.058455,-93.669247,-126.175216,-130.497441,-60.330083,-8.718741,3.354188,-50.441851,-182.519028,-190.10343,-127.526356,-1.994898,8.879008,-41.423037,-66.961235,-113.394823,-198.17643,-237.613308,-216.264023,-149.91003,-2.819094,37.626151,39.86214,19.75162,-20.815667,-11.235418,22.933904,87.385881,78.466443,-12.416716,-82.757613,-225.120631,-222.173756,-168.360949,-59.524393,-17.470494,69.468154,100.729564,67.908212,8.297671,-102.409653,-157.569095,-181.590413,-184.97723,-148.566947,-51.809501,-50.861723,-228.705872,-413.689566,-410.87147,-249.589295,-158.134666,-48.640417,-21.498981,5.623314,10.112854,10.59697,12.415821,45.377975,147.589656,171.946408,189.333244,199.318431,161.024197,82.792633,82.510118,142.531037,158.165625,164.811848,187.831583,246.045358,255.738255,234.679415,185.377417,163.42857,211.217456,289.895831,359.478413,288.192004,87.562977,34.706203,47.611811,136.604084,201.645993,243.732934,212.982878,142.711857,127.366599,119.106174,104.771532,116.485418,147.604721,120.540858,2.083235,-35.492651,-62.603189,-186.034268,-261.919505,-196.590486,-73.675133,16.842085,-45.129536,-133.568298,-112.976929,-80.633062,-146.506604,-164.12672,-99.442565,-58.582261,-79.958409,-129.986834,-201.634561,-181.324613,-157.112605,-124.320733,-116.811129,-114.99832,-111.140258,-100.225428,-109.442196,-142.579856,-132.031806,-91.85913,34.561445,97.233984,170.298312,156.426525,41.613998,-17.52495,10.335334,144.468761,211.373712,244.768135,226.806326,207.104709,208.960737,205.30679,161.517134,141.634304,146.948301,169.107856,197.217676,174.010707,67.325333,-17.510343,-29.636803,44.47741,99.58403,136.511792,144.949467,200.041429,202.986795,103.985972,52.333516,101.266381,223.974514,242.603396,171.99791,80.950243,-151.681937,-251.40473,-224.740841,-90.59747,-23.436324,-11.507116,-67.891532,-175.943609,-191.187596,-185.587386,-181.004007,-150.079419,-56.006731,-21.300203,36.624711,46.508102,-37.493207,-120.820593,-109.920072,-37.237482,12.374997,107.221779,114.673826,61.284584,14.66053,-119.626355,-172.306698,-122.855683,83.149125,176.674395,231.953114,211.319893,111.162227,-27.346666,-45.347516,64.743255,131.398819,157.00616,129.00079,45.82253,-8.317136,-103.945067,-123.111791,-104.668284,-3.481145,66.621349,164.897908,171.510881,101.507049,4.175536,-24.234821,6.757716,58.411694,128.177546,117.544204,19.749945,-40.693568,-87.666099,22.36483,94.347721,169.038269,179.744244,148.662697,83.984855,-69.010045,-111.75397,-106.616315,-85.364239,-67.137754,-40.121819,-36.391076,-28.469718,-28.260848,-57.67379,-69.70312,-48.37594,19.05654,49.677783,99.294128,98.00829,-17.878485,-144.844684,-140.860519,-26.823285,22.65144,52.494966,64.30025,79.298829,38.020584:170.048752,47.008162,-62.521481,-144.697414,-127.764686,-142.0483,-188.544933,-251.908179,-155.110456,-95.549695,-107.209485,-161.24736,-229.460584,-209.219672,-96.719393,-64.89914,-96.068071,-172.807364,-209.900101,-214.214413,-183.937003,-113.367708,-86.184607,-125.08641,-223.56814,-238.230814,-227.412989,-218.07707,-190.682489,-175.427646,-145.588577,-131.192203,-113.648685,-118.368133,-117.013395,-57.889035,-15.172747,50.415007,78.419447,91.037182,47.634306,36.479348,15.715916,-21.323945,-147.504158,-198.401354,-232.170799,-240.531795,-256.50828,-257.797069,-254.975097,-225.554066,-201.539724,-118.980063,-74.289559,-85.745929,-141.30789,-151.921314,-166.945336,-144.990999,-40.387088,4.370924,45.787472,80.682377,233.654003,293.354895,227.925423,41.8704,-4.399799,-3.214705,-4.876956,-76.033055,-164.772062,-175.840522,-115.105105,-81.937216,-111.264631,-139.674843,-100.677905,-74.212159,-120.56228,-172.609264,-193.662466,-295.359806,-352.481613,-385.111916,-379.574252,-407.725717,-429.368001,-419.604527,-367.93145,-321.369921,-230.159829,-211.308986,-195.694418,-178.395222,-142.950663,-168.078405,-199.812917,-242.363699,-263.349799,-342.406969,-384.236468,-361.069489,-150.895837,-43.521173,7.503827,-33.670925,-81.847845,-54.920556,29.488367,62.611489,138.295036,167.104807,163.396639,193.067157,211.416257,217.471272,225.24768,291.582687,370.348849,370.140851,293.021419,248.806547,209.386415,221.954554,193.048981,108.60132,-16.363086,48.377082,65.897348,5.476887,-29.004983,-19.347593,7.652073,-1.59608,-55.376395,-59.297376,-91.203386,-130.785906,-142.860405,-100.790281,-18.64533,-10.292724,-37.223245,-54.382447,-49.502694,-16.198793,-2.664734,-13.106635,-16.664214,68.177687,161.143598,150.201463,78.013862,46.356226,-7.278537,-13.195111,3.168755,-5.249161,-24.313579,24.296682,64.821989,161.206964,196.593307,210.429579,176.034969,19.905015,-79.567572,-94.902588,-112.919543,-93.594736,-5.539204,27.536156,50.59809,54.395781,70.978794,67.580951,73.399972,114.805308,102.717023,-9.560208,-50.632695,-45.324178,-9.569192,13.316838,74.867462,111.948925,139.255676,100.831819,4.410024,-1.178593,62.966172,74.613768,43.861632,7.352518,5.098073,-47.388252,-98.180485,-178.522897,-186.871967,-170.07649,-100.459442,-58.026794,-47.348135,-74.791466,-59.450305,5.534142,191.349453,257.771361,201.764129,88.174327,90.153876,159.188897,185.284508,171.182748,155.159294,163.818268,223.764646,295.175294,432.91799,451.633059,404.817271,371.486794,354.962125,357.91983,334.539638,329.660342,378.426396,466.299662,447.807269,334.473543,283.050868,281.201504,283.794022,282.670447,235.771144,188.400859,137.563182,136.314454,109.692423,83.774344,80.780617,119.452099,164.427158,230.312634,228.40439,192.069711,140.159096,87.987486,29.216812,70.523641,172.609048,178.599523,158.592754,159.991631,178.774395,117.243609,35.724305,-30.15719,29.996684,147.338138,134.550838,3.248981,-96.617384,-111.627252,-101.10261,-88.868249,-119.850183,-155.059454,-174.386731,-156.713977,-109.72893,-100.991415,-92.511271,-13.393601,33.439552,113.991751,149.010844,149.567745,91.49912,85.49104,145.370647,203.834891,280.95614,247.52685,75.00171,13.454888,1.508514,-30.328646,-65.011525,-82.91215,-63.91995,-8.585072,9.803775,10.532579,-10.326119,-8.247325,45.71727,69.639643,18.744783,-37.48718,-45.021669,10.728928,104.96361,124.858595,113.368386,49.420399,15.62208,-3.715439,-9.322876,-91.561036,-146.547665,-129.745981,-104.934642,-132.051563,-260.398808,-320.022045,-336.920295,-302.057148,-217.074995,-172.250608,-161.846634,-92.141886,-39.205323,-0.199856,-18.81508,-39.293454,-19.849006,-34.823363,-79.15857,-49.752879,89.550631,126.755267,81.177813,19.842706,-116.541263,-120.372266,-55.160861,70.936881,99.1751,140.290632,156.722846,135.940928,114.049296,121.631249,149.652641,157.484614,118.897075,96.350919,102.881883,108.792501,86.745577,-5.755153,-61.990105,-86.339031,-55.389699,-16.101878,-30.196742,-86.201052,-75.545174,-51.412025,-53.09054,-77.831706,-109.018892,-99.703903,-48.131975,-17.782138,42.979468,69.053216,52.850203,28.359063,59.083662,157.235092,147.033582,-64.854019,-270.944484,-290.346462,-230.54299,-215.269545,-254.780546,-260.214228,-198.306762,-169.733192,-156.498667,-178.186747,-205.315922,-213.110012,-155.150768,11.018131,29.26131,-150.129675,-341.790201,-349.58838,-220.712104,-133.277046,-38.988692,-56.645534,-177.545611,-240.335015:75.828074,-130.473515,-276.73142,-365.607394,-318.031618,-255.753407,-257.666084,-216.031345,-83.611779,-36.714726,-43.949158,-87.221648,-173.05621,-171.837869,-110.489161,-93.399654,-91.040153,-140.25055,-185.497162,-198.616788,-152.593786,-19.981814,32.649661,19.454421,-77.826167,-116.85492,-174.337597,-165.838484,-62.319337,-31.287028,-93.658664,-134.829365,-141.310776,-145.414406,-152.417698,-88.81555,-37.746712,-19.220838,-52.841377,-102.016805,-78.130131,-68.191737,-102.7854,-153.026591,-299.061963,-356.973576,-399.597496,-393.65352,-351.706313,-338.589747,-342.038666,-322.32899,-299.719206,-229.533316,-193.082836,-195.729966,-259.583413,-288.963404,-316.078332,-276.744227,-125.545842,-68.174149,25.413171,94.981814,223.299986,209.905512,158.327103,38.414241,-21.542568,-92.769714,-87.941699,-46.814543,-35.226376,-52.393515,-100.082673,-123.280584,-194.936391,-204.56797,-109.778255,-61.763335,-64.616056,-148.507396,-204.151969,-317.950418,-368.001057,-416.839423,-416.961764,-441.192723,-465.62153,-455.240297,-390.853917,-329.391198,-184.067115,-146.838632,-175.410603,-201.597746,-210.079305,-178.851002,-166.42576,-205.836532,-256.690292,-324.689193,-335.020522,-323.944358,-221.588387,-179.033781,-182.353663,-189.585347,-163.058736,-135.979743,-47.476154,16.412326,151.616382,100.312675,-9.982808,-135.131357,-103.312287,-38.484356,-42.364425,18.381027,107.402541,80.728574,-8.67774,4.920811,98.132754,116.493866,60.285042,9.632197,-110.612396,-202.552819,-195.037217,-154.608131,-167.699036,-214.140395,-213.105976,-129.419654,-29.05301,-43.821083,-132.433918,-131.250303,-66.446149,-46.971487,-26.102231,-5.786129,43.390536,6.702142,-42.537849,-52.888013,-3.863171,66.869789,70.435228,104.046104,171.853325,151.007258,-19.020374,-96.821955,-120.725468,-74.603863,50.106649,69.978267,-3.02956,-54.524147,-42.652529,43.574589,92.5498,107.802439,66.922495,-34.35108,-74.223325,-81.368228,-100.409318,-96.11731,-35.13892,-3.965693,-3.731775,-29.736532,-32.037638,22.171691,14.544476,-36.964717,-34.336168,32.897831,59.166526,61.087462,2.402291,-48.66812,-69.070042,-4.672375,131.927034,137.98389,51.447843,13.309336,15.661433,0.267153,-41.232953,-56.576818,-22.018272,-25.571982,-88.555705,-206.936915,-228.356901,-242.596674,-221.933123,-156.248741,-25.338061,-7.017035,-38.680903,-42.941882,39.116046,107.969343,95.125338,93.560094,139.257001,250.386275,258.856862,137.007545,68.446887,99.623515,146.277685,141.629501,149.087428,178.242396,264.434126,291.890133,268.751643,196.179187,149.133251,76.115545,97.909534,238.88472,281.281489,221.24977,130.358972,116.541236,125.532325,139.567906,161.914059,159.233027,116.830521,82.600082,43.638796,48.911102,46.041525,35.351149,41.941963,145.80262,234.215017,323.908943,205.52409,104.798742,-11.490719,19.061257,135.175418,149.249455,144.707075,179.324537,245.896442,102.040675,-9.238855,-83.389589,-36.201888,93.246737,112.617708,37.672913,-36.897775,-54.390366,-64.364787,-60.64751,-76.562022,-92.943179,-85.717509,-72.156007,-102.902339,-169.085947,-157.04677,-25.235906,52.83544,157.920714,176.821596,138.500966,66.065528,53.722476,127.334432,212.595849,305.049053,249.12346,74.518641,46.745992,82.578743,10.664296,-52.319112,-84.311008,-54.401274,32.209552,59.864757,49.571736,28.046844,16.295571,-12.660521,-5.006752,9.59748,-14.302647,-45.621671,-16.278844,56.552341,46.740789,70.910661,229.948675,282.186809,229.692265,172.74073,63.288496,-23.902165,-48.653501,-107.74167,-161.336992,-286.869399,-323.845261,-327.041173,-311.306499,-255.15143,-181.749152,-144.915387,-49.166518,-4.036089,23.030274,4.339133,-25.155224,44.845821,74.016972,65.714628,71.887688,124.672676,122.682069,21.128948,-39.347888,-78.475997,8.884928,80.955021,188.085801,188.88583,165.875566,185.058919,239.814895,233.385373,216.50884,191.813477,174.424918,119.730937,113.832319,154.44217,160.014485,154.535614,150.322182,113.249714,43.475177,56.848879,138.120721,139.293885,17.119662,-41.174689,-5.080128,109.033898,149.02858,170.647771,179.269753,238.271036,254.211677,242.004307,292.541927,303.124363,232.90856,203.31942,194.91845,169.927955,13.172614,-162.371775,-208.289114,-260.109189,-283.071199,-273.456918,-217.1158,-54.714166,-22.651653,-131.049296,-228.065713,-194.344168,-21.26025,62.78971,128.634627,94.695745,-77.76101,-221.428308,-239.774526,-206.849889,-162.100773,-29.641135,11.428826,-55.465731,-130.675981:179.982903,-0.582029,-105.051186,-149.89004,-121.708918,-91.511062,-95.399354,-157.907448,-190.676349,-148.328883,-39.202287,-42.523978,-174.268545,-218.717652,-124.632306,-35.086011,10.494532,-153.522938,-218.199188,-217.508758,-190.202155,-141.469532,-125.216165,-99.063513,-77.369911,-104.235001,-178.293519,-174.519617,-125.956834,-90.004502,-13.445394,-21.051311,-75.540616,-59.202049,-42.21031,12.146417,50.527108,109.8349,118.275078,91.873216,45.373273,29.697411,33.009444,57.716232,80.989961,31.377468,-180.346399,-282.422912,-368.055987,-318.026978,-266.207535,-144.552756,-90.841426,-61.355906,-97.96427,-197.054254,-199.135797,-173.484245,-157.768725,-151.607228,-71.431354,-19.933999,32.638203,44.699172,100.646038,191.092134,222.587037,160.092965,70.744317,-44.361455,-48.781453,-86.431371,-161.019636,-179.99329,-199.649773,-193.813587,-198.970393,-235.862801,-266.028617,-234.229117,-185.98638,-209.645915,-225.238999,-249.898387,-270.715759,-308.831047,-315.579052,-332.838584,-353.499281,-350.795711,-301.52367,-249.051254,-115.694493,-65.004445,-43.965457,-62.277349,-87.243298,-77.389978,-91.010829,-163.246858,-189.514775,-234.284108,-275.232536,-308.172225,-215.919777,-170.892822,-155.512116,-159.293134,-92.553447,-45.469161,-37.428245,-63.395664,-82.536443,-84.706065,-97.166131,-97.971537,-82.92335,-22.43276,27.48604,100.488372,90.294202,69.263945,61.195118,85.004974,116.331794,108.873152,74.394916,34.359275,-77.750285,-81.541264,-27.087291,78.628444,80.915534,33.404187,22.045667,-58.372703,-193.437255,-206.656788,-172.988805,-165.809374,-130.887392,-94.589666,-80.638003,-114.96431,-159.955209,-160.939256,-164.316397,-146.55866,-125.68844,-84.888192,-62.402231,-11.033406,-3.556848,-14.623425,-19.584912,-7.35562,2.81135,2.995664,2.715103,-37.063242,-134.960435,-61.890554,-9.470768,21.331602,19.384627,-6.394429,-59.454518,-208.768764,-219.050272,-179.044778,-113.28095,-76.684638,-21.440127,-25.882791,-27.304729,-17.35117,-3.973649,58.163249,83.584032,64.229568,21.731125,-82.678231,-113.76412,-97.527596,-19.515215,-0.99079,26.993554,97.643685,250.086045,241.395164,92.248532,41.875809,98.814777,115.552653,53.092524,-32.424672,-25.542546,-7.912893,-29.897461,-131.904799,-242.732826,-252.123794,-116.524287,-31.934207,15.945493,13.175489,51.995372,77.522877,78.321741,44.094935,48.489585,135.559228,186.500248,231.826746,247.07507,259.524902,183.033305,144.528252,167.573254,226.227841,320.699589,323.849275,292.828922,288.104181,317.362285,353.216838,353.169211,371.090249,404.234864,427.995514,374.960691,162.519899,80.143976,146.26474,275.487472,269.870043,200.633105,180.345531,173.172022,186.649385,237.950482,209.538796,149.052063,49.19222,40.527548,50.125733,49.810673,37.164025,-34.762868,-84.232096,-72.783024,-7.989245,47.094235,22.874595,-0.919114,-5.700636,-77.109055,-122.223486,-94.022531,-5.241887,14.351912,-3.572369,-30.761719,-138.378057,-201.637929,-163.874259,-62.969232,-80.31112,-220.41377,-249.538318,-179.9802,-152.403692,-149.849871,-132.343771,-120.958956,-66.552444,-16.230385,97.251711,132.847243,109.512699,67.452853,90.794526,189.855955,241.566042,272.706575,224.190007,68.693802,20.926584,51.43265,107.655383,83.906062,-4.630777,-13.928743,44.473317,66.23891,30.112766,-42.505117,-41.59407,61.672942,120.173471,124.534411,74.361159,-12.779482,-13.435023,68.378907,102.411549,78.166164,19.543205,-5.515422,-57.115519,-87.23892,-150.08667,-161.368236,-149.505326,-152.934569,-170.907445,-221.123206,-245.595192,-251.130185,-244.543436,-243.353832,-175.476559,-116.945493,-46.386196,-43.376877,-37.906127,-40.974587,-117.061016,-124.372024,-76.721004,-20.528681,-3.039424,68.066045,93.873474,73.818874,34.968671,-63.07994,-146.584569,-137.553702,6.957828,73.149178,71.04301,33.029554,-12.890906,34.476494,71.155259,90.349133,78.084265,76.113383,80.381064,50.81523,36.114918,44.464124,-12.898109,-71.129648,-82.410672,-21.080477,75.287927,63.368501,-29.422718,-18.709037,18.842005,9.814058,-21.611341,-76.466283,-96.553066,-25.048847,48.260695,116.14612,153.680213,186.813788,220.986761,212.639435,148.117666,78.054486,-101.092399,-124.939862,-88.605888,-88.626316,-114.155264,-101.890305,-60.859081,16.800309,9.14588,-94.484093,-92.82683,-42.175883,20.529106,28.145737,34.853382,20.297734,-74.478183,-158.49191,-163.219574,-116.369168,-60.813035,104.748823,159.898684,80.81106,-28.22282:forward
-170.306287,-197.555054,-207.364581,-142.41706,-46.789138,151.447907,169.878043,57.550781,-12.8988,6.56726,84.85806,74.4155,-24.569188,-38.872142,-3.441376,16.754965,43.29412,28.246786,14.780213,-22.257115,-43.604428,-34.692061,-2.105496,69.262171,60.504747,7.705329,-73.968564,-68.666844,-10.759487,28.674278,107.676502,138.510845,132.163128,-2.634537,-44.615609,51.119337,152.07389,278.982953,254.38883,114.306804,12.894943,-42.132342,-144.149908,-163.90926,-139.632682,-106.494368,-83.286281,-112.691146,-152.613168,-105.384171,-87.707115,-68.053786,-40.647837,45.548779,65.127318,-12.402307,-155.079029,-194.257229,-195.898522,-186.972998,-176.776201,-168.548417,-132.310066,-98.285599,-26.233631,-48.107644,-95.192457,-159.693578,-125.35895,102.27478,226.645532,301.806816,207.892374,183.098516,219.738761,241.647986,254.97737,263.197066,281.938859,287.049169,307.873574,316.880507,329.267407,396.679519,438.885049,499.233349,493.381833,358.19148,136.649812,79.600392,142.100517,210.315517,290.76271,290.259913,185.975974,95.142355,-34.161449,-89.420242,-108.618083,-64.425993,-7.580489,56.430113,40.281705,-26.807518,-85.279698,-107.326702,-77.113534,-43.814102,-34.588476,-47.251395,-101.128499,-154.362641,-266.866663,-311.711842,-289.704776,-152.345317,-53.875698,112.393311,133.710304,72.95374,48.750011,56.151373,22.070857,-10.050151,10.011843,70.740347,133.312753,94.602512,-16.634981,-30.072473,9.344266,115.962396,164.33736,217.06464,200.214846,126.715135,97.305706,113.501921,186.660311,201.623295,160.583935,131.770139,73.847148,29.923498,-128.695069,-265.521848,-252.418891,-108.674624,-36.911129,39.311052,44.138051,2.620289,-61.454922,-91.731579,-123.9348,-105.789732,-7.189018,40.479759,61.901699,47.624094,40.642651,8.467665,-12.932106,20.383753,59.221045,109.618336,114.671511,90.492704,-17.295952,-87.067134,-109.213662,-74.990932,-76.165248,-118.90868,-217.044685,-251.139317,-304.814367,-378.308899,-353.495758,-140.107403,-53.113411,-71.785798,-129.487539,-189.777464,-148.92356,-100.964206,9.746426,44.140476,70.556252,113.680186,276.982902,311.769941,183.903094,36.568087,46.216984,157.076525,191.839649,251.210982,301.249703,359.482402,274.910516,215.441765,179.212157,197.122574,271.279777,330.667466,388.498301,345.797576,207.845209,126.316693,109.001906,93.777271,91.769735,85.850356,59.843619,-67.193538,-230.384332,-294.687212,-297.531393,-247.85809,-136.821234,-76.249062,-17.946395,-47.318328,-138.506414,-193.476891,-190.79134,-91.209937,-23.121651,27.08643,4.221754,-38.659065,-66.293203,-98.490867,-99.881773,-43.951132,72.302543,98.190855,70.515746,18.968337,-133.206961,-297.420516,-332.381884,-301.595752,-260.128149,-66.835336,64.426449,172.662372,61.179137,-4.735654,-97.524062,-119.188148,-117.286046,-98.3755,-69.380327,-84.307043,-155.258606,-185.967548,-164.133322,-108.01252,-114.592872,-185.458407,-226.113364,-279.425249,-311.207344,-343.068278,-367.825414,-342.762541,-273.32836,-247.835823,-234.710585,-248.363424,-330.521859,-470.268183,-524.444229,-558.235788,-519.822739,-319.219266,-212.63394,-133.11696,-199.636448,-203.904297,-36.042688,73.728802,144.146745,119.098752,66.856109,47.320488,-9.311005,-41.344087,-6.165451,100.659394,126.267855,146.876513,173.670583,246.546302,239.752218,206.55834,183.211893,202.963425,260.622015,295.91228,343.026702,336.25618,274.609988,156.419736,111.828723,119.107666,138.721264,149.502416,156.815093,194.901226,146.442868,51.729147,-122.296707,-142.162862,-100.639014,-57.841442,65.79318,104.109213,19.218457,-158.888368,-195.129424,-165.423722,-144.79088,-122.052943,-110.93934,-54.359541,22.642245,7.46778,-117.453147,-150.426837,-58.058909,30.419625,121.298476,112.533413,87.10551,50.903066,19.772041,-41.58859,-60.511504,-51.545777,-35.258258,7.910698,22.693737,-7.070212,-29.769446,6.292778,118.592384,189.276048,281.314175,259.482443,138.812469,75.641237,81.221328,119.510988,135.33393,166.984035,178.656065,165.989062,131.45285,118.839164,143.713699,182.829053,276.377588,318.693688,377.769755,386.067758,317.180641,160.942979,116.856318,158.902461,199.100658,242.224587,254.812683,276.285732,240.369681,188.111025,120.486514,146.310597,234.1814,257.805163,306.684588,322.155231,229.178292,51.723188,8.143572,33.58057,57.557499,49.196234,34.276581,64.283178,198.81031,286.176318,407.546036,408.943444,374.823635,398.084182,472.743503,486.6572:-125.42134,-137.938101,-109.82978,-21.583334,21.390586,87.728683,93.526618,49.450571,-21.607919,-39.206282,30.180862,91.786022,109.712798,46.623837,-110.263072,-146.482872,-101.828519,-16.695872,6.496036,30.840139,44.566394,65.861616,68.844437,47.658159,-15.606881,-29.499524,27.08995,69.678248,116.871438,115.71706,84.61456,69.473609,26.496138,3.507267,31.613542,112.860099,162.224132,241.970137,208.853489,66.593857,47.71002,40.691401,-40.555521,-69.727466,-31.705363,9.903005,8.832623,-30.045119,-101.469553,-164.09193,-161.043079,-56.09489,15.602185,101.473281,82.68071,-49.197259,-169.352717,-183.052793,-125.738317,-105.005186,-127.385611,-137.161223,-110.522001,-85.831077,-54.945187,-57.675626,-60.869366,-84.082873,-87.118871,10.012177,94.997399,211.223678,114.191417,10.116998,-64.208773,-13.243303,75.729704,82.809092,98.234685,102.944325,30.858007,-2.663963,72.397241,259.138657,288.755772,268.210926,258.941792,232.350104,199.018333,177.445621,112.8361,102.074144,159.759268,187.50919,161.330001,101.359899,-81.399959,-179.726199,-137.060656,31.363112,57.839236,-29.149375,-70.863287,-81.823324,-72.007107,-90.453188,-135.060122,-127.460731,-84.836971,-84.312865,-123.910018,-148.75131,-204.594783,-184.165636,-114.817892,-2.178377,13.49232,23.102011,1.134546,-80.996362,-101.716114,-78.2378,17.342557,60.893865,108.646105,112.230772,86.09733,80.65286,76.100244,71.457585,107.400436,218.043473,236.816445,170.153642,131.808045,138.363294,163.842245,147.773566,129.816047,139.78168,123.302761,90.55748,23.273249,-18.320248,-147.642063,-230.377158,-224.494533,-115.202009,-27.364201,91.144338,97.172693,69.609753,22.816998,-9.332621,-3.851138,35.434842,90.912487,101.449004,73.233153,26.349124,-46.183053,-60.99118,-71.166379,-42.397796,21.766563,152.424487,170.032192,132.131217,35.04037,-15.510206,-24.32268,-2.45652,-0.379443,-8.875032,-17.776,-32.739746,-125.276734,-261.936659,-269.804992,-63.143419,80.289822,140.493918,38.763859,-149.1308,-140.577671,-88.102956,35.413252,55.473336,55.130181,100.562469,207.142522,188.892596,50.293948,-8.871949,-11.274165,-16.748653,6.842857,127.746067,183.885153,223.991839,141.30563,60.020939,-37.505189,-7.251939,205.23896,315.506562,302.964506,199.812727,20.321348,-71.857561,-87.171206,-6.81237,66.940921,112.50971,58.712687,-91.755098,-226.309202,-286.213139,-292.894014,-226.817587,-92.670707,-80.502128,-169.017693,-216.866499,-225.052595,-212.300103,-215.028099,-185.760617,-131.531497,2.054728,20.184522,-46.852988,-101.322612,-113.552748,-87.179059,-41.824455,88.876934,159.888933,163.898752,52.206611,-186.701206,-140.723325,-67.456674,-39.637412,-62.916669,28.621917,133.226758,233.521984,119.636084,47.507721,12.634547,49.389443,147.123824,158.327762,50.239158,-6.398387,-13.480328,1.339318,-9.350217,-47.792454,-64.182492,-74.583205,-92.238239,-195.259367,-282.465661,-282.171531,-196.447013,-143.58883,-96.130574,-93.045859,-116.895749,-159.034289,-265.683151,-334.904047,-355.983434,-410.769712,-425.100472,-311.638093,-209.524574,-77.416986,-64.456924,-73.117829,-56.980256,-32.240273,41.371351,88.555659,128.981793,81.861261,-105.878285,-85.655046,17.76283,123.465143,107.455794,92.894118,101.262033,105.858673,127.061583,161.066745,280.513283,327.573444,305.458853,270.083809,279.62819,305.739249,253.490598,141.926678,147.318652,229.485435,243.442755,197.676215,172.798552,163.280693,89.040092,20.635293,-26.535895,-6.677637,24.725525,45.488426,130.156718,165.312981,127.812848,6.536172,-35.254463,-98.175077,-119.128199,-107.092041,-99.39394,-100.203727,-84.362258,-111.242053,-219.659916,-233.486578,-122.815665,-42.465743,32.56442,16.637261,-57.522679,-120.789255,-126.042908,-64.469156,-23.643818,7.64535,14.145965,71.596911,28.650783,-38.871361,-39.307605,26.182285,132.627188,170.549359,227.080122,232.115643,197.700822,151.606683,152.790407,190.903908,207.953419,228.50464,220.18061,147.304822,43.752929,17.409312,98.647764,175.666116,262.75129,264.566112,251.872216,263.146374,243.576411,89.803247,44.530213,127.801434,194.821457,244.798085,248.544151,267.092443,228.968645,175.861415,110.399475,115.87892,146.831746,176.249527,204.959398,151.008953,-44.199486,-178.972519,-180.560825,-71.913692,-14.110014,29.892769,36.678963,116.401314,214.284131,226.238439,242.158825,259.50183,287.432538,316.12006,377.019827,388.163899:15.899481,-20.184215,-41.594417,19.552465,87.296113,141.398884,114.767696,39.572843,-21.137627,-6.600911,116.016872,145.228942,84.940099,61.352418,60.507769,47.563003,-4.227849,-27.832959,-9.593074,62.057181,96.621576,130.679777,125.174082,103.397487,25.667671,-20.054449,-0.94587,59.322865,147.522469,139.233383,71.969541,52.277635,38.479331,12.782105,10.839426,39.125017,49.345265,-5.548474,-69.390014,-141.642694,-104.37593,-95.561658,-133.013309,-142.867411,-63.144446,-0.656168,17.975666,-41.459799,-151.468391,-115.670251,-72.574146,-5.795407,28.607515,79.011212,52.044075,-102.552671,-200.329382,-193.710154,-153.834929,-143.432666,-88.743842,-55.03468,-68.211805,-93.729629,-110.115534,-86.67435,-54.011885,-6.269327,-12.040941,-32.651033,-23.623071,12.685812,-26.741518,-63.394827,-69.434921,-40.086906,-9.042706,-19.171485,-67.412462,-102.768906,-160.609628,-98.992029,-32.643875,61.832519,100.040271,175.603676,183.082609,124.60825,38.71156,39.806601,155.531096,209.06641,218.87463,192.176199,93.956968,23.714966,-98.495935,-106.644257,-75.27867,-32.087528,-38.235012,-24.101379,12.289247,46.564308,-59.754135,-121.445325,-100.887437,-29.222246,74.439703,58.473038,-93.531061,-168.454241,-252.679627,-256.874395,-206.872729,-82.141131,-52.29209,-32.648992,-14.002769,-13.11691,-152.896783,-180.964126,-58.056996,-7.10458,-13.495843,-13.018239,1.930412,-6.919045,2.023708,73.562068,124.824626,224.242362,242.222306,183.043695,121.721423,34.35041,79.763908,127.105852,148.658208,105.51143,-0.479356,-34.837834,-79.049115,-93.604788,-165.94242,-297.938599,-307.859176,-141.735101,-33.443362,11.457267,-60.01082,-202.421702,-218.992739,-200.179966,-101.33398,-38.731035,8.701685,-17.983953,-122.354326,-166.777267,-220.108513,-221.915441,-190.043451,-78.856965,-16.865658,44.938877,22.313189,-46.611743,-94.640249,-133.340828,-196.968957,-180.97675,-55.293051,0.09807,-32.256604,-117.103219,-281.221753,-308.969763,-274.267943,-129.066668,-33.208029,32.76222,-42.16685,-222.303467,-249.959449,-210.601606,-77.022414,-21.016908,52.180535,77.069414,84.160422,67.99868,-11.805284,-133.725536,-158.256131,-114.223577,-76.278235,-28.27016,-4.649845,59.50424,23.175826,-20.407951,-40.035446,-6.05252,148.649246,219.266499,158.514452,63.901147,-58.386522,-85.698622,-78.632986,-34.645083,-9.197647,1.84026,-24.524879,-114.760223,-247.314183,-305.860378,-263.487311,-177.036431,-70.07068,-83.394288,-196.331506,-246.623189,-264.983106,-273.28899,-267.099928,-150.183118,-54.186498,63.464848,50.319584,-24.454349,-57.548652,-54.246509,19.221476,85.921521,201.954179,215.918009,123.421076,46.922654,-66.695524,-93.181134,-68.824982,26.801832,83.378753,148.091776,127.82599,84.234289,147.47487,182.658973,213.229284,228.208803,322.63478,382.410811,368.940354,277.184962,81.943297,110.530541,189.325778,239.266798,184.252804,31.759643,-43.122119,-169.014169,-212.821676,-198.884549,-124.100504,-87.288927,-5.578308,43.171441,72.989217,34.329699,-117.842117,-251.869884,-260.503431,-191.156001,-155.546486,-128.58625,-131.241948,-100.279055,11.511366,59.180087,109.524922,121.826079,142.811124,167.559798,221.53723,223.715329,159.843226,38.399938,10.539125,81.071661,131.394134,169.223227,163.359508,158.837679,166.528113,170.578275,257.226829,323.259964,363.071207,330.049312,268.689844,270.790756,252.10275,174.395465,190.385931,328.711408,391.09361,384.28636,310.087302,163.10945,103.793202,103.19224,184.821653,236.896501,262.576979,238.844482,184.59294,156.29881,43.219631,-48.664643,-44.407518,-4.447595,3.553755,-16.432849,-36.521959,-95.039931,-163.073401,-175.701311,-180.426718,-188.861873,-177.239438,-139.86066,-53.452393,-39.127876,-75.237886,-101.010925,-72.577936,8.769171,18.287585,8.982977,30.709929,120.383058,86.351928,27.834407,44.372684,118.509339,223.324794,238.521198,270.289521,286.366183,222.380619,61.291015,21.049537,79.889492,139.757705,179.795264,133.295401,2.155408,45.475117,138.50925,275.824686,272.9023,250.387244,287.206089,365.693072,341.098387,185.564859,93.609107,96.008079,152.107783,196.00954,252.959597,247.412699,204.074411,143.154148,105.545356,49.852909,42.45021,90.182547,134.3967,157.237828,113.284495,-18.362382,-125.867385,-144.804077,-64.678357,16.454559,126.162896,127.261498,127.128072,191.544683,207.36014,215.688122,225.991118,251.967641,266.093301,315.38041,351.609143:-153.395559,-171.322993,-164.510455,-81.536335,-1.308962,142.086816,143.624198,61.179656,21.423431,29.055644,122.568085,157.305721,84.978306,34.230311,26.592772,39.328573,25.853842,26.788302,43.77836,76.041608,89.040479,88.297001,69.543641,38.668141,-20.993848,-72.839866,-91.604104,-39.399654,66.527897,82.275629,84.798561,94.595362,67.06794,-9.10117,0.038831,99.488529,144.462007,172.300818,145.118785,35.601464,-30.406466,-52.071232,-121.106647,-148.367378,-108.874247,-39.233241,74.012004,62.626508,-61.559023,-119.384672,-85.760251,34.322038,88.67672,139.743263,108.577351,-33.111684,-110.418197,-121.78105,-176.802694,-220.464535,-244.867071,-211.930145,-125.877318,-94.838486,-64.953663,-82.809054,-77.626457,-18.162887,15.533113,90.40817,129.40514,152.154867,85.590731,48.723318,3.740026,-9.769048,-7.531518,10.296074,61.621037,94.667051,114.680263,47.167943,50.009309,158.432997,221.415341,341.919981,400.073758,419.889982,280.708273,214.896272,215.73942,259.323615,311.99916,322.595232,304.080738,239.489308,21.156513,-78.553025,-28.634657,96.28309,91.999552,30.28768,29.806573,54.485836,21.013013,-1.692163,3.741577,11.575927,-0.313598,-9.281007,-75.290935,-135.672387,-235.672832,-255.764629,-230.946282,-159.503994,-120.532721,-47.246461,-48.453203,-106.966268,-121.902097,-114.17016,-85.522061,-77.835567,-79.561249,-58.985832,10.557818,14.657613,-59.900289,-124.219635,-100.045914,36.422688,101.143161,169.935496,170.04218,125.091004,107.740765,106.655512,69.943308,37.510678,-20.501698,-43.59412,-78.082799,-94.231858,-189.011496,-323.83602,-334.034165,-210.289116,-124.86576,-22.934551,-33.694659,-124.436421,-195.953795,-226.917406,-214.770178,-159.936314,-47.548283,-11.075993,4.481905,-25.97261,-90.577008,-99.719479,-109.95411,-102.900306,-40.730105,147.496899,174.442189,22.178613,-170.13586,-223.460911,-190.240287,-119.094942,-18.141442,-22.859348,-119.039742,-167.102743,-207.645335,-280.816076,-308.979664,-218.148664,-132.382722,-86.839039,-140.600249,-219.556906,-166.208983,-124.499344,-31.253024,9.451306,63.5827,107.373705,238.43643,264.956381,121.576231,-92.764292,-112.218315,-14.189747,25.978848,75.523347,119.702671,228.297301,210.883706,135.130509,35.484338,56.813516,164.174083,209.93,199.206544,144.399526,7.076931,-98.122244,-105.100187,-49.537639,-12.913449,21.317029,-3.390704,-113.316754,-212.054915,-248.424398,-267.921745,-258.333099,-253.314142,-245.66463,-228.10037,-228.379271,-208.815282,-195.336365,-186.656111,-121.27239,-69.107617,59.675037,111.129896,92.258717,-62.064464,-123.303166,-89.294826,-7.288812,145.017291,188.407801,166.314762,80.681353,-166.855761,-285.770711,-265.032518,-177.244045,-123.116205,36.461801,96.972882,104.614478,47.966148,17.738227,22.011329,61.991777,144.180308,169.019514,138.523948,83.881099,-25.695385,-57.396068,-23.588559,60.856661,64.088415,19.120303,-24.517285,-157.20272,-254.544237,-278.790056,-243.253873,-184.664395,-77.840308,-49.62091,-45.58186,-62.619206,-112.298588,-208.280051,-255.408553,-285.709124,-255.809964,-137.447412,-88.020571,-38.654316,0.283872,28.349652,115.627853,166.012733,248.374074,269.593781,217.447072,150.554978,45.376684,81.728593,160.073199,314.344268,338.516473,294.031425,261.113254,243.456081,240.416567,216.948808,217.823999,262.766709,352.809208,359.399624,298.606305,265.25325,238.000072,215.448338,209.476097,244.324163,263.499349,232.034639,200.632602,195.986149,130.93983,48.834286,-1.092774,67.906398,188.57479,169.652894,93.849629,92.038891,48.78829,-138.892538,-206.89178,-184.833623,-134.294385,-87.3065,-109.719193,-135.324481,-28.103547,6.39791,-68.357325,-127.807983,-138.771563,-86.386317,14.364071,35.024676,36.75054,-46.055381,-71.499647,-8.035967,27.26002,19.075406,16.974897,100.385914,102.095824,19.458379,-94.423459,-53.067706,140.226228,229.557343,314.827517,303.304598,200.0405,58.000833,3.740735,1.55332,51.87844,129.566459,119.475042,63.648999,101.311183,145.257321,202.711648,216.267794,265.751195,322.754993,421.878093,408.796591,250.700072,106.69484,102.539445,168.770945,201.693305,263.560802,286.482175,288.734072,224.449849,170.035435,97.340244,106.799901,158.894909,167.679074,189.681662,215.973551,168.426574,-68.825572,-147.438271,-94.346105,-33.12818,9.065038,14.541187,91.256618,176.643625,186.35648,205.154375,240.396447,313.922621,332.69457,358.403435,379.482761:-186.964323,-285.922883,-273.4195,-94.010398,26.329071,149.168996,123.578984,22.46268,-48.287001,-39.262866,110.662541,178.041065,149.563616,92.547131,26.615386,7.693535,-53.189646,-24.301057,28.371105,115.855168,164.172279,242.10188,226.00488,117.318243,-21.382632,-88.599582,-125.019771,-79.958731,60.407064,113.631468,144.016396,124.865215,13.587482,-86.705934,-63.454158,77.478967,132.666114,104.058374,27.370645,-132.263498,-224.565876,-236.119358,-176.881463,-124.24625,-29.498876,10.851596,71.869429,76.356677,21.687526,-30.503138,-24.524731,48.749084,117.281433,257.3833,256.932495,32.343176,-251.676492,-284.153412,-149.393852,-84.634304,-43.387879,-35.03659,-40.087631,-53.274949,-61.8829,-33.120407,-0.692475,61.523583,90.49254,163.19039,184.115671,143.416644,34.858855,-1.868203,-8.812283,2.274404,22.395788,20.735033,-4.053197,-4.595209,-19.983286,-62.36236,-27.869921,156.892144,241.477361,277.384481,260.499518,235.788348,179.904305,146.74032,122.305745,147.633473,234.859357,239.307868,145.657047,93.766722,-18.826662,-100.692486,-69.243274,72.998897,125.847475,136.904561,113.903395,127.25428,112.504197,48.861953,-20.742794,9.853057,52.489224,3.262342,-158.799798,-194.596381,-189.934503,-236.104678,-256.00165,-190.6773,-115.545249,0.205113,9.552703,-60.647203,-139.816205,-137.946469,-120.141133,-145.744801,-182.709002,-150.447799,-74.377508,-80.73911,-157.21723,-203.373439,-184.44957,-25.594256,75.455918,136.063587,90.306947,3.76767,11.393816,25.943079,39.562023,39.050292,16.138746,-20.490586,-126.855588,-177.327137,-295.145457,-403.998742,-401.764438,-247.859799,-134.890699,-46.008088,-109.13568,-251.244665,-295.511461,-316.050802,-256.125384,-160.080119,-2.653746,3.558273,-97.398146,-157.148203,-230.859709,-234.906856,-194.349341,-75.41589,-19.68711,84.838279,109.878057,40.130697,-123.54001,-182.513366,-189.06634,-145.226597,-41.77181,-26.209589,-125.225452,-198.542692,-267.738349,-296.101726,-299.452822,-176.298102,-64.814193,21.755774,-44.111962,-202.912299,-186.756937,-123.032031,8.334222,49.981998,127.262987,164.350763,140.663443,86.974424,-8.113718,-76.022039,-91.354505,-76.846794,-41.594287,92.280541,144.166528,111.27595,-17.499737,-49.692094,-9.714032,17.979696,57.514008,87.176675,86.7561,41.94688,-57.747407,-102.785764,-108.684453,-85.311394,-41.757508,59.527609,77.177343,-13.772964,-236.135736,-317.708245,-301.599057,-244.536537,-147.350267,-116.967018,-139.129748,-188.641625,-269.026163,-231.343561,-173.415261,-79.542326,-55.255162,-12.346512,2.290851,-6.197558,-51.313879,-62.626707,17.62632,96.609276,234.661531,279.227118,254.865894,162.826412,-67.988136,-128.544724,-79.222124,30.293445,56.759497,68.487745,52.074997,30.423011,33.179462,22.468738,60.194352,111.307027,224.937241,275.644347,280.879649,229.706507,92.300695,23.344308,49.78662,139.386474,148.749172,70.752669,4.029763,-114.196317,-182.848191,-190.293438,-138.556252,-95.847638,23.556207,92.321641,135.957102,104.035086,-1.085699,-70.358304,-65.641377,-46.764882,-40.567741,18.335951,45.581043,39.948926,35.579686,63.556819,181.752101,243.871382,330.181392,340.899005,273.618641,209.451726,81.013996,58.425234,113.422551,283.587344,340.89251,339.032152,310.64465,272.663967,204.00402,174.04011,240.393273,296.242511,296.05333,262.146596,256.461422,292.864415,311.660444,230.585428,235.81775,362.686329,414.323524,387.31331,334.690873,265.62264,195.882927,130.338672,71.595145,115.92876,232.073842,247.343115,206.452083,185.644587,114.6536,-15.717186,-43.829702,-11.832998,4.283421,-42.345218,-97.497259,-130.75176,-49.006862,-40.382808,-129.75078,-179.757164,-170.733778,-118.831836,-28.033825,-12.231843,-46.327047,-138.664187,-154.882235,-86.679327,-49.415219,-36.950589,-31.003929,62.516817,115.953543,81.890284,44.806641,77.006731,179.791852,230.519731,292.931189,282.532191,158.546334,18.105302,14.092785,114.576391,154.004417,104.240828,37.567605,-3.175596,64.716159,69.396968,80.142056,129.093327,302.472569,384.207694,431.333405,397.91779,256.473146,91.153164,46.037989,60.296782,103.192437,193.895393,211.817882,163.479279,91.174658,66.015544,41.323747,58.937823,153.321052,184.260803,139.413507,89.993506,-23.300157,-139.692048,-172.397045,-168.20594,-119.345397,50.929672,111.689793,84.59822,-22.724496,-33.276331,69.326604,149.813449,279.040147,303.424732,275.596777,246.995729:-172.536091,-210.731473,-199.666473,-160.551219,-117.219116,3.062076,33.689706,33.70701,29.849761,18.570731,3.064664,-2.331902,-21.732691,1.014069,102.378657,118.017107,35.657291,-23.201693,-5.743962,53.685222,77.958715,103.321278,107.083973,94.595795,-46.599629,-135.787582,-159.11334,-95.226037,44.207284,78.83005,69.032872,66.366925,95.528144,87.167175,80.786801,100.493502,126.006866,163.860677,145.822698,34.212434,-111.883325,-173.629352,-217.953267,-213.58617,-183.694321,-146.240112,-67.092953,-42.545619,-9.315783,-15.443574,-15.591501,73.203199,139.942838,192.390951,149.598474,-36.349634,-182.317069,-210.933968,-213.996946,-210.732242,-217.390011,-204.506767,-114.90687,-61.61517,-42.485441,-128.090824,-138.088089,-84.964047,-46.964028,53.977463,104.136399,176.148312,174.979161,129.050499,82.490605,126.280543,214.069253,210.714119,181.178081,189.097299,226.83373,263.621804,305.830615,403.175864,430.346296,489.056675,509.733275,433.002885,258.568489,192.331521,178.411298,215.436979,293.608179,310.783929,250.461781,182.778891,36.588717,-92.327001,-123.406705,-98.031865,-59.200569,31.566345,59.152155,55.518546,66.622581,83.675411,103.198776,87.676024,0.31904,-31.090829,-46.476609,-74.215669,-199.213878,-307.429137,-321.197217,-229.817896,-119.785061,91.537718,104.721705,-31.838263,-92.018156,-59.98909,-8.683335,-34.81097,-93.170718,-70.494232,10.430635,14.805226,-64.519171,-196.025719,-237.449984,-161.828782,-59.911056,79.995797,63.607144,-10.021656,95.105024,164.607701,172.130124,120.742999,1.429927,-25.839,11.937293,25.122523,-80.095193,-260.840342,-297.713143,-207.316528,-128.111989,-15.80363,8.342042,-24.929042,-124.270288,-151.499007,-99.870633,-55.730623,-27.96001,-31.284759,-17.889249,-8.581799,-23.087263,-71.758988,-86.341907,-54.305861,-2.032278,129.965649,160.035761,82.638707,-110.562364,-204.213316,-252.580552,-201.689581,-105.583227,-107.393426,-175.129457,-207.40669,-264.523339,-313.746418,-290.699661,-157.654817,-97.405994,-46.93909,-59.324874,-107.264375,-54.854281,0.646291,68.774625,75.562474,88.29431,110.223735,178.288595,205.932099,200.802277,121.127338,85.184484,87.348785,126.709312,232.872201,266.812986,250.655389,154.67837,98.999407,60.618172,103.806015,243.126637,279.587816,202.73875,134.56591,93.843274,51.023541,-11.911221,-75.076525,-38.888629,14.005059,-44.875327,-215.336226,-215.461451,-194.575082,-176.927682,-160.224104,-117.922237,-101.406611,-99.107238,-103.857289,-74.117529,-63.010911,-85.318966,-107.948919,-83.287924,-9.785936,11.757062,25.074438,-31.342498,-99.59496,-188.654003,-153.825355,8.729043,66.916626,39.306816,-44.031274,-258.772424,-410.450843,-412.548384,-312.564807,-262.400444,-134.798385,-46.48394,85.36964,135.177667,120.931038,-28.496881,-122.408959,-174.400145,-121.583636,-29.35461,-47.874119,-177.391763,-242.005741,-201.302159,-31.81482,24.359499,-22.82467,-94.9751,-202.658193,-229.983518,-234.31854,-215.63453,-191.809971,-159.923546,-160.419027,-147.700167,-117.980799,-99.647679,-234.566018,-306.724157,-339.509985,-295.235793,-140.282094,-68.534875,-30.737952,-120.09558,-145.103063,-55.516406,40.142899,221.087303,258.637702,176.452814,91.305527,-13.959774,22.427721,73.055885,185.375554,223.285263,217.06481,183.330227,132.031434,111.255259,95.572935,64.137012,71.782247,152.544218,194.589113,209.97048,211.521666,247.516616,181.761822,118.917535,44.495738,28.05807,22.567748,63.224433,185.371218,106.502092,-4.099365,-141.640908,-131.174374,-23.886141,27.533413,60.90719,36.82873,-49.46986,-131.01174,-150.857373,-127.415197,-95.782335,-22.099729,-15.955045,-73.888188,-78.872485,-74.427972,-95.389548,-88.262454,12.86518,92.933869,204.649842,209.504026,148.908625,42.111695,11.131827,29.873571,42.800822,41.888746,45.718977,67.077738,30.263397,-21.378398,-88.027935,-61.053796,56.722016,101.047816,143.780317,145.688417,88.349364,-3.991664,-4.95025,102.384929,165.190739,249.561881,274.031342,284.114681,269.872171,266.652581,266.958422,274.100839,309.325832,340.835476,409.209122,425.722379,394.105069,298.078985,260.240569,254.922354,272.172151,321.305822,347.807062,357.781182,226.796986,124.780388,70.719265,145.999751,290.171526,288.692269,227.520019,231.602301,263.714269,195.384181,137.04831,24.961859,-14.749199,-36.585364,-12.021436,115.164039,227.403581,237.130526,234.000416,253.102423,343.610166,395.549295,414.88361,383.712059:-279.230346,-357.433961,-318.586327,-161.741886,-64.339032,93.284412,93.229483,-20.235386,-63.439854,-48.72133,9.68916,33.161223,44.465747,52.686253,61.576674,38.558122,-27.487893,-0.965945,54.934449,176.553483,211.440341,197.072044,167.120567,114.448402,9.302296,-53.901364,-101.975259,-83.795833,18.580524,77.232118,121.026752,123.659166,95.100652,-20.794559,-37.451242,57.996312,113.217949,107.297763,36.44606,-135.665902,-252.460458,-294.427362,-314.227835,-281.295556,-149.961955,-65.498833,43.269128,26.814514,-89.336848,-124.272662,-94.243954,13.076465,73.303088,127.327548,95.683834,-44.061765,-160.566253,-177.893116,-175.239046,-179.135755,-143.888769,-100.102985,-50.095293,-49.772481,-82.327385,-127.54434,-85.665389,87.508478,142.327197,177.244058,185.269197,161.273294,15.939523,-58.674807,-58.189909,7.605484,149.749931,172.290179,60.218318,-20.748538,-86.30137,-11.665936,66.393759,242.815092,329.632272,498.252438,537.606674,423.314912,211.937151,161.498352,201.754604,251.125322,310.510853,302.103244,199.182499,138.093084,49.144091,-12.986502,-15.04809,59.878692,116.559871,184.934105,166.333329,74.227761,66.002654,101.856907,170.45041,174.092345,114.658492,56.032474,-88.22795,-153.468557,-288.911736,-376.011464,-333.223056,-120.151516,-25.65403,30.250168,-11.595287,-130.570466,-190.625641,-194.187997,-144.276763,-111.933674,-68.110535,-48.225419,-49.949476,-96.871352,-224.634038,-285.332592,-288.372907,-214.608443,-112.15816,130.209778,177.2614,90.614807,-2.287393,-8.388357,4.777963,9.199069,10.556344,-9.575881,-82.777257,-109.952652,-196.248346,-325.056548,-334.28955,-198.233865,-98.537919,-7.351384,-49.270643,-189.297261,-256.254817,-259.792691,-165.455501,-82.176767,33.654231,46.95225,15.55051,-10.990822,-64.519707,-95.910976,-98.436777,-73.850605,-30.511394,132.408603,190.737938,77.829784,-174.409349,-222.407904,-117.235697,-38.612656,5.272467,-42.334326,-178.598532,-202.213794,-191.091294,-264.628171,-279.994231,-175.669826,-90.535519,30.411731,35.993013,-34.371466,-97.660895,-90.347523,1.753115,49.720653,119.634609,170.439087,273.644771,267.025016,100.139169,-68.264529,-83.972284,1.430069,85.550097,271.201942,315.78349,253.71983,108.230968,58.151627,89.516878,140.249679,178.983552,171.497992,131.190609,101.055792,20.620365,-56.629865,-51.236335,25.826325,64.03573,115.065516,110.596538,-8.88354,-162.033624,-192.608637,-160.246275,-129.999282,-67.009549,-31.969109,-31.616572,-80.55427,-166.710749,-137.969411,-96.537302,-11.287968,37.214144,156.805264,181.512876,77.936926,-98.454378,-148.53831,-112.169087,-39.469903,142.208262,211.092801,181.646498,77.836084,-189.627629,-330.100515,-304.56037,-174.583021,-117.188284,22.716553,96.445558,154.141191,65.478647,-11.180457,-82.813678,-45.71755,102.660251,173.861774,190.764265,113.894222,-75.105411,-96.930881,-40.500384,87.525484,121.437769,109.347307,67.266496,-53.917941,-170.895964,-209.855346,-204.842303,-165.008998,-42.194026,28.499845,93.483853,64.479798,-94.621801,-269.866838,-276.663796,-110.298874,3.430601,168.378601,193.114109,131.83792,8.449811,-28.658441,40.433062,129.644109,292.915771,329.054843,250.824285,158.706057,2.509335,-9.154586,52.075813,221.550346,276.83114,254.395204,193.184408,141.141164,189.776334,185.206184,188.484182,224.323749,274.591475,266.788685,254.696406,276.09365,308.048271,205.447196,143.97776,160.907497,219.31791,263.857117,239.282266,193.024167,123.052136,56.92637,1.619457,49.952734,167.75023,189.639253,209.339536,218.137053,122.839383,-79.131365,-117.211817,-60.957999,-25.489363,0.416375,-8.484007,-43.015326,-55.905195,-64.298868,-91.224537,-100.334145,-67.645398,-7.080542,114.82014,122.701584,44.262341,-39.218325,-33.629611,70.339843,109.250605,87.195875,70.36581,112.967511,46.026722,-61.132778,-175.619709,-136.558212,43.309499,140.212463,224.984662,192.912663,40.471276,-100.505188,-103.803816,33.819493,119.330613,202.060367,198.020311,167.492264,140.982731,131.167701,172.244524,225.159211,317.22698,340.604654,389.249498,420.904495,383.18725,175.779246,91.934897,70.777677,106.357695,186.067465,216.468628,224.399274,154.04643,108.268928,41.879271,40.918678,110.620841,151.445927,220.390172,258.837103,232.850465,-21.265088,-141.885578,-167.038932,-82.98138,109.648336,155.440528,113.791142,41.963343,48.626787,103.40882,115.52054,135.020103,165.586727,208.9994,200.671265:-177.606255,-124.360693,-144.766355,-210.627784,-214.162309,-125.395865,-80.381167,-35.191709,-22.587608,-64.907538,-170.012462,-164.602488,-24.371897,61.316803,118.689074,75.716532,-47.215976,-124.177881,-141.446116,-157.974287,-157.983582,-102.056336,-45.842136,40.426864,4.991961,-34.994397,-63.692131,-49.412334,-26.089447,-30.646959,-1.166054,73.434678,228.488935,168.042318,97.808838,-10.627583,-34.985904,-22.144174,-25.946123,-70.272862,-117.758267,-179.460452,-309.520222,-305.870945,-180.014351,-119.60173,-70.223128,-59.475992,-13.035965,31.265845,57.507226,115.930147,119.416577,68.826022,37.267323,-49.244817,-175.368429,-217.991974,-252.120886,-266.722693,-255.425719,-190.141827,-6.721523,44.770955,35.23863,-17.092827,-32.635052,-63.75558,-69.69391,30.955501,126.869258,277.6303,303.795623,283.454256,270.344764,296.149515,350.779478,351.87704,307.503861,276.735122,245.665867,322.829191,384.623163,475.024305,511.882952,590.015483,591.233105,437.165912,234.664674,183.600426,152.558222,141.426888,114.837799,102.902593,46.196883,-0.871796,-49.220072,-26.724904,-27.235589,-60.163917,-53.053028,30.97347,54.861773,65.553727,142.635774,170.517071,156.9573,125.11007,45.338361,31.235678,89.136936,124.811819,60.480994,-147.658406,-170.002676,30.96543,132.942313,132.296939,75.583829,5.13615,-12.791618,-3.284609,40.329018,35.761297,-26.645251,-37.668052,28.502989,74.143165,48.764864,-199.589975,-318.725434,-337.265793,-251.355227,-66.953752,-29.926358,-11.377312,113.452664,173.312953,139.017064,67.255671,-57.737872,-89.352807,-86.486255,-64.677064,-51.052815,-136.386081,-192.515604,-211.35262,-154.617096,-4.330232,43.62295,53.187283,16.865,15.449453,28.333949,21.046447,-15.163165,-29.182281,-29.181605,-2.711149,81.555775,30.735433,-37.53811,-64.385284,-19.214356,73.10561,89.28986,19.103143,-98.125817,-106.049797,-26.859325,-7.892837,-33.169235,-29.332901,-23.117532,-52.619927,-114.057679,-148.940621,-160.208698,-117.390875,-69.099193,7.026574,21.458923,32.035246,19.974834,-1.428377,-35.057035,-29.534763,23.994659,52.888829,90.391002,106.388943,124.701919,74.528315,26.547542,-45.188809,-23.282035,137.159882,197.977703,128.470128,-70.011514,-135.989336,-115.381477,-48.276356,68.145889,91.094044,58.288479,36.503801,74.391547,104.034335,74.930664,-12.181328,-48.82865,-134.557228,-172.506099,-159.770375,-149.800362,-172.28248,-129.244528,-67.367714,41.463473,100.441231,180.597301,158.06619,61.585654,88.417586,137.769432,149.183538,96.849125,15.206258,32.045629,118.567846,104.738655,15.639079,-201.177387,-229.650605,-90.489305,5.060326,77.067762,28.926363,-170.243281,-320.359985,-319.129691,-222.803118,-189.498212,-144.575427,-94.270198,41.623341,134.893478,124.322276,-27.862306,-107.197405,-131.018327,-82.262648,-7.766987,-34.971002,-155.322745,-172.089729,-129.444828,-13.689928,11.402951,-67.745665,-138.329727,-194.954783,-117.157227,-92.552487,-132.931261,-161.831037,-151.826757,-118.035212,-97.754651,-130.332694,-217.25452,-326.093081,-380.666413,-382.513036,-314.331256,-117.324618,-39.429294,-25.263914,-185.088618,-241.438267,-161.783458,-76.975835,16.756849,18.769951,-54.997993,-123.210052,-217.257993,-189.752545,-163.579272,-140.094857,-144.524338,-149.943336,-152.808966,-159.297572,-96.48301,-69.812668,-83.702047,-81.232757,12.435924,54.711053,26.442448,-27.9964,-109.378193,-64.001792,-37.069396,-79.119598,-107.207405,-12.411113,76.3143,116.996554,-19.095504,-83.368009,-123.221526,-110.573363,-106.697883,-122.538117,-115.544057,-75.961613,-14.938971,-131.315049,-203.214262,-193.587242,-119.88294,13.833956,25.093212,7.50914,80.009671,101.80599,26.824699,-26.953855,12.817771,119.6455,317.260745,355.479597,330.245709,220.932397,163.934449,69.118264,21.993915,-38.852105,-32.423017,41.503278,57.088237,1.667365,-96.148903,-71.711453,83.873349,156.961034,181.27451,129.116753,-1.953728,-1.110889,78.447544,273.987208,321.871667,287.90501,240.255452,194.090635,263.042925,320.054561,440.476582,463.2927,383.151337,345.938109,370.234001,388.539817,345.864241,205.016414,156.868105,172.892421,206.269478,305.40423,367.085339,376.588809,190.948225,99.140744,62.682222,113.868894,226.47049,246.688682,231.044899,228.68619,247.731928,190.860382,137.211722,58.707789,32.867105,-18.553537,-39.097125,-21.134627,46.895734,67.486686,102.06517,134.966071,195.786721,210.443979,240.676569,256.133614:-163.855473,-275.497626,-275.08647,-211.499528,-186.411098,-88.261802,-3.069209,103.152072,69.619596,51.305382,54.229788,40.971627,12.940083,55.274309,158.417748,135.309669,-0.42804,-19.708168,-7.287648,-77.496271,-129.569427,-114.995221,-46.601874,107.549828,92.085089,13.013366,-105.49089,-110.331952,-65.414926,-34.996263,15.715724,42.393821,101.820623,100.871358,81.205555,55.861092,77.522275,139.078253,120.374943,38.09757,-6.727897,-53.945751,-145.228498,-153.95238,-137.400667,-137.004054,-146.005374,-119.378308,1.712585,28.477718,-11.028977,-63.784298,-26.368205,137.909547,177.475681,61.214835,-103.049317,-130.40732,-127.192942,-134.209314,-161.081691,-151.486269,-86.038387,-59.693943,-50.708532,-50.183135,-36.991915,-37.998851,-41.465757,83.34592,200.004848,369.239324,338.764016,284.88938,308.992305,399.068499,535.036848,536.866017,471.697367,450.530497,453.574655,439.002318,450.873438,533.582693,573.462994,615.193595,595.553854,403.429474,142.314954,80.79217,124.934309,153.296739,77.932397,19.095304,-40.527202,-49.215185,-59.255921,-163.691039,-235.990291,-268.486062,-212.763237,-59.20733,-20.86293,-36.20187,-59.593785,-66.791381,-32.052226,4.787079,-3.039549,-65.653237,-222.159605,-270.487212,-297.767087,-284.13986,-245.05916,-85.047955,3.224047,121.511701,135.683334,90.593654,24.606057,-14.094316,-93.737543,-121.590865,-112.842601,-57.070468,81.753461,114.760966,76.748611,-99.393686,-174.047541,-126.244555,-25.122207,151.877489,177.417674,131.211636,129.504648,166.769067,229.520445,227.346895,182.399218,166.459429,142.728718,111.394989,8.496772,-70.705651,-73.598916,-7.971011,49.782642,153.079719,156.033269,59.887496,-31.337241,-50.199456,-59.895734,-48.883752,18.664297,53.318406,57.880035,48.037864,69.396262,24.084501,-28.579202,-50.582565,-8.613782,104.384406,128.042562,49.77814,-64.134667,-84.444576,-61.276944,-52.315093,-129.192174,-194.070377,-246.968064,-231.954678,-206.380078,-261.172317,-281.965222,-228.868301,-182.829912,-105.366654,-74.664702,-40.801263,-48.155271,-55.021574,-14.431529,39.701542,152.832187,186.166996,205.164625,201.31865,200.154386,184.956997,166.186311,145.715545,153.10586,217.241767,246.645723,198.893519,47.79543,-25.866316,-46.39913,38.698361,268.591599,331.495591,303.995497,269.13782,289.641533,319.994616,284.284127,103.08948,8.467302,-0.700591,61.32807,93.887537,-31.399004,-105.418161,-174.168436,-149.454549,-30.974963,29.130942,47.856852,11.84779,-12.730603,5.668087,8.870724,34.590897,36.915322,36.633402,65.112886,120.720234,76.461005,33.801247,5.276338,12.042168,-8.505741,-27.852856,-76.404539,-135.335422,-324.76171,-430.816547,-389.784455,-257.284355,-231.496202,-166.252215,-85.733368,99.845616,157.579119,84.446407,-189.767422,-283.981418,-229.334711,-132.311866,-45.28704,-76.832758,-173.761678,-236.787658,-244.186121,-206.09177,-177.661697,-135.562024,-127.396482,-160.42868,-240.25906,-258.369416,-205.489179,-170.610018,-195.820733,-240.233997,-253.356511,-220.913239,-268.332249,-510.512397,-595.602375,-583.548133,-520.482144,-339.639736,-250.453769,-199.696506,-283.829804,-300.968922,-216.306524,-140.012563,-50.980233,-53.9127,-98.091351,-133.092724,-203.380833,-222.637415,-182.685248,-52.659021,-23.53362,-3.875856,20.929423,71.009187,72.756845,47.205694,-41.600209,-78.202914,-46.034713,31.948966,174.595236,165.333766,21.691904,-63.262645,-50.574801,7.82118,13.051893,12.61374,36.93981,84.400808,38.848677,-20.310284,-133.648003,-149.502382,-105.835266,-66.628136,11.708344,26.247807,-31.65998,-164.200459,-203.105151,-175.406702,-149.257886,-102.426552,-52.837551,87.616758,153.245771,119.739364,-19.01493,-45.136171,101.722119,224.554671,342.849447,323.362507,222.210299,69.917095,-2.380799,-130.421025,-183.784308,-146.145129,-60.460614,45.916736,-21.362891,-77.994547,-123.897209,-103.048353,-1.017417,86.727424,194.988659,145.090394,-13.971106,-18.40773,22.304924,85.20283,89.856325,85.740093,87.00108,89.722874,112.03264,138.949262,225.963118,254.080019,243.411116,254.955818,331.132375,342.419774,264.575963,138.003279,107.297553,113.156266,112.560348,129.185807,175.217963,262.753955,159.497427,72.68978,71.313607,154.838243,280.221923,292.115933,268.468846,250.766394,251.091296,250.886888,224.230953,153.991892,97.793948,-77.864035,-138.409316,-82.297096,92.667127,169.093601,268.316657,294.590829,340.034127,370.185529,411.866571,416.947672:-169.386365,-233.45268,-246.231823,-149.981758,-66.550059,12.69429,-23.046009,-121.842369,-76.171941,-36.804473,-3.264119,-0.127623,2.944796,22.734425,87.318443,77.749049,-51.637469,-94.866404,-47.134415,32.981315,40.258357,71.874253,91.273957,64.549852,-55.681602,-112.260778,-113.304576,-78.699964,-30.26739,-10.421581,58.506295,100.096027,113.787249,18.109231,-12.718447,12.644492,41.285792,42.840003,-5.876483,-144.535,-231.165971,-257.852166,-281.651926,-275.265694,-198.760219,-119.459425,24.243786,48.673336,26.38921,-68.511904,-117.835462,-118.95288,-81.840112,-25.274049,-37.997908,-127.254561,-179.682162,-197.979891,-222.750402,-206.795887,-167.991041,-148.357281,-28.441336,41.524324,12.586133,-110.966113,-104.351007,-52.60249,-36.059031,30.023678,73.755654,149.181747,140.501442,103.443592,83.41319,119.426323,158.459906,122.833232,6.80017,-7.477613,90.295927,163.921965,206.004403,381.893028,460.050631,487.506182,444.131663,276.767797,131.153866,109.536013,136.37784,147.837904,141.461391,141.745043,134.672517,110.936232,16.562548,-110.809918,-135.529082,-61.579338,-13.204964,22.174601,20.390985,58.155116,138.252359,148.081963,142.493194,138.355617,90.983607,64.742711,60.3051,50.726785,-69.931657,-201.25401,-212.757525,-103.592953,-15.163727,61.099437,34.650293,-2.465997,14.404365,8.617838,-9.017706,-27.086597,-49.673614,-6.665035,64.638755,18.12027,-155.539934,-303.38458,-333.936441,-214.923996,-83.802768,89.936285,62.651138,-36.343518,95.585423,152.533575,58.950143,-8.648367,-54.8647,-57.939803,-41.819272,-31.94562,-76.151636,-187.235537,-205.51926,-155.185308,-127.7196,-83.160247,-58.673189,-38.480918,-126.084829,-170.008465,-111.037382,-38.069442,51.610019,73.158481,105.523954,104.792489,59.588682,2.025648,-2.998301,43.108236,85.604407,175.773743,178.629156,50.121532,-65.465803,-79.733837,-75.512875,-72.661402,-68.059954,-57.110633,-79.007138,-126.405432,-179.384782,-161.273564,-161.878144,-168.56748,-145.303914,6.92259,105.017785,180.16981,68.872228,10.546841,2.513462,37.142876,67.058469,63.217277,106.53566,153.878167,171.055674,28.771231,-18.084016,31.546519,77.749175,138.174173,167.029687,166.347874,38.608811,-9.007835,47.231801,110.236005,143.804936,120.831399,85.420253,83.301716,90.330104,18.636288,-46.388118,-93.643978,-60.704085,2.135016,-13.228864,-134.210478,-233.578319,-244.715052,-234.780607,-218.38679,-129.393599,-62.240175,15.412645,6.140014,4.821019,39.623705,28.698611,-22.529119,-26.507428,50.489159,100.063997,121.928974,64.651063,19.274225,-46.356452,-39.674935,4.186851,13.817632,-4.513125,-38.495893,-178.476685,-295.283188,-283.625175,-197.786993,-169.797523,-132.080446,-125.640953,-99.823209,54.1426,88.054594,-51.553528,-133.855127,-121.461477,-38.09889,80.298114,50.81414,-106.364208,-134.872935,-78.784976,18.829129,26.605904,2.207751,-34.874062,-169.605847,-259.651882,-266.399738,-235.408542,-208.745695,-127.994813,-69.9124,-3.244999,-39.048791,-214.633592,-311.816768,-267.764647,-94.56943,-58.933437,-74.263964,-40.760917,76.703412,22.708702,-39.582259,-41.752852,19.786714,145.339215,165.203969,87.001294,6.459998,-121.475417,-1.546691,121.830971,215.781902,156.09309,48.303224,42.301743,20.473753,-13.467543,-23.36946,-25.923564,-10.383859,44.554639,60.921514,41.385158,24.211302,-1.717141,-42.295969,-58.723419,-21.039126,32.134369,148.102543,184.94365,193.453002,116.282359,36.198102,-92.173063,-88.15534,-8.648034,13.839954,6.133322,4.629045,25.274712,-35.515232,-93.716768,-130.318014,-106.799508,-67.499626,-71.779446,-83.124358,-11.053291,14.188787,-52.107365,-97.671532,-74.52699,11.893897,247.782394,310.62439,234.382163,59.930967,6.706766,-11.108061,3.670254,25.488651,39.535437,106.570918,94.121384,25.391009,-112.488265,-125.876392,-17.562171,68.18798,179.061541,176.193745,72.389709,16.182638,66.991439,201.347718,206.580441,155.287148,146.805333,154.943874,234.732062,294.127147,341.675056,306.569752,225.764942,249.481161,369.460415,384.448359,292.596169,194.327257,184.684504,185.13689,165.416482,164.735879,201.828035,267.297155,208.892948,134.571785,55.478994,83.959385,146.497208,136.129681,95.317929,108.716973,202.667869,179.571918,89.656386,-49.848857,-43.538307,45.49421,75.993736,85.336145,130.667825,167.188184,191.141588,167.91045,92.310023,80.866196,150.317765,196.828213:forward
-158.365146,-175.18561,-145.98824,41.145347,138.388181,188.448967,156.978973,92.333986,66.854921,57.213564,67.679863,88.701565,69.64077,29.027012,-25.894666,-26.759489,5.999554,-25.416713,-96.732747,-254.071916,-274.302269,-169.506616,-107.993529,-132.52027,-203.843328,-185.510328,-108.571206,-85.132368,-63.825046,-29.623696,101.486196,141.070697,135.090657,144.713802,157.060608,160.098514,144.951516,113.866763,118.439232,100.279199,-67.618392,-150.937446,-152.280096,-89.815097,6.892513,37.975384,136.965097,184.048918,179.486588,1.270537,-89.479482,-75.553108,-19.849163,-15.074992,-47.172559,-107.887241,-189.314053,-189.590381,-84.3098,-52.511994,-111.132578,-140.550129,-105.219823,-80.988689,-76.305856,-79.078567,-94.23217,-204.968394,-284.787558,-339.27998,-266.757243,-68.932431,-135.740821,-258.601032,-392.39474,-351.242641,-177.796344,-91.074877,6.01885,-21.540999,-166.789959,-207.8266,-124.968354,105.066139,118.546903,-33.828663,-82.442411,-96.892749,-131.084121,-161.724901,-211.541749,-192.085302,-62.080789,-9.179146,4.142789,-2.679337,18.114692,-56.399699,-134.31071,-175.901096,-124.646158,11.869809,68.321845,133.195466,145.664956,149.44028,153.451287,145.528418,148.213028,187.360902,294.648951,305.50386,194.227363,-30.483117,-117.816691,-104.740497,-29.312899,156.555638,228.49078,219.997403,140.677479,147.159365,232.938011,263.183506,231.864816,227.475428,332.844644,359.064591,229.414222,106.203211,99.871126,110.268711,108.788117,119.142491,124.701818,94.368981,62.399191,52.318052,-11.232772,-27.377898,102.773215,190.849798,129.639629,2.97954,-126.205208,-103.039599,-123.574933,-179.194919,-177.592845,-112.56977,-68.596276,-34.403075,-65.94172,-87.732504,-104.751804,-82.400939,19.015242,67.767282,92.06864,81.18626,82.296553,75.126901,47.279282,-9.690647,-25.314429,25.197314,97.010956,134.5079,-71.791886,-169.307048,-175.416228,-103.991759,32.043462,81.414355,170.406577,179.541627,95.790024,-2.897079,-39.556625,-105.753204,-115.097923,-22.53885,42.342404,63.268104,-29.907689,-71.506019,-88.27217,-60.73401,6.050611,7.08025,-102.82648,-181.382491,-214.903286,-137.498983,-131.511327,-123.497196,-107.632845,-108.367189,-111.534415,-77.865046,-17.623928,-5.927768,10.950287,54.600129,119.12764,67.988438,-40.557418,9.660771,165.435639,134.210091,100.687294,87.364079,107.508267,190.384911,210.476233,138.687441,64.001949,69.136412,113.766373,115.104597,63.624067,50.886038,87.102355,112.111246,158.673166,162.435069,116.789084,-22.779372,-55.416412,7.794851,34.679646,-71.637171,-162.40984,-133.793055,-57.743281,-39.438783,-43.436575,-49.724203,-12.102087,-5.233895,-107.705678,-196.23966,-185.616344,-169.47576,-206.544784,-224.354311,-166.945234,-113.310374,-196.954612,-235.24463,-253.507371,-224.127986,-142.335867,-110.050161,-77.189848,-86.297493,-131.133284,-137.571147,-111.047562,-46.933171,-38.664567,-36.664291,-15.538935,59.790779,123.75876,110.614454,37.464126,66.828912,272.703406,352.887586,298.765139,185.0907,-12.820919,-41.386216,-4.814063,78.344498,71.014345,13.814862,28.827483,99.815809,90.30504,75.023081,56.620844,57.545364,101.711973,125.16972,127.971361,100.196648,-1.505296,-62.003866,-53.950771,-11.584883,4.538834,71.294338,104.081596,54.187787,-25.254226,-60.57527,-183.401397,-222.301671,-200.712161,-170.302746,-83.835891,-21.420003,126.357288,179.815268,152.355146,182.611673,253.07781,326.257146,312.852639,235.749456,111.320429,51.260267,-17.057798,6.299809,115.92231,135.300211,102.359898,85.793385,62.169206,50.700754,60.980559,131.495613,157.464995,133.596244,111.297626,66.291802,-14.343226,-64.211279,-121.506165,-101.979701,-34.378919,-15.420554,43.668031,100.682479,179.275399,103.585421,63.611933,60.510531,65.80438,93.978708,117.018022,75.222498,-40.850845,-48.702065,55.734957,109.250397,105.409541,62.452287,10.076994,20.487106,34.219517,-110.379179,-209.68455,-281.827277,-270.334673,-249.694182,-239.234515,-258.507083,-316.997718,-328.329878,-324.059152,-306.501351,-255.497486,-253.380974,-273.553711,-256.004956,-176.289976,-227.432246,-322.430059,-483.477793,-484.888401,-304.62843,-180.160678,-63.429935,-74.747305,-59.059098,-32.46673,-53.71147,-132.523643,-150.64395,-56.953605,47.813218,226.748736,250.847802,245.179305,349.405884,450.129193,565.449231,541.81814,396.204942,262.945489,233.466651,225.324221,229.675078,260.788483,289.895145,290.362974,242.76556:-104.506836,-235.592069,-232.558663,-50.861462,61.813367,156.403838,122.166497,9.626958,-9.435009,-1.32443,22.695015,25.817799,-31.554035,-62.276167,-69.174924,-61.128143,-69.560581,-115.470737,-149.221662,-191.856633,-153.487823,21.498566,71.949984,9.268165,-86.297811,-103.059501,-71.437849,-40.533809,17.354317,49.626806,110.812732,129.087118,104.329341,12.49476,-3.648159,60.834627,92.882261,103.09981,110.756953,118.382649,-15.900804,-102.432779,-119.77137,-57.502397,65.041188,112.433757,170.290665,157.25846,57.559384,-94.459924,-139.934298,-51.403944,37.000909,125.319294,110.170034,10.975271,-84.456907,-101.452121,-63.387928,-26.473587,31.192091,51.252231,52.144772,9.178138,-124.307151,-209.857239,-214.234359,-202.615813,-222.937751,-263.802964,-242.72645,-159.040612,-168.766711,-229.406188,-300.581917,-254.133649,-101.965132,-58.957041,-68.002,-106.579026,-194.842073,-177.968432,-90.340916,122.7149,157.058752,94.689023,52.215069,-29.317842,-57.74695,-59.893377,-71.639592,-34.603744,94.976361,112.610734,63.619603,40.948142,-8.264644,-76.199184,-66.92893,16.96923,22.02354,5.790019,43.779968,123.684637,100.764718,102.671681,153.450632,142.683916,75.767233,97.929448,188.761365,181.123277,56.911549,-111.582692,-153.708215,-41.611417,71.435497,194.43348,158.394423,1.734804,21.86961,95.115569,213.49872,239.206871,239.106667,241.157507,312.135795,341.931292,288.466457,165.229915,119.878772,89.310931,101.683369,124.717072,108.843359,47.376316,10.548161,-3.187736,-9.291612,4.420281,61.19792,100.784126,86.967994,15.813624,-144.340138,-230.611472,-233.948776,-205.453821,-179.203083,-92.7568,-70.314973,-127.679619,-169.142263,-172.674491,-204.284803,-204.357565,-92.714545,-12.208777,67.271753,70.555559,81.281105,66.871445,31.052384,-15.688076,11.862272,157.281323,214.034143,156.129861,-17.496304,-94.97794,-208.44958,-211.941687,-61.82366,54.088421,210.090147,197.615724,47.1075,-39.075827,-59.098057,-104.632245,-111.588943,-42.058446,5.873889,4.772004,-92.259225,-121.484234,-45.648636,34.02229,120.813152,99.641214,-71.888504,-176.005205,-242.829344,-221.485639,-232.791456,-198.245186,-145.858421,-48.294629,-13.922523,30.515137,23.078039,-24.849091,-73.704935,8.019517,227.251741,228.115877,32.960704,-31.436498,-1.281625,1.565585,-15.875084,-18.795265,-2.172433,98.316558,151.921767,140.104119,14.622225,-22.025697,6.561183,28.81918,41.220741,62.516274,126.836124,131.95405,67.347611,41.730122,76.076678,97.07166,71.58684,88.680533,90.359486,-92.223329,-199.258544,-144.116209,-48.168473,-49.350117,-35.173831,6.058781,96.438926,109.840914,11.891044,-148.993255,-181.917458,-146.84022,-123.215546,-79.814337,-46.534746,-2.563545,-27.207631,-56.430301,-48.991566,17.041664,177.905796,194.414669,58.385459,-5.523175,34.896013,114.007963,108.944922,78.007541,76.216162,98.397565,101.22936,54.810952,34.908732,43.146377,57.738314,86.636188,194.438243,221.839667,140.288166,69.705865,-1.475522,24.242161,61.28867,96.577044,70.76713,37.16801,30.551329,-46.432445,-41.360543,-13.234367,-77.921035,-111.69557,9.765401,94.148127,84.166433,21.237987,-70.675493,-117.019841,-108.849075,-35.181406,-6.464464,107.587961,186.148368,151.286662,-61.968999,-145.050323,-198.889825,-156.866534,1.83557,70.946652,128.916833,137.192674,173.925255,160.903136,135.045216,213.04181,296.952816,316.933682,250.146688,133.863342,107.126529,106.037372,119.075219,151.135349,236.942729,245.496171,153.970616,78.501061,-20.35611,-8.099388,9.615382,82.95575,142.134886,181.368038,119.942796,-52.874947,-46.401835,4.423247,49.525512,52.892006,51.313808,29.907085,18.535542,65.173621,140.630904,52.000316,18.542438,28.044045,14.770268,-8.759722,15.524162,10.585126,-132.35855,-145.348755,6.383975,67.980092,55.695776,33.041076,10.455913,-5.475363,-56.129604,-141.360172,-185.827888,-223.767336,-235.373714,-269.576095,-261.925112,-182.216155,-164.569209,-213.14596,-295.913638,-274.426484,-167.718506,-145.662616,-186.411493,-214.0181,-222.762312,-255.290058,-318.394697,-424.997042,-407.356742,-257.108168,-180.594727,-94.482028,-66.937751,-59.818078,-83.356028,-121.785234,-150.027138,-105.130198,42.051406,116.253264,203.998877,172.601581,146.568911,201.797548,287.474133,395.290493,380.420165,295.187088,167.071706,136.403488,210.166038,259.65947,322.944416,340.134193,309.012119,287.133254:-233.454336,-209.324231,-108.120957,96.524236,115.60583,20.450141,-34.968791,-107.892351,-102.519508,-73.474651,-26.08861,-33.593723,-85.310509,-93.678108,-101.071265,-117.618635,-99.536701,-42.065545,-44.829594,-82.434977,-75.126686,4.987758,28.022282,-23.185965,-95.208491,-85.392478,20.834778,48.491008,7.632372,11.121981,116.936876,162.039422,118.831575,-47.469233,-80.676456,15.01197,77.859765,114.433095,104.400243,78.223245,-26.970262,-99.227546,-99.846209,-22.71566,94.764511,99.152562,31.884523,-7.640898,-47.369036,-175.44046,-233.385894,-135.053825,-30.082933,86.899511,76.276013,-20.382714,-108.987059,-132.381403,-94.199105,-46.325979,44.990583,87.325313,121.073956,90.975925,-64.038855,-224.332974,-234.527614,-196.790565,-213.527734,-262.623117,-246.25429,-135.57856,-68.659159,-94.820125,-177.550658,-187.075911,-129.782239,-94.862036,-128.373394,-189.310197,-266.340333,-288.684541,-283.537669,-126.412214,9.796513,118.268062,39.023451,-169.57124,-186.623231,-147.3629,-67.381486,-12.961293,87.826175,94.560418,74.536801,72.048153,24.069186,-53.245911,-42.036404,31.873877,47.538757,121.445686,187.785414,175.94252,-18.063045,-55.469343,78.958829,135.723035,41.537331,0.172894,54.473446,58.71196,-78.152019,-240.101351,-255.202924,-121.839199,0.843587,206.19325,206.00906,66.454954,74.174938,129.179512,193.830651,188.933522,144.668922,135.262446,140.018955,127.762964,113.786471,154.965557,152.826642,66.3923,30.092595,8.155176,-22.889292,-126.070136,-160.992412,-149.264188,-131.748589,-141.613031,-102.044162,-20.807916,41.193386,-46.36043,-255.940431,-315.416279,-306.204301,-223.773471,-162.772479,-58.891239,-40.705115,-118.343575,-247.447003,-263.977706,-182.997166,-132.121497,-45.250576,1.881829,34.810407,10.481344,-55.148655,-100.101402,-101.243133,-69.315251,-44.86914,29.763825,62.437655,48.714553,-31.798689,-72.488861,-135.756841,-130.366176,10.311808,110.287389,221.976909,210.166416,94.267995,-24.936571,-51.439949,-52.964733,-28.043077,101.110033,152.584651,87.097104,-52.537976,-68.299296,23.618797,77.234325,84.303399,55.999806,31.09551,24.654423,-69.585971,-215.705443,-232.595544,-126.196282,-50.830684,65.182868,89.409538,48.578026,-83.871904,-154.555464,-114.008218,41.100879,321.701866,305.665592,107.813745,65.473603,94.613593,52.778055,38.123236,62.370778,61.692895,85.521106,115.298322,93.575583,-54.688758,-123.851832,-136.677289,-78.525232,62.473539,99.212496,71.648439,22.495147,-81.774218,-113.32895,-91.308751,-48.10087,-27.294278,100.018809,142.938908,-41.138409,-217.099138,-171.801985,-9.116937,46.931067,162.346574,219.788085,207.725978,141.554048,50.960606,38.896342,32.220484,60.072774,93.103418,105.840728,85.133046,73.478679,76.019709,49.098753,31.502735,90.569663,272.316876,310.325441,183.399772,98.716246,127.078564,255.893269,270.848711,228.233135,195.12366,173.188314,183.489704,154.690707,81.139362,65.053873,133.9553,194.223485,243.275368,227.830711,137.331061,74.507227,-11.604048,-10.532819,26.072623,115.588049,136.889843,144.685754,119.628123,0.152121,-74.438594,-94.436228,-141.28137,-124.915245,21.723159,63.728178,24.901874,26.505329,60.725216,-57.471397,-102.427425,-24.748125,28.97086,72.928708,96.540894,131.88906,46.988001,-39.16003,-139.878267,-102.695168,62.242305,125.872276,162.354746,162.043588,174.631619,151.249403,129.213412,114.279325,130.591873,191.280272,217.660059,217.079982,106.252272,59.313485,121.289524,201.429787,287.813187,274.97939,222.809476,198.998024,134.938352,109.403938,124.582315,193.593482,227.991407,220.049773,155.302739,-19.991121,33.556675,120.892818,132.051611,93.214857,140.949592,191.792457,195.084335,154.204417,61.052844,28.026695,34.83084,34.130952,20.845084,10.227212,5.934473,-52.338487,-128.127203,-143.240783,-91.337788,-47.207631,-16.016619,-15.717044,-22.980657,-63.408884,-206.252687,-278.788459,-264.213643,-213.139756,-199.617636,-169.199763,-151.77476,-152.241926,-232.387031,-290.489016,-336.245578,-301.943429,-232.126024,-235.152931,-237.09121,-228.75696,-298.06837,-365.814872,-338.799679,-283.741374,-276.562024,-210.233443,-147.391496,-38.568518,-49.400352,-95.08345,-152.719251,-125.306272,7.759225,66.555711,123.401325,145.615128,184.059628,133.236375,105.023048,181.127068,279.576049,411.03412,398.556167,287.309094,164.69406,154.503956,261.440021,313.462859,383.210539,422.052622,438.705117,416.904537:-26.414417,-30.307259,-20.637697,67.358246,108.730073,121.576464,93.882265,-2.101034,-35.457193,-13.151416,71.57426,83.849026,-19.572364,-82.43774,-131.96073,-127.439823,-67.096887,-14.274192,-54.953037,-232.326115,-278.004285,-150.483266,-40.177513,19.156978,-130.529726,-179.821618,-100.833563,-20.627351,77.422609,98.960798,109.589258,90.464576,41.993777,30.141083,54.444783,165.949783,197.584293,143.434363,93.978171,-4.041827,-120.136399,-171.771716,-183.694474,-137.413841,-31.992988,7.34945,54.650159,57.05946,14.357739,-117.096997,-165.228193,-105.892153,-52.277992,-23.364696,-34.167183,-77.922648,-116.28585,-105.017942,10.577779,75.435495,81.081499,41.234843,25.439645,37.357883,-18.532439,-137.81017,-184.221325,-246.925773,-276.734607,-304.497305,-269.478589,-112.102063,-34.907239,-88.475363,-235.912821,-255.831254,-210.31835,-166.726124,-89.451444,-92.560152,-181.092039,-257.393536,-223.47635,3.301044,107.044123,124.709404,70.705233,-28.533237,-86.397626,-101.05618,-47.342791,28.019794,153.281703,168.391665,168.640943,167.836784,102.841765,-91.504108,-163.079537,-103.309993,-32.654111,53.720491,83.618258,108.392272,89.979877,94.137862,114.812787,97.051047,52.350556,96.772661,249.957398,257.553792,121.63799,-57.780408,-109.056538,-47.92403,41.475072,196.512107,218.504871,165.220834,124.707244,130.960832,158.893051,155.060031,87.615987,75.259197,142.897086,153.652898,90.792298,39.327551,-2.303754,-63.684572,-24.700548,81.642246,51.517692,-132.700968,-206.783641,-196.652478,-193.620338,-199.932166,-125.36627,-37.327261,45.470262,-12.601541,-178.885156,-270.023611,-282.795524,-196.194363,-133.929393,-91.087699,-94.882776,-116.285766,-166.588543,-183.421262,-167.867293,-139.748295,-61.404184,-22.716914,-2.883265,-16.158859,-14.973458,-62.730715,-132.186372,-201.684887,-170.752468,-57.509045,-0.989452,33.269865,-56.22081,-116.730674,-201.663811,-192.265121,-63.737304,33.195972,181.449565,177.317141,65.720215,11.988971,10.736772,17.864747,27.226835,62.221086,69.614237,10.144538,-75.108756,-79.275301,-3.246312,41.870026,81.116762,70.640619,-5.424126,-61.366948,-182.495609,-236.686637,-202.032818,-83.420119,-56.060655,-23.231435,6.554391,41.182261,37.995334,13.85845,3.30427,73.590091,220.059447,190.847372,48.535855,50.244216,151.886009,123.307467,97.086148,153.144725,183.073991,163.446759,160.358344,172.763511,25.644085,-64.724831,-60.540969,-2.120691,0.691538,-36.046652,-21.309457,-1.001066,-68.024484,-153.821845,-131.017653,-33.721818,-19.979066,1.364487,29.069272,9.491596,-30.974746,-19.737633,18.667,47.504544,96.964217,103.949618,115.077389,111.136986,31.30524,-101.329427,-148.445038,-136.616797,-99.736745,-45.586417,-32.543478,-45.756131,-103.10422,-128.536969,-155.847715,-153.636796,-127.269773,-107.020213,-64.229535,-51.273619,-4.703173,71.415064,98.113162,109.910776,98.223604,108.09617,137.944688,175.556612,149.581305,116.450166,77.168685,104.447613,227.239299,277.093339,238.131667,157.264576,20.294926,4.134948,26.522531,73.921989,91.623633,123.878732,121.798079,69.84306,17.132747,-14.529877,-48.501124,-19.329659,54.574878,55.249346,12.089906,-12.118596,-65.623249,-93.869473,-86.235656,-50.533728,-17.21391,125.754989,193.694438,173.26628,62.946785,27.223267,-6.947064,-6.521003,-8.243339,-7.83509,71.224366,140.540585,210.765934,139.010478,118.548271,240.051552,319.423523,302.125944,226.367744,148.985697,205.814365,208.755402,140.56746,144.877083,278.449522,334.564853,296.169908,224.127842,108.612987,82.697237,86.343233,135.234036,170.463768,204.285381,178.859875,41.444271,1.9225,24.014119,-12.930139,-43.895063,21.147064,94.710477,165.852774,147.05122,63.925212,-23.856165,-37.131585,31.654681,80.955539,137.032852,125.72992,-16.467093,-191.943492,-209.643052,-103.175478,-56.280184,-107.372759,-164.319035,-189.812254,-152.291347,-82.340999,-152.819566,-208.820227,-221.517875,-187.723229,-131.147829,-120.499583,-124.297815,-182.262087,-250.343026,-357.753506,-327.010222,-172.906111,-144.645315,-189.764346,-195.447845,-170.532052,-218.234294,-247.011371,-272.027794,-280.057246,-228.707859,-140.805837,46.614281,70.972295,51.685214,24.256492,2.78661,-53.493869,-41.137096,128.708453,224.749249,302.545571,284.043203,266.640609,298.042809,359.204786,446.150391,443.66103,377.983653,241.247814,192.061312,249.463455,328.290722,409.414851,398.145511,380.407089,386.966608:-86.888899,-150.851307,-136.892841,-4.237189,47.703086,32.039499,-22.241897,-122.697135,-131.343423,-123.880756,-67.47208,-34.115261,-63.669319,-105.216,-124.579372,-108.448171,-96.448923,-124.761636,-135.023758,-142.103695,-140.487339,-94.499774,-65.82313,-81.931053,-207.376514,-261.947131,-189.37772,-86.895675,37.067778,55.923593,106.748239,125.121774,70.398207,-64.173705,-82.646113,48.512472,126.360516,154.429479,117.505622,35.471096,-50.373663,-112.720444,-170.217297,-128.797746,-28.811819,-23.809588,-66.67004,-82.769997,-135.17715,-275.395612,-320.98773,-255.112503,-173.91274,-0.594749,60.524995,54.756011,-71.817095,-117.719565,-68.7925,-2.049796,71.04174,73.478081,67.141248,52.302394,-36.047886,-145.055358,-164.139579,-175.705183,-211.623649,-258.992564,-217.918739,-93.089565,-35.12405,-44.861689,-153.138627,-216.628637,-208.564085,-129.861788,-53.046506,-107.810247,-239.795648,-274.497118,-255.993885,-85.573806,36.544612,150.326357,115.491715,-32.180141,-151.608308,-177.356367,-103.284567,-19.387911,66.815488,58.862558,60.322273,75.457886,41.629881,-105.740347,-151.219986,-108.199056,-65.358923,9.778833,56.780739,114.40243,25.211282,-38.293162,-44.600491,8.086532,92.57882,112.944282,141.86506,131.129107,-12.154836,-189.15444,-195.554981,-23.176945,95.878083,236.448346,235.08316,151.350144,88.479496,88.13015,95.270702,97.928966,141.276492,171.842769,170.839196,122.416971,32.684259,21.543163,-1.494234,-69.268934,-47.717638,57.213779,46.795253,-102.972149,-208.961467,-219.013104,-185.872623,-154.829625,-40.304103,55.474771,154.931693,104.423943,-101.455337,-326.153243,-377.19584,-288.730539,-205.301706,-63.008236,-10.238286,15.503778,-67.734601,-132.079386,-213.10733,-177.984508,25.973071,112.819883,105.697471,43.082201,-63.754126,-140.0274,-168.858487,-188.999546,-162.758284,-28.980567,38.528013,73.442869,-7.256692,-77.304756,-217.579244,-228.435603,-45.383343,99.731105,260.531605,239.816776,112.361588,0.865348,-21.705261,-3.729943,19.914578,156.422948,242.790535,216.292954,-21.431492,-90.173282,-2.27435,83.516332,146.116049,147.126306,141.148298,94.360118,-105.521382,-256.199055,-250.759229,-117.142428,-37.036638,101.494818,138.575387,95.662609,-23.831551,-81.184781,-84.544275,13.400525,256.248133,287.215308,139.936702,62.380842,50.513683,36.551473,24.566302,131.934281,207.109188,272.460543,267.287602,199.004418,75.211274,4.637595,-74.638418,-63.246726,1.309486,36.395608,90.546,81.255477,-25.049767,-143.698121,-162.816538,-89.677682,-22.155457,116.280155,152.093737,75.804557,-10.678651,-2.726268,78.883382,149.410478,306.597935,340.132046,239.216285,143.586958,-11.573444,-135.086934,-168.684728,-92.482749,-7.711282,114.211044,127.533789,71.162682,-54.485609,-115.456582,-136.031913,-83.112947,29.975104,38.653819,-7.827494,-10.563851,62.495681,105.214323,99.960019,106.305538,122.469329,175.643368,194.80171,142.729331,24.810516,0.523363,67.203155,108.724106,130.671432,149.949324,212.027538,188.626632,-14.728086,-150.900052,-106.843823,93.588403,156.507102,140.475142,87.055261,-36.756117,-99.540322,-127.478761,-171.300253,-139.404596,3.960038,38.982215,-24.174897,-68.048772,-135.950069,-233.719153,-241.904156,-122.356684,-45.570416,33.777723,30.809719,-19.626006,-98.236271,-147.759547,-174.878229,-128.979142,-27.275512,-10.302792,-2.708948,17.585906,61.367446,-4.865772,-33.585925,42.940721,111.355635,188.235788,187.714414,137.991433,39.291381,-13.505599,3.638141,90.749254,215.158566,197.062741,135.315436,133.256529,101.104614,-29.773209,-68.549597,18.869883,89.119684,119.342618,75.697771,-27.766638,-53.057964,-54.59908,-52.220836,-21.626826,91.216052,118.903888,46.256698,-22.816789,-103.523068,-51.62013,-18.385466,-19.236,-36.762301,-29.323596,-13.256013,-47.474102,-162.949431,-209.522152,-223.607167,-201.096715,-131.058086,-92.749106,-82.147099,-117.162323,-215.069987,-275.183476,-246.434982,-120.957221,-81.101422,-92.166027,-125.886365,-193.69017,-264.296169,-308.11063,-375.298241,-367.158664,-250.389202,-181.685375,-127.779329,-155.542375,-299.720761,-427.794462,-416.828708,-295.931524,-241.306199,-177.852815,-147.567865,-63.97488,-56.412487,-94.450772,-121.940664,-82.886933,13.834508,62.217269,187.657623,246.040117,281.686252,180.776264,147.47933,247.323001,345.985674,470.391653,455.463842,322.989393,229.380686,218.943188,270.97088,317.53102,407.34083,452.565743,499.181181,482.577163:41.148835,65.487242,79.660518,127.517643,158.989073,196.871016,188.158331,146.172313,130.250096,123.811356,145.53596,189.456584,236.032395,210.020514,99.965513,42.180097,-7.817619,-52.959619,-104.727007,-173.952842,-175.226785,-200.980374,-233.615073,-236.976162,-163.842828,-137.430533,-33.046516,41.618164,90.637136,93.750686,180.881919,220.280915,200.358659,149.632316,161.834308,224.400348,229.792882,203.756298,185.393061,53.562296,-149.323169,-202.002551,-145.449243,-70.877686,1.678706,-2.493484,41.151312,89.153714,104.588694,-71.38642,-169.251261,-207.548186,-166.099423,-117.906057,-127.182847,-159.93851,-174.292338,-154.060311,-44.617483,2.48522,-20.480271,-56.381116,-29.833248,14.55453,-1.248997,-136.934086,-191.031902,-275.850685,-314.002403,-266.546219,-143.367156,84.556578,-27.485519,-146.949203,-279.971364,-284.299971,-225.504847,-171.304859,-77.441009,-70.044527,-119.81786,-177.929965,-174.738751,-68.518085,-18.623476,-39.791117,-79.412013,-144.554014,-175.283029,-183.176808,-172.920993,-129.741785,4.88726,58.660068,108.308798,104.01538,18.721768,-153.240539,-214.072486,-191.486314,-144.912602,-46.329607,7.695109,103.688481,148.255722,139.832799,102.190155,105.318911,161.345014,202.295179,293.266679,308.050767,200.203937,-2.337097,-64.781463,-33.26669,16.813705,114.489894,166.821663,212.172041,129.607911,71.449988,2.16503,-10.440672,-35.840491,-21.170983,83.891355,99.823628,-13.059493,-107.203434,-121.168022,-90.19123,-30.527836,104.138094,118.111731,-3.966764,-110.10611,-117.171145,-112.824523,-88.373319,65.183044,152.993928,159.391827,69.784648,-101.153682,-141.483549,-148.320392,-176.163617,-183.642232,-150.970862,-111.46661,-44.16738,-49.464505,-64.916178,-62.971047,-31.542753,75.37429,133.976795,215.285018,209.396077,106.079651,21.913617,9.536242,8.371396,8.219772,38.084172,76.013561,115.425,7.748815,-75.489618,-153.802169,-126.780059,-16.271393,25.705381,49.164388,33.555016,-47.142401,-114.527,-104.038558,-68.715943,-82.292674,-64.191677,-10.86792,25.030392,-46.230481,-50.571073,11.030381,33.037359,4.797447,-30.617669,-96.440841,-123.91901,-176.091488,-231.515493,-225.176571,-103.521592,-50.436582,-35.227981,-40.354331,-57.107273,-61.276063,-61.765397,-51.914636,-1.347757,114.977351,110.723182,56.774582,77.766158,172.504333,118.189086,54.113921,32.439668,79.30197,179.0264,193.24644,124.786454,43.373258,29.390654,21.105011,29.100657,56.827403,55.822372,59.465458,69.209743,27.983237,-68.880407,-98.615423,-117.719436,-109.501372,-15.747908,40.660979,11.36447,-96.394478,-108.004102,-34.681968,36.477338,116.811028,105.071449,84.835635,78.93372,-4.570603,-118.243051,-150.923255,-190.776907,-208.177613,-187.891944,-146.193628,-125.292982,-224.062785,-288.197039,-377.266867,-372.24582,-312.790485,-285.332395,-238.806689,-231.299665,-247.987006,-249.944915,-241.108898,-196.324383,-152.140687,-41.38219,-5.060569,-8.71769,-20.260442,-11.815274,5.008798,30.175116,163.032366,241.21784,260.699032,170.757598,-63.523043,-120.643041,-58.953354,53.663258,29.443674,-80.299698,-106.069123,-132.330873,-147.137019,-114.041058,12.573907,50.828184,20.335293,-5.962231,-27.424267,-60.128355,-178.327551,-211.61957,-172.549892,-98.485819,-96.877501,-64.512723,-28.739608,-47.474608,-115.580298,-130.761719,-163.394015,-180.151891,-215.926489,-235.190204,-222.039386,-174.922733,-49.531041,5.63486,18.911212,88.767058,111.420061,52.723249,14.333105,10.466923,-8.672005,-45.821536,-110.085809,-122.396417,-121.712923,-103.90998,-17.73455,10.8132,-78.667071,-213.108714,-194.122892,-37.250197,2.106215,-24.336029,-39.124964,-61.000133,-138.453231,-207.225543,-294.648418,-264.461578,-134.233121,-92.602657,-67.398431,-58.439832,-24.33739,-10.216843,-2.135702,21.663433,20.74284,58.540709,96.2822,37.280421,-129.003515,-146.599401,-41.902004,11.980194,12.991225,-16.009978,-20.771302,7.59462,15.42452,-115.982142,-175.233751,-175.666508,-157.121389,-169.637813,-181.390149,-188.360332,-245.46349,-294.146141,-348.226399,-322.006123,-200.225207,-159.288845,-160.183545,-173.480991,-188.567122,-248.990241,-277.443388,-250.486594,-217.852987,-188.33147,-173.621561,-108.821118,-41.807839,-19.376509,0.135586,1.255358,-18.733147,-23.369372,55.181799,131.555855,275.77469,349.260457,361.823454,397.959924,429.457686,461.099269,450.566097,399.064857,263.548104,169.715972,87.721115,121.884824,230.087291,276.210529,322.825817,299.961893:35.765012,2.013557,-7.735401,37.998946,84.700213,130.407436,102.749177,-8.264843,-51.182657,-35.015176,41.34426,75.891412,83.420839,75.060394,29.833831,-27.013873,-145.521934,-179.504633,-181.671633,-222.709206,-241.672062,-201.183547,-173.352145,-199.824068,-251.040974,-240.140262,-86.264817,29.165423,158.510929,163.962491,164.348873,173.185683,183.869894,122.392108,98.764396,174.137272,235.28089,280.167269,249.170288,80.220223,-118.001104,-192.863318,-242.797072,-189.270096,0.348633,63.850361,78.064906,61.19106,-24.214442,-238.050586,-315.353296,-233.998798,-135.462947,-34.347583,-41.136243,-121.473102,-156.080025,-125.393014,-38.364085,-12.306015,2.687903,23.091963,98.631999,97.390338,-29.171496,-145.455345,-171.741523,-214.676611,-230.825496,-179.770408,-112.706477,1.214553,4.996147,-52.705717,-204.473365,-226.814736,-146.008676,-90.299468,-60.844836,-104.210521,-215.269583,-243.699685,-214.892633,-70.579235,15.280978,106.606074,89.213447,-42.388848,-159.729759,-175.33467,-104.269005,-30.716544,80.867767,107.701828,168.723569,186.685183,99.663012,-119.371933,-191.093352,-129.379304,-40.603682,97.736528,125.863362,101.745221,3.7615,-27.815606,46.054446,114.676091,184.329721,218.826606,332.128058,345.172369,182.616119,-93.985752,-160.271712,-42.748933,71.266251,243.339567,275.557979,199.046632,96.849499,77.799902,31.447014,9.20078,46.455645,105.385054,169.898992,130.048221,-8.233146,-112.231026,-154.764092,-136.619852,-58.660017,82.644267,82.362777,-43.645619,-205.79252,-266.222211,-262.445179,-184.395602,7.583034,80.443757,133.147787,91.084269,-70.931954,-191.869784,-208.780079,-149.854455,-105.004082,-47.47208,-34.083538,-40.488912,-102.819269,-145.044535,-173.989952,-133.904158,2.731263,54.867515,55.536868,12.505867,-65.149555,-118.125758,-151.276451,-179.766188,-147.051803,-5.74022,60.381506,54.562478,-128.017352,-218.437268,-275.162004,-231.505741,-83.272275,-3.615012,107.109887,88.598283,-56.917745,-100.614579,-81.978923,-71.596342,-66.425201,12.315538,43.163646,-20.268884,-91.481778,-69.266555,29.123043,54.602872,19.339935,4.23167,26.630781,8.888009,-107.993421,-167.368538,-141.632616,-20.939131,20.750122,31.450227,22.822358,6.288766,0.507175,-18.767519,-11.5133,53.389324,194.107175,223.419441,215.876286,195.493492,119.129051,-6.348135,-38.51933,48.042089,137.823331,275.655864,291.052919,210.053073,27.084628,-54.788674,-65.605703,-15.852821,14.926368,-7.70745,-16.034891,-6.922833,-50.728133,-160.756343,-188.902966,-153.069964,-106.22494,6.853482,44.022638,27.318585,-20.664812,-27.647797,-5.000719,14.947481,73.009907,122.874053,182.350182,147.830634,-8.31581,-128.164567,-143.599079,-97.674027,-59.850683,0.444692,14.376906,-34.178866,-173.334726,-237.342838,-263.80886,-232.401765,-175.996875,-144.101005,-50.754638,-35.076695,-80.639864,-124.593331,-130.019069,-71.262306,-19.405931,81.276198,112.5979,110.159975,28.277468,-29.526695,-87.379542,-52.183376,125.6618,217.253797,231.253157,126.421679,-144.909598,-174.899543,-84.246997,65.916369,77.597574,86.935765,86.288316,-39.817289,-205.010539,-224.62561,-145.976418,-93.219508,-50.064765,-48.390386,-55.813253,-91.256231,-220.137801,-290.938337,-276.184596,-177.291414,-119.522284,-10.902868,32.472506,39.201757,-91.556803,-170.598319,-190.548014,-134.812749,-66.856578,-75.288031,-69.459709,-35.682814,-14.581042,-123.331898,-137.429005,24.400865,108.517457,108.553734,63.371556,-5.444601,-63.807356,-101.849767,-133.052314,-94.530183,44.22514,88.430026,59.716842,5.514589,-102.943539,-177.367545,-187.723832,-125.869113,-77.389018,-29.344375,-45.963723,-115.403988,-136.765023,-168.890269,-262.611582,-230.658084,-44.926402,10.604472,9.146367,-18.298721,-67.914461,-83.308251,-94.659573,-77.787776,-22.587039,106.419057,113.543541,-47.372927,-249.858169,-287.643427,-246.424985,-210.318694,-117.452888,-44.194425,38.547402,6.999716,-119.35574,-205.162663,-194.506695,-84.05938,-32.508586,15.900526,16.767819,-59.787565,-227.72041,-307.370917,-364.755861,-318.803566,-156.500429,-105.654669,-112.848757,-134.617399,-167.044361,-261.237704,-296.534677,-232.036356,-159.529283,-30.350562,23.25079,85.400496,11.595782,-36.074239,-7.672954,45.125316,85.593307,82.951004,124.42739,175.048968,276.364795,274.132155,251.892544,267.511589,318.626878,450.284626,482.896848,423.231986,261.577458,180.309772,119.408295,146.789261,270.084691,342.144182,375.605984,323.755299:200.284689,155.785011,117.126821,147.012719,227.410946,340.448637,335.200825,275.296107,208.520523,174.146722,153.934943,202.591749,331.303622,339.371613,237.628037,160.315014,51.765411,-25.304981,-126.109332,-341.319944,-378.550094,-383.658875,-398.203606,-398.187149,-275.978799,-184.674411,-7.582829,49.519919,74.902622,91.812751,238.283715,336.741977,474.973493,495.500881,467.203844,379.03627,340.413432,282.850883,248.567343,140.345736,48.410691,31.329581,99.514642,173.582425,227.392699,203.258001,191.963201,204.867961,198.918004,95.085113,11.812636,-143.306224,-212.699088,-323.805788,-342.581175,-311.27582,-231.672026,-178.92425,-117.029425,-122.536737,-137.19929,-117.428297,-22.512509,27.776173,79.755998,52.944805,23.089599,-77.781964,-151.500132,-187.989531,-89.005991,192.764476,222.859612,123.348055,-64.889456,-76.650036,36.703489,107.983896,143.782306,98.825226,3.596867,-66.988303,-124.441921,-252.790608,-299.142475,-343.873123,-359.940673,-415.291645,-426.452798,-411.257242,-388.372802,-353.8218,-224.278166,-168.908282,-101.91963,-83.752198,-61.643264,-102.409936,-170.476618,-236.302692,-173.892904,-2.607852,26.299142,30.603757,132.037001,184.718106,181.892388,152.786721,139.357521,178.773468,357.959727,425.5999,322.016842,42.791218,-37.385664,-48.248138,-49.32366,-31.244974,37.235151,165.764456,94.988228,29.027174,-43.877788,-49.01874,-19.786179,31.035775,139.333291,117.394175,-31.682201,-55.474211,-22.601928,32.054023,33.921002,27.543199,42.17464,32.417517,-112.150359,-178.686131,-131.050735,-16.489817,235.261788,293.953141,235.933211,169.026638,37.366875,-64.774722,-70.268627,-54.23444,-83.242389,-115.988394,-61.257689,114.284466,212.556615,223.718768,252.801651,298.247802,399.263332,415.654158,378.421807,348.853345,281.122547,216.606637,209.891656,226.203423,203.703646,121.598173,108.489958,113.985342,82.981987,60.004568,-17.832732,-64.289976,-75.564704,-42.424722,-42.646242,-116.876381,-285.870236,-299.872624,-273.411341,-224.758424,-213.046868,-178.288441,-129.585961,-34.760956,-30.412172,-47.181809,-94.175319,-104.107723,-43.555413,3.705028,21.78679,-10.489363,-73.875282,-97.234756,-101.266343,-63.029105,-28.304402,12.200185,23.102854,57.961193,66.941325,34.669299,-49.977674,-54.543792,-0.468286,-1.10205,-82.232604,-86.94775,50.31639,94.730917,39.626116,6.638989,58.071175,155.5842,172.559088,161.853846,142.700916,127.798981,63.459522,44.043104,44.0146,33.29994,32.257725,53.14639,46.950621,-32.52481,-67.838006,-97.700052,-92.854597,-49.808913,-20.760408,11.393887,8.027981,3.609574,16.522877,23.415993,-13.775576,-22.655369,33.789186,46.07576,-19.088293,-102.425979,-137.801576,-183.498109,-188.033931,-184.997967,-176.86136,-151.737671,-204.091043,-267.291684,-352.681364,-343.663591,-306.150269,-309.296167,-304.859532,-285.989188,-273.678339,-318.778338,-320.688562,-193.751292,-100.970635,9.76828,35.096968,66.791603,66.59924,59.374547,37.972675,47.301946,139.804807,200.377966,244.693542,193.40595,-11.64552,-155.802805,-166.75401,-100.928267,-55.744958,26.24761,61.386061,29.722999,-93.487235,-88.376986,69.066142,139.703309,156.960713,130.510827,66.749283,22.772875,-64.929396,-140.52181,-180.183114,-211.157835,-194.910215,-153.747188,-161.858209,-264.707535,-298.451463,-262.748969,-236.184109,-266.161338,-355.412703,-386.04565,-346.699216,-269.477836,-73.850615,-5.298032,-31.691112,-60.919035,-36.8091,12.384071,4.273555,-84.370359,-204.256381,-246.852729,-288.868764,-307.990949,-322.855355,-283.883609,-146.908336,-112.07301,-168.336826,-251.821847,-219.216539,-32.733217,7.64183,-142.599107,-242.299301,-269.540779,-217.982025,-260.895382,-362.785276,-325.881455,-153.398413,-111.821042,-125.218044,-128.510285,-102.062378,-113.670148,-124.662406,-85.647029,-38.190549,76.227045,106.957972,36.770604,-91.688073,-104.614917,-17.999205,33.078238,49.422442,18.225205,-26.452083,-11.579014,23.275434,-94.79335,-174.357063,-190.075184,-137.097782,-110.94712,-167.360215,-248.608621,-221.840409,-228.822055,-244.359259,-207.362694,-148.449068,-184.007996,-289.900962,-293.841232,-233.136989,-236.116267,-259.723529,-296.965844,-281.954607,-187.529124,-158.739216,-215.46302,-241.040953,-183.621844,-60.591158,-48.149232,-122.750969,-160.627832,-92.593332,-1.274673,128.643341,150.704055,173.076581,303.822398,366.79837,359.497706,305.208334,224.253571,173.007998,118.267172,13.121913,-0.619427,23.622283,39.523062,54.006673,44.087159:-42.10859,-46.319806,-38.902022,91.457256,192.538543,299.63807,298.497494,257.366778,201.246076,179.061098,171.904194,195.685167,229.579083,214.581236,160.230101,128.118446,61.427413,-32.282282,-108.580382,-229.275386,-242.445199,-233.135316,-239.295645,-305.876215,-349.94604,-314.034733,-144.822878,-69.65309,-65.326845,-86.96405,4.40934,86.717164,197.489233,223.948466,202.157836,122.372204,94.025207,73.364883,58.773072,-10.551219,-112.233085,-140.486984,-105.265602,-65.800832,-44.20869,-51.857332,5.396111,59.341373,112.551994,32.315401,-32.358167,-99.472562,-108.161297,-130.672433,-145.967098,-218.465686,-311.067214,-293.287862,-132.420322,-68.451934,-74.066313,-104.299739,-106.841569,-73.888427,22.320187,82.147484,62.277988,-88.844036,-165.663725,-142.72579,-35.175218,137.657528,4.267634,-122.976831,-257.70592,-219.846479,-26.19569,65.675468,143.679413,125.321602,48.144488,-19.696298,-31.604465,-20.77053,-46.040559,-161.834188,-207.777996,-277.338545,-323.060177,-314.275663,-264.163577,-246.257565,-253.578222,-257.927173,-175.637138,-103.727904,-50.753405,-179.677598,-237.346076,-198.736833,-140.816608,-29.447052,40.182484,149.29723,117.739924,88.403443,98.764088,107.580982,77.874748,99.956541,298.196737,396.849133,370.823467,67.721358,-74.273702,-141.031066,-86.767827,99.077926,200.709719,253.851316,89.973819,25.404182,63.314138,132.96125,218.87199,239.07268,293.765007,290.887794,179.607441,107.118878,119.275751,132.030577,102.964864,53.981859,68.503443,119.448384,49.371636,-24.207793,-57.187791,10.400263,178.274834,220.444727,210.186141,179.725023,109.935959,14.974497,-44.754003,-114.090755,-121.760644,-104.803764,-64.293801,68.125881,120.634321,75.26976,-12.8875,31.897678,208.845278,247.033818,250.884019,266.305592,265.917103,158.842281,115.5315,134.804833,171.158169,193.318752,164.581681,29.823659,-129.427391,-173.535581,-153.281997,-104.965222,-55.879682,-81.755438,-138.788995,-134.733352,-95.280891,-124.460559,-163.337319,-173.014,-122.233599,15.364633,54.897199,40.439071,-40.927327,-90.930796,-156.854254,-150.728191,-101.393854,-94.253427,-150.805859,-176.504241,-88.747582,-45.27077,-125.306616,-226.88806,-184.956272,-77.240096,-60.921625,-90.350311,-100.228633,-102.474499,-123.143222,-105.133657,-15.711007,5.351011,-1.783692,13.213706,72.571232,51.129572,18.800616,14.49902,47.213917,112.837796,119.913276,85.623467,111.395482,155.488619,201.299368,177.627691,65.497165,19.117667,15.376071,38.630114,75.265286,50.65339,3.981261,-82.884083,-88.974755,-61.403447,-58.779384,-67.670431,-29.301283,-14.763623,-35.315283,-44.388677,-76.329721,-115.703119,-119.721807,-56.637468,39.242855,-60.16508,-136.857906,-196.159394,-187.674634,-159.994295,-135.32833,-114.277641,-189.714622,-242.969388,-314.969549,-320.656616,-270.43098,-215.512291,-136.192106,-159.456314,-259.314654,-252.856238,-241.409445,-258.038314,-240.008344,-95.495648,-14.653982,62.860007,90.08301,107.709387,120.171338,132.840927,236.289657,325.226818,462.977848,426.399944,177.824181,-11.611025,-46.989414,-18.795576,10.621867,53.363184,75.884151,93.222635,98.471773,119.944958,159.169153,186.899783,282.291588,306.309731,263.721892,229.950531,198.412775,160.317593,120.514783,17.933485,-32.186031,-21.082116,28.30083,-14.553728,-174.022214,-197.462054,-142.585624,-114.921709,-169.096819,-223.915303,-200.311096,-105.656901,133.979412,244.053778,234.23013,218.598477,235.686817,238.702475,206.598775,111.225066,55.456088,36.005014,-31.011786,-43.321221,18.606332,53.224735,81.132276,76.069751,7.85532,-55.762048,-25.958934,117.903488,160.064766,95.070506,34.618993,-5.393627,26.677447,37.938479,4.163384,-31.330584,-58.777193,-38.703752,62.162467,124.86661,183.36861,83.897649,12.762449,-42.471148,-18.271378,75.922617,117.442361,131.619842,77.79067,58.792717,77.390061,108.803977,125.384309,89.498398,28.269861,37.729782,48.671971,-100.316517,-191.831611,-247.0532,-237.277704,-284.960515,-327.218135,-336.804466,-293.948609,-303.502793,-356.586816,-350.323741,-281.138111,-269.138512,-334.675736,-379.638038,-398.244401,-407.528776,-443.384298,-467.729019,-418.452358,-266.016265,-217.992087,-219.720541,-216.355208,-193.063669,-167.752552,-174.199021,-235.468549,-278.153241,-258.614556,-167.27284,81.544646,245.052876,295.248929,423.583531,469.713934,413.30462,346.514536,270.976476,283.954855,280.426447,227.815608,200.414277,181.79919,201.619807,216.924108,161.542071:57.929728,67.65961,48.749697,-2.991385,14.395638,166.821609,220.81767,123.921536,10.449644,36.781876,180.989394,242.640302,241.554371,193.587321,87.976298,24.57539,-111.736838,-183.379119,-195.359722,-212.003573,-228.641879,-274.203439,-292.1349,-279.412537,-183.322963,-129.488893,-11.001152,63.882675,189.63383,239.939335,367.975682,431.996293,456.263233,340.562783,313.647784,397.976968,452.90549,445.874344,382.683803,230.816147,112.041341,64.694459,20.526551,37.740554,129.856832,178.170762,201.543272,158.289796,15.526688,-157.501192,-245.869271,-291.220646,-239.27422,-138.844843,-135.408634,-168.624193,-106.055911,-71.765676,-139.317017,-188.866674,-144.366806,-79.864936,20.15289,51.187018,63.789037,-19.765153,-102.376147,-267.624111,-286.442516,-150.773085,-49.006349,97.433093,101.502968,55.162228,-29.170086,-34.926331,-26.080506,-36.369522,-73.047231,-92.900011,-125.592787,-197.210598,-235.269926,-200.644666,-143.713837,-115.859072,-155.329542,-230.60957,-259.423867,-265.442953,-221.788329,-152.871473,-11.864474,20.13151,32.599174,16.226622,-68.30509,-163.711603,-192.287428,-191.257288,-165.293672,-92.208966,-49.402544,57.74346,95.870331,64.486502,37.960729,85.050481,216.16648,265.245724,306.774641,288.27262,162.824162,-61.446049,-155.127417,-150.382764,-62.63991,154.336943,224.636059,200.850437,80.042521,51.288234,24.235893,1.306194,-38.78189,-32.486733,54.075258,87.934127,25.452422,-130.750473,-169.306166,-74.027956,14.800509,97.920321,73.405825,-36.929154,-105.231449,-113.241872,-113.320205,-88.862729,70.932482,175.060533,246.242093,206.661818,77.762273,-90.878686,-149.35301,-152.704167,-127.293925,-48.457796,5.055814,38.966217,5.33169,31.139415,118.56164,142.455438,173.27412,198.298296,234.652872,213.707964,116.843213,78.345315,97.510888,140.279843,120.808143,52.826828,50.665324,76.638224,79.088045,82.991739,58.743209,18.723164,-33.041834,-10.871214,51.146279,27.921793,-111.100112,-198.037497,-200.349662,-167.575203,-159.656246,-118.81216,-69.490381,-13.720653,12.406819,50.212406,102.430368,89.386702,43.723126,45.272055,51.470642,19.224815,-82.253753,-82.072091,-41.348045,34.235709,41.4895,16.681878,13.250362,2.910517,9.663398,23.943414,21.478231,4.516589,-12.624716,8.178532,66.525951,67.723375,61.544377,107.094478,119.518136,106.817355,91.25085,63.399221,62.353875,121.729899,169.651175,130.819943,11.821208,4.987468,59.32718,57.688109,-16.042353,-61.031785,-105.01945,-57.489706,-24.018255,5.169423,-2.589495,-19.738301,-13.056832,18.203754,55.598079,45.233545,-46.896674,-62.727781,31.294783,93.89516,137.707647,110.817267,37.298786,-15.869514,-65.759531,-163.265608,-171.39658,-140.822119,-126.678596,-127.008601,-208.419351,-286.320273,-392.714717,-368.956583,-257.338059,-217.246391,-141.800972,-112.125429,-154.977394,-245.631254,-226.685598,-66.836314,7.032022,77.801543,83.022427,61.44557,71.651811,92.001251,107.567616,96.966935,88.221307,116.143275,156.167071,101.443102,-122.521994,-202.093807,-143.719296,-5.556678,0.596374,-73.866457,-89.347406,-71.688552,-94.861074,-93.805076,1.949868,54.581541,62.444786,41.396529,8.695604,-11.090582,-58.930276,-140.851129,-191.609862,-174.190143,-102.86828,30.825933,55.690917,2.255028,-51.018889,-52.57383,-63.118013,-71.608627,-86.475822,-86.157719,-46.698241,-20.940915,22.956726,30.134004,20.817633,72.049091,121.82391,127.865972,73.748824,-38.24924,-87.511912,-111.723454,-152.520544,-142.126667,-75.202044,-46.587268,-23.848653,-33.988224,-114.586582,-217.978643,-213.322399,-59.840584,-1.04387,-89.710324,-178.474674,-245.626373,-173.015325,-156.379842,-236.664725,-260.07629,-181.82523,-148.72452,-157.618777,-142.038217,-24.988861,13.194873,-31.821984,-103.520904,-92.198554,-49.827339,-54.366866,-116.510655,-194.138332,-212.276198,-176.360208,-153.558315,-129.756666,-101.763509,-59.020991,-71.201956,-110.031772,-113.668416,-107.232806,-86.457866,-79.103646,-93.77749,-121.868287,-190.206576,-219.254603,-221.849062,-193.282872,-154.349458,-104.663897,-107.947174,-143.460317,-174.304076,-182.548903,-136.07291,-142.17046,-150.417807,-126.300423,-76.213791,-69.269055,-85.156119,-62.747663,-41.159897,-34.046358,-24.42636,31.855834,59.809886,119.295248,157.857317,213.358374,209.834951,216.235288,294.391882,341.002398,355.289003,322.202304,257.887869,212.537635,178.111066,87.124018,52.567508,113.112788,182.72453,191.079204,128.664703:forward
101.677658,160.796212,106.417881,44.705899,54.067755,32.293267,1.523495,-10.011241,-10.737525,-11.971363,48.855043,83.634878,62.268432,7.317138,-98.716747,-121.533414,-130.746703,-56.433336,8.659788,66.8357,49.685605,17.168749,22.930742,65.81707,82.89554,77.038571,78.277547,74.681544,35.046209,5.408681,1.866538,57.845562,210.42178,282.098085,245.12241,20.917769,-96.353948,-174.331813,-130.286657,-18.628375,-54.179586,-81.2095,-73.62693,-87.346421,-157.661831,-178.467236,-179.523879,-167.102275,-165.489941,-177.025953,-159.505404,-146.092036,-182.982379,-286.122211,-305.993156,-241.540499,-90.407095,-6.098232,138.188571,159.19098,67.12557,0.892635,-32.444405,16.139352,140.201825,210.409346,222.147836,162.44722,113.375559,90.074273,110.248585,142.527746,71.282244,7.053937,-55.782463,-51.859589,-8.90407,16.526596,-0.205768,-39.875744,-111.636938,-98.725349,-60.738937,1.272614,9.795224,-32.531859,-74.164928,-126.143485,-105.756853,-71.222675,-26.003333,-58.763774,-153.831485,-129.737566,98.110213,221.90685,290.966276,208.763869,194.242402,204.923583,192.952127,109.636135,64.822646,74.256128,153.676248,153.764311,72.361749,8.102263,-137.727959,-186.452613,-153.111888,-88.106529,-26.917333,-89.510404,-130.519659,-225.219347,-246.222033,-195.062717,-159.330161,-148.634494,-165.571699,-136.058853,-88.279761,-117.22265,-200.833755,-230.755927,-295.476314,-321.201454,-338.207579,-296.997422,-253.781819,-202.218227,-224.268047,-324.672225,-348.872691,-292.497918,-215.115611,-175.735671,-49.095942,-11.596841,-88.486794,-164.546662,-268.479796,-276.483148,-236.201046,-182.480227,-150.115879,-105.591549,-110.525765,-162.859426,-192.153733,-190.951259,-91.972928,-29.749068,51.129154,45.834936,-49.221187,-117.255452,-202.819684,-185.65451,-83.860595,-24.301462,-30.452603,-62.703589,-46.591394,10.026167,14.558369,8.539242,-20.497951,-64.859241,-174.860501,-191.786639,-86.937383,-29.53715,-68.532085,-134.20968,-193.360637,-128.840181,-103.929546,-78.147259,-49.414575,-52.928121,-114.725671,-230.08568,-209.219133,-180.506523,-153.877381,-156.91959,-215.77848,-270.404094,-350.054522,-343.126137,-246.919423,-71.855732,1.29424,-33.082318,-115.344305,-205.480736,-194.434119,-152.203346,-126.125907,-103.914707,-24.763922,9.350506,0.795026,-38.456493,-129.805582,-169.478948,-243.51441,-269.79601,-253.385948,-225.258588,-241.608879,-311.822635,-327.175461,-252.166435,-124.906204,-94.283324,-146.718246,-217.568249,-310.631517,-297.42726,-226.553062,-203.182759,-193.077433,-209.792526,-210.413644,-184.084481,-185.281741,-265.335485,-304.736725,-274.918272,-215.281505,-206.32859,-178.024139,-172.361629,-198.414612,-212.114804,-217.628662,-213.522218,-208.570438,-166.658574,-156.254443,-196.769823,-218.139898,-304.490458,-373.363419,-384.725686,-201.730623,-122.647101,-134.690821,-214.435259,-353.271864,-375.676071,-323.535187,-258.5141,-149.040628,-123.886439,-127.82339,-199.500641,-264.176266,-350.620592,-346.728544,-287.338371,-230.82991,-183.507349,-108.876528,-140.131099,-274.008374,-318.91443,-309.090118,-245.990234,-57.774332,80.701031,99.198504,77.405073,78.070262,92.828569,91.006162,87.133846,59.662203,54.208687,113.675297,148.535322,157.818304,141.296986,171.563346,232.585222,316.731318,280.575091,245.537946,157.018064,111.092664,28.263408,-4.495909,2.789629,139.464326,211.203249,243.138283,219.614202,194.21572,201.811685,236.099765,249.391759,213.016564,131.128337,115.196113,73.424769,10.611793,-165.167256,-224.498247,-199.150021,-98.500285,-71.646148,-78.01147,-103.245995,-129.362056,-130.646654,-161.677909,-162.765299,-45.10056,157.180471,226.994815,225.271877,179.026367,83.342001,49.636867,46.719995,63.144831,49.28393,19.302913,10.690834,7.528033,15.066417,42.756051,67.724224,169.594241,332.161043,366.138376,259.091983,185.480872,113.268582,99.806016,97.637476,142.548569,174.798743,199.952435,193.100402,212.152305,224.439853,179.728692,160.890643,213.753804,293.36716,307.677611,260.712303,224.226227,203.80147,222.131288,286.178526,359.944975,381.985924,358.210015,315.812239,227.73967,206.045619,227.64718,283.953952,435.425417,482.859846,445.407942,270.990815,173.193495,54.388685,37.569494,66.704186,128.61831,148.024972,163.708279,169.086998,211.890372,245.605433,294.292143,322.926216,381.459378,337.183318,293.624539,259.291591,262.290676,239.500049,225.235709,261.542429,329.23987,331.395228,262.271687,223.202108,207.886974,229.827193,318.444729,374.530601:-20.26395,128.471595,134.975089,86.404817,64.38516,-15.616811,-57.919929,-49.111877,34.856811,79.506393,136.990609,128.107969,17.237347,-65.716,-150.178662,-118.998163,-6.506434,100.897173,162.636298,208.428732,152.672929,-15.487994,-39.872132,50.183172,106.608633,103.455546,76.2695,33.283355,-102.771824,-135.471889,-57.570444,3.144404,59.701575,87.623181,75.066878,-97.033477,-215.030209,-293.328239,-236.990356,-123.042839,-154.880572,-191.895969,-200.960927,-172.451089,-148.175517,-171.168377,-210.908332,-209.687492,-207.413076,-183.206003,-146.873559,-120.956508,-165.325849,-275.876397,-272.271639,-132.690561,18.664228,79.557738,151.751297,140.15494,46.481812,5.071251,5.702519,46.786312,152.282722,213.771934,210.673371,139.074791,95.903833,55.973173,68.366584,150.006411,171.832319,147.529019,112.640274,82.262794,-46.049735,-107.363048,-122.342988,-85.868503,-53.784929,-68.231046,-52.015825,-40.469617,-69.546417,-126.428785,-125.919527,-110.345519,-112.05785,-100.303922,-128.389142,-183.996752,-205.738103,-139.083073,14.769357,55.010492,68.624045,132.553564,193.842993,218.545189,161.392286,23.474527,-5.636471,35.455411,49.843596,19.392003,-43.264103,-66.092006,-103.622083,-117.154692,-145.697289,-165.407525,-177.608157,-115.669745,-104.692154,-189.619085,-237.220765,-245.328731,-224.375705,-168.002087,-68.872565,-17.905129,-13.032223,-72.700219,-234.838496,-291.565094,-271.365231,-210.274483,-128.534755,-118.848781,-115.418716,-138.790324,-171.284456,-246.340158,-276.23379,-306.892982,-264.470077,-204.610477,-78.293895,-69.464773,-185.054171,-249.608916,-289.841119,-281.386382,-223.605071,-65.912795,-7.045427,-96.73925,-230.123375,-450.832977,-444.562015,-215.649913,-47.169489,-26.478629,-4.786813,-1.355397,-52.274752,-102.489677,-153.269677,-128.469318,-73.35078,-123.089957,-164.111889,-203.670776,-187.583357,-80.064785,-20.073561,-10.230028,-88.794969,-97.210454,-103.765192,-137.053197,-179.607871,-146.257429,-12.44307,29.601307,1.705419,-47.306676,-57.987958,-81.584735,-85.174134,-69.38318,-66.420618,-87.474704,-115.033769,-112.051708,-79.938827,-87.258502,-164.624667,-209.893076,-284.619475,-305.271526,-269.963358,-82.593528,0.273593,-19.895406,-101.885824,-225.472643,-217.194361,-147.275563,-113.770733,-99.263396,-85.729663,-83.567684,-96.238044,-135.626087,-243.863924,-277.263738,-316.25598,-306.99659,-277.001433,-258.435871,-304.616165,-447.32489,-481.6192,-446.488141,-367.579211,-314.47242,-227.332082,-237.414455,-345.99048,-391.952695,-378.176869,-316.833744,-201.634684,-234.234704,-269.716391,-292.198771,-303.103041,-393.451884,-436.290558,-390.436229,-216.635766,-146.379795,-125.448355,-166.567647,-258.028788,-279.229762,-266.658268,-232.924784,-140.405148,-71.34462,-76.36435,-196.079182,-263.027756,-324.466684,-327.534711,-295.897853,-240.060979,-222.868511,-224.587897,-237.959056,-286.540782,-305.444204,-267.134974,-218.858728,-148.592942,-146.088281,-156.287124,-195.827911,-231.536906,-280.515458,-243.701439,-74.483397,16.369016,32.15171,27.328226,-31.246307,-192.271216,-226.86203,-132.242217,-12.940906,221.395179,278.866602,236.032578,84.923206,29.803996,24.922908,62.65953,154.431259,189.010743,187.621833,184.394088,179.788576,143.994031,140.010721,273.327235,374.890789,438.737649,355.963303,324.53957,292.10757,253.536667,119.423125,81.168459,141.181315,281.337504,341.321558,356.910354,302.2368,202.792505,200.83861,223.300485,215.85595,192.004814,196.413908,177.004213,63.929478,-0.021384,-82.974875,-89.734347,-32.318162,22.182931,18.9339,-36.978716,-59.549525,-42.866635,-34.470196,-84.333752,-106.043268,-15.841612,197.992454,269.896281,260.034155,204.940389,74.164956,48.785059,152.33438,259.093982,270.917101,245.680352,203.2957,121.737724,114.047514,144.113422,174.059341,277.131027,388.846031,388.9017,297.38029,267.336092,227.593665,183.309238,123.263011,220.13121,287.211636,301.79043,248.274383,153.896405,143.606664,173.991908,212.030762,335.01223,407.918561,378.510386,237.216041,194.662334,211.209807,232.464245,269.237644,354.045725,405.00225,391.379164,316.914991,196.274872,192.179051,258.645724,317.205041,470.272517,598.095066,573.089932,356.459049,260.072601,203.836279,220.148992,252.657666,289.157614,321.706288,351.675916,329.366921,304.952676,324.090013,328.079548,314.209425,340.578764,361.786772,327.348717,227.604606,193.097195,173.112797,186.438821,231.74047,276.95668,292.67186,254.224714,199.327863,116.852628,110.64122,150.800132,184.322936:-0.559067,56.152934,36.000144,41.027665,60.434135,2.381492,-62.377436,-91.286994,17.548124,48.825405,36.487687,32.484059,20.397386,-10.839884,-19.175504,32.201597,135.632723,219.034581,265.531096,284.13254,234.534902,89.567491,60.968031,122.22338,169.297758,168.08515,120.781512,60.599773,-94.19771,-135.338959,-69.332385,-19.272535,-14.147759,24.224375,49.103669,-55.254241,-155.435401,-257.581128,-238.883768,-152.134929,-94.653826,-79.137231,-87.124322,-108.204638,-160.286427,-206.83237,-278.55072,-246.415438,-116.311285,-75.851612,-79.560992,-96.686285,-112.910001,-131.970028,-106.977744,23.893418,116.669534,135.779065,216.442176,259.595249,211.74249,132.539558,45.173689,64.552587,126.369661,148.211689,140.039348,50.164363,-6.81282,-63.867531,-63.193485,-1.719431,120.697731,164.223875,120.709858,42.738762,-111.695537,-151.53452,-146.416201,-128.96752,-115.161089,-89.276896,-74.842328,-80.027795,-110.835552,-210.938733,-227.538159,-164.832486,-138.559344,-148.804306,-161.770825,-166.303733,-168.696159,-158.369815,-100.794238,-46.178804,100.082286,194.716432,180.985719,46.303619,-26.843245,-93.25601,-96.318445,-108.745606,-137.903023,-113.918988,-0.724816,11.52965,-128.585576,-217.992684,-274.048552,-244.372311,-166.994553,-132.131437,-147.261349,-238.471069,-280.86419,-282.676652,-239.512569,-128.670485,-82.009409,-79.464778,-94.161989,-112.379942,-148.405427,-159.482124,-164.622933,-155.358895,-91.790573,-4.947409,-12.933069,-148.912142,-213.308795,-239.901544,-215.992409,-185.741375,-179.876355,-148.682375,-110.804709,-148.030647,-287.538783,-341.009545,-337.749737,-283.512662,-113.024602,5.252226,-5.232555,-135.563953,-222.525495,-376.108531,-402.928703,-272.67895,-30.473717,43.804985,36.538281,-10.042532,-79.405227,-104.904861,-171.725325,-195.036967,-143.939009,-12.525526,-12.998619,-171.209665,-220.133101,-125.109117,-42.047467,42.483412,13.101294,-12.239997,-45.344475,-59.479514,-88.235801,-90.17909,-46.886788,-16.514269,-6.422101,-63.15143,-80.103062,-61.531871,-59.481958,-145.359272,-190.87287,-153.388144,-70.256323,-55.731998,-97.858423,-164.611676,-310.89313,-336.296215,-262.496088,-207.845537,-144.72226,-81.10453,-63.182757,-118.088181,-161.206415,-180.784722,-149.212351,-75.866741,-38.215328,-26.475021,-50.00272,-77.177682,-124.102513,-162.400427,-258.618875,-290.285476,-322.823655,-326.011211,-313.332427,-273.608892,-268.66051,-340.651367,-389.456936,-369.590777,-186.011486,-118.072892,-197.780816,-311.24923,-444.298467,-424.064711,-304.762469,-255.443153,-243.414238,-318.852969,-342.299179,-324.288233,-325.455244,-433.300287,-482.334614,-385.420332,-183.331839,-139.799311,-161.485928,-182.037461,-204.734962,-210.758836,-173.028735,-138.419176,-83.434935,-27.452225,-36.155622,-167.40783,-239.989627,-301.554269,-295.133272,-237.717236,-170.900375,-158.856459,-188.34695,-206.114548,-193.529827,-183.31062,-190.00229,-178.628115,-104.698143,-97.741248,-146.19613,-257.164471,-293.770335,-288.510121,-216.343943,-52.920693,-23.480227,6.408733,94.816555,83.760441,-52.354757,-112.706217,-71.140682,32.333187,217.746156,213.827783,156.766723,16.995242,-20.069009,19.856556,69.494347,135.513857,138.123639,150.588679,205.407313,219.271346,234.165559,261.795076,372.72894,430.901237,456.417837,372.206656,329.532685,258.249554,223.117406,169.331149,163.829281,201.584515,235.522456,241.587156,239.340106,222.759781,157.052628,122.167876,130.086126,171.021031,201.058436,189.356856,187.482643,96.912099,14.907039,-111.953704,-133.115809,-59.9386,75.354436,97.598799,16.211537,-50.835159,-117.477719,-121.567179,-153.134781,-171.162166,-127.232452,41.348319,117.318062,122.544026,65.291392,-27.988109,-16.249741,105.157052,176.54141,175.021534,125.466504,93.84487,57.904308,57.795559,113.990963,163.48472,279.938128,373.528523,354.914077,195.970436,121.895558,88.128638,112.709657,154.031726,181.825601,200.056972,176.892146,135.679276,82.920577,82.394749,124.481168,153.740503,214.41727,276.990457,267.461845,159.758186,110.292091,99.416336,131.305612,198.936051,223.35736,230.38933,216.141051,186.28734,144.117165,148.193832,186.8869,223.118137,330.735816,468.749462,507.447947,447.047271,372.499834,247.865374,226.373929,260.469039,283.212949,259.159594,182.583662,154.930887,172.059282,206.738279,235.500945,226.205088,227.878017,289.252946,314.053147,294.878666,251.208448,132.664392,89.638267,118.787566,213.94766,214.989475,125.180344,78.88065,42.103168,37.010818,49.464696,93.769139:-43.239932,107.772361,122.042458,43.973985,-11.508735,-89.943173,-94.637675,-44.173304,19.75602,49.777804,64.480255,45.657871,19.008374,15.539392,38.736602,73.345803,137.42955,204.218035,249.796568,267.213798,204.054195,44.06373,25.184789,97.222301,129.123266,137.473874,169.187231,158.512072,52.750744,-14.94267,-61.695435,-7.259716,139.792243,155.355395,109.34233,-57.497569,-139.869814,-195.492936,-174.094263,-95.04607,-17.87313,-8.811808,-82.698598,-136.285186,-158.549461,-142.20712,-152.585481,-167.868859,-163.120254,-101.06303,-70.227744,-65.770356,-75.781374,-94.055473,-102.842658,-74.2015,37.845071,117.227799,212.886211,183.441442,58.010743,33.917614,77.746771,103.442583,118.620418,147.352852,155.383106,90.152669,43.321474,8.193183,31.880776,119.096913,108.310078,91.62517,100.223873,71.933854,-86.898699,-156.729064,-196.144591,-184.731549,-141.943688,-101.602624,-93.864923,-93.726627,-98.047444,-141.48915,-170.694475,-179.510643,-138.340416,-131.224738,-158.019188,-166.609281,-131.130294,-95.499645,18.739627,100.57616,217.967038,205.192943,184.387894,153.367876,122.216123,-13.073205,-84.60412,-89.252599,35.328142,75.272757,53.63493,-2.689432,-142.408552,-185.526867,-193.850362,-182.761475,-173.393826,-201.508893,-228.853318,-266.823512,-262.862568,-239.374846,-234.406197,-224.247793,-170.822921,-112.016431,-23.203486,-46.523365,-169.885595,-206.632513,-192.284666,-174.091872,-181.001504,-183.593055,-163.710095,-140.982758,-161.371012,-260.676145,-305.34946,-297.380522,-232.614439,-204.112313,-146.32307,-133.704509,-166.283514,-199.468145,-250.913483,-251.326441,-156.721062,17.588102,74.288223,38.340074,-42.082309,-191.371338,-203.381286,-84.751165,50.964457,87.312015,99.548125,74.243254,0.939315,-35.956562,-81.015135,-71.174647,-46.22333,-57.610241,-59.135279,-57.596195,-54.701551,-47.984218,-42.962652,-34.661411,-53.49011,-57.745269,-68.864407,-85.917414,-85.147644,-67.497196,-44.001611,-31.414792,-11.342007,-30.600776,-46.213735,-73.805361,-89.620629,-147.992205,-172.466457,-160.503097,-92.623499,-62.12519,-115.505342,-213.994153,-369.377178,-355.802804,-250.359989,-222.666707,-200.506714,-132.07779,-91.620911,-97.707062,-154.687271,-264.83657,-272.672092,-179.82436,-21.083371,42.765663,92.096589,78.743006,10.223532,-32.731571,-122.612557,-165.840767,-224.134652,-206.731357,-184.372069,-247.517115,-337.219843,-427.707359,-380.48373,-236.59902,-158.344398,-123.307884,-88.000718,-120.20123,-238.504467,-275.448296,-238.223717,-191.200627,-162.605878,-223.909361,-254.942043,-295.801148,-312.317946,-357.990177,-367.485149,-292.761764,-188.67702,-169.703819,-164.353369,-159.365034,-152.755594,-158.687387,-136.6316,-94.489231,-74.061743,-149.529437,-163.645276,-152.76055,-158.475737,-233.875894,-269.122791,-222.034233,-134.631831,-123.822172,-149.515268,-178.250999,-245.818246,-273.874062,-247.203433,-183.419463,-90.513245,-136.572817,-176.920575,-219.341801,-226.537641,-247.025927,-234.040136,-153.925777,-110.215831,-68.745067,36.441083,27.689308,-94.931463,-147.59926,-141.930894,-66.770922,123.800413,199.940686,186.956648,104.848314,77.088226,109.225665,150.36284,198.150467,167.628473,152.882571,151.380977,165.619701,222.593626,232.74381,213.563154,229.768142,288.534387,230.116154,170.381746,99.16011,100.555649,109.213087,94.343324,84.023449,135.894869,143.467002,75.415865,36.36861,32.219086,44.136182,52.800522,67.600786,100.320005,91.379243,85.593998,61.591814,14.244484,-143.419757,-198.760697,-175.390692,-111.786742,-120.202808,-205.313696,-245.464119,-240.58776,-224.324805,-242.266316,-234.795863,-105.538584,56.268627,101.699468,107.184351,83.950124,67.323978,95.476732,139.233779,36.954963,-21.844684,-54.464614,-64.876888,-117.087846,-122.126676,-36.187643,24.312723,92.852145,151.399173,168.976204,82.64514,7.310654,-81.846485,-80.320989,13.458104,117.451835,126.933181,56.22595,5.454355,-2.923546,35.759432,74.160214,80.653094,149.83191,220.00552,219.002199,130.800033,77.715504,97.623621,165.798994,254.461884,257.444761,285.268916,339.033228,311.38398,204.389686,190.287554,253.865294,277.583162,277.314435,382.941336,435.138253,344.896259,251.146326,144.077998,128.382095,158.444123,268.605912,304.386658,286.81853,268.276922,292.562997,320.342384,330.304423,326.217979,356.537621,360.964866,335.266725,308.989041,314.700609,280.167087,235.957871,176.065495,200.624978,236.09813,261.849732,221.347701,153.077724,160.34896,196.718834,234.307146:-28.20406,103.551174,132.532994,43.361533,-46.851945,-172.924505,-174.23746,-92.648514,-49.815001,-39.770063,0.435637,13.764392,7.165186,-2.070368,34.51938,82.487866,197.642193,345.598506,379.278261,294.297392,227.044201,159.717276,171.376846,240.639855,259.92444,236.239986,142.444504,90.682522,-1.772694,-58.201564,-151.530217,-144.129022,-38.880253,30.264087,13.190244,-111.091128,-177.73728,-226.520739,-197.635875,-83.319998,-21.967385,-21.643984,-74.079455,-116.23825,-179.609813,-193.558316,-183.993925,-159.45638,-93.568079,-27.250299,-9.930871,-46.043133,-80.767751,-102.384349,-73.256489,51.334507,179.97146,222.021288,267.472519,269.560039,183.38774,103.837564,-1.327886,3.466699,66.675469,105.793598,97.722551,-17.511848,-106.117373,-173.570154,-118.53032,49.342663,135.53138,148.427465,128.78572,86.46934,-32.376137,-88.456552,-192.012089,-219.227059,-151.658222,-19.902427,-4.442727,-70.010611,-105.132985,-145.653201,-141.352529,-78.233474,-44.186819,-45.393466,-81.507797,-125.115315,-193.985731,-175.402555,-36.914788,54.737178,203.55405,223.199566,195.855601,131.527672,102.269712,12.997937,-40.824464,-69.45896,8.686424,47.436156,27.916025,-38.267477,-190.009864,-248.536155,-274.865806,-213.390439,-17.042545,4.368199,-83.865,-287.370774,-333.923098,-294.576232,-252.519267,-215.721829,-147.510568,-74.643319,-2.513236,-40.864846,-145.33317,-170.145797,-178.994564,-157.89436,-55.238676,-20.159181,-51.298586,-91.60622,-93.490761,-144.787392,-191.133392,-254.096296,-230.747781,-178.174777,-63.765419,-61.085538,-173.356983,-231.813596,-244.21724,-195.453192,-16.747073,150.438783,147.152838,-39.546826,-161.493671,-309.190788,-282.030537,-85.14511,41.597989,74.0495,100.596363,65.39323,-69.23516,-124.700753,-141.811366,-107.364234,-26.703654,7.332303,-9.26601,-92.108796,-130.053868,-156.062069,-127.679829,-8.579018,40.104964,27.090895,-13.45305,-39.795,-98.743941,-123.177672,-144.626991,-125.38242,-30.955348,23.36965,6.945447,-44.889112,-68.062635,-157.722058,-202.945175,-184.673224,-79.539409,-53.341687,-117.622717,-201.837475,-355.664139,-375.625521,-320.404634,-286.727217,-222.718425,-150.084205,-158.253175,-234.550807,-233.169121,-156.042274,-127.744251,-97.149979,-26.103031,34.625929,118.26736,96.405872,-56.87875,-133.426964,-175.980146,-167.679059,-196.178156,-165.595403,-117.350049,-124.818257,-194.027577,-304.641109,-299.944315,-221.407097,-113.062343,-62.025867,-102.467526,-191.908586,-308.971626,-304.774078,-256.587644,-235.324066,-197.270376,-207.184808,-235.224419,-282.174958,-315.659256,-431.484495,-452.653657,-336.295301,-207.547212,-180.841306,-158.045848,-138.204054,-77.900099,-64.16435,-82.43227,-100.282621,-106.572556,-34.043522,-13.096867,-92.977377,-171.730583,-309.045938,-320.903646,-189.818503,-84.495089,-90.385432,-122.713623,-123.195316,-129.024278,-161.182982,-226.536452,-209.116315,-110.29497,-140.96629,-210.465939,-300.355155,-310.077755,-270.531879,-196.141163,-20.554356,33.874301,42.56579,22.945657,-19.023115,-100.010474,-129.190552,-139.290173,-84.572602,130.50649,252.216406,224.594202,81.369746,31.989648,59.923547,110.852868,222.977399,301.016075,308.413241,277.182475,267.12308,242.020124,205.507117,190.34906,248.654141,363.244517,323.046929,271.745199,188.502132,164.320198,125.519729,130.958959,199.423282,190.163907,179.138355,201.194821,181.260112,50.223324,-7.554862,-5.616489,39.879953,110.25945,136.31519,140.863332,105.428145,46.526145,-114.673077,-146.656723,-97.107898,-57.347436,-38.085502,-19.046137,-47.944918,-141.008342,-173.843106,-195.118524,-173.168244,-15.648779,189.338302,221.956485,159.156771,116.858684,53.213704,44.754471,107.111897,171.451261,152.031567,15.992071,-52.758451,-132.26999,-149.718181,-74.665358,23.551486,182.110794,205.547608,175.827944,67.408913,16.099078,-50.705487,-42.950815,70.434601,167.46835,182.218717,152.51086,108.487029,-16.610496,-75.010478,-85.046976,-24.356081,132.436541,224.95285,224.306156,123.97593,56.519689,-11.550376,-0.993605,82.089034,231.240161,298.187485,307.534192,261.165004,163.341387,140.534908,162.770646,183.839051,253.979185,382.37347,393.784657,236.06866,140.914238,96.099342,132.244865,191.395531,215.660548,238.180265,240.810551,201.594704,133.329139,123.882378,142.725822,187.827264,317.973314,355.776722,329.146368,255.696857,231.820024,229.748203,243.389771,225.45454,190.100946,224.021542,256.109887,185.049136,47.820408,66.134734,194.135957,243.814123:26.122039,172.452911,211.787574,137.021923,12.904854,-205.141374,-221.355985,-113.373387,-3.092699,7.672971,-54.824932,-85.834395,-91.645783,-96.162651,-101.566075,-69.991726,-9.666887,-18.989727,-18.392133,-38.967795,-78.391531,-120.707822,-86.956467,19.81935,47.888887,35.628213,8.264151,-2.831407,-10.789994,-6.64244,32.147899,73.262547,153.921623,220.025218,230.758038,132.393251,60.652907,12.725776,30.23526,56.098724,46.697826,49.577997,31.955248,-7.450949,-50.735435,-30.078771,3.263095,-9.355804,-46.347736,-31.376516,-15.532085,-25.823501,-58.912064,-138.158433,-160.29057,-159.518228,-83.519564,-12.949595,100.25018,116.437179,93.601945,66.105949,24.441709,41.260223,133.759157,160.861496,126.782184,31.294974,2.486212,-13.878768,-23.100072,-31.11034,36.974898,73.744362,55.943403,18.885215,-14.060174,-33.664841,-152.08284,-199.653417,-158.701451,-71.39437,-71.443214,-133.539715,-152.840529,-166.111885,-187.826756,-216.01765,-165.670126,-131.213093,-83.172908,-85.0938,-100.24546,-71.819886,85.204532,187.574479,300.729038,217.939494,153.917083,95.576932,95.800011,73.500746,62.866559,110.269778,112.891422,54.862579,-104.086908,-182.709085,-288.525325,-283.471145,-174.20879,-117.847877,-106.944655,-198.30574,-220.797149,-190.106292,-184.460446,-265.302479,-314.661226,-349.503369,-312.278804,-256.326785,-132.768721,-113.498541,-154.865368,-194.281269,-285.919223,-308.669483,-280.525566,-250.967183,-236.159897,-180.474118,-155.173292,-181.954617,-224.445393,-234.911445,-179.842763,-158.308943,-63.081875,3.401573,40.756053,-23.848473,-213.111998,-259.12805,-237.074765,-176.990811,-147.718407,-113.354483,-103.879693,-93.70833,-104.310094,-102.815844,10.555243,74.027043,89.894224,26.156307,-143.309481,-188.18868,-168.899633,-128.613618,-25.433517,54.922432,59.30904,30.868591,33.755813,46.077985,45.187412,107.58988,141.530326,80.416157,-102.020109,-159.785139,-99.671521,-10.527483,51.178535,8.606271,-62.193597,-48.611291,-32.471993,-33.592681,-32.337925,-8.695567,-29.634649,-115.23568,-82.521639,-56.158492,-124.834789,-188.335488,-249.206431,-263.243739,-288.491392,-252.041281,-105.29856,-52.209989,-64.383872,-127.069602,-162.021063,-203.817292,-206.674093,-155.417911,-23.466231,64.465395,210.416751,236.918132,183.173457,123.49187,37.276001,14.211352,-51.494424,-45.815574,-27.094438,-99.210448,-152.935849,-137.240309,-87.397035,-45.097042,-68.027078,-71.658606,-102.121579,-118.94391,-36.875557,41.247832,79.651314,15.047451,-156.879814,-221.802537,-212.542798,-152.212172,-122.702996,-141.600005,-183.717147,-208.687345,-130.623589,-90.256762,-34.262222,-27.318029,-52.736568,-71.288539,-91.009555,-97.705229,-138.654064,-160.076961,-154.989396,-152.229371,-155.491052,-184.679838,-211.37573,-205.435657,-103.396797,-55.718145,-57.828828,-112.983035,-190.495924,-174.987929,-90.40956,-47.790902,-20.336405,-75.925584,-109.799584,-206.373951,-273.810561,-358.88026,-340.987018,-245.096862,-232.074189,-239.226448,-208.784874,-196.571369,-230.432893,-258.746168,-217.389039,-114.505128,118.422102,158.249582,108.293364,27.850062,45.10591,111.173685,119.690456,121.327324,75.889562,28.538843,-22.788832,-18.250294,-5.106818,-10.781224,-11.866962,16.230974,72.370799,11.581962,-41.441427,-87.768837,-68.26132,-22.292153,-24.911264,-21.22191,80.532473,133.088639,124.038781,73.760504,8.777159,20.1071,71.192698,73.892428,49.27845,87.205567,113.171809,18.428332,-94.85518,-238.047135,-243.474132,-231.885595,-253.746847,-259.095434,-230.541417,-219.240068,-214.243818,-206.391485,-187.479197,-171.79146,-70.939416,100.00605,170.955869,218.171026,196.4782,138.587607,140.773502,183.57398,71.260194,-43.22643,-208.008712,-207.678756,-89.24062,-62.333727,-125.340339,-130.520415,-23.843742,90.797909,115.714937,85.218137,41.939127,-52.328433,-87.214138,-79.267126,-22.071349,-22.844504,-56.674485,-57.252754,18.42289,64.236688,44.803688,6.875916,30.717793,82.84706,67.857211,27.136551,25.006814,30.1724,40.247313,103.671427,153.627772,158.569694,156.509408,144.389977,100.867278,93.91601,132.505513,166.162309,235.491494,282.156176,268.238694,110.284995,6.752273,-95.497992,-89.184806,-19.471234,56.178924,68.582648,70.081134,73.731351,100.941293,129.673856,214.925446,258.988266,257.515846,186.081101,181.172154,209.56372,224.056299,246.867027,255.872171,255.597093,229.197427,217.069409,182.534001,156.526951,157.047181,208.230879,374.125757,451.526841:9.328713,117.681473,125.644914,16.883691,-80.403768,-208.376824,-199.923108,-80.74186,45.801281,73.904147,26.255543,-28.04916,-108.409491,-122.414167,-72.126296,-0.447815,121.697209,115.05728,93.469331,37.810439,-5.744711,-65.593436,-47.525221,31.980492,71.804989,87.930904,76.993576,24.16226,-107.990851,-146.627943,-137.933396,-103.511786,-19.177476,43.499137,36.324841,-57.039049,-102.401093,-138.217145,-137.193994,-67.041542,39.630516,49.296463,-37.735265,-93.004483,-134.846203,-124.271871,-70.245148,-36.488553,-19.142061,-22.978882,-4.63762,-11.967451,-54.202995,-123.817864,-114.605423,-31.092641,79.749357,138.762471,209.630936,199.929113,130.486119,97.484171,83.956242,103.469216,121.971721,106.783336,83.94822,-6.558429,-42.241189,-49.486282,-28.908905,55.658341,114.752639,94.05356,-19.910742,-80.983556,-161.206037,-177.776993,-168.251429,-140.944722,-68.525914,-37.52562,-47.683743,-91.226901,-103.40065,-105.9541,-113.076813,-142.443608,-133.683496,-101.171516,-28.526908,-22.124454,-100.043893,-151.806577,-100.131173,20.659412,221.60128,173.126034,98.57023,-17.060585,-40.619686,-57.118558,-58.07419,-13.633653,85.220738,123.084353,80.188138,-0.470818,-174.593074,-233.172774,-254.506595,-220.183367,-129.173847,-65.554495,-75.114536,-192.200418,-245.365565,-257.254164,-233.11356,-178.462563,-130.795541,-93.381978,-51.467913,-72.344472,-134.184718,-164.130422,-221.105147,-213.882892,-88.876985,-19.566242,-65.82535,-196.734655,-220.693001,-214.727217,-211.261435,-181.944365,-131.41803,-98.89653,-17.696941,-8.06644,-105.921298,-180.366897,-257.551276,-233.650278,-110.450867,-17.474711,-25.580748,-155.171133,-210.221113,-187.830993,-139.525252,-20.94768,107.011155,137.941277,84.330331,12.489057,-139.461818,-189.577832,-176.991627,-115.786124,20.107018,88.027887,80.896302,-18.43055,-60.57353,-34.338613,8.370286,51.890202,31.153624,18.348203,-28.470144,-68.375495,-124.755168,-132.497914,-125.409857,-99.985827,-13.483834,18.047175,-10.595839,-84.026887,-98.544911,-121.785486,-149.630407,-182.165067,-116.453781,-87.737026,-195.282629,-307.941266,-425.624602,-408.655458,-340.067108,-311.963872,-252.596181,-182.492558,-165.055831,-180.977707,-191.600201,-192.847578,-178.643044,-112.964607,-3.419362,83.446056,251.195747,281.080136,230.45622,171.609257,30.55908,-24.455028,-61.377009,-34.420307,-23.992908,-101.267644,-182.117791,-255.901569,-218.408585,-105.670358,-26.667983,16.014623,62.840594,24.627588,-98.205661,-119.293815,-107.018288,-113.608503,-128.667888,-86.297492,-91.857831,-231.514229,-317.654343,-373.62432,-334.887966,-210.014155,-118.650481,-104.645514,-152.433068,-174.094563,-125.691739,-93.106539,-95.791374,-109.369519,-106.389864,-93.122223,-115.984125,-206.272996,-232.069293,-241.576679,-232.901835,-128.075277,-10.558787,-16.820384,-123.892572,-176.52546,-207.702891,-200.223793,-167.669605,-138.94574,-118.856689,-146.04935,-170.229863,-245.974677,-266.416537,-248.101677,-220.661037,-127.414754,-35.600453,2.756621,28.431018,-15.892836,-157.636254,-200.600831,-162.386563,-84.151631,102.829025,184.064137,163.954505,69.448838,28.739992,10.114134,49.492306,183.805767,226.398702,194.290777,143.798823,143.881991,92.490258,37.98238,36.789352,104.437721,211.838378,207.154405,182.307666,103.929764,48.340924,-66.967175,-87.717889,-9.582719,112.188586,147.778413,144.508333,109.328633,-18.952244,-80.556458,-44.156177,47.95511,184.133179,191.839841,173.655684,59.299489,-29.797312,-142.143351,-142.631939,-96.300118,-50.978662,-32.796798,-17.422036,-40.096008,-116.176271,-142.443105,-164.481314,-128.568806,82.763097,300.412021,350.996421,320.461021,261.91337,194.657893,221.541829,302.58708,239.976189,167.247681,36.628118,-12.101789,-74.94658,-90.122913,-71.926509,-19.926059,150.942073,274.760506,269.467954,132.326672,54.918926,-7.662121,8.702021,59.970594,70.228017,78.037566,77.188795,48.381792,-12.56503,-20.020819,-26.275703,-23.405566,54.10965,158.590158,170.853777,108.734806,64.506875,-3.881654,-15.029125,61.666724,200.341447,237.279367,236.680923,216.549737,150.567549,120.436933,147.242839,209.768642,317.929803,311.937409,278.762233,140.139544,49.43136,-42.110669,-17.854217,95.18273,162.09524,162.306474,113.051307,87.012853,96.580225,119.796851,178.848163,226.935954,281.847214,219.790456,186.289886,177.33703,200.566289,240.651633,240.263438,233.895095,243.746234,233.963979,119.091882,37.879421,31.159681,105.331478,228.88488,264.214625:199.665456,129.478855,135.181994,124.138333,83.906747,-52.006613,-125.686675,-207.676073,-206.616306,-189.886487,-147.25139,-126.186509,-98.150576,-100.972316,-146.832334,-196.540374,-307.307187,-308.343936,-275.153916,-222.934829,-218.995542,-262.563157,-294.869312,-305.07478,-262.833037,-227.190933,-122.557865,-89.11903,-81.08663,-70.557705,26.829194,104.18689,217.92567,255.304541,277.894427,270.54541,222.562508,166.282354,188.063494,265.574436,328.745511,349.186353,360.14742,353.02983,319.40442,302.985833,281.494355,278.200058,302.406594,267.199308,193.427542,38.468307,0.693906,-57.050793,-117.358672,-272.361515,-295.211494,-220.793667,-31.114448,17.097903,-3.660129,-31.216811,-6.192836,34.372101,69.799073,62.642922,53.857309,7.235138,-16.486404,-41.108418,-58.935273,-127.765887,-147.552663,-118.076895,-57.607618,-40.695768,-28.395192,-72.244301,-265.799149,-327.17481,-258.198342,-90.150779,-47.151249,-48.073291,-53.147057,-91.953867,-141.301711,-211.95105,-155.102354,-120.800974,-143.524322,-182.164167,-168.01375,-94.152301,130.392384,233.977019,254.277698,95.018261,45.833539,23.817345,31.921407,80.078264,115.979312,178.094053,104.032724,19.278958,-73.638598,-66.986764,-66.696175,-86.0206,-57.238172,-10.217004,-19.150876,-174.104671,-237.805643,-292.204145,-297.453623,-299.463706,-297.451717,-274.266279,-245.805233,-227.982286,-174.015918,-137.985209,-65.721705,-60.635618,-173.301333,-253.002457,-324.28188,-305.967804,-296.976225,-278.372674,-269.281583,-280.057163,-291.462839,-290.657805,-212.286083,-121.772207,51.856223,62.531043,-48.111893,-111.747637,-195.195645,-213.035861,-248.810814,-264.33856,-221.424419,-106.508876,-92.253876,-168.837661,-216.174521,-209.504056,-100.985814,-38.456443,55.887959,52.357287,-51.464912,-104.203817,-123.836662,-85.187006,25.903813,98.420754,115.221942,131.583171,142.923422,139.175206,125.839466,150.623494,174.335042,155.660618,109.313943,91.334043,60.440306,33.51279,-47.348808,-52.354029,40.327428,68.869768,29.87067,-59.803085,-59.494835,30.91204,54.431539,17.73113,-30.872103,-57.558542,-92.755743,-80.285525,-9.466992,11.977927,-18.77912,-36.803879,-26.821301,7.148243,30.936436,77.823954,96.7748,90.828484,55.622124,33.064955,150.73432,232.069879,414.333021,474.583581,433.57344,368.630231,314.184398,314.042791,237.001937,134.082289,124.89592,165.205079,200.625813,240.310081,207.738031,70.25444,43.237746,104.100312,255.076207,299.464717,353.396348,379.56905,359.418076,299.811376,178.043272,114.814581,84.078115,37.259386,41.571312,48.359922,39.930434,90.210021,129.746367,87.01019,-9.594222,-16.109488,24.729714,22.029738,-86.082459,-127.2849,-88.318946,-31.817511,-14.840668,7.475276,18.79234,57.878305,64.766781,13.541352,-69.668877,-95.059256,-121.393371,-142.098092,-192.760793,-210.306702,-205.092931,-161.047447,-26.062769,-35.952967,-104.394178,-228.947237,-252.685955,-295.202251,-340.700873,-393.262623,-370.753337,-358.056619,-332.778571,-336.119726,-382.346431,-380.091294,-245.733763,-145.918354,-28.968951,8.038206,25.826545,-2.233845,-24.16352,2.779757,26.91407,38.270004,38.998082,48.791988,57.609959,53.365233,60.025602,58.87861,16.331831,-9.194301,-90.484256,-234.545392,-278.378288,-266.219641,-234.652323,-206.444604,-231.22045,-270.391063,-175.39903,-118.890909,-109.980363,-124.482787,-69.518044,-29.017831,14.149753,31.154904,-0.269068,-47.907639,-33.978255,-65.873469,-133.307905,-290.194882,-362.083383,-427.048224,-325.822768,-284.196725,-332.951,-359.700919,-288.068112,-240.63316,-240.606843,-255.193989,-176.840969,43.037304,141.414765,212.705562,207.36509,203.592939,204.008158,180.950791,67.153966,-25.26404,-163.676914,-177.502173,-126.738837,-101.809878,-100.919755,-97.050104,-32.841485,64.29621,91.250212,28.78015,-38.680789,-137.487593,-151.542452,-116.492752,-97.290199,-107.399703,-121.214382,-138.910558,-199.339714,-212.27106,-203.610065,-205.212504,-194.44111,-136.778725,-134.736268,-237.231076,-283.31377,-248.002228,-214.02354,-234.423096,-254.305802,-206.411838,-41.33092,6.208833,-46.95204,-99.931196,-124.021726,-94.429451,-41.920324,-45.727549,-51.852576,-91.561729,-127.369664,-226.359768,-285.8537,-312.127548,-198.546774,-169.936432,-248.445397,-317.858008,-366.443393,-328.758504,-213.914099,-182.123713,-246.682706,-322.319776,-291.708752,-205.55254,-206.065141,-244.907218,-242.339521,-183.377026,-126.77397,-123.661998,-123.443554,-113.348684,-49.897003,7.938976,124.94658,172.916797:35.571817,79.527048,83.369519,63.94296,51.416048,-7.779693,-60.606783,-152.855843,-169.454344,-130.272031,-29.718203,-31.3044,-89.526448,-91.81378,-46.532759,-39.756796,-115.103663,-146.52005,-120.406645,-120.807878,-161.634495,-212.626769,-198.155074,-148.399581,-97.178307,-48.047661,41.963956,32.931058,-76.265767,-123.496081,-85.503,6.873752,213.375561,312.974319,310.454446,176.387671,72.075911,-72.413064,-87.590617,-15.453094,77.318305,90.626001,74.955109,65.194679,52.441907,43.72995,8.813356,-15.765492,-58.175801,-67.06195,-83.806388,-176.147493,-214.153228,-221.494362,-209.274187,-193.113789,-196.361225,-181.340203,-80.712545,-22.053587,16.473318,2.120481,34.585957,101.238337,204.510624,163.720119,115.842352,51.314265,60.754992,123.566041,129.160826,42.28145,-71.433823,-81.086598,-41.724364,-42.155414,-99.379353,-156.02628,-309.238119,-344.951908,-277.759008,-186.663287,-164.796482,-164.580266,-172.19142,-197.55655,-226.971698,-268.725166,-197.475386,-136.215299,-77.468418,-100.585886,-186.631682,-184.433195,24.609563,164.483993,241.094047,143.623981,135.862302,176.717885,196.61957,190.5851,157.804866,152.235516,186.441491,143.598732,10.25847,-31.107282,-79.950558,-98.31648,-66.977369,-21.020848,-18.230931,-181.341385,-241.581746,-218.51782,-171.620423,-122.778335,-139.433185,-223.394333,-247.631435,-221.555615,-165.003634,-156.007746,-170.025034,-198.966489,-323.422539,-388.768465,-442.853421,-354.692402,-279.700699,-217.111733,-240.161703,-298.859495,-302.575188,-239.924696,-164.318072,-133.27027,-24.326758,46.526363,89.113068,26.496512,-166.927165,-232.428783,-261.055504,-220.573902,-213.979498,-236.168012,-232.4876,-178.316209,-149.739229,-98.87266,-72.27331,-58.486239,5.061025,5.318137,-107.069819,-151.005392,-111.558461,-56.546129,30.190929,63.78014,65.103425,54.908472,71.537186,122.091662,127.547978,152.325098,193.607848,179.24522,79.385839,37.206731,50.710003,73.877507,23.117919,-39.535191,-96.494402,-28.436623,7.115551,42.710506,57.511661,55.928533,24.347028,-49.994958,-65.405999,-49.121851,-2.189333,-3.386452,-69.937532,-98.93235,-106.672156,-94.959099,-67.914096,-42.737744,-31.216483,-8.154627,-6.441567,-63.794659,-95.44714,-71.587319,5.024394,33.704249,105.016506,149.10707,175.887742,142.35152,65.936862,52.85263,32.101917,11.594778,17.903474,53.360331,67.554944,18.112984,-41.25197,-108.769137,-58.358053,-16.634648,28.415471,18.786046,-13.202422,-16.421585,9.956528,33.106418,49.296396,11.118164,-8.892159,-6.921352,11.557685,7.774399,-30.337145,-76.520043,-38.12234,-31.451466,-39.025439,-44.459311,-86.911369,-128.770107,-202.19255,-209.334997,-187.202787,-139.393543,-121.391852,-127.238951,-133.286884,-171.010445,-202.676575,-184.155346,-110.619569,-102.580029,-153.625889,-193.320027,-223.396277,-219.774374,-205.034969,-168.71568,-68.730738,-65.130438,-98.261357,-179.892368,-223.455951,-328.27103,-367.938269,-370.816184,-375.358107,-390.28397,-404.301822,-408.873229,-406.085557,-395.555638,-342.693253,-269.946163,-32.121366,132.921763,137.446559,82.433182,88.276919,94.902139,40.028755,-49.375642,13.283472,48.269569,73.225726,74.638438,63.10336,45.884273,16.164699,21.53418,17.066734,-40.001859,-63.615214,-115.679265,-127.251115,-107.299091,-118.868291,-171.139379,-90.697184,3.448438,121.377753,108.963633,66.212633,71.554392,72.688547,53.841746,5.970535,-0.232027,11.20332,-38.411041,-103.230125,-245.187791,-305.345744,-359.313238,-324.766986,-291.769919,-235.653675,-231.936796,-242.434701,-253.55406,-300.471791,-290.687876,-158.944337,2.302471,80.845126,186.232615,186.816326,130.673604,105.430215,73.178597,-0.274863,-45.216207,-106.029242,-129.140113,-168.128846,-164.486915,-77.633028,-14.656913,71.130216,99.96472,82.74939,-14.395923,-55.583144,-109.68898,-147.436649,-176.660967,-82.325923,-54.923315,-80.678894,-79.49512,12.845322,51.660092,28.720676,10.251366,5.643176,-3.095411,-14.725275,-94.323285,-146.097457,-193.080977,-180.676006,-92.883234,-3.881849,7.980203,-12.937956,-32.057024,-80.122752,-96.905788,-54.365368,-3.896197,35.480108,16.156,12.571399,-40.075679,-93.745839,-245.157404,-322.145949,-338.301646,-221.994082,-209.097869,-300.574981,-332.429355,-264.320408,-221.7184,-157.099665,-85.995586,26.987118,-29.377506,-53.680818,-19.103649,5.84052,-10.33764,-35.489587,-20.938958,71.413717,110.684446,108.337905,82.384394,95.119045,140.713282,254.173268,313.879702:206.121627,223.200702,225.717941,175.646978,73.413374,-146.224465,-153.871482,-6.073135,29.560701,-2.468542,-10.656678,7.268148,-10.940835,-31.008482,-25.457511,-15.104516,-36.591447,-81.148012,-85.64324,-95.631696,-126.068489,-165.172289,-134.802941,-14.44555,52.619455,38.39922,-46.848014,-81.560954,-99.907334,-100.09755,-95.656864,-72.206666,3.123135,55.254779,56.597675,-9.040817,-31.849557,36.871256,90.264937,133.200583,154.953372,180.278334,195.449396,167.356313,97.943012,89.585303,126.900884,156.188978,193.074512,153.34168,116.905916,11.010592,-62.707304,-153.431526,-144.533626,-82.568816,-9.592867,24.697796,25.227091,8.505718,48.926828,84.121067,94.477775,98.524653,116.061022,19.518746,-45.234627,-98.546001,-95.115838,-55.733106,-13.952888,46.424709,-12.265596,-36.226404,-10.888607,8.356549,-4.167286,-43.407181,-126.835124,-138.968924,-103.318505,-61.314272,-54.673717,-19.579807,14.843462,-4.171963,-63.681411,-131.189216,-130.509156,-125.745515,-46.397984,16.423738,53.954623,19.803105,8.256186,59.360768,124.185396,99.99524,102.165786,86.80402,58.084261,76.640832,124.870168,138.534342,26.708614,-14.144694,-58.630866,-84.704361,-122.785311,-133.414625,-121.12975,-80.478931,-10.490796,-94.169246,-166.764394,-242.329802,-240.57971,-229.125386,-243.060681,-301.308623,-298.265627,-228.151844,-52.592722,-26.391255,-52.15554,-70.957665,-184.399001,-259.754017,-285.599391,-176.411065,-154.372693,-189.765298,-194.625943,-175.383901,-189.067748,-219.451007,-171.574847,-139.698795,-94.22316,-87.931554,-135.660233,-175.857678,-221.42137,-231.93794,-245.13577,-158.02314,-103.712628,-119.948193,-160.91322,-177.688149,-176.940583,-189.041443,-43.651517,53.637101,66.290171,-21.806517,-195.110311,-216.716509,-133.215456,-59.088804,50.406789,79.342483,98.819021,114.421737,95.374984,47.453506,42.850292,77.445373,89.080705,77.599894,26.933365,-10.56636,-33.416732,-5.88209,18.73458,8.144774,-12.727551,-84.568142,-122.170907,-78.811864,-11.997129,26.689879,-15.97725,-65.683757,-38.37485,-40.118246,-123.534889,-185.868544,-229.255561,-205.24717,-163.47446,-141.54876,-48.902279,11.323044,-0.011271,-33.332227,-2.112443,117.663095,147.857583,110.889258,103.524889,178.548435,399.859465,443.574399,318.226427,231.792866,191.418298,212.254703,182.427533,103.664997,102.925856,163.620646,192.260989,160.490163,95.971047,18.551891,111.99138,169.963481,205.816734,182.203826,103.683768,60.863702,8.744165,12.336907,-8.896588,-62.793953,-63.989082,-109.747682,-151.841785,-156.107045,-128.732624,-74.678537,-32.398701,-29.044896,-53.015194,-53.819216,-5.698615,2.443612,-59.801381,-90.173204,-100.254218,-39.152674,-7.427185,-43.062644,-86.013855,-132.912331,-136.749997,-57.478238,22.877808,-2.596577,-96.890056,-112.595017,-106.538049,-130.325962,-186.563165,-158.762543,-58.261434,-123.192901,-186.670844,-253.817479,-256.942641,-257.389275,-264.572849,-247.986517,-197.661565,-180.986861,-152.109089,-138.976486,-150.779465,-185.96521,-240.75353,-195.476212,7.062164,73.278701,47.907102,2.983381,2.531741,19.532006,35.080962,92.8609,91.522197,61.1002,36.491726,51.556057,75.426576,50.725404,-58.506113,-78.365459,-4.373041,8.155253,-45.634028,-190.62832,-229.286228,-229.7391,-230.728469,-228.422115,-107.788523,-39.204783,-8.571389,-29.491416,-84.893313,-100.584385,-62.497645,-25.869146,-5.535392,-23.584768,-6.804615,-8.42396,-57.425923,-161.968513,-185.965546,-198.450903,-210.173394,-195.766006,-138.51321,-135.695178,-186.168134,-204.336898,-161.960996,-83.57267,114.298482,206.158984,239.506247,281.05019,262.823493,200.667318,184.917254,180.920123,113.559909,45.023093,-57.15204,-71.27483,-91.796992,-109.233961,-98.495545,-57.42465,26.472108,73.787241,96.68533,78.459304,31.827191,-50.233248,-74.557132,-118.90797,-181.706187,-193.011752,-147.060029,-143.748072,-193.979962,-190.303748,-134.746921,-107.275282,-36.250886,-41.37116,-96.290823,-179.266178,-160.251478,-70.508758,-45.356355,-54.212568,-84.75134,-60.003584,71.488158,116.495568,100.914429,62.20865,5.686762,24.822749,71.938177,8.039186,-29.867585,-98.791904,-118.360677,-105.372016,-97.388593,-72.814025,-19.550282,-12.430408,-57.067524,-97.370875,-114.750427,-65.772649,60.285184,98.877893,86.798843,-10.501439,-48.349722,-25.594181,36.875396,154.018065,147.412159,31.999241,-30.222364,-14.361249,30.372067,12.541317,-19.073729,37.409603,238.561925,306.158049:forward
321.640105,388.811543,423.553994,430.878301,394.285316,349.649238,366.360104,393.993805,409.968219,434.930412,472.452615,449.017709,297.510355,216.607587,128.627234,106.437849,59.146839,7.11836,9.085677,83.402096,129.349518,191.748685,181.200235,77.086213,29.466434,55.387393,176.675787,236.769652,251.692506,205.987384,77.223794,36.417095,48.782632,59.690964,69.661627,156.525741,196.944945,170.986153,100.99865,6.790291,121.075144,202.168453,277.505174,245.504495,106.695655,66.525244,35.929286,17.457171,43.883182,106.980389,101.420091,61.26615,28.16673,-112.880723,-190.19953,-202.682891,-34.557223,30.36814,7.350896,-53.917803,-116.992447,-99.574776,-75.941299,-78.044522,-14.665892,101.643652,137.104283,160.872108,162.833864,124.21925,72.556998,-56.715838,-83.060286,-39.015092,16.022575,-19.965643,-126.013393,-141.813632,-155.446589,-168.345794,-99.108803,50.874511,96.500102,66.527887,4.606807,-84.933473,-100.27227,-170.26048,-253.990494,-249.033885,-136.978566,-68.935733,-46.272825,-110.427571,-302.936124,-381.03863,-398.040609,-268.725837,-216.469913,-228.049757,-276.909626,-351.506872,-352.461442,-252.748925,-112.704492,-98.391667,-140.82871,-142.02219,-105.548179,-100.576538,-158.606327,-197.188086,-188.300611,-86.994135,-21.037913,108.137918,144.382342,176.08103,189.791418,178.322204,90.189354,59.361495,119.182735,190.338043,309.980383,330.064059,248.622897,183.989922,171.291695,272.361099,300.195071,282.795963,245.968097,158.208928,134.932565,106.787306,67.184503,92.878099,265.290712,351.270777,395.850282,357.144938,237.794736,203.218244,219.186888,217.65853,199.512745,187.000809,203.54946,261.563591,267.33939,239.954437,275.702184,314.928503,406.702292,437.252616,363.15446,277.328046,133.560329,86.614597,51.767617,81.693474,112.502695,168.008159,167.933829,119.600208,102.575207,131.654759,214.11367,283.019853,491.046083,559.285247,486.363469,411.975358,342.736011,303.691773,159.556033,137.234472,196.140226,260.509932,202.69285,3.86323,-62.864776,-123.051129,-141.90742,-101.766964,63.960272,102.674281,-12.762053,-90.682142,-149.366323,-146.116078,-95.73604,-55.708257,-67.144001,-152.630434,-211.19076,-302.456958,-324.118294,-299.315108,-283.528537,-310.915812,-279.654549,-196.513382,-57.8032,-54.159574,-148.962258,-201.667184,-197.153871,-65.07001,-0.80853,51.858357,34.179845,-38.666291,-82.430234,-167.332327,-179.682042,-149.247928,-49.795093,-18.355496,-46.965654,-77.019388,-121.543605,-150.660563,-209.129709,-172.588154,-122.000187,-66.901806,-84.744914,-164.280639,-202.237216,-258.914205,-249.564951,-224.474112,-207.066741,-226.663235,-329.837291,-377.915963,-331.821204,-243.019178,-65.045174,-12.091016,-22.361939,-53.247156,-75.048982,-171.600779,-254.239115,-393.435833,-324.729257,-241.025959,-132.812038,-129.405525,-225.208999,-281.725961,-271.806664,-226.256582,-196.382617,-232.620168,-211.163215,-81.3923,-43.901974,-96.066772,-144.959672,-163.433474,-76.980783,-49.626502,-7.515269,18.609056,-16.18791,-85.347251,-216.311846,-236.478648,-195.230908,-146.404187,-124.400694,-92.968869,-102.449936,-195.475317,-267.629507,-354.230029,-225.430565,-108.333277,80.135922,110.360173,44.603304,-1.561336,-44.538287,-47.254993,-11.590649,-4.913752,-30.003935,-48.579074,-26.255323,9.924579,-6.270232,-65.878998,-67.986778,-42.481725,63.122335,112.239123,128.400308,122.493644,109.558785,77.802076,-3.496985,-20.772336,-11.044583,17.869414,26.013624,-10.276481,-50.111402,-53.612352,67.295272,115.806736,164.390553,185.325922,168.96237,101.063697,-83.154311,-140.389006,-118.731179,12.410644,98.05351,246.450184,268.747606,227.835207,190.882382,90.5238,-0.291827,-25.468918,-40.928823,-55.00491,-121.237562,-144.990374,-193.039045,-248.039762,-311.952017,-197.981846,-123.36372,-67.751121,-90.955147,-145.332197,-176.023523,-254.9446,-244.833182,-212.158363,-145.392935,-120.433623,-109.538353,-104.928337,-72.532745,-66.099077,-59.065742,29.961048,92.514587,99.885203,37.573353,-15.188244,24.151302,131.165274,182.334306,181.424086,190.769297,198.23004,169.05589,142.816928,90.000551,73.949908,98.973507,135.935244,146.569302,158.067423,164.347991,179.798772,161.179432,81.023716,98.543953,148.871535,232.409547,243.104663,231.495945,222.744692,130.14443,49.633847,-14.291602,69.597628,111.952342,159.69513,162.532272,102.774871,61.588558,40.160772,41.542212,24.923748,35.11243,76.441308,133.990664,129.516159,87.181956,56.823515:267.049992,244.599657,284.618911,423.735444,441.691817,337.906198,274.619525,226.155556,249.534106,282.219061,420.690772,483.873933,438.177263,332.681881,110.67756,48.334685,20.413494,15.069684,17.3594,49.477967,65.540379,82.754801,94.292566,93.939344,21.175624,-7.274013,20.014141,79.746258,197.909232,183.922708,16.324963,-44.164127,-8.204692,132.186089,204.105953,251.884106,207.620987,68.587229,28.355813,55.358145,107.695227,108.116059,77.529517,52.316411,-2.568562,-34.738709,-137.170361,-170.679268,-102.052137,-4.22804,-6.452239,-68.738288,-89.023695,-121.165316,-162.430747,-211.914896,-86.421072,-11.555173,30.208415,-10.977946,-102.946243,-96.068898,-38.473453,-18.453431,62.784487,155.127659,184.002668,207.226713,193.12835,98.506423,23.790127,-72.266013,-0.273401,52.535302,57.032717,-0.388066,-133.216528,-170.622031,-210.037899,-212.108657,-122.970625,18.873222,65.238773,68.368624,16.654429,-135.911441,-186.702962,-219.902089,-244.892598,-250.884566,-206.291948,-167.047007,-134.672992,-158.824227,-255.336148,-301.340255,-333.743912,-274.250989,-232.060479,-202.604932,-221.747371,-272.135298,-291.555679,-285.124783,-190.737244,-131.969765,-34.445206,-10.454601,-21.323918,-40.902547,-108.629398,-145.372711,-118.488005,53.392966,132.441778,153.18521,116.45258,89.180174,111.222596,167.231473,156.836774,126.414912,115.242184,138.450169,132.209545,92.484817,29.602628,25.215078,34.114482,87.048914,142.066846,211.475352,189.081545,95.227788,71.051152,73.615881,95.891465,123.941907,203.862102,224.695993,190.775642,164.034019,155.839008,166.661762,195.317252,261.345468,274.968179,197.728709,164.846619,210.337961,225.289848,167.532421,159.843745,205.551625,330.476252,355.26801,265.20353,185.498798,53.532739,12.260909,7.713483,154.134829,258.008288,343.934709,299.924784,159.459621,118.215368,151.997568,253.158808,316.360069,513.987712,596.838539,572.036459,482.759049,289.467896,218.201776,172.375288,248.933986,300.301458,294.395372,213.171384,26.646147,-34.319837,-91.839678,-56.374841,-1.989963,155.582885,215.366197,176.698162,97.37072,-64.535571,-114.168237,-92.813535,-81.926307,-129.871938,-226.273432,-245.118113,-257.990108,-289.980532,-425.930225,-516.118317,-500.865209,-404.970828,-368.605316,-286.829688,-244.369918,-268.920967,-313.6072,-300.535636,-158.535825,-125.540616,-175.009851,-197.843242,-204.350744,-211.082209,-256.742421,-341.043372,-341.292656,-167.392745,-48.909035,21.812157,-50.428796,-282.867292,-360.725033,-297.20899,-95.827063,-41.096256,-44.112296,-64.250165,-135.23132,-194.757989,-264.860663,-250.691658,-256.459791,-273.334785,-261.135465,-222.495665,-250.189938,-409.619281,-422.367337,-194.36195,2.511118,21.129175,-33.664856,-84.259832,-260.701805,-385.456301,-482.701051,-253.220358,-131.794003,-47.541017,-72.246502,-168.565047,-208.045213,-222.302121,-194.151133,-128.216603,-137.123824,-139.49571,-83.631885,-61.924627,-107.121721,-163.353918,-229.53153,-153.806196,-99.138936,-2.691447,18.789729,-71.26963,-158.131651,-263.160934,-259.514627,-212.625677,-145.885328,-108.714505,-98.759284,-129.247506,-231.977136,-291.83206,-321.475793,-172.413242,-86.582478,20.038727,41.518796,-19.052182,-90.009463,-166.453473,-147.027709,-65.234712,-57.032882,-79.217142,-104.692928,-105.103905,-104.785233,-107.881922,-77.373754,31.997601,79.959592,94.823852,70.894623,58.923373,80.982227,97.868727,95.277435,139.694405,213.608706,210.758084,113.483256,58.73715,-25.534885,-60.33089,-47.442093,107.090652,181.602999,231.537322,218.519574,169.988195,121.973623,-38.037758,-114.146844,-155.166608,-20.953086,68.943119,162.347954,167.05436,173.991166,166.896036,71.652225,-25.101609,-23.432171,24.298328,27.831999,7.70655,-2.92747,-71.96749,-120.047453,-136.585436,-48.719328,-3.482375,17.045107,-6.415581,-63.228224,-86.843016,-111.822824,-93.192772,-67.816569,21.847448,57.406092,10.964177,-51.426863,-142.742592,-157.580894,-105.884805,69.003679,140.127003,88.80489,11.078139,-20.808343,27.376727,106.109422,89.242937,81.437702,121.688151,138.800809,98.525527,47.553846,-60.996532,-76.438126,18.176502,138.88843,171.338158,157.712159,116.974361,50.673484,41.441839,65.512425,152.149245,198.330792,250.847028,256.732776,247.037707,224.982473,145.100963,142.365802,236.730306,239.980459,219.914778,196.068915,161.616048,42.02982,-16.063038,-71.090315,-30.314692,5.356304,91.046119,135.642274,162.018285,142.464936,95.380315,82.006269:179.228265,264.760235,264.612476,213.198954,180.480034,127.47406,118.440011,166.767604,211.876612,206.04699,251.154739,299.73232,289.819727,212.644642,40.156593,4.015907,21.137697,14.732179,-1.238034,8.575108,35.728577,45.587993,6.782521,-87.062782,-86.624008,-56.403793,-10.734357,-10.755331,-33.0692,-45.222012,-71.195956,-80.341528,-66.78349,5.812904,66.491643,167.553439,160.632227,69.791978,40.325096,39.554526,22.610988,-1.437113,-24.539222,-28.690226,-87.823213,-149.146808,-227.842665,-195.681683,-34.030682,86.17581,88.053492,-16.607004,-82.562264,-193.322638,-239.196289,-262.803177,-138.86301,-58.633506,4.300253,-18.836402,-89.469454,-98.341987,-49.279161,-3.252195,118.007509,185.497962,169.083632,100.743706,102.935776,141.195342,109.541179,-27.719108,-25.111595,40.99996,147.605546,129.676073,-12.676798,-63.706807,-62.044709,-51.91028,-51.235141,12.025736,66.777737,113.302214,60.856946,-117.022618,-160.557122,-136.755485,-148.05154,-161.893624,-120.824544,-84.590827,-69.320227,-108.937944,-231.460327,-265.55102,-276.573556,-234.273024,-177.761726,-113.791907,-138.222561,-222.158025,-240.968149,-201.600568,-104.897451,-54.363379,17.03807,24.695358,-27.459367,-77.509715,-171.163153,-180.020239,-75.697195,96.155708,160.549487,196.040097,165.513368,71.900723,31.810649,-26.923373,-28.301466,13.124446,126.989807,149.352228,99.632418,51.70406,-38.306561,-56.733007,-24.851672,66.224693,132.090752,214.068026,186.65811,68.406277,40.46347,82.345143,168.967199,201.672655,241.996225,244.7385,188.605738,144.242101,79.816309,80.601156,173.625514,298.939543,322.987123,274.141388,231.968713,181.671183,172.735759,160.001774,85.015606,50.518883,158.403125,265.563846,293.691077,184.968068,-21.747388,-35.134327,32.465156,120.46357,186.168377,260.299455,237.870331,146.948006,100.330047,60.438529,139.59112,202.996768,349.015459,394.685639,365.81033,315.607882,187.688629,134.906153,155.178504,213.082733,209.874162,167.192395,124.997973,16.971944,-35.627421,-90.218048,-22.762393,32.098172,124.641041,155.907299,163.911377,118.136951,-68.81443,-147.725544,-146.253668,-71.859509,-71.686168,-88.814134,-97.854396,-211.967866,-293.704485,-352.195298,-334.65984,-348.699244,-372.619089,-362.17195,-313.383183,-281.275498,-244.584405,-243.806617,-209.409152,-132.062685,-100.827976,-97.237923,-125.731484,-213.340118,-253.854783,-269.520584,-222.173876,-193.602515,-119.266626,-85.393277,-101.401199,-144.46626,-185.395513,-177.323716,-168.342257,-125.980679,-82.590996,-44.868532,-54.958818,-92.858791,-134.188268,-226.394766,-222.370594,-209.215681,-212.061715,-216.163909,-214.3179,-221.484394,-268.424847,-260.317879,-96.365389,76.618832,100.669367,52.327139,14.714005,-96.463877,-192.903585,-341.977922,-207.582179,-85.079482,23.05085,-16.869461,-163.032025,-213.494432,-208.036881,-159.967903,-52.480779,-4.511238,3.807066,-11.708231,-49.3126,-149.684176,-179.076733,-141.063073,-51.671035,-47.631437,-53.281906,-35.699108,-79.018077,-150.721778,-244.803329,-236.596447,-184.324205,-106.929325,-54.060084,-41.522055,-96.021487,-188.862053,-205.886145,-214.833753,-168.378168,-108.835324,49.330434,93.014277,35.832523,-20.081455,-46.379227,-22.110294,22.495649,34.180061,28.531639,9.326944,-0.309055,-84.196456,-161.939328,-197.347743,25.780049,128.639037,157.33433,111.582297,72.836542,106.937203,163.333061,162.998574,185.845249,288.430544,327.59307,275.123298,195.770289,36.271597,-7.042882,17.636547,115.260323,155.662973,176.296088,160.61674,138.142627,128.404249,48.693266,-0.766635,-18.232792,77.090732,136.224959,201.76563,209.818206,197.28045,167.216436,82.978145,23.411698,-1.371854,-42.575794,-50.695827,-41.603023,-40.562706,-102.174019,-154.822533,-175.438745,-36.425315,24.216439,-3.884463,-66.440658,-141.915235,-135.974483,-114.68536,-135.358233,-125.317231,-61.340438,-40.471803,-50.622942,-73.00451,-93.506067,-65.016167,-5.296772,-17.562221,12.84038,131.930749,150.156719,69.092874,25.027053,75.404884,241.226942,282.111853,259.786802,221.819495,117.355088,67.501717,-2.926736,-24.036436,15.882253,129.435977,164.315348,153.014302,121.876295,47.554031,13.941343,24.26199,140.704012,197.919087,287.767538,313.77646,303.412993,281.186105,272.314233,294.49393,316.00812,252.773584,221.788262,183.232144,151.520608,33.103463,-30.191531,-47.008558,72.847417,116.695171,144.356289,164.023448,235.454536,250.732336,192.606406,160.050437:107.859001,156.009927,203.144429,329.802449,352.10199,296.764236,270.651772,278.058224,272.396879,259.16506,296.510382,337.32787,339.949161,297.766353,163.007571,78.172254,-26.934526,46.847397,98.353916,90.011351,51.957487,3.456702,-15.550359,-50.213353,-35.328869,-17.29498,41.870126,92.629336,181.997509,176.948099,53.93866,-5.230875,-4.325268,64.19331,84.609353,83.601968,78.571252,90.779252,85.048527,48.332351,41.494353,50.145464,92.54435,100.981384,37.020501,-11.117467,-91.07543,-109.738516,-46.75772,74.008851,98.617022,26.492217,-48.333877,-170.125783,-198.578023,-196.46819,-86.312029,-3.166068,91.935222,77.951521,15.679949,5.167342,-8.848019,-13.733054,46.653665,141.341444,161.072074,163.800595,173.952538,174.059078,133.997388,52.663375,90.802766,114.745945,106.666234,92.975276,39.530701,-9.402375,-98.277217,-115.221119,-70.393488,68.721134,130.342387,121.033743,68.646307,12.341491,-6.372144,-114.033796,-211.148406,-221.270686,-167.706239,-111.015121,-18.042453,-32.719275,-174.547728,-238.911096,-255.520034,-189.848349,-171.368344,-190.298615,-208.396783,-233.615969,-254.339953,-261.769436,-105.253951,-15.079935,65.489042,72.601078,59.106607,20.374581,-117.291114,-160.165155,-108.330299,38.708536,111.586935,179.950318,160.583891,102.780289,93.787387,62.993521,-19.12028,-30.525097,80.06664,144.32358,140.251971,94.439964,29.728742,21.498895,26.281642,68.68447,124.372934,237.778541,250.78262,197.164055,167.076213,167.066879,230.009917,272.755264,357.453043,370.705943,320.622457,273.655017,164.812211,144.067334,251.342865,359.889154,350.746731,293.100034,272.349803,220.559717,183.46455,172.33449,247.842652,269.227512,295.533584,303.942545,196.37811,84.22357,-66.93971,-68.965358,-15.048321,59.381862,115.907814,181.588542,148.839244,26.582111,-6.870261,28.985554,143.292881,209.135367,368.70681,439.488847,431.998933,347.100149,142.593576,75.76593,46.994122,111.631564,151.099326,118.803019,43.071858,-93.076073,-133.415187,-209.836638,-212.281499,-145.05747,41.147802,87.031028,34.920131,-25.396765,-160.266717,-219.251768,-237.39403,-151.618616,-119.800712,-153.647293,-230.257327,-416.337253,-458.174069,-413.194502,-359.695672,-345.376475,-261.108812,-188.252052,-84.096207,-91.231108,-197.37579,-239.951546,-188.020515,-55.404079,-24.316508,-46.521219,-84.681539,-185.56599,-234.132014,-294.245902,-263.536872,-221.050549,-107.100018,-57.306302,-64.166401,-109.05709,-173.285186,-185.006109,-169.946795,-35.03902,53.929283,96.826855,34.570102,-101.9837,-130.865452,-152.917814,-165.749756,-160.132728,-161.807055,-181.462028,-234.994725,-259.216854,-274.646473,-236.047163,-77.836462,5.740214,6.921827,-5.536466,-16.253014,-89.170553,-169.258767,-320.062929,-262.586014,-187.057718,-125.47535,-152.15571,-227.582447,-248.419974,-240.739437,-225.880149,-212.134788,-227.911877,-218.777721,-157.050146,-140.250019,-156.469364,-174.56793,-212.701024,-235.429288,-236.321934,-164.173559,-117.963289,-156.325721,-226.663294,-307.49169,-275.893576,-146.801166,-81.506557,-67.466262,-74.621324,-100.42046,-173.412841,-216.803455,-248.029369,-158.490984,-103.796681,-8.428313,21.398687,17.02683,-7.649629,-80.329494,-97.727473,-17.825366,44.733054,32.219449,16.695234,12.978081,-72.811707,-150.4858,-226.357885,-94.986667,-3.076886,125.313789,137.952617,96.586514,98.374216,114.637622,87.147192,37.811222,42.945868,39.606918,9.725317,-7.765059,-28.568201,-26.908723,-11.081202,19.009159,48.352973,97.665103,107.352044,119.960184,120.600929,79.967649,42.869076,-3.285835,33.354929,82.770994,193.887844,217.183513,145.629011,59.604472,-89.413947,-91.772911,-70.409684,-50.165039,-57.662614,-96.211889,-115.810717,-166.667498,-211.104864,-293.976389,-256.864628,-196.389653,-127.043376,-142.413274,-188.747042,-178.8431,-87.367836,-74.374505,-120.471306,-162.48289,-139.318056,-126.10363,-146.086461,-146.60369,-116.756243,-32.275422,93.418703,154.843032,169.891884,133.441513,111.37946,138.884635,235.984828,341.435248,354.7214,312.066369,283.327366,233.557914,218.845289,204.517941,183.599787,135.922319,221.298684,295.146472,296.483026,220.979752,122.562462,126.654751,162.496164,214.858181,235.155309,230.682708,231.880615,293.030595,323.466235,310.709718,288.424748,259.375106,233.890573,233.236991,232.433321,195.285971,58.713906,15.16183,33.648196,78.260964,84.786752,123.852578,165.820451,219.4488,223.744358,210.796208,188.892421:-1.805009,108.512264,132.141715,152.630334,137.43489,63.061233,38.604726,55.761691,99.202996,125.979503,215.715452,256.900483,254.380684,203.964239,40.876408,-26.115484,-34.273601,74.759533,124.021661,105.817711,37.561968,-103.23586,-153.558877,-220.081688,-167.987152,-77.323081,117.782499,150.295133,18.27437,-104.710427,-257.337428,-233.530399,-94.582031,7.480453,66.066605,179.804935,179.421406,56.546054,-2.705125,-13.798448,18.521784,31.436932,97.657223,104.709301,-3.419941,-64.648496,-121.769231,-130.763575,-93.083271,40.062216,86.230292,43.007148,-13.41857,-150.587012,-225.947954,-274.580309,-150.201519,-59.75472,73.492563,68.841913,-45.095494,-90.783994,-103.523998,-68.818737,40.70217,98.994697,113.264034,154.639688,174.959822,117.561449,37.033325,-64.835127,47.958658,143.656327,266.988895,269.440524,159.42866,69.024585,-71.984875,-81.278608,22.08435,169.01699,208.091936,188.317484,148.371527,19.630184,-73.848431,-187.92605,-144.776453,-125.710243,-72.656412,-11.113463,61.961317,18.447647,-120.03565,-135.831363,-100.659962,-126.645409,-122.892221,-62.527957,-58.14404,-115.923556,-141.528163,-119.747528,-6.259534,70.621028,211.632611,220.059319,84.30892,-2.533861,-108.430841,-111.999179,-23.791381,157.070315,242.911843,239.970364,161.708974,60.735355,56.072302,53.235476,80.224355,122.116216,180.479377,151.440488,40.219573,8.735671,-7.382898,0.327075,60.470554,146.994653,179.383523,190.283916,184.053054,143.99568,100.185854,91.631577,268.15615,347.896385,370.345245,322.937986,200.327022,158.79414,133.539804,156.98824,274.850256,373.445497,387.381635,345.437406,296.920158,219.618174,200.578508,156.942238,144.298257,179.754413,308.77661,348.086795,264.230877,157.579607,-37.531423,-71.364557,14.655395,188.024016,256.086307,268.593209,208.065067,55.475013,9.696202,36.700285,157.334865,218.804912,325.669105,350.810429,274.71886,176.002073,-12.453635,-44.586548,-11.614511,65.193954,119.848081,143.949983,77.815689,-111.952764,-167.194877,-167.858581,-126.252212,-89.807578,6.472148,31.062461,-2.742329,-54.200913,-191.70969,-233.675688,-184.301612,-74.086456,-53.225339,-82.911738,-127.04146,-270.979874,-335.356852,-312.612344,-176.189292,-149.609108,-149.072298,-132.068078,-55.601089,-43.588696,-156.346076,-227.985561,-208.993095,-37.797431,22.341661,23.079103,-37.716029,-236.248209,-322.006236,-342.787967,-202.25176,-123.258658,-29.174285,-35.373066,-103.569239,-125.403135,-122.468041,-108.793087,-58.708632,55.397976,116.41197,137.48892,82.472793,-104.72214,-188.029514,-186.245324,-27.563111,2.660222,-42.464485,-53.124118,-56.822164,-90.86242,-170.891516,-159.79941,-6.629929,169.817402,205.009539,162.697793,112.816987,-36.821439,-140.694167,-235.979679,-75.528698,10.557809,73.630706,45.795665,-110.977436,-190.680204,-234.08344,-203.084444,-102.893806,-8.017179,22.358761,20.957746,-14.694145,-151.468339,-220.707992,-263.03763,-179.493636,-119.554523,-35.575779,-39.999594,-147.450279,-224.381022,-310.074917,-279.26737,-124.660815,49.601963,114.661535,70.365,-8.97161,-105.810787,-139.761561,-201.613715,-139.397221,-59.151484,120.089714,159.851871,75.55647,-4.470088,-114.564133,-116.839642,-13.539059,105.594317,125.806288,112.047732,98.169376,-2.802809,-74.997948,-74.761216,107.308935,177.023744,185.907164,148.870657,73.566502,37.458848,-26.268387,-14.766075,118.163854,223.814029,227.45406,131.527641,56.064641,-32.035536,-33.951855,4.891404,69.926942,121.817214,229.828877,226.210098,105.531535,50.659176,6.980767,8.435695,31.048931,95.677557,160.136559,254.274065,228.426758,58.876845,-19.809303,-81.03951,-62.043739,-44.505223,-41.715103,-68.945992,-130.265862,-137.757137,-166.577715,-220.699208,-299.532426,-204.726639,-150.552283,-183.422418,-229.408887,-228.626765,-196.038051,-144.626659,-123.903545,-104.156249,-43.639523,-30.395916,-72.772653,-114.223517,-147.44082,-111.401619,18.291324,85.628429,98.270201,132.369834,128.74183,33.681185,-0.059659,116.767572,303.75181,344.1252,374.519195,367.096202,232.305717,132.561348,29.732898,46.961707,149.673076,254.171012,278.322999,201.065332,121.162007,35.620467,43.342822,97.367271,162.938207,198.18906,280.955031,312.243051,330.22221,320.074143,262.985528,229.562279,211.614441,281.883369,315.523247,265.763624,180.186826,17.491396,-14.11781,15.488804,108.241014,162.990203,247.924136,266.751369,232.393883,176.301553,79.592568,73.873229:71.250704,78.672968,83.734609,142.203363,188.035704,243.333264,233.560654,167.870437,164.969343,184.450533,226.715601,251.650461,237.584527,193.860972,114.244787,91.462695,70.217666,88.354632,124.632413,196.083684,185.229063,86.602864,44.771056,4.043271,-14.470226,-5.421689,115.883024,215.969564,315.098235,278.394666,132.764182,89.366796,132.115857,167.758813,148.464803,137.716497,132.865684,46.7198,-8.815728,-12.696475,119.391674,178.492134,261.857243,289.772364,252.336512,185.863447,64.094107,53.336459,123.135744,164.606488,168.809576,154.832371,110.665544,-20.661236,-66.629616,-90.144959,-27.703151,29.779035,106.820045,78.964281,-58.666049,-101.130142,-105.725809,-89.743236,-27.342939,97.856389,168.598183,230.251906,215.423296,129.370845,77.466121,3.63092,-10.613049,15.432391,93.516586,89.031031,-32.506725,-92.614757,-146.021903,-148.200096,-41.342211,218.267351,330.580479,349.561562,258.35616,105.295124,97.813896,45.261009,-143.046726,-177.833144,-7.840047,101.266552,106.653919,28.474059,-135.287866,-199.39489,-235.315351,-134.534768,-59.140469,-21.620038,-86.377008,-202.775529,-213.065873,-194.268312,-139.979141,-96.004024,-35.690746,-40.507842,-48.230238,-20.093819,14.045027,-14.923449,-89.495139,-41.592329,24.638614,131.805503,142.123551,100.340839,74.195113,19.18938,-19.267503,3.904876,111.302321,145.205032,144.434999,124.167143,67.482405,66.054601,169.703513,246.100561,222.877436,158.373662,165.276097,231.314103,241.303233,196.63301,209.390609,245.129063,341.981339,382.160889,382.870213,351.737569,261.91042,215.395042,184.394123,222.834716,248.07619,263.085816,236.662331,197.999332,208.967905,223.227263,239.218934,265.644617,337.18709,355.169334,243.708362,139.540412,3.171355,-22.168005,-24.930158,76.63039,127.92365,60.090491,-30.268448,-104.371541,-72.01407,23.800956,89.283762,143.264216,345.749838,424.120915,327.538326,198.648158,51.258124,32.672699,-42.706342,-66.403979,-15.489367,18.558689,-61.666296,-270.059629,-323.736258,-317.339347,-209.557994,-136.90419,11.572648,66.116115,56.449361,-19.364333,-230.756797,-292.318816,-227.11832,-78.585862,-46.335628,-81.383939,-118.158822,-198.932926,-235.453823,-231.923556,-154.486007,-110.768369,42.076383,133.610642,172.491578,92.134276,-134.225236,-196.730868,-131.760556,33.111625,87.076433,106.118125,76.823942,-6.750311,-39.37021,-67.470331,-36.140618,-15.811481,-10.636343,-17.448777,-1.287968,28.081995,47.801597,-3.039505,-138.728667,-60.99916,39.213727,118.610022,83.197103,26.05496,12.465468,-67.038439,-73.711417,-20.816228,58.755368,40.918266,-87.216135,-137.826703,-103.373616,-53.376874,6.028035,32.774176,23.594083,10.787553,35.09952,35.564312,-42.465477,-259.243895,-294.40514,-232.855828,-79.383293,-54.985748,-142.545683,-180.515413,-153.515322,-133.082586,-152.462819,-160.466192,-116.137813,20.919736,51.882764,-37.431834,-109.795374,-119.386173,45.347025,99.608587,87.276391,52.877079,-55.96784,-112.817006,-173.626948,-177.647676,-151.554609,-132.618389,-110.338546,-41.723136,-45.389942,-163.961808,-237.103687,-301.643546,-237.543331,-163.296664,57.502938,140.458615,118.222778,53.646432,-9.442946,11.202216,73.189774,91.586672,72.804018,10.348244,6.561618,43.371165,30.70546,-59.283576,-36.671797,25.203648,134.586725,149.493475,101.131289,75.366482,71.563627,67.293564,28.199367,-13.023958,-17.038899,8.914386,1.651398,-67.675193,-71.054471,5.060568,8.538975,7.125315,111.478826,170.651012,123.855758,29.55579,-101.818508,-93.980681,21.653899,119.129082,127.670584,106.136825,101.730586,116.217621,104.096378,16.409206,-37.085871,-42.980806,-53.331981,-72.358185,-133.765325,-155.889196,-199.193161,-232.497446,-306.151798,-355.365198,-337.834927,-252.996726,-239.539563,-241.559816,-225.380329,-212.521876,-185.221361,-143.767869,-125.783996,-164.448541,-201.791378,-164.714429,-47.966955,3.32812,91.864028,136.229918,149.187437,163.489971,152.471454,104.740474,76.017305,60.325083,154.689706,231.069866,376.842374,403.971457,310.190531,231.079318,136.947743,120.255977,115.769955,173.950261,230.660647,275.211182,220.011823,53.548565,-2.887846,-27.740135,33.142852,77.305674,161.285412,187.199837,208.915929,205.062497,117.416328,50.299243,-6.722502,36.854849,70.845509,154.015004,172.769596,95.659249,22.508032,-48.709766,25.442097,74.635096,182.864176,230.210294,228.151816,192.469378,106.332374,56.754533:44.160395,95.741504,89.18932,128.31067,154.474589,137.283076,103.321259,72.25354,121.151261,172.526386,299.556328,328.703597,273.189772,221.535633,91.538201,11.389222,-73.660045,17.585061,99.932898,199.349496,173.572565,15.428368,-68.82945,-128.479706,-47.870395,-11.139365,80.202658,156.901094,227.730314,164.820029,-41.992987,-78.667997,67.015534,206.686085,201.53504,143.296168,121.191813,66.58234,25.869305,-31.141491,-12.698435,24.75379,162.774547,215.605402,146.939377,57.421536,-49.858983,-45.646399,21.861601,111.215359,147.131397,110.013746,36.048574,-109.837153,-155.458544,-203.717065,-152.652963,-58.033632,151.874957,178.036136,59.776412,-11.054487,-68.776051,-57.628017,-6.396905,78.254666,137.275607,173.525417,130.77586,15.726231,-22.656983,-24.42435,86.107403,156.363412,238.201989,225.060741,75.62835,-30.257798,-149.528536,-120.17946,69.19013,279.676419,339.157893,285.126206,189.914096,16.397386,-31.679128,-84.432634,-57.300246,-0.637978,143.70557,193.806723,166.41101,88.917029,-85.505734,-122.619844,-81.29665,-16.128212,16.09584,60.519819,46.845784,-49.025816,-106.703475,-141.947336,1.325582,103.874604,240.550869,232.351315,103.915473,40.419119,-75.04465,-118.386427,-58.403863,140.139788,231.330985,298.069413,257.491506,101.314225,29.972178,3.659933,131.667428,196.741641,259.052371,246.608966,143.495072,85.949171,47.601309,63.12404,96.408746,128.419977,160.845982,208.319744,197.885206,137.332802,110.513455,131.468424,252.01055,310.475299,401.121042,420.76333,343.259892,268.072366,152.885861,135.491895,210.58926,366.411045,417.570585,372.206067,286.467962,144.029217,122.581442,137.517847,177.996671,215.195962,333.207339,346.448692,159.082509,37.529565,-50.873294,-26.542742,63.220428,159.263075,202.949251,219.339666,159.535642,-29.484988,-90.591013,-81.48076,72.539678,182.532166,370.899589,406.10173,340.92397,269.057458,96.221706,10.638687,-50.943202,64.232937,103.755813,3.46215,-92.033746,-210.555344,-238.924251,-264.548361,-205.643573,-140.780597,27.177624,72.106996,-32.572793,-147.591557,-321.511353,-332.648154,-197.181535,-13.197395,28.742837,-1.233879,-54.65914,-208.200358,-279.221636,-292.488015,-167.280561,-115.293309,-13.783434,57.451475,104.964231,21.505958,-228.83925,-286.961156,-191.60736,-2.948239,65.94834,117.180439,103.551146,-33.709318,-161.69533,-330.260452,-162.982216,-37.070031,78.85845,68.511339,-19.888358,-72.75436,-140.5711,-145.120535,-67.899644,125.111687,202.590902,175.395775,99.040145,0.719681,-1.797376,13.399466,42.303998,67.54851,117.766261,114.710547,-13.438538,-100.612877,-171.681219,-137.304542,30.003272,203.428639,257.761794,282.509763,237.700957,16.22622,-104.311431,-172.238099,-68.687901,-21.869681,50.14425,67.67139,8.552982,-59.831696,-176.794908,-179.528874,-60.494039,82.906436,140.535597,213.079388,198.894861,28.629612,-90.602082,-201.108207,-71.570326,11.04163,86.687609,65.61327,-42.138095,-91.836733,-136.298949,-120.295222,-25.513314,91.741891,138.86137,144.622999,86.973075,-98.759488,-186.289236,-231.963744,-108.015369,-44.814658,70.883474,121.987647,84.814951,-13.133571,-159.107137,-124.186955,104.134637,226.24754,199.1058,66.046691,1.445398,-75.903014,-102.897444,-143.727534,-70.350546,6.358255,137.836012,147.223633,28.034819,-48.170125,-136.791289,-146.050408,-60.293707,92.696047,121.923906,62.825883,8.939735,-91.259593,-123.27311,-138.964376,-106.606531,-63.168117,68.322711,116.158974,78.341986,10.262652,-73.627025,-65.440265,7.412679,126.689509,163.632782,119.466793,78.845722,3.52886,-71.217112,-221.702089,-175.990317,-114.234569,-52.162624,-75.157809,-200.176975,-263.53588,-345.581824,-362.174395,-327.837382,-256.503115,-219.875668,-204.070059,-252.809046,-364.346107,-363.843942,-260.409212,-154.57605,-103.63142,-23.689746,-37.472993,-158.906107,-206.520239,-194.968311,-147.963378,-39.354662,47.852023,94.743818,135.069827,88.642756,-49.611513,-72.762846,17.553594,215.531699,306.530158,398.537991,381.682523,247.998706,153.025158,-46.691674,-93.381357,26.912369,274.156437,351.300829,259.606959,129.700576,-34.131283,-57.686346,-85.096908,-14.147397,61.804578,207.925643,250.248183,255.561411,226.687567,128.520711,75.889525,49.334474,175.39445,238.209698,251.365805,223.862658,101.60553,-8.102484,-140.920669,14.796265,128.86761,292.39056,310.562774,171.786415,69.959195,-41.008759,-39.444028:-259.870906,-233.289805,-192.969031,-105.84677,-44.205104,147.57635,205.226153,105.183613,37.690933,82.538205,147.893142,119.039112,15.770086,-7.62485,-12.03076,-14.864357,0.350442,70.279065,130.312942,285.579918,340.495551,334.147862,270.872356,80.448083,17.589615,57.393119,189.581398,256.381519,297.461229,264.932487,184.674388,156.156232,120.796979,88.968359,87.054623,176.522909,231.175985,226.411385,186.001843,147.433233,235.859854,306.824181,386.209391,384.369738,353.452561,332.975015,261.83692,230.037293,263.768235,361.417575,383.602383,348.314704,298.652948,184.506081,114.998056,-29.795857,-16.890836,22.184705,24.527908,-4.641807,-54.123442,-63.084516,-109.96194,-153.354306,-153.381188,-48.44125,-10.541553,-4.025982,-30.735995,-133.188011,-188.550829,-187.899451,-36.082278,15.872565,-17.098979,-75.911189,-168.283448,-177.32756,-173.664531,-174.829508,-60.089187,125.369302,149.867301,127.132365,131.269171,185.765774,209.911497,151.205549,-28.837737,-67.274732,106.35175,248.705734,325.256133,233.271894,27.332057,-8.400444,21.851005,82.668862,115.217493,150.515597,136.950659,56.540072,10.641448,-26.015585,56.061127,90.365275,46.408539,-5.893939,-100.124977,-126.03783,-120.287002,-93.042915,-15.742389,4.436321,-5.641581,-13.000575,-4.405825,41.868654,71.569012,140.700055,191.363005,177.002529,124.113514,133.655042,198.720687,212.831477,194.085974,186.321955,227.417741,294.025761,305.035552,284.024069,265.086871,242.149942,216.056339,109.23425,113.272757,159.73425,198.952607,182.446066,167.889502,174.590011,114.120167,50.981948,17.457298,112.410234,135.16468,64.054402,10.951365,0.159433,21.440294,14.882403,38.474038,99.452249,216.595411,218.522433,146.659306,102.282777,-17.665068,-58.040717,-26.151857,-20.783205,-39.263951,7.353492,47.290027,50.506499,33.4708,6.765124,-10.256502,6.652237,130.872799,188.974314,165.596493,122.26585,30.126238,-51.414322,-213.155154,-183.299814,-139.854117,-171.292414,-226.372202,-322.277192,-360.335492,-343.867004,-182.613256,-104.938411,43.889508,109.670314,110.178878,45.908288,-95.362851,-128.366829,-78.322881,68.742008,151.896659,247.448915,226.185739,99.757577,53.469606,80.269739,173.903141,214.197163,303.763269,335.551533,314.741009,265.892405,103.255406,40.641682,127.274563,273.291035,273.171675,233.307445,237.173002,271.747195,260.527011,146.774028,103.460842,138.547065,205.517534,201.072196,75.895608,-12.372531,-112.271878,-127.693302,-137.369592,-22.883026,83.105548,202.439277,176.339688,73.356434,32.5791,-43.709928,-25.643258,34.894231,162.657613,183.02048,120.691494,84.184893,45.940512,26.987343,5.400256,22.460873,56.454074,164.774983,186.125561,113.466123,54.774853,-2.388528,53.179007,101.202743,148.96183,122.950872,67.965397,82.387192,114.567909,118.582117,173.524244,211.62668,219.162147,280.481013,302.912795,258.285523,205.598147,121.563984,155.75486,191.193745,214.273437,204.099408,149.310808,102.071826,9.796551,-11.774871,-19.252046,-88.180521,-124.653688,-78.478606,-23.470278,-22.71428,-90.02335,-234.329951,-258.114742,-222.151289,-107.001287,-58.953436,-21.733502,-20.325411,-23.325998,-20.179032,-10.804413,-28.06563,-28.786875,37.777591,90.306694,127.806566,78.393427,-107.159151,-178.642497,-153.744128,-65.576154,-13.099982,62.049779,46.559117,-82.012126,-137.626001,-152.775197,-77.850927,-31.940131,12.406971,4.397155,-6.886126,5.225147,-9.271111,-68.77364,-64.447111,43.545165,108.501633,91.879626,7.310206,-114.162413,-99.186781,12.756893,58.189874,44.902517,6.01185,10.152161,74.081055,94.668806,54.190918,-29.872023,-61.558255,-107.853829,-135.3007,-184.812634,-189.754173,-208.297286,-237.134335,-250.598599,-213.687885,-208.539579,-194.104137,-168.383391,-123.627207,-125.574727,-116.287253,-39.417192,-20.242631,-37.278846,-41.585563,-37.976358,-41.864716,-42.211544,-17.244919,91.748097,139.361963,118.317659,74.22955,51.64069,-25.175764,-51.04236,-21.376357,111.472052,172.7005,226.211632,244.404793,223.069421,155.063794,2.419885,-37.646339,-68.949169,-52.639313,-25.964691,-35.778729,-77.332187,-124.133677,-126.904146,-151.279748,-134.415217,-104.911051,-46.450593,-10.188813,42.897061,23.194576,-102.481939,-151.160434,-103.375179,13.990012,63.182752,152.471767,161.601133,56.386874,-48.852135,-246.062735,-187.6836,-71.105542,109.398336,126.010088,93.776419,87.944215,54.585796,-6.650334:95.857523,95.595005,82.401255,114.926678,161.77114,258.364013,284.571768,300.994762,337.236885,343.273082,313.454692,285.92127,176.926964,108.176749,22.872033,9.032885,20.470963,110.821365,179.211954,287.772532,296.99895,226.319242,168.936976,104.958865,165.334122,189.255603,165.824368,161.056154,213.961566,215.790544,95.31165,39.985498,42.609919,31.970744,13.039967,68.788616,138.963764,190.142727,130.370589,20.920883,129.91119,223.72148,372.055223,397.735221,299.502874,199.425314,29.672114,18.321069,148.09442,249.822783,256.1212,218.331068,179.127105,80.420585,16.942968,-117.847987,-100.217745,-24.248483,91.262973,69.78881,-82.767679,-135.277615,-154.510872,-157.236198,-119.87868,-8.418829,32.391224,50.183956,42.434951,14.805114,-31.157819,-155.000898,-105.262792,-38.596498,-44.665526,-125.747223,-244.993252,-222.526752,-145.622257,-157.253714,-149.241363,39.618811,144.545134,230.24453,201.150793,98.407861,58.518974,13.186892,-4.324624,-22.327967,-3.052984,63.546952,135.359233,61.229311,-184.168864,-242.230449,-176.006627,-65.722743,-27.895804,2.976484,-19.04019,-116.708404,-160.814154,-190.856117,-209.409134,-239.243412,-257.70643,-212.429687,-69.068624,-20.528296,-54.550035,-111.898375,-152.152467,-115.698281,-87.63124,14.161507,71.178444,132.197739,132.197629,116.286681,129.30086,143.758024,176.858151,204.641199,271.129081,288.067891,257.527505,227.816971,229.873575,290.235947,304.58435,255.739744,197.327529,113.300506,104.200363,66.811223,-1.622815,-4.284504,98.63897,176.789489,249.188582,219.944546,106.509698,66.832038,54.780639,56.810517,44.680008,-8.564326,-29.727423,28.362205,83.362025,131.311244,170.114843,198.691724,225.333074,219.421138,196.825383,189.910561,140.458169,78.242482,-46.483834,-12.566498,55.838021,124.588213,82.056217,-56.077817,-89.867332,-79.400089,-18.288479,48.466286,264.977861,341.610078,300.474564,236.415745,131.966413,86.425169,18.215422,-31.596645,-45.726344,-67.212768,-115.265883,-281.115525,-347.062223,-389.218473,-312.137343,-227.459813,-23.341311,45.182879,20.808902,-47.870558,-162.882585,-177.166181,-114.110729,-49.495872,-49.603471,-69.475133,-61.572274,-31.580498,-51.663112,-103.910748,-28.914088,17.841388,94.933978,136.211965,157.305458,113.386292,-28.501847,-63.351211,21.787605,138.743136,155.392445,142.235049,130.834702,100.012525,74.246944,27.454671,47.961268,75.890524,107.435227,81.716916,-61.196821,-115.510027,-87.139395,-55.867542,-93.471383,-185.205686,-174.738774,-32.692872,24.143506,-2.141471,-69.848294,-210.465501,-172.672093,-82.563424,67.056051,71.8454,-50.624584,-124.952004,-179.828225,-157.383242,-77.777684,-51.867853,-55.963225,-24.930688,5.166258,11.538567,-45.926159,-253.452851,-266.029757,-148.495042,77.323539,86.29562,-64.867207,-134.686226,-148.141137,-106.154524,8.646136,49.829185,46.320419,91.782165,139.723387,230.334316,244.281475,178.189983,136.7239,162.251499,254.780332,272.122205,128.611971,4.073104,-157.631828,-167.21573,-86.910094,-4.030537,6.106785,-19.689115,-35.185568,-84.846075,-142.599433,-245.392157,-174.293197,-99.342634,20.815022,31.019378,-45.923099,-82.701673,-77.93277,-42.360828,14.85609,-62.470589,-113.199588,-59.42716,38.339235,141.442369,80.643962,-138.326988,-168.58225,-97.129942,26.120771,39.63407,59.000828,86.776747,76.190015,27.075169,-28.966107,-30.046709,-31.420381,-27.526851,-24.829619,19.319702,37.177122,-19.867769,-62.339026,-40.207069,63.688333,107.342601,42.424437,-50.739116,-183.310974,-180.337056,-60.649943,19.153406,45.370501,163.162883,211.349805,202.993945,177.507223,175.907277,231.362325,220.315374,74.207628,-16.690761,-120.111272,-136.565269,-210.250677,-255.921034,-224.092668,-118.597423,-96.164268,-63.108387,-31.013606,-4.136372,-47.328087,-155.28103,-126.903031,-93.031669,-50.167859,-17.995489,54.086437,70.403568,86.926754,106.037758,172.675348,227.561895,256.13858,279.167558,239.065823,155.951388,161.919869,209.724904,197.490392,179.139116,175.698877,180.676896,144.680333,109.371976,49.306142,38.805349,75.361191,119.298635,122.96776,61.492302,4.348529,-64.588728,-73.483365,-73.264574,-0.146252,58.293772,164.025955,167.461033,57.962307,18.034671,23.640025,20.082403,-27.568277,-44.304638,-9.464796,103.837307,127.580478,72.590647,19.825194,-60.609843,-41.319707,-7.078451,69.997843,97.800522,79.300077,48.48259,9.449982,-18.207386:-124.164246,-82.697528,-72.897299,-4.806086,54.992619,154.938894,171.853674,110.978324,54.29514,90.98688,226.006776,252.125633,175.008237,108.897118,-8.501071,-25.541309,76.62029,143.112958,132.350879,163.88988,190.813346,160.817268,119.578994,44.841172,-23.378644,-22.209315,134.0296,245.718714,357.609929,340.988739,211.38059,132.86449,50.896302,87.059802,123.836132,188.725794,196.562938,148.320318,109.16335,38.97349,48.466752,109.353639,275.720616,302.257425,166.087946,89.36551,84.515712,112.189908,135.732497,206.703152,267.740469,303.085174,231.844526,22.14227,-45.584969,-74.766655,32.841238,109.990775,163.281717,107.990785,-31.564598,-28.60806,28.536302,-8.07992,-85.208259,60.64788,147.120093,180.83625,131.728385,26.508867,8.417624,15.998624,74.416958,100.393353,56.399511,4.476849,-61.12896,-60.948782,-37.733701,-29.013684,27.169832,172.796131,251.353389,289.358375,239.949685,173.170576,170.198307,73.171266,-36.804635,-8.361547,183.145146,281.379498,307.997504,227.030357,53.747555,21.93783,35.068181,70.762665,101.171526,117.821211,82.525696,22.028319,16.952036,14.677801,49.538955,67.128,61.422121,48.162131,10.122561,-24.068633,-103.77951,-112.486492,-59.429318,19.517818,66.559939,116.711491,97.619793,33.372795,24.911719,60.492216,119.95384,129.616734,100.85266,92.189993,80.876138,69.47062,43.845027,28.811811,72.1485,215.393967,270.481768,284.71131,236.706564,110.827584,85.505421,141.061283,230.974343,252.688506,228.648074,210.112855,226.49162,236.119327,164.353158,110.848939,127.787532,247.026633,268.714044,176.282966,79.47295,-60.053863,-58.631675,4.07693,60.378189,90.929049,117.099582,98.428144,59.901514,65.451148,46.706955,-2.912626,-65.772806,6.954791,47.761963,54.580221,26.665039,-3.738243,4.844583,29.710228,49.683267,60.67981,137.813037,188.517592,174.556416,116.229281,11.51606,-45.099069,-201.328783,-245.315425,-208.100425,-195.819701,-244.946912,-319.79382,-305.37168,-232.6838,-239.624517,-235.050115,-86.217968,-3.096903,-25.268971,-108.792114,-254.619729,-279.475665,-216.559979,-110.447265,-57.519816,25.979839,6.151247,-117.28397,-141.620606,-76.67302,-15.971263,0.581727,89.625216,154.112078,169.212562,92.028571,-133.269718,-203.734851,-153.090074,-24.516069,24.920703,105.368324,97.08966,-25.631104,-72.028452,-46.643496,17.085183,26.87845,20.369586,11.067136,-2.219917,-7.706323,-89.980218,-155.030395,-156.861886,42.284177,132.480406,155.861696,104.50897,6.484931,-15.645165,-31.529594,-2.790635,27.570064,68.838416,65.857597,3.534146,-34.676402,-47.617993,-8.841252,138.948025,248.032522,260.426325,248.81007,223.850898,141.23151,103.924536,82.455289,103.626535,93.893536,83.845488,91.664441,54.367393,24.561323,25.750915,52.600377,113.496238,112.947297,98.733491,119.138752,135.29415,93.868549,34.707676,-50.111278,40.324029,105.403097,160.476834,128.197789,-9.036218,-41.900315,-14.188489,-14.495541,-38.081452,32.694882,72.524199,86.898217,74.937827,28.877162,-37.333556,-263.082467,-343.461099,-264.675432,3.14713,116.203592,170.402589,119.822754,-16.2346,-59.103985,-40.768939,10.060631,27.87857,64.194714,52.511464,-27.056032,-65.227355,-120.936157,-114.097066,-80.919491,-7.445995,9.109878,12.245807,9.3207,-34.781346,-68.25169,-78.068931,1.409664,55.479062,89.462243,60.599644,23.951352,26.306509,17.365606,20.776162,54.215576,177.718094,218.399184,132.375714,21.225793,-141.893562,-113.473119,87.737727,129.242592,81.764148,22.829822,32.260184,37.189063,-10.200571,-119.580864,-92.511437,-70.507562,-107.501772,-149.993206,-247.380333,-288.605046,-297.015429,-272.783447,-197.337673,-146.0217,-147.943709,-140.878673,-139.199336,-216.203698,-267.892893,-263.205347,-155.468967,-111.087295,-37.976714,-11.312596,1.546433,0.722038,9.612018,16.600856,46.779627,80.545813,86.441439,69.656838,50.880184,6.457919,-16.111091,-6.144084,128.249784,184.308729,186.874498,167.325566,135.520648,120.343374,92.778524,78.765855,80.953075,144.830433,175.514216,140.189555,78.150518,-19.219047,-37.739503,-34.670485,-6.42746,19.570374,102.050303,134.88873,131.238336,90.243344,-41.216815,-91.687886,-61.135297,97.830301,171.571257,223.843407,210.701424,146.826138,77.780509,-51.421984,46.295662,148.009881,279.039158,282.237625,182.336517,114.939773,34.121525,18.126718:forward
31.431296,-33.874003,-55.317756,-62.121128,-44.799444,27.842677,66.809203,103.26549,2.977084,-67.025316,-111.044072,-91.179458,-67.198268,-83.698287,-90.572907,-56.934336,-7.396406,14.918408,62.538835,144.486069,110.027977,-61.822453,-115.925827,-109.204788,-90.950696,-88.811748,-56.953955,-22.529286,59.452994,73.569834,40.096007,35.150533,18.287171,-158.141091,-243.583039,-214.206298,-133.800852,3.40115,55.588588,118.049184,86.597744,88.199695,161.147636,183.755657,179.776431,194.940061,293.19883,334.22209,316.612195,237.457685,191.146284,81.078532,55.027712,108.689244,149.516925,209.144365,286.858785,307.845964,235.769607,159.541041,44.947883,31.275037,-17.779967,-68.932589,-92.386524,-50.998648,-30.211745,36.152112,82.45973,176.770094,202.211329,211.590057,225.276672,224.585586,145.194405,77.121319,20.20906,46.492101,106.115008,105.247664,69.12086,114.080983,138.63684,54.525186,-20.937291,-114.198089,-134.957612,-146.892131,-135.887066,-143.60675,-189.842261,-212.250292,-223.579543,-221.050946,-237.427308,-244.603143,-239.539269,-241.089095,-257.818198,-272.128221,-234.792926,-143.210882,-123.67806,-137.774242,-192.575465,-182.052341,-127.635213,-145.12425,-174.154033,-123.889927,2.889339,17.965467,-38.662978,-84.261816,-102.387568,-197.336593,-239.972489,-196.813281,-111.181173,99.852228,189.305425,173.953588,150.824161,166.029873,169.670457,141.628072,136.004138,176.35211,190.63264,138.63621,161.397157,228.453312,225.869113,171.493563,166.648499,258.766847,303.814808,253.99992,104.804494,47.122292,2.979916,15.873781,66.636824,102.520094,205.081717,286.350256,295.036605,217.123201,163.065045,159.932461,202.64505,253.623223,235.918576,255.494998,339.575746,336.085991,256.81501,249.221202,287.106727,269.881463,133.560937,50.278362,44.762879,32.232875,34.599251,93.471197,128.463496,124.520821,75.845146,77.388316,77.758184,61.324552,37.6222,32.243871,71.556948,155.829628,347.669368,292.152385,208.694003,119.009652,122.081558,190.104996,243.914064,345.138605,302.801521,208.019568,31.203499,9.050892,95.087437,161.529547,202.372085,166.513855,73.23356,-12.884618,-69.015993,-151.399082,-163.456987,-259.201748,-346.665804,-358.986321,-196.709289,-157.825739,-143.186911,-140.105677,-156.629737,-171.754017,-162.529892,-130.816305,-41.616732,-30.033622,-81.819242,-111.35483,-24.927741,167.014125,194.964436,168.096439,121.198892,110.69612,109.602983,90.50464,61.731789,63.628787,29.104628,15.84112,58.355897,103.668166,109.090348,10.984948,-91.211938,-211.885621,-177.161858,-26.332021,28.365292,9.564309,-106.162494,-201.347819,-326.769508,-284.765298,-53.427543,30.80774,-22.495772,-218.248783,-290.089026,-336.228965,-311.963594,-274.393237,-298.763358,-326.972217,-254.310562,-224.025374,-247.829993,-300.07336,-368.03889,-356.885096,-290.824184,-251.48991,-215.24208,-273.046122,-320.80438,-423.452592,-440.243353,-337.83764,-264.78331,-230.899917,-332.405038,-352.309725,-259.356003,-200.740712,-169.19682,-206.515285,-301.585379,-285.015071,-152.592256,-153.227761,-208.317865,-349.844058,-405.441516,-387.409175,-330.27551,-250.649472,-265.294196,-278.724927,-271.519825,-263.231939,-247.349759,-230.223995,-175.604519,-156.424084,-181.654391,-216.529435,-230.495876,-305.350826,-320.865196,-198.05738,-106.054688,-42.766014,-170.913314,-243.28144,-344.313694,-390.99355,-431.266705,-408.884511,-339.179975,-285.40546,-134.483052,-37.444137,-24.111821,-44.131573,-47.248156,-21.206412,-17.10162,-17.238047,21.141556,31.937806,5.020728,-23.534526,-123.006214,-194.082958,-241.668912,-181.307897,-47.792586,-38.422049,-63.467289,-159.116577,-201.566526,-218.363112,-210.374941,-116.193063,33.525685,16.013413,-166.704585,-235.184929,-262.762582,-258.823008,-261.082727,-240.35039,-149.067385,-137.536475,-183.615738,-276.328389,-265.653604,-128.249887,-60.338914,-24.975987,-29.113023,-25.203209,-78.039719,-116.798568,-77.046033,-22.301898,-15.695043,-36.160546,5.330289,-5.290346,-67.536967,-176.986693,-185.308156,-94.815111,-11.087777,92.128469,-22.681419,-121.154456,-250.553672,-240.429913,-111.398115,-53.295707,47.707298,120.69628,201.015013,104.054338,48.47353,-13.344436,-41.147521,-116.301945,-125.365253,25.539025,199.243391,171.049151,-32.563233,-104.079612,-114.441025,-80.784835,-4.708807,20.776261,26.393793,-22.378053,-61.154609,-133.525752,-138.30083,-109.545282,-97.592921,-34.900953,50.392438,50.750327,-51.836982,-121.855859,-186.308856,-150.216214,6.179942,63.455684:-15.351162,-88.690525,-94.2669,-18.142599,42.181165,136.365794,158.321157,151.963821,48.862909,-1.63057,1.183455,38.120378,48.511537,15.933753,27.332085,85.606717,157.040334,76.979217,27.610307,-19.873229,-37.32497,-76.670544,-56.983493,68.133891,76.018189,3.298827,-159.499916,-167.410766,-20.986478,29.281847,-11.484687,-23.816038,2.639752,-127.287183,-222.83941,-208.982166,-112.336293,51.500978,109.688062,144.663173,19.846762,-19.706922,47.316675,113.165841,159.715807,137.912131,154.112811,199.88746,198.548079,128.772352,127.934013,143.954714,169.63761,250.923933,253.456806,160.469107,61.126344,17.174632,-36.339568,-12.990059,92.855041,126.764239,94.546175,52.103664,16.336089,-14.049249,-42.052575,-19.455488,54.212969,207.24818,213.623669,113.347537,108.111773,138.809684,96.997684,50.815301,66.213374,89.263172,37.930121,-23.007464,-123.386579,-75.847506,-35.539619,-70.553694,-110.543735,-122.565834,-120.03211,-188.064624,-291.274478,-302.992136,-249.617067,-236.408123,-301.324936,-350.933916,-378.49024,-350.443265,-320.526747,-370.570953,-386.838821,-325.268039,-259.438475,-141.150245,-105.610843,-128.26535,-214.631023,-200.425681,-151.281618,-176.845169,-176.113874,-109.346634,1.516776,-1.763449,-63.931333,-75.068643,-76.173777,-158.895154,-213.599098,-188.109439,-85.534695,150.789996,172.253973,120.704711,64.126958,68.505876,88.809947,108.179781,209.320604,258.184682,166.236784,-30.501344,-21.7345,127.536014,153.350544,65.877512,32.660654,85.281075,81.992386,11.910566,-154.381033,-185.454302,-103.264509,-54.939037,-8.496387,37.315309,145.811001,161.116023,172.410535,212.865982,197.811194,128.922861,126.938093,165.883252,175.103502,203.577438,283.911564,279.065006,227.139901,243.907764,334.723271,328.445661,161.823328,18.346696,-25.88202,-35.061064,25.27515,155.777054,181.593518,196.033735,214.149877,216.47601,128.30132,61.117296,47.109013,84.645473,159.843132,228.61212,372.582069,330.589779,272.930789,205.436818,210.717503,282.742262,317.141486,334.539212,239.217477,143.314564,-5.796866,-18.843727,38.3235,67.914851,58.646565,37.880017,20.263635,-68.639956,-157.270939,-250.486386,-225.203467,-185.916778,-204.856713,-251.199781,-269.805989,-253.388461,-204.667698,-227.429581,-324.875248,-333.239282,-227.59012,-150.724779,-69.51848,-126.254861,-192.860702,-280.643277,-252.959105,-79.490085,17.114182,63.161636,-100.846594,-156.137967,-168.060249,-180.229843,-180.018819,-142.604708,-73.862984,-51.576671,-32.681227,-86.162977,-113.670844,-154.293928,-193.666963,-234.400704,-182.980721,-29.14442,-19.1987,-42.624149,-116.389298,-206.116596,-358.82022,-338.932564,-170.195479,-91.07747,-60.723921,-195.372145,-287.790578,-418.062962,-402.174567,-244.577365,-168.652203,-101.337588,-149.212364,-204.999927,-342.874705,-407.23042,-456.397167,-422.818422,-296.040291,-262.955843,-326.250256,-412.781727,-428.822448,-427.834654,-397.898444,-295.08064,-252.574463,-196.029491,-215.197789,-239.977844,-217.947971,-187.501261,-203.383104,-258.42973,-328.632474,-294.972019,-179.092788,-182.76519,-251.257149,-447.362721,-480.933914,-327.643856,-238.777136,-250.898274,-389.727676,-408.063189,-319.265438,-268.967292,-238.475704,-243.331042,-191.74084,-155.327248,-209.680319,-268.866786,-257.522428,-251.256937,-238.450271,-149.231412,-103.99793,-131.174208,-319.960122,-382.686321,-399.545473,-404.224369,-391.673818,-351.599199,-251.551122,-194.32928,-79.539802,-67.61415,-89.742572,-105.489004,-100.035809,-108.554022,-91.659792,57.482078,107.751168,51.131592,-52.027803,-49.923956,0.2094,-6.814849,-72.900611,-85.511889,-53.507545,-40.04266,-61.021422,-138.430543,-164.580994,-151.249009,-137.705913,-113.989253,-1.037526,31.553639,-97.26249,-194.182602,-250.970568,-218.408738,-101.061068,-38.56453,-4.530258,-46.252911,-63.676669,-106.428497,-118.335313,-33.228506,54.626244,137.806154,98.154907,70.744324,-79.864962,-139.934983,1.940566,92.025317,-12.71485,-90.774065,-2.49249,26.880448,-54.8328,-128.784234,-99.458757,-56.626224,-27.359416,66.200183,0.132001,-72.540726,-128.708732,-116.920178,-103.26292,-92.847727,53.014984,166.808686,235.748631,85.212546,26.250943,-15.620556,-40.433879,-51.468175,24.562293,244.914897,223.73249,106.782839,-108.537382,-132.084172,-62.365424,-32.20437,-17.391415,-13.188795,-12.803182,-26.294858,-38.690199,-103.43048,-142.449858,-155.034193,-111.885262,12.867018,63.271927,58.518105,6.535289,-33.121777,-53.45566,-18.63123,53.248679,59.893439:-50.859728,-90.129027,-53.333569,83.039736,150.424617,213.591674,202.065002,122.580457,69.280845,80.949788,118.66312,128.927935,153.419035,159.271105,198.83579,238.308792,216.422435,75.877968,43.939601,40.986842,37.531066,57.272379,85.13829,104.508843,40.481647,17.276777,-2.243154,-11.606298,-5.798813,-3.286105,49.541214,118.081212,126.217858,-97.386115,-171.409964,-82.75397,2.601507,-8.811254,-45.947873,33.390917,115.745681,108.50296,71.133096,65.16736,141.459383,200.306666,258.671163,264.425925,276.764044,248.891789,194.977033,108.238166,130.105125,252.231565,277.311303,208.162278,107.600622,12.738787,-233.234871,-250.435476,-44.375908,38.267155,69.162444,62.8654,23.673054,-9.101425,-1.642995,51.916276,89.884025,167.224329,192.325821,166.831432,80.29011,78.940357,129.726329,113.585957,8.291522,-23.239333,15.965278,45.662038,-18.203245,-179.66158,-248.821472,-274.721494,-197.509618,-36.57771,-39.21031,-106.165585,-52.155681,-13.929198,-65.27967,-150.182407,-222.840206,-183.101681,-122.787242,-141.376696,-245.418782,-339.865023,-365.238081,-360.793641,-326.150263,-226.697237,-171.431999,-94.519383,-102.445077,-96.384232,-96.2761,-146.403,-234.022042,-208.399292,-85.196749,-52.128265,-64.301881,-38.80132,-2.277787,-5.102516,-49.929236,-97.407616,-47.933883,162.433696,225.330627,153.042274,-36.896224,-81.443349,-34.752386,7.958785,59.630093,70.602261,41.340941,-7.444242,6.043959,73.604767,75.783023,-11.122859,-48.269276,-27.728634,-0.490593,-27.509861,-145.187495,-186.779594,-158.046748,-131.859229,-109.694378,-78.239784,26.318562,80.340297,91.100993,105.118685,93.949191,33.04633,6.933801,32.314913,183.643417,262.291129,244.766446,135.469381,-42.469444,-26.249973,133.073081,197.71862,209.671239,80.525915,-19.491581,-116.429722,-64.608503,105.044586,151.413356,95.176408,-5.856622,34.759292,188.916625,204.458897,168.553431,178.84847,271.486819,344.008265,453.537961,368.10775,294.62624,287.46595,350.836266,441.849432,425.852557,307.352608,204.2544,175.964819,157.653788,168.506987,220.386532,225.634909,143.453108,81.568211,-69.266614,-244.032737,-282.568465,-230.019319,-212.085948,-253.037444,-249.134205,-182.913517,-158.57585,-163.836766,-229.453427,-286.369798,-340.712711,-311.309225,-181.621471,-133.765304,-162.384652,-243.524113,-280.823169,-334.867262,-295.748706,-100.44011,-30.202937,-48.23522,-181.260874,-253.239918,-354.906829,-356.841429,-265.362432,-213.80505,-168.624141,-164.818833,-182.491614,-230.648674,-258.529946,-323.724847,-352.669812,-352.490323,-302.959352,-170.964861,-173.162462,-210.734586,-268.827391,-289.15817,-304.435653,-284.098722,-169.38987,-91.443833,-46.581207,-216.598985,-306.640894,-349.571611,-292.711671,-99.817799,-9.862979,27.984877,-139.844257,-215.782276,-277.701518,-307.406658,-338.365534,-294.730076,-172.086571,-156.046358,-234.285496,-341.45917,-369.198886,-355.192515,-324.278987,-246.3518,-193.142328,-97.21926,-167.234729,-237.786548,-256.579379,-210.071619,-154.269914,-158.933897,-156.830031,-122.724779,-42.892863,-94.610899,-189.453137,-381.779924,-385.245351,-221.930024,-164.218127,-205.490209,-251.263614,-244.851768,-242.893394,-247.596392,-226.413601,-199.46776,-131.715153,-115.688938,-171.042623,-233.587544,-240.483642,-225.926276,-212.269114,-189.305445,-172.18133,-140.467244,-186.166679,-218.015188,-243.510217,-246.313144,-225.578258,-175.710173,-10.058968,48.738374,9.163015,-116.539937,-154.450176,-182.359682,-195.847159,-253.395899,-244.993293,-76.96139,57.154078,68.207821,-23.205801,-97.290522,-94.868393,-25.733248,52.697012,55.135961,40.907085,-7.637145,-36.296857,-93.226978,-122.149822,-143.45011,-151.275191,-228.817252,-166.545263,-61.815498,-19.007728,-97.990923,-175.796557,-147.492275,-74.989144,-29.692127,76.370196,49.922298,-45.311113,-224.638601,-219.821905,-23.529501,81.759841,140.484091,140.472025,148.302473,20.789123,-75.550258,-54.590671,36.447223,111.992502,91.309831,72.472257,25.106564,-43.667363,-159.101283,-138.862284,-0.897345,52.101354,112.998813,109.457586,75.407654,-48.628503,-105.064769,-120.467265,-99.01683,31.382025,141.884806,225.553874,103.331634,34.635742,-125.298681,-164.230326,-17.576194,107.497947,230.265843,165.890415,100.115026,-58.103303,-107.517441,-91.319848,-52.843092,34.211455,74.725228,125.677841,61.104444,-30.83546,-191.65052,-208.45298,-142.764233,-77.514562,18.730319,-24.39629,-18.67778,50.866844,38.765611,-26.011224,-30.512735,4.446771,23.017766:76.902387,-1.8121,4.315237,73.642642,119.054339,177.054589,186.652984,179.179603,83.369588,30.224006,29.428396,83.968622,201.413639,220.982335,226.859796,244.170747,254.199722,185.45282,142.708869,61.136201,27.830704,-2.248116,5.53149,28.186244,-20.81333,-45.627264,-27.318975,7.240975,73.414441,79.633444,68.658108,82.418092,57.783554,-144.701005,-222.205136,-164.733361,-90.466146,-39.700323,-42.496609,-23.630326,-34.206738,-32.564706,18.843448,46.951269,111.493086,154.984009,251.959963,295.224494,335.802776,309.535966,272.997078,172.852004,152.007588,229.380796,276.304258,263.515827,179.848807,137.044801,43.186273,13.615338,37.499437,54.710552,-14.009002,-78.098129,-136.778269,-87.414938,-52.955856,20.078728,71.36335,180.008942,197.820298,139.32429,135.317701,179.160202,223.853919,189.361819,83.761426,61.36457,98.498656,122.684282,112.982023,57.618781,17.667789,-80.54599,-109.366187,-141.950935,-174.139266,-202.914698,-137.993656,-103.419654,-75.785675,-96.975756,-180.318069,-217.407452,-267.465507,-271.631956,-260.861726,-272.188708,-258.500735,-193.055395,-169.069853,-131.175661,-101.218196,-72.277312,-125.041661,-125.732331,-106.495769,-142.302225,-185.86799,-131.523316,38.157109,78.100041,5.88352,-69.668196,-80.828256,-164.2839,-214.011466,-161.335934,-53.632774,142.460904,148.207894,110.791542,73.370146,76.310902,73.228022,56.135146,68.477239,126.985976,195.734586,108.746118,95.635404,159.033198,172.324707,94.977652,59.567553,125.615277,208.159032,192.128711,106.960233,57.984069,-21.392307,-35.937147,1.579698,54.716467,152.532274,148.072864,137.091233,125.700918,119.581023,134.517556,155.631033,205.740892,232.876375,232.194822,207.262843,175.113083,108.894278,109.858576,183.668589,218.285297,195.252271,81.614585,13.063133,-59.284913,-30.040485,55.015417,47.84126,-68.977817,-104.590878,-48.196893,27.103432,17.972785,74.400663,159.289661,295.109036,319.475596,371.380003,381.992017,319.656596,213.821853,242.168725,327.554227,313.767826,260.205825,246.018687,221.519871,141.581665,101.131914,103.338342,154.236176,222.163146,206.225009,99.526445,-32.175403,-86.298456,-174.712025,-205.733443,-224.485488,-215.537014,-199.489183,-202.58453,-188.431268,-153.738849,-166.751271,-206.168334,-210.684217,-208.328713,-197.570224,-137.490114,-72.147252,-78.187712,-120.787959,-100.347672,16.53382,70.345324,90.8813,-13.82509,-54.743157,-66.090985,-68.881496,-71.509681,-62.85347,-47.311618,-36.454111,-31.76135,-65.26791,-72.373325,-127.963017,-192.531011,-254.660825,-204.803891,-54.331502,-75.717912,-143.828156,-228.37832,-228.138821,-235.895538,-239.668211,-131.444559,-26.487249,69.445106,-107.255319,-209.990986,-284.253139,-253.723714,-165.679777,-155.612968,-176.025019,-159.521817,-143.166505,-175.923605,-231.680108,-296.820917,-272.144413,-177.29621,-141.627271,-146.014067,-235.497723,-270.709759,-282.917225,-255.913662,-173.811972,-157.762959,-195.750152,-246.971327,-254.730044,-198.950097,-144.354172,-71.34969,-80.000135,-126.578958,-121.274549,-64.118809,-82.848673,-134.429976,-241.50219,-245.896696,-118.346087,-58.829858,-83.565892,-148.888331,-153.199257,-188.759593,-238.49537,-269.662008,-221.90582,-87.687125,-37.913565,-15.259075,-76.884918,-131.583011,-249.845191,-281.022484,-236.196014,-167.043194,-67.902122,-180.149478,-248.899088,-258.757871,-231.477025,-198.842416,-182.699277,-92.025757,-17.761003,83.269255,48.260576,3.994048,-111.799999,-161.109223,-203.977677,-199.751873,-95.945841,14.177604,5.701995,-62.027839,-70.987279,-22.567151,-5.848228,-35.632588,-49.580488,-30.943174,-26.765102,-59.402858,-167.928044,-194.727597,-143.168888,-118.125687,-153.337816,-143.2727,-110.158552,-112.25053,-138.499368,-135.121134,-111.533996,-90.026221,-83.548883,-65.392142,-79.898623,-121.906006,-222.998691,-214.259934,-69.723056,-0.297312,49.043853,53.256197,34.320383,-106.434763,-174.098131,-109.348443,-7.977651,108.11936,101.938654,45.551775,-57.589814,-129.783186,-215.10923,-189.074624,-39.807257,33.421397,109.257033,66.595504,5.537661,-121.37575,-147.933675,-107.711502,-78.860806,5.14097,90.971467,221.765409,143.983725,55.398685,-118.397113,-137.687658,-0.489024,84.523842,163.253928,137.52402,95.550182,-32.99204,-94.798157,-146.948585,-129.358277,-19.300148,49.364958,87.446345,-39.411358,-115.401021,-220.908227,-248.791983,-251.930436,-202.818542,-53.968463,-22.746894,-27.322534,-2.257981,-12.088055,-86.867321,-105.480785,-70.892717,-31.693681:178.445681,37.373006,-0.411748,25.603417,87.611626,235.738783,290.421708,286.151007,152.411871,107.08152,117.762245,146.222599,177.927668,181.502966,249.698715,308.726854,323.865306,215.095316,160.398922,84.437624,73.642679,75.206135,80.088346,95.045137,38.014301,1.548911,4.536778,35.469183,74.508689,66.980643,78.139922,105.86164,59.437239,-113.092953,-176.982384,-182.69506,-141.231248,-92.077727,-77.179521,33.256016,118.340346,107.631523,86.358178,102.086515,172.246627,213.632253,300.687871,344.670179,358.034608,222.090992,124.069834,32.876791,80.240781,215.629079,235.204521,188.552319,102.861383,34.112971,-160.214493,-220.157634,-168.61217,-109.737251,-14.812123,18.233714,-19.076172,-167.107024,-221.569515,-221.763119,-167.244512,-4.665439,62.283811,90.84188,25.967696,16.649614,51.135631,43.368638,-48.568049,-93.147945,-74.068213,-26.207812,-7.662114,-122.211437,-190.893862,-243.358233,-199.591165,-111.76976,-131.468708,-199.168615,-163.468826,-143.305092,-150.074527,-166.399441,-212.291992,-231.780265,-199.348796,-164.592235,-209.249757,-324.13088,-339.242933,-306.71195,-280.792022,-234.277072,-201.80509,-133.876656,-118.162775,-115.734032,-188.750548,-267.293754,-303.529085,-232.665755,-61.844597,-12.408389,-22.840858,-112.153035,-156.872261,-175.433083,-139.281165,-47.563451,-3.010794,103.632105,131.960898,66.922038,-113.589639,-146.799831,-54.925796,17.916779,104.902955,120.321988,100.703165,4.524602,-34.842125,-41.826478,-29.515975,-28.21644,-19.049406,59.429175,77.559389,28.254985,-109.120053,-145.379136,-99.083157,-51.018243,48.101677,90.848426,73.151126,4.249619,11.798718,43.866224,16.033176,-77.52059,-78.903424,24.931301,160.372551,208.618056,129.880692,6.002804,-118.97197,-76.313406,45.192792,87.850336,145.655003,107.570222,27.537583,-118.218434,-112.465013,-8.826112,19.244921,-17.271466,-41.254052,-26.398847,-13.041627,-8.198609,85.000545,172.630836,315.774096,336.778399,308.815119,252.92183,224.940787,246.425087,299.561621,368.213196,364.754151,330.735227,282.627327,259.489037,203.331095,175.25743,186.737342,210.738455,225.004941,229.711139,184.722449,-19.329134,-110.867324,-168.51724,-178.003659,-182.110099,-133.377815,-4.380137,-46.778922,-112.030159,-199.595933,-225.090616,-269.731691,-261.418907,-142.697352,-84.548828,-77.752749,-96.586427,-86.556557,-60.118672,-39.187286,19.551104,40.736704,42.631165,-3.628036,-52.212939,-205.951969,-266.509208,-236.413043,-167.086843,-52.209217,-33.506249,-90.175106,-162.66416,-161.07542,-195.912373,-258.511301,-296.382837,-228.989671,-99.77599,-141.728211,-175.503288,-222.94783,-248.204885,-235.557035,-173.287471,6.553665,72.911676,43.656049,-175.243741,-268.308933,-249.589068,-150.630541,45.783404,98.136685,86.462186,-32.499426,-73.017134,-119.469315,-176.794584,-303.682211,-295.023647,-135.419772,-58.75775,-49.488921,-159.413163,-191.10887,-217.883595,-229.339041,-206.408393,-162.180855,-54.984054,-62.666018,-128.883751,-237.977807,-230.825822,-139.899789,-94.025964,-45.72796,-49.018874,-52.559761,-56.944787,-105.601555,-227.638347,-237.11546,-140.105291,-82.748885,-67.205034,-147.492122,-182.079684,-245.287241,-266.62373,-248.674535,-219.800564,-145.945103,-106.604835,-78.538672,-155.031964,-206.748262,-195.729915,-129.60373,-65.991939,-73.457133,-39.592897,-58.247037,-99.917597,-146.733314,-158.617231,-160.250927,-119.15935,64.459355,151.072599,174.605432,71.884372,10.305369,-90.268581,-117.185588,-142.344673,-120.777996,-11.025715,14.157852,6.788072,30.746121,40.712827,58.677844,72.623953,93.345769,117.86358,186.186772,137.65077,50.383642,-94.350624,-94.923298,15.004889,73.822616,86.206966,46.534317,46.682244,13.497495,-5.856312,31.07289,47.029283,40.982193,78.147461,192.188948,111.703745,9.097855,-109.611462,-93.563769,19.331188,94.290732,207.166608,208.209222,166.670641,-10.019984,-89.589217,-50.038785,40.625684,167.474442,170.648523,99.659201,27.416441,-11.377588,-112.647314,-129.414467,-16.128087,79.478503,191.601631,132.406413,71.70268,-52.096061,-102.100573,-150.442397,-140.09214,4.457233,107.393713,138.532444,-11.44546,-64.551244,-133.725842,-127.494603,17.092491,98.956014,147.551725,76.983535,20.055145,-111.125137,-144.49956,-111.533062,-78.472604,18.026311,96.855514,186.346962,61.845433,-37.839596,-197.574235,-235.55431,-173.542042,-79.748781,50.628418,-8.020392,-26.030599,52.00267,90.971068,75.192024,39.648646,-16.213264,-34.873646:160.476772,105.412933,100.794697,106.874576,93.483056,78.031784,92.366102,109.642819,54.422916,26.622947,2.933602,-14.689668,-40.746953,-25.280893,13.150337,13.266569,23.057615,68.305749,71.059574,-12.423157,-60.446903,-47.991428,-27.259387,-101.896593,-206.264301,-211.645591,-144.786468,-87.592811,24.887325,44.258124,12.761926,-9.68977,-88.84651,-228.547177,-286.319677,-293.602467,-242.176169,-150.023689,-127.525635,-67.689059,-58.175565,-81.250031,-61.247077,-14.088705,83.296945,128.845428,180.607284,176.436749,194.120428,245.822667,220.495522,85.755272,45.643541,107.525613,164.43936,194.632314,159.146338,140.943362,59.598983,-1.742707,-63.866872,-72.563955,-181.613748,-256.855804,-275.598039,-197.854174,-161.574531,-68.176455,-16.289264,46.409649,46.415831,12.112331,25.674333,47.520643,37.821745,-4.21214,-91.735213,-90.899254,3.853145,43.900511,22.803411,-49.256234,-82.27658,-176.794955,-212.477905,-223.578671,-218.196955,-196.607531,-167.735933,-163.53764,-178.723522,-199.757359,-226.347848,-198.83155,-86.984735,-44.597548,-88.377937,-227.289742,-246.805229,-173.495394,-123.642995,-92.478387,-122.638586,-213.07824,-227.484011,-194.73082,-133.459312,-139.1885,-171.957203,-157.669437,-71.874094,-36.168403,-51.437802,-126.79287,-165.22743,-238.842544,-244.335251,-187.243705,-144.562809,-29.382085,55.943929,70.319086,66.628787,54.70208,28.488378,11.05044,-7.381049,29.915618,110.004075,28.253693,-6.484095,40.523889,96.86469,149.664305,123.774737,90.708254,158.470543,165.137075,64.534067,4.047063,-21.973047,-2.185664,22.940017,51.48231,181.166595,231.259428,200.760556,101.974811,85.177521,201.851826,290.35493,365.375994,307.930863,287.69058,305.616711,315.719608,327.560612,337.308247,319.795407,272.975067,126.603928,54.631206,59.546477,45.076771,31.664599,66.622989,91.553823,40.872041,-54.328661,-49.581064,16.081028,25.851797,40.437618,95.383927,292.634717,380.115502,413.868872,331.016835,295.131072,235.057767,232.785161,321.16275,353.513589,342.857746,316.864449,252.997032,21.039262,-60.802159,7.918861,127.027368,292.711602,289.586956,134.871801,-88.163562,-150.462,-139.914871,-100.045639,-77.371441,-122.80549,-211.52421,-164.820405,-129.451632,-97.650399,-88.810378,-78.772674,-85.55587,-89.188442,-79.446335,-34.754998,57.822452,81.793312,111.473603,168.016655,298.720224,326.461955,303.310099,219.781757,201.138179,236.62307,264.222376,257.727836,190.206405,40.912077,55.038152,215.983355,201.502326,99.88277,-107.651097,-161.767948,-168.081166,-138.363279,-47.273554,-0.38835,-31.041657,-184.62815,-266.092849,-273.692313,-176.362889,42.966497,91.497947,48.984509,-142.360735,-247.345084,-297.530714,-234.383086,-102.363852,-95.089173,-170.707147,-208.312752,-214.923634,-287.834449,-338.806129,-346.420392,-301.712001,-218.89223,-201.5385,-232.554052,-301.185113,-313.023036,-326.685652,-341.361408,-325.25776,-288.825901,-238.107215,-305.369527,-336.378551,-253.899651,-167.354729,-61.928192,-75.566046,-159.602364,-159.724923,-91.158943,-132.32443,-194.949643,-337.326078,-371.540694,-264.513881,-176.203992,-132.134869,-216.883974,-226.351879,-169.321947,-149.738437,-147.831774,-138.576741,-91.740936,-74.245936,-77.691249,-90.502243,-117.793822,-197.419442,-199.255287,-84.099822,-6.767222,48.935049,-51.652233,-96.550265,-122.883762,-130.662844,-146.074544,-153.304064,-138.224558,-82.522984,58.464379,53.953192,16.453671,-11.024614,-1.638582,-13.783488,-37.865727,-46.44765,-24.480071,-17.038028,15.800753,10.041136,-85.090016,-126.390582,-101.935057,-49.316442,6.787169,-61.063626,-86.271072,-109.706327,-126.122088,-131.76612,-124.824877,-79.613181,35.969279,51.911434,-66.619363,-137.694137,-144.146031,-102.39229,-88.707279,-107.522903,-110.672871,-143.107273,-179.247381,-184.804066,-126.748953,5.512768,33.381118,37.628826,20.700338,18.484938,17.446723,3.496343,-16.196482,-2.368223,43.53147,63.168949,94.402387,35.092666,-46.749924,-187.817627,-178.526359,-16.16456,64.129577,101.909171,-22.734204,-83.973933,-95.812836,-78.105898,-92.690492,-103.771053,13.249153,138.5589,263.758562,90.600889,-31.19471,-175.906697,-145.534863,68.377012,158.883429,238.43278,239.691578,193.092687,3.394448,-78.609714,-60.268786,20.404862,140.009704,152.482227,176.862119,165.225996,85.262839,-144.202768,-212.961518,-224.354947,-193.605055,-91.326356,-56.284602,-75.229731,-102.22008,-100.508625,-88.385927,-88.426082,-75.047865,-36.092674:235.48052,118.327398,102.973226,100.710376,114.163126,204.190138,261.852402,269.037729,127.023792,86.965484,95.536685,106.101103,145.921522,184.572393,264.995227,280.986487,216.817588,105.468291,63.853052,27.151945,37.598462,63.354229,64.261372,78.750154,76.715923,53.870087,10.951283,6.817134,32.023846,46.657603,72.669053,80.70528,-12.133337,-224.402607,-286.401906,-241.951579,-176.118154,-108.378514,-98.522483,2.24031,94.880146,79.343615,10.424935,-8.99384,22.837036,77.592255,234.238597,301.678363,306.120498,182.79005,109.77718,23.020753,48.383529,200.415177,263.161602,269.504592,133.01362,49.311292,-38.571001,-38.605736,-43.393441,-76.912457,-167.816261,-193.071898,-205.544977,-215.704555,-222.261964,-218.054249,-179.519394,-9.749567,69.119718,76.683066,-32.054565,-54.58408,-54.305072,-78.527406,-149.726197,-137.700673,19.768039,89.015881,39.56568,-152.497044,-227.612223,-256.833107,-228.490955,-215.109151,-239.535413,-249.426841,-204.308152,-192.963656,-196.535646,-213.223929,-226.157432,-192.609516,-115.551144,-110.519513,-195.870355,-332.000814,-365.499995,-318.255583,-248.187144,-130.477235,-111.108529,-105.472765,-119.013646,-137.086635,-230.664986,-295.454924,-321.471835,-250.758418,-54.56169,-7.603111,-60.394909,-157.326857,-198.558459,-255.46042,-250.477721,-160.260288,-85.163521,59.172625,48.583623,-14.055616,-111.151805,-113.364399,-47.252271,2.236029,116.748479,166.031094,144.610951,-23.78299,-81.920763,-55.35797,-2.505857,76.866757,102.411789,163.557554,152.843302,94.21404,-49.733711,-82.116201,-19.521007,35.58939,110.244329,141.556513,176.497843,88.572464,23.98676,-55.336718,-54.758358,61.177809,154.103192,255.699207,218.04986,190.288393,106.224689,48.246801,45.145504,110.53921,205.333431,208.056005,169.528251,52.262922,-45.268592,-188.771712,-169.739456,-7.48384,45.937041,-12.249646,-132.821775,-144.75996,-69.947727,-5.972846,128.575095,188.629811,328.002408,395.221059,406.090315,250.330808,156.95834,62.242705,95.852856,264.482515,336.092719,348.277855,248.972615,202.27151,92.850735,39.203643,109.538708,239.997993,423.605942,404.608843,210.998436,-34.525992,-118.066042,-160.489949,-133.124705,-29.407072,17.480608,10.356533,-123.6343,-177.103015,-235.800993,-251.353342,-201.084404,-136.451702,9.580122,59.967647,66.815448,48.534473,34.157519,-25.7753,-27.142451,88.775399,165.760227,224.129468,163.169552,134.581853,108.700323,102.145769,94.588393,87.38972,79.980281,85.877866,36.897877,-83.991941,-127.942215,-195.926545,-220.819339,-209.784003,-148.536329,42.821088,49.698209,-33.313983,-206.710892,-260.941167,-256.584377,-179.177997,77.591174,175.27148,150.113122,-62.725878,-158.483411,-199.256362,-141.785287,0.792876,36.450113,24.726666,-35.21874,-80.452943,-191.469422,-239.894454,-272.499522,-252.1882,-182.552063,-154.410533,-149.252846,-186.09605,-220.229569,-309.648036,-321.466714,-256.511363,-213.026218,-149.737581,-189.64353,-233.867716,-261.973665,-242.382027,-185.718592,-157.51423,-89.00145,-54.90455,-6.16645,-46.394747,-125.368779,-270.354641,-274.708262,-180.480264,-123.896959,-44.468436,-81.723495,-133.888731,-233.156424,-267.944468,-253.356899,-189.171045,1.713148,65.658862,25.682728,-112.075213,-174.515453,-243.816827,-226.465112,-127.626242,-79.791266,-33.450581,-89.811243,-123.871626,-150.322553,-153.896127,-133.482793,-100.751699,9.559025,76.955579,137.93116,65.747855,17.455829,-71.590865,-103.783614,-117.452187,-97.549985,-9.576247,76.524612,72.678141,-26.945688,-63.34738,-4.684155,47.85973,89.140518,110.917102,170.124627,96.943079,14.102037,-133.407806,-156.999078,-44.628869,42.036043,71.536115,7.298104,0.984647,-34.108611,-51.889356,23.121514,81.382838,134.162005,156.091569,157.562978,-16.907122,-115.786544,-164.239209,-122.481867,9.512906,90.541558,227.061615,196.969555,109.258732,-80.383283,-118.59812,-35.105663,48.107105,167.39921,185.492671,161.472203,88.169249,36.277494,-62.582019,-73.182767,22.941507,113.586239,251.924438,135.263306,9.833213,-169.471226,-200.93947,-176.010899,-129.768066,16.953082,105.728196,184.018425,20.786123,-101.662515,-239.191609,-191.049474,78.650642,196.652925,244.622443,121.884879,60.341868,-20.602352,-53.879449,-93.340704,-76.689194,25.929364,77.157566,109.796982,37.14936,-41.253585,-215.05786,-262.416471,-238.875859,-180.456463,-61.507923,-70.161735,-103.243056,-123.161705,-104.575633,-55.5091,-52.539878,-91.937574,-96.06409:75.727702,93.364703,121.191888,127.316404,133.053933,181.825675,185.182844,115.381205,34.293066,5.780134,-98.639617,-185.640696,-275.01141,-236.723589,-134.98381,-131.385132,-191.925528,-209.759944,-191.413626,-176.791634,-179.439166,-175.82052,-199.736155,-323.53336,-409.525062,-396.99058,-255.589817,-162.143772,-48.400868,-46.968084,-120.097338,-162.055644,-238.439958,-367.197092,-414.096097,-366.646879,-282.721384,-80.968405,-10.847286,-22.154074,-111.675621,-102.410752,6.594818,48.376286,78.836435,97.763291,139.903519,144.767124,144.851862,139.329223,110.431778,-2.623933,-65.358981,-163.787505,-185.615587,-160.287468,-124.213666,-119.006409,-119.318732,-136.055395,-183.267861,-210.50328,-313.359427,-344.917999,-283.658641,-264.91992,-291.13629,-302.444404,-283.362764,-248.390268,-235.715926,-207.128139,-213.667356,-246.192206,-379.453159,-455.243954,-454.251765,-351.200085,-123.688772,-74.061747,-96.01452,-159.439267,-178.400642,-203.252222,-212.935025,-243.310241,-272.161272,-293.958131,-195.609766,-131.280415,-76.87772,-86.450112,-86.640362,-71.064507,-48.096141,-34.168618,-25.575539,-54.588108,-60.703975,-69.882743,-75.923129,-76.104863,-86.471158,-142.162968,-166.032301,-152.782318,-135.790981,-144.711427,-171.128613,-185.114643,-210.141339,-207.382738,-179.538404,-192.956785,-216.102913,-276.766527,-285.647757,-221.198023,-180.515781,-133.366097,-68.724692,-31.089967,-49.360322,-99.704828,-139.045533,-102.607447,-9.259492,0.378354,-78.400038,-143.409223,-116.205167,-18.777273,-0.861328,-57.153996,-86.558692,-42.350093,-62.839462,-131.395089,-148.308012,-94.352497,-97.20012,-156.601994,-206.374754,-159.699691,30.559459,170.798213,177.18686,84.536823,32.570497,8.080839,38.901046,137.447285,155.002483,142.178014,118.748721,95.503179,100.717306,137.979475,192.157845,197.140045,170.328783,158.99269,150.853285,78.493126,35.80071,-33.581454,-60.351447,-29.706767,65.872713,72.88517,30.741771,14.356027,45.778305,125.228667,373.859019,474.681046,513.925599,415.142238,371.476895,319.532835,318.906967,359.862713,366.361656,353.606038,366.262236,340.102136,201.990694,145.033222,165.034745,219.786242,280.701153,268.598921,163.922314,27.420982,-21.99027,-103.914725,-115.902592,-71.878776,-74.022004,-123.182044,-96.680256,-70.258241,-47.101897,-52.774488,-57.486784,-44.757939,-15.232181,3.609707,101.17851,214.586002,252.630228,347.788794,405.530818,439.080153,395.413684,313.903361,369.457196,418.221467,501.492349,528.355933,516.549155,465.913381,303.252246,230.643776,151.227814,89.139827,39.691585,-92.700273,-150.438878,-183.517246,-158.855816,-28.788204,68.509169,43.871579,-47.08442,-76.975799,-106.989886,-80.419474,121.058185,254.363512,362.040796,242.596112,179.238156,106.968504,90.665768,78.582711,81.125848,85.239057,17.704713,-25.455719,-35.323721,-6.644178,20.00453,4.699396,-32.832858,-46.250546,-90.499144,-97.523791,-57.218003,-38.715471,-107.116902,-224.737514,-197.509528,-29.97956,47.489723,32.081211,12.335532,32.206099,85.905275,82.167554,1.888083,-6.760898,77.002726,-2.435334,-109.204813,-250.57461,-247.465434,-164.279515,-138.14335,-121.852585,-56.615015,-15.837771,-31.170284,-77.791054,-92.663496,-48.749856,24.185758,32.168341,4.689365,-68.144939,-94.65379,-108.844411,-91.568492,51.375141,155.841594,236.226413,98.754918,32.928319,-5.417288,-10.503973,-23.353574,-16.493199,31.921611,73.272255,135.385103,110.692597,103.647023,114.459117,106.852275,70.784238,40.48023,-22.227016,16.70405,51.104582,10.733876,-72.412767,-242.566177,-288.879426,-288.643176,-249.098366,-190.77907,-229.537934,-240.586287,-201.176158,-172.559627,-97.760157,-39.48654,70.52861,26.041923,-54.564988,-171.661446,-195.823522,-219.922755,-213.44608,-153.966136,-114.791186,-90.544552,-145.776969,-162.287946,-114.958798,-57.271442,67.073742,125.493536,223.852504,235.760566,250.062866,270.330176,203.994953,32.96494,27.199597,123.942669,163.375832,173.552515,73.976953,-9.366183,-141.100509,-139.974832,-39.870348,6.363968,62.829835,33.072384,-22.978139,-95.364246,-86.239624,-49.328724,-43.522172,3.437384,70.369944,179.881209,40.137611,-61.169369,-79.620634,-7.664396,123.929497,158.790767,230.097898,296.160615,282.068836,192.371129,176.388246,220.499614,230.865015,210.767788,207.454091,208.180206,173.036039,132.17631,26.961464,-9.055786,-33.614455,-48.885204,-84.600294,-26.995431,30.263205,68.236776,33.363335,-11.887637,9.85242,62.203082,73.014358:35.435411,167.951686,185.71243,98.756776,78.467664,120.328782,124.151425,75.61987,-20.626114,-76.041601,-126.273492,-130.841679,-142.809815,-148.774338,-144.869213,-133.05137,-115.303158,-82.274169,-56.379257,-62.764226,-106.707791,-241.587929,-311.404652,-376.516723,-348.021101,-314.224391,-180.762801,-91.833295,16.397703,6.892405,-40.318173,-22.006601,32.386043,-58.149227,-112.464427,-90.37822,-19.89218,148.799874,195.770431,175.169185,183.350511,234.460848,308.955971,296.722878,265.173821,294.066308,386.429153,406.432891,371.821831,268.480008,212.270493,101.808782,50.882811,11.679046,28.264356,93.444197,187.207244,230.825231,226.488409,160.434718,-1.808018,-46.043081,-124.036259,-172.067144,-172.770127,-110.226515,-83.506596,-38.486794,-27.857141,-13.22606,-5.299007,17.936896,72.028196,85.486381,14.556714,-52.811155,-96.678924,-48.769349,43.264065,41.96567,29.750881,100.896028,132.367067,116.411181,79.055324,-20.381652,-59.604512,-65.762751,-52.028182,-64.041122,-87.87489,-94.84995,-86.997177,-55.71484,6.855244,5.8808,-3.023164,21.904377,10.927826,-14.819869,9.33616,72.870029,69.270229,-6.408052,-58.11346,-44.169889,12.747434,34.28137,75.542149,80.085972,36.998786,28.154162,71.401559,51.543602,-29.841799,-230.705852,-254.443067,-138.660091,-69.674165,27.308486,124.336505,171.727149,149.195541,78.647245,-4.417031,13.070982,84.73566,101.063125,31.233609,-31.621063,5.601917,120.283805,151.520326,141.827694,118.683787,103.188066,92.306648,75.157558,76.84817,83.416692,15.419407,-53.854274,-156.205295,-145.55915,18.798202,185.423711,197.430499,91.214018,42.167766,76.351453,132.873014,213.816215,242.495242,283.956429,385.299125,384.257521,300.580029,266.821514,228.645673,201.002034,88.443436,-18.004483,-26.23966,-18.764659,-29.688761,-12.238905,22.679834,70.338766,70.101053,58.155706,18.243173,4.318114,17.23397,34.907993,103.172479,179.290195,321.939487,283.610289,243.092641,194.868193,169.838749,148.780756,178.895006,286.690741,306.741369,247.901783,52.891325,-10.560088,65.784898,153.860572,216.387529,195.760872,123.79303,40.364255,-0.025785,-82.484167,-105.359564,-139.03938,-168.559346,-174.530038,-104.232303,-79.962067,-43.160212,-35.803918,-103.588147,-160.954348,-182.597077,-119.537693,46.703008,70.271132,42.902457,76.284601,140.206086,215.118014,204.282376,175.248247,181.561445,189.600937,227.600601,245.118491,202.553662,147.051933,99.090429,131.647624,175.910226,112.068473,60.253547,-104.959037,-194.026346,-245.787764,-186.34811,2.292264,77.732006,58.402516,-37.843974,-86.774111,-82.270752,-17.302857,143.000624,191.404725,162.862681,64.044591,36.187786,-3.241664,-26.528988,-69.698472,-85.005039,-73.570945,-60.236448,-77.874125,-120.014005,-125.430812,-81.451702,-55.652722,-42.047858,-22.228935,17.329845,-21.274996,-29.28715,-75.344559,-129.969154,-193.384461,-179.334551,-142.114407,-195.9574,-213.649,-100.379587,-12.115269,51.265807,20.520301,-84.450461,-103.442836,-36.26579,-27.804419,-82.651758,-230.446133,-262.319438,-186.254053,-130.689264,-73.387937,-41.724037,-41.608178,-84.00208,-107.514582,-102.61549,-75.340231,-44.908134,-61.158127,-109.64476,-86.897331,-69.958873,-103.246784,-124.770661,-47.042982,22.122594,27.461543,-93.101482,-120.129292,-124.64184,-162.011416,-284.988251,-315.717249,-295.203232,-248.090112,-106.117048,19.842642,63.492694,67.69783,33.95296,-37.524578,-69.319725,-119.462904,-122.894793,-99.751562,-50.600702,-67.29289,-222.432547,-323.165137,-402.028373,-345.919572,-183.948573,-138.345923,-127.371467,-134.487916,-177.240816,-255.200274,-247.654423,-144.881294,-64.217417,-83.069096,-177.490407,-235.647805,-377.046384,-421.181345,-367.248434,-293.843815,-218.418128,-277.270162,-310.19945,-308.377625,-254.156345,-81.752042,-8.227018,59.623354,11.110957,-20.057169,-54.959083,-90.068796,-153.221218,-143.170539,-102.503551,-82.543772,-6.936575,-16.303924,-65.211192,-145.365822,-168.629845,-172.834144,-136.57703,-54.723514,-136.338006,-226.822893,-297.827188,-225.147386,-4.223371,53.99293,90.624454,133.336824,202.150721,112.752605,56.971985,10.001447,2.595738,-17.640156,-10.563661,122.973728,282.534662,270.573172,114.407452,52.757639,56.385388,101.550053,186.841476,217.437159,229.633716,123.886158,62.295309,-6.168007,-15.327573,-28.337793,-40.206465,10.81876,149.45207,169.419416,55.921216,-3.70383,-0.905721,30.585882,91.882447,124.534638:190.059121,90.777078,79.391027,130.318983,163.835978,160.570082,142.19226,158.245334,183.656031,174.072607,129.638016,113.184801,77.17326,33.780188,-15.344238,23.675318,90.546001,-16.566764,-82.753766,-153.103505,-145.265928,-50.1343,-13.174682,-41.730272,-85.590266,-76.852071,-12.476504,17.349417,16.727912,-11.490428,-79.51073,-103.13273,-177.163871,-324.497022,-384.864349,-382.785336,-306.558342,-143.843463,-127.461547,-149.531684,-144.908956,-142.579535,-92.681868,-51.130225,24.594025,59.052824,139.227199,195.764381,274.879157,206.194505,141.765162,32.872491,17.175282,70.462617,91.047553,20.826739,-99.697054,-125.423657,-130.984674,-126.864022,-119.457468,-138.880613,-221.467067,-250.471484,-264.727395,-250.024789,-235.254152,-224.400298,-215.123223,-134.533925,-108.602334,-177.200094,-218.815417,-173.159047,-74.174178,-83.530366,-135.662356,-100.935688,37.071582,45.801463,-78.199597,-178.598671,-206.824267,-236.052425,-228.936304,-235.407005,-260.697792,-293.635297,-249.248654,-200.465558,-111.337071,-106.185095,-117.13244,-98.261858,-94.268361,-118.387248,-124.380652,-92.6622,-107.78251,-162.799941,-144.330447,-55.053216,-51.802385,-90.711999,-87.366379,-88.991741,-96.530858,-116.278715,-195.081928,-201.510862,-127.900337,-102.362894,-101.621769,-92.528995,-92.415532,-131.133964,-143.297272,-133.524556,-130.031616,-79.964369,-8.582235,-21.816722,-150.57185,-195.68557,-78.229828,38.034941,122.223931,76.079708,-31.660005,-71.950199,-84.923955,-87.041903,-61.788987,-10.810945,2.747839,59.379389,91.777043,49.735244,-77.232825,-98.801425,-41.820107,-3.453512,56.93738,101.70323,183.279838,121.956906,61.139186,-20.556557,-4.832939,104.74962,132.107271,141.868574,139.246413,111.59713,75.297624,93.635276,163.718104,198.116849,246.350863,237.673695,147.395447,58.965356,28.25461,-46.246843,-77.338638,-76.013815,-68.609853,-64.040857,-30.551937,-27.621627,-33.672049,-8.600472,106.364055,170.985024,260.770879,286.608381,300.780899,203.359822,119.205412,30.98268,66.201512,210.241447,261.997356,272.434093,177.070575,107.960649,-4.874806,-25.018458,52.050214,134.670356,225.304754,191.249293,16.134786,-140.720863,-174.054407,-189.752133,-175.650146,-149.658225,-161.923213,-174.143679,-129.798597,-106.099725,-126.895967,-164.677775,-144.657289,-77.955779,24.952379,46.707785,112.733823,204.879247,232.913207,250.402922,260.90591,321.299132,349.027321,342.524642,283.551543,258.839037,300.302383,358.833011,393.82684,347.807048,216.869826,154.828589,54.803256,11.95077,-4.525573,-97.795037,-165.411941,-241.715472,-215.611415,-55.501848,30.97855,21.021701,-45.520049,-95.189397,-113.402057,-34.499038,197.873822,280.723979,300.212459,149.865125,76.359879,56.374585,101.340089,170.66522,165.659607,139.388991,120.713013,85.943545,-38.065615,-81.356212,-38.297773,4.529293,0.151892,-34.522436,-108.068636,-117.103159,-66.216682,-40.668378,-124.01869,-295.633275,-296.244784,-126.420765,8.338331,-17.507857,-123.733097,-116.808628,-9.126643,14.389897,-16.924747,-11.297747,50.741292,25.6202,-33.293046,-162.399897,-197.32073,-204.840937,-185.43929,-122.7236,-149.461949,-185.64097,-164.274266,-122.092644,-89.349644,-85.418719,-26.24115,22.298406,67.979876,-31.493014,-92.37665,-107.655048,-82.539287,-50.370344,-53.707548,-59.681317,-23.596572,-26.19908,-108.361674,-152.966124,-130.296979,-60.855053,37.839819,49.110405,103.290378,141.993203,98.803707,-63.51078,-110.357899,-73.667757,-28.491876,51.516754,57.737448,17.098542,-90.771733,-127.841055,-130.523856,-109.331061,-120.553375,-140.419646,-84.448368,-11.148022,-17.869583,-82.17519,-110.49643,-98.436808,-67.453183,-35.885349,-65.685781,-85.141534,-117.457072,-121.478072,-46.008931,2.553757,-8.367226,-40.944841,-44.367908,0.889956,18.108306,-6.42538,-29.326618,8.221088,61.449475,125.818016,124.298062,148.949612,166.49906,93.956121,-52.672973,-36.691821,58.464467,77.44032,103.069014,92.776924,50.405925,-28.888628,-43.111269,-41.258674,-16.046742,64.127657,20.396711,-41.403422,-98.05702,-79.496096,0.212295,34.03621,69.495215,83.981485,80.851311,-13.614972,-74.399655,-125.489729,-97.135241,44.660353,139.581187,313.826014,330.914797,255.014948,59.843675,0.469273,-5.400788,34.765172,110.147567,122.806531,114.793589,49.448549,5.25568,-88.329665,-144.89868,-239.69022,-231.978313,-93.831857,-29.169632,-40.568383,-28.026848,-17.131661,-13.007949,-0.030644,39.098912,51.907411:forward
-261.921256,-367.051817,-338.272813,-243.725502,-248.319096,-306.960294,-298.83605,-205.168898,-134.559833,-114.28139,-38.024102,6.673991,62.254047,71.165601,-10.52804,-88.219623,-163.487995,-91.954571,-42.888978,-28.995174,-65.910235,-165.679764,-215.306238,-242.759619,-109.506741,-7.084429,189.812243,262.653755,325.423503,307.737189,168.858966,72.362371,-54.000854,-48.141331,-47.389624,-104.182081,-87.830701,91.354318,154.316094,116.625477,15.469667,-37.468725,-123.167405,-136.662944,-141.592904,-146.775016,-134.448239,-125.251315,-164.919032,-198.017704,-171.356867,-138.473747,-181.290934,-324.881245,-377.526421,-374.736904,-249.814209,-199.439453,-182.431029,-217.099657,-324.841424,-355.950317,-360.857657,-360.641306,-380.621408,-380.983946,-340.439683,-240.443661,-223.565519,-267.042571,-301.758455,-301.433054,-227.031198,-197.980098,-101.975689,-18.881305,91.155712,86.420601,61.829339,83.989736,172.727809,209.110769,181.845235,45.260142,-30.009819,-93.972754,-79.950909,5.313864,48.088461,15.592697,-56.821569,-56.326668,-10.942564,-4.604756,-100.461521,-183.885544,-268.325413,-184.696502,-107.993539,-13.050706,-29.042796,-109.041082,-124.168156,-80.341221,-58.482746,-79.360113,-96.425068,-59.296977,70.812975,122.797701,132.534756,103.1104,71.655575,118.484603,158.234457,192.476431,145.195605,-59.404049,-147.660323,-123.202213,73.640304,132.130617,137.781197,88.708096,-72.10584,-137.824432,-256.820772,-320.773153,-382.736381,-391.066326,-394.010644,-417.894641,-428.721608,-382.377967,-359.573473,-374.607371,-276.737321,-163.675447,54.044042,109.983972,99.660042,75.673128,67.236126,68.549037,-4.996134,-133.144914,-160.834745,-187.876285,-216.421346,-266.009846,-276.277746,-239.265401,-184.832587,-203.582935,-248.139486,-228.447874,-164.25635,-156.542706,-205.61469,-251.866063,-301.50063,-183.307423,-90.172155,-23.036955,-68.567965,-164.23266,-151.509259,-47.355229,-31.473626,-42.345385,22.600324,59.734356,-4.141068,-83.123678,-210.492034,-230.344627,-131.086615,57.113073,103.11652,66.74254,22.190515,-69.941394,-107.381501,-91.870264,9.386323,26.636642,-7.464845,9.694845,143.257627,164.595978,-13.74691,-122.108587,-133.852618,-49.273316,-60.987967,-155.037336,-200.306938,-245.664616,-268.861749,-348.515915,-373.27159,-340.149485,-169.10614,-68.188748,5.93497,-34.983324,-174.253347,-216.449579,-214.023473,-247.861961,-289.923174,-335.926516,-299.19365,-139.964212,-96.597053,-151.398049,-178.380422,-108.08172,150.412633,246.720698,240.466354,198.159272,158.486774,136.849859,76.557511,74.297528,90.067009,49.809195,-32.348798,-240.750104,-321.589558,-377.480046,-323.476485,-294.944679,-243.167731,-215.73884,-182.358843,-177.7378,-189.530682,-191.074034,-105.531138,47.838718,96.197157,97.515234,75.695689,12.757296,-50.798826,-178.053633,-175.78663,-150.439304,-50.492455,34.131874,122.560055,76.656464,-105.894426,-178.400244,-192.243672,-34.847865,79.484832,216.72084,195.844022,95.421679,74.124678,97.485417,141.583405,154.686389,162.480683,143.069556,-1.19945,-91.706308,-128.608328,-70.3258,76.975236,194.005379,240.023478,297.001169,313.505089,311.594349,284.258058,260.689806,310.441867,307.338572,247.267779,223.333003,183.814886,172.500722,226.105029,288.585837,367.811081,307.115722,282.888739,273.363538,231.180534,59.335115,-30.933961,-135.015043,-117.215074,-88.071206,-14.869026,0.119741,-58.419762,-104.439074,-145.93949,-133.137738,-95.438132,-67.778193,-38.144964,17.810915,24.447983,-12.507764,-69.491984,-222.709564,-239.884025,-188.115271,-44.546899,12.036239,29.857265,1.68931,-41.758512,-13.395791,110.557623,158.777311,179.579055,240.808408,223.702474,47.109518,-70.433813,-186.937922,-31.569384,77.200146,180.014417,154.762731,55.220078,54.980193,132.699661,145.942352,84.385474,44.747772,85.84743,188.295772,173.484055,9.365485,-66.971498,-111.819944,-138.445438,-141.869483,-31.362151,32.087164,21.097899,-25.642259,-107.206294,-117.316181,-21.840413,52.582389,42.714474,41.393887,73.089093,113.227537,56.543257,-129.513951,-69.054767,36.028065,165.769417,149.989552,17.887083,-43.202946,-126.491038,-152.164028,-145.730563,-128.075282,-110.079974,-34.826072,-9.251601,-30.031195,-76.978517,-174.893142,-117.077167,-44.203529,47.044305,38.608797,-0.182806,19.976133,62.471215,45.63834,5.837184,32.192953,62.7028,68.95929,28.127076,-66.782627,-100.517297,-144.052258,-144.682578,-142.191764,-119.446752,-103.063446,-133.746963,-170.019064,-193.78957,-179.29166:-95.960827,-214.915369,-219.996886,-159.506896,-147.632965,-186.221629,-214.858105,-193.778417,-43.524333,27.93541,108.376129,113.705017,77.390423,51.158257,-73.889537,-161.903438,-249.470228,-169.556859,-117.660261,-118.678764,-146.623367,-171.536025,-188.978601,-193.771962,-13.713964,92.277545,174.816098,182.975463,223.996394,216.365582,90.002205,21.590763,-18.239304,-0.731783,-14.388359,-84.239316,-69.193,132.038715,214.154479,150.199709,-25.730228,-89.282477,-154.719045,-166.877871,-223.058493,-270.655062,-350.077513,-368.12952,-337.197161,-239.655736,-194.691025,-152.57089,-164.809301,-288.723803,-374.714161,-422.468881,-285.717835,-213.241266,-177.094008,-227.778986,-375.117513,-413.344918,-362.265296,-304.63668,-258.965852,-266.747457,-246.892211,-216.851632,-210.799907,-182.047993,-186.505251,-257.190528,-308.118186,-289.378814,-145.728541,-73.327775,-64.805809,-106.483818,-106.152416,-36.828747,118.372256,159.262481,143.283297,46.204462,-25.67811,-131.004433,-118.914345,20.101397,56.385343,4.16264,-79.884986,-63.635566,14.632498,6.051479,-127.315807,-191.2431,-228.933389,-198.702871,-164.447603,-99.833377,-101.441345,-198.565532,-257.87009,-240.764237,-127.06304,-108.929242,-144.573646,-170.583252,-174.697532,-165.577839,-150.129517,-117.586525,-45.14258,-41.592053,-33.181113,-59.928632,-131.027528,-312.156829,-363.046966,-317.107983,-163.634263,-81.948831,11.891485,-9.645526,-97.34559,-120.833945,-158.655343,-189.127389,-277.46304,-324.344767,-286.9719,-146.619784,-109.931999,-163.217514,-207.356585,-205.198076,-119.193106,-81.598805,-22.469466,16.802239,101.931892,105.601175,30.830979,22.144994,60.45847,-25.972704,-95.516974,-193.260849,-226.711613,-312.032918,-361.956624,-400.638274,-328.030092,-276.831752,-202.275651,-193.507477,-232.802584,-280.650834,-394.215089,-416.451637,-334.416457,-169.730434,-118.287263,-115.359918,-144.291728,-208.594257,-203.817344,-83.698768,-16.53971,-20.204096,37.99879,80.742988,32.951133,-55.031008,-203.290089,-222.477809,-155.442896,-28.505055,9.041752,6.99167,-17.423937,-91.233675,-121.191082,-114.188609,-66.810043,-38.004322,66.803037,126.578868,127.524178,56.097216,-71.968081,-82.52363,-63.32798,-81.390781,-73.668231,-24.255992,-40.40425,-184.521345,-264.356013,-339.233198,-334.982823,-314.57172,-185.615012,-121.077472,-179.381575,-264.290046,-325.189677,-285.270022,-196.564614,-238.492442,-288.254123,-354.523617,-353.789335,-321.400885,-300.087335,-230.147975,-164.832781,-135.362594,-9.501042,73.196247,172.527414,173.458899,107.929201,72.555821,64.920338,91.836626,51.835859,-142.208562,-244.844417,-405.347306,-462.046444,-510.049908,-464.980625,-427.727005,-382.386556,-372.788796,-339.827462,-322.13367,-316.433501,-322.51977,-257.331917,-21.163303,83.852243,61.373579,-25.168063,-126.772276,-129.534016,-98.128045,-40.757491,-8.572698,52.97032,84.11663,125.624289,98.795634,-49.368161,-96.26492,-26.638544,93.654396,124.16751,132.83776,115.760275,27.030378,-10.221247,41.467874,144.285137,185.102733,251.936938,217.923866,-38.520743,-157.652039,-149.808122,-61.342901,50.052639,66.740729,83.225043,79.329506,62.026571,42.364285,26.231771,22.674551,126.835657,189.503209,231.991291,196.786872,121.876601,112.697122,106.350418,108.828222,187.047882,292.382286,305.135684,218.213292,119.121802,-101.082364,-166.113278,-122.171388,36.581784,97.317956,141.511543,113.927032,24.36604,13.196807,82.461641,125.258359,147.508864,159.512865,197.227355,229.95606,185.994082,56.875503,26.738809,45.483554,80.006304,97.241482,197.873289,287.733217,408.907174,391.432208,286.751014,273.137125,355.45447,435.834959,453.26854,439.43305,391.203355,186.9303,55.331151,-105.962104,18.883607,125.519994,226.9754,210.435199,139.99053,127.216595,145.078862,148.537232,104.532254,80.557145,115.621761,167.790618,129.589641,-14.070667,-65.534033,-79.7657,-25.081144,8.434025,111.199639,161.469753,222.959674,242.149531,231.147558,220.643135,262.107532,366.641389,394.288965,328.653714,274.334356,180.502035,128.692973,76.246854,176.579216,256.90406,317.432594,259.494125,123.107923,97.281338,37.580006,-1.369674,-48.86677,-60.600189,-41.880556,33.353364,58.096807,-23.665182,-112.140929,-201.383755,-152.484274,-128.696166,-119.34702,-134.142841,-183.475569,-198.23666,-164.015197,-130.26181,-108.693092,-95.21807,-59.984661,-18.960811,-58.199438,-239.045033,-315.552873,-304.637069,-194.080371,-161.57887,-139.641269,-149.662009,-196.987957,-195.159242,-132.767427,-120.39454:-26.352681,-32.62519,-13.441039,4.388853,-30.240213,-119.475902,-130.099995,-76.028368,60.77497,150.437348,252.806845,244.61254,213.013316,195.516132,62.542384,-23.093841,-80.064834,-42.652081,-51.265379,-149.125643,-189.146419,-167.763131,-141.887842,-110.704075,-9.531309,58.223475,118.958483,94.260481,28.575917,35.538826,76.492088,67.659721,6.09116,-23.010619,-29.598336,-70.668454,-72.813172,-31.429121,-39.770973,-74.657463,-21.783464,-16.89133,-84.641822,-105.542286,-97.336705,-98.436037,-138.012874,-160.727751,-140.87046,-56.548776,-16.260695,55.496197,44.969175,-160.260861,-276.807673,-258.564203,-72.283898,-35.00011,-47.146485,-80.583886,-204.229814,-252.71087,-179.426415,-76.248072,26.46577,1.48825,15.965492,26.424714,-12.973281,-165.580757,-240.409942,-265.366207,-188.293799,-147.267816,-36.650465,20.380633,72.710596,56.429994,25.217139,54.742712,133.333443,166.88911,173.895857,88.967986,-10.661913,-170.241747,-158.133194,-5.327168,37.568961,23.211291,64.283038,83.273439,17.365126,-39.685766,-145.477026,-195.322062,-268.484672,-278.186112,-248.196353,-166.232331,-155.443073,-200.522771,-224.564957,-224.158531,-233.82408,-242.665672,-228.810682,-237.400834,-276.474586,-273.36338,-240.480692,-217.131501,-152.874963,-124.852703,-133.333476,-202.967494,-256.743639,-366.936322,-407.343386,-374.368377,-214.164367,-135.374349,-53.766071,-81.778796,-188.091184,-199.276243,-127.796284,-89.753693,-83.327882,-74.45252,-29.856712,25.047779,-15.84486,-156.460398,-189.530722,-113.562091,32.529315,67.707321,43.345396,31.638307,125.780745,193.785599,203.074418,157.967814,68.848912,20.605266,0.131958,-80.620229,-108.196954,-97.628256,-115.134903,-227.910217,-293.731614,-286.702303,-255.085452,-250.600065,-258.187618,-280.365056,-361.293738,-374.069509,-264.708731,-103.841179,-81.4689,-160.625115,-205.140413,-244.513335,-235.639301,-94.426425,55.288745,66.714988,76.520821,80.481613,-17.387603,-95.120486,-175.856279,-168.965302,-69.739387,107.602866,167.404038,159.810101,122.066818,39.218425,-7.575297,-70.410748,-31.154918,24.500301,137.673079,164.530643,148.775559,109.242325,-2.626033,-33.413012,-10.913534,5.322939,6.551749,23.206438,1.372662,-149.079374,-235.177578,-304.1915,-245.66571,-193.228878,-83.677381,-62.353847,-117.237129,-172.065285,-288.274794,-315.273116,-241.645203,-164.375053,-203.451172,-337.033015,-338.450145,-264.375343,-266.841457,-279.111627,-226.730617,-219.32656,-189.475661,-134.956392,-1.158296,24.146792,-27.993611,-51.870201,-38.836382,-25.594877,-41.654375,-128.892781,-196.121317,-386.353996,-476.138433,-476.380166,-343.725794,-312.258743,-320.865706,-345.611521,-386.294123,-396.154128,-427.840507,-422.241072,-280.923874,-78.841127,-28.408655,-60.734486,-96.231546,-116.223452,-114.376824,-96.726486,-36.556447,19.283633,152.299217,190.685689,179.801428,139.465863,44.201181,38.015771,133.249418,210.039983,226.519208,235.953713,217.223478,125.181548,86.229286,116.694936,212.591865,235.137825,199.057772,136.69201,-22.490317,-81.14746,-108.061618,-73.771473,-11.258406,2.354353,29.545075,57.540221,25.525956,-66.887287,-84.572829,1.216308,139.004603,172.21225,176.324183,144.880083,14.694596,-45.246,-80.385574,-60.314801,21.292131,117.928602,161.519673,151.469706,57.597907,-210.030095,-283.398472,-186.89132,10.139246,63.556288,95.633657,85.625729,40.836644,14.849708,-7.698209,29.93271,173.703196,275.769954,298.322854,266.77946,222.941409,143.628453,112.340389,82.448939,126.529565,164.814949,267.095554,330.538043,403.318722,377.5805,284.314074,284.686549,368.896185,422.797026,421.305161,373.998595,339.943068,194.983442,66.176307,-136.823345,-40.724431,78.687001,196.109753,165.583838,69.453175,53.586502,67.806171,62.079432,67.982702,192.81629,252.343789,234.219586,166.621894,13.45852,-59.548446,-142.367846,-44.355642,33.231694,117.698538,133.862122,213.310982,264.355322,280.828985,267.144802,341.118733,480.438361,512.227064,496.100399,451.691116,257.044602,140.620887,68.709499,214.309132,303.793478,375.050517,312.169492,112.293572,72.17844,68.817964,35.112502,-80.068567,-70.403375,5.155393,140.938387,134.73894,-30.342404,-120.39433,-135.79497,-32.240188,-12.403752,-67.159335,-110.817595,-127.396739,-106.742258,-103.892839,-109.573788,-37.411862,51.374123,44.970819,-43.065008,-101.889176,-276.272995,-382.931891,-464.951198,-304.864273,-192.133845,-41.648956,-32.816568,-66.607081,-64.290518,-65.433288,-81.61288:-213.325059,-244.945073,-194.68063,-78.313941,-69.433161,-122.533862,-145.141574,-132.605554,-13.606605,65.582398,214.481601,287.310871,416.883512,419.078767,204.49279,75.618592,0.759359,56.024101,77.522022,49.647014,-1.337275,-128.892937,-189.285015,-209.916976,-58.789735,15.725823,93.668044,128.309519,199.091788,193.74081,68.724215,-4.655646,-87.989755,-140.541482,-153.972274,-126.940508,-94.727092,-27.026758,-7.774181,-10.601185,-13.021625,3.504582,74.210962,109.001946,116.536055,108.814663,173.952371,242.720011,293.686687,147.023351,83.265495,82.153014,93.918222,0.301962,-91.34417,-177.627061,-78.362209,-27.532383,-14.019328,-65.819071,-221.719518,-256.750872,-196.72914,-151.525177,-142.128364,-172.989945,-174.675071,-177.210927,-176.881853,-203.599881,-244.142449,-318.00262,-276.514107,-202.686009,-3.709217,84.377074,170.105594,161.132341,99.65904,92.089015,142.949999,182.06629,176.297279,69.753594,-21.511212,-156.150703,-169.749091,-105.515954,-47.135859,-47.151787,-10.542713,40.090186,112.430442,106.502983,9.418468,-65.791145,-171.715695,-176.667342,-129.389065,4.771594,10.169374,-115.519435,-170.130576,-180.662382,-170.173172,-183.74272,-204.341939,-185.974972,-70.278249,-11.210939,3.131761,-22.716704,-60.393808,-69.285476,-58.04949,-66.062305,-115.040346,-240.256061,-280.459065,-282.153003,-141.947883,-31.659993,100.690049,54.001307,-136.139068,-196.116651,-264.697745,-285.67194,-268.057654,-207.045214,-169.522307,-102.528982,-98.22976,-164.58877,-193.045664,-136.70005,-14.591715,45.222483,191.26528,250.980157,278.033819,246.412396,152.483468,134.084051,139.033242,74.705577,23.799796,-70.959898,-112.97453,-206.354502,-268.397207,-346.608413,-332.991362,-333.712966,-309.012414,-263.391715,-221.593824,-255.383124,-344.365919,-349.666061,-219.639673,0.544236,57.576109,-19.690928,-104.086774,-161.250917,-114.707445,4.645111,64.353429,93.887719,125.16121,91.074206,-35.927217,-83.4709,-130.825714,-141.450201,-87.954508,43.823495,92.422746,95.865507,53.109258,-51.980007,-100.359492,-158.17963,-79.440342,-2.342536,131.806844,149.396493,37.710606,-53.071138,-166.239003,-159.555073,-92.420653,-90.825469,-71.085363,19.375337,23.926513,-61.857997,-117.036609,-231.426369,-302.409619,-271.645288,-59.681041,21.176562,-58.905122,-150.478597,-214.864603,-188.272583,-130.999952,-149.72696,-190.437344,-272.420763,-271.936413,-200.871006,-178.558246,-201.058928,-217.142329,-175.028394,7.812772,90.159268,144.328313,133.915295,81.4518,42.010351,6.098915,61.633425,72.308219,-36.862772,-147.684946,-388.101012,-485.792195,-556.240083,-445.727744,-373.144926,-309.621566,-327.331794,-383.545433,-389.811243,-395.691724,-403.284378,-317.804821,-106.652513,-34.380364,-58.004095,-105.30635,-139.083859,-147.103767,-182.910327,-143.606009,-97.556004,-14.017515,26.632156,99.181021,93.756847,-22.565301,-72.927572,-36.213524,127.698631,204.434374,233.725709,194.460928,119.422508,105.45107,139.167398,159.830484,136.756016,98.634786,76.011014,-44.187039,-110.870135,-150.788035,-126.276991,-70.962558,-5.402382,56.868302,160.407192,175.582852,172.263837,165.231325,140.062873,115.942319,116.238054,118.913005,99.336788,43.899415,38.222298,59.770093,67.705856,72.927206,123.975404,182.327583,214.125473,130.026159,-121.170431,-205.661002,-192.013895,-46.298439,-7.630176,-13.544689,-35.67213,-86.714239,-103.599562,-116.708129,-114.68615,-72.653371,63.0344,136.397017,149.309649,103.758054,15.658727,-43.693143,-189.155673,-254.263732,-240.923256,-82.304386,33.620203,144.480234,112.16674,-15.952517,-42.996135,40.932782,171.824819,206.62911,182.36658,114.880411,-97.07387,-189.933849,-214.641467,-48.803026,48.414005,153.590326,133.356817,48.258271,45.403459,49.913375,11.095521,-63.053012,14.572572,85.860577,136.604808,95.97866,-61.716599,-153.011763,-240.254675,-101.246886,4.675004,157.851406,171.515535,118.840973,91.66027,28.466566,3.171689,52.959462,148.726806,155.608129,113.767432,95.124344,53.450759,10.787557,-49.769968,25.789033,89.738789,175.996503,163.404397,54.800616,24.548951,9.429562,-28.604305,-120.771392,-65.638246,16.252416,147.521641,144.735972,21.123743,-38.773369,-9.612991,112.01349,106.989527,-22.942705,-78.870134,-64.685167,-1.443498,81.203927,51.629614,-53.313486,-37.126437,5.6965,21.367918,-17.617615,-121.332621,-164.78305,-181.910212,-160.499381,-153.935118,-79.657954,-36.398542,-55.409287,-96.714175,-134.82852,-119.04004:-77.699413,-90.48618,-54.035153,-40.96263,-86.029875,-171.076309,-173.68773,-71.885154,95.486032,172.568031,339.174756,404.90329,411.379861,353.701313,187.258422,129.943986,123.111293,154.788275,139.523452,21.307314,-47.129656,-144.890743,-169.886469,-128.331169,-7.612154,33.62631,72.757279,88.925059,73.12005,13.21015,-133.468486,-154.128102,-82.996794,-34.618139,-41.295129,-80.738159,-93.082729,-96.928549,-103.291917,-106.560905,-30.411127,40.914266,191.071384,225.391226,169.180442,127.550811,168.180479,249.527738,384.141382,371.701929,335.075402,232.539344,162.75892,-6.021637,-82.425116,-103.863115,10.621581,49.901057,31.956025,-19.843474,-113.663656,-134.183253,-139.434487,-116.64712,-60.805036,-34.377695,-18.803771,-28.564512,-72.951389,-237.209581,-315.286907,-293.558021,-67.457831,33.833565,154.261346,187.145049,204.647553,190.106005,144.317485,132.384625,169.901012,262.226846,272.17114,113.455792,-21.414803,-166.911713,-125.750892,54.936314,114.047073,100.756996,141.385061,195.78729,226.967068,154.294555,-83.652992,-141.877506,-77.063961,-11.315831,7.42128,47.068623,30.692266,-90.041196,-146.013718,-155.461783,-110.945963,-103.737597,-97.792526,-92.598686,-80.291582,-87.429029,-140.896571,-141.919699,-54.260705,-13.026688,-37.734311,-134.218595,-181.652989,-289.721637,-349.826899,-355.167464,-170.986144,-59.371131,81.331014,70.912587,-83.215282,-178.184439,-276.930308,-257.261918,-140.406778,13.706225,92.577683,136.163814,70.719231,-93.841193,-99.940221,62.442475,162.866252,147.818304,178.420574,244.745204,298.699696,245.592697,142.235596,163.094028,221.29764,147.788516,116.058263,83.49452,54.28751,-96.771079,-213.525725,-301.343424,-154.994724,-116.857893,-157.225152,-186.748378,-252.258777,-300.309218,-377.189157,-360.575603,-182.095999,23.396324,71.526037,6.729448,-82.234807,-242.091129,-259.238081,-136.592408,5.138578,44.627253,86.909021,67.356737,-45.211472,-97.576472,-126.777513,-92.055512,44.028466,144.294882,143.863886,74.898037,44.878519,0.945979,-30.667081,-50.005657,-6.213232,-0.179794,46.103801,94.018982,77.834277,-2.848812,-87.251878,-34.112384,79.250079,63.111705,63.253069,66.858691,34.834213,-77.749336,-132.818593,-159.10614,-39.050232,40.477689,119.420029,77.846427,-82.702425,-130.58265,-136.632841,-114.92729,-47.858568,-5.629692,-24.224648,-138.814555,-186.21981,-217.271482,-226.565581,-203.106102,-98.591741,-31.145848,101.227998,124.544497,31.538326,-42.753109,-87.758392,-45.126247,58.084462,74.724643,43.195726,-82.673827,-165.833286,-374.443495,-479.549539,-516.700249,-322.172096,-228.167395,-172.259281,-220.13261,-368.801019,-407.473956,-390.590846,-358.19011,-248.439629,-79.49886,-19.190555,-40.877226,-89.65666,-158.864498,-175.559373,-140.584647,-13.109282,60.581193,161.463798,160.076338,58.294679,-15.029582,-117.193704,-105.308363,-1.589657,92.234143,126.579183,112.816995,67.085033,-32.893148,-67.397131,-40.954131,52.360751,67.190786,8.450005,-56.601819,-225.303666,-307.557387,-362.831891,-313.519944,-203.307964,-194.318605,-190.733011,-152.920171,-146.489965,-203.288754,-227.444352,-150.360324,-55.499551,-57.258829,-64.787366,-69.552932,-163.342071,-226.870805,-260.570344,-230.56802,-145.991635,13.79221,113.424879,132.316177,14.083104,-283.771166,-356.920056,-256.465741,-80.544612,-22.946693,87.370707,101.261102,-14.506358,-96.716236,-154.187719,-98.793675,103.470806,257.903385,276.796222,190.636322,120.005426,6.052891,-37.306349,-101.49753,-54.368693,31.145223,216.182846,249.545095,159.216189,69.671182,-43.873501,-18.503123,132.753293,257.697827,284.378459,207.284957,113.172995,-83.419492,-153.60226,-169.707303,-40.944277,40.069833,158.652213,166.778596,68.147839,-8.296334,-94.600976,-77.153238,14.342957,118.125843,167.3863,152.629143,93.401156,-23.987065,-79.280719,-152.621277,-15.506169,113.946582,268.90123,247.258765,130.268422,99.945528,73.559053,66.891423,136.729027,273.874144,314.895814,270.343736,195.849226,25.973473,-42.437647,-55.783388,111.369433,184.138321,177.778095,115.831051,1.883121,-26.929232,-54.097745,-63.679934,-64.136522,40.919763,101.331377,86.429544,25.367056,-93.270579,-126.133993,-69.882147,82.901453,114.441912,53.435911,-5.135714,-101.493515,-116.634845,-62.556472,-18.902782,23.806061,27.480761,25.166579,-37.616849,-100.458535,-254.12415,-321.495841,-327.649541,-196.816622,-142.348057,-74.853194,-63.059898,-89.261798,-101.453603,-106.477769,-109.075814:-161.502473,-215.487749,-154.250888,-55.466507,-68.843918,-120.085701,-127.272439,-84.065878,43.173117,106.973954,220.062347,276.156915,355.293124,348.661198,197.37362,103.894903,45.417892,107.315928,132.953218,81.380938,11.815537,-99.868486,-139.377053,-194.696693,-98.687955,-4.267256,140.246114,174.038817,168.941509,136.633763,40.956883,-16.642918,-130.462076,-184.40228,-176.798267,-136.064418,-121.000931,-92.840701,-65.050269,15.9863,95.108704,125.491817,169.85938,190.607216,211.903376,208.102285,224.869553,262.157999,288.29073,187.681866,158.148226,106.402359,33.67587,-100.113377,-113.138215,-66.554295,39.176045,84.491129,92.048399,55.712264,-62.491109,-111.693293,-132.606502,-121.234867,-150.702254,-259.273817,-272.965385,-188.206883,-154.030363,-197.490437,-231.87411,-226.961873,-221.473461,-214.140097,-81.395536,16.051838,124.6361,134.358221,124.21589,122.163337,143.264106,129.850191,105.095333,54.993642,33.209872,33.345904,55.14111,81.187354,93.414716,114.814281,154.348584,147.205065,117.310473,109.535847,5.22244,-87.026656,-147.453106,-39.912263,26.138959,137.021098,144.027145,84.200584,75.003449,132.854862,128.87394,87.661343,84.430096,134.104667,190.664481,163.842912,70.964702,54.87805,114.391105,185.674383,202.872862,166.027282,94.217952,-55.663828,-75.417271,7.21317,139.342961,186.276027,227.903669,204.564106,39.820174,-71.791433,-281.613191,-345.336416,-319.06681,-220.512958,-200.31081,-220.829427,-229.325223,-216.730437,-221.776452,-210.547709,-52.809503,43.086569,158.560474,166.507613,95.015652,59.359826,95.717678,135.263535,93.944395,-26.241535,-64.568833,-152.684986,-195.966199,-169.670159,-109.661446,-46.902709,-101.558882,-116.243396,-107.977561,-121.736008,-170.493595,-174.775669,-138.064531,-118.799468,-81.629484,-9.278219,31.520551,47.642096,12.068004,-33.005002,12.471242,168.833266,168.807019,127.71039,85.781659,59.323906,-28.969948,-55.881087,-59.479769,-50.459903,18.152989,143.535463,176.392521,135.617317,91.860868,40.727486,21.527232,-22.351563,-1.041886,18.13636,58.331403,84.498013,71.094917,33.585412,-3.791674,-18.441349,-75.258012,-125.527593,-142.684398,-115.507824,-83.386975,-71.409001,-96.103376,-145.446114,-151.04122,-121.487325,22.478132,94.100944,74.29378,-20.41002,-169.11263,-141.39983,37.14736,67.692801,10.986845,-115.088517,-138.355763,-69.106518,-30.019936,-52.320661,-90.028779,-66.632535,87.936849,183.102482,261.594748,237.723294,92.996214,-2.12306,-29.949234,91.798885,76.150096,-73.146806,-129.611355,-187.218604,-237.257322,-371.541406,-350.269363,-270.958612,-169.325295,-188.588604,-253.890155,-261.643956,-277.337207,-294.410401,-242.817465,-48.19214,32.585282,52.729136,14.073257,-69.6894,-117.298249,-219.847941,-220.972728,-169.273681,-15.960212,48.214479,55.057753,-11.781076,-198.677088,-242.740005,-143.597929,-1.700527,41.868725,90.250038,88.974469,65.680324,47.095349,3.000855,-20.978435,-25.491474,-14.787504,-26.399539,-124.67207,-186.564536,-241.705908,-202.742719,-53.125089,7.106698,18.429597,71.939242,92.698072,114.885556,133.519979,144.157832,112.189533,104.198646,64.551528,11.770824,-94.971321,-109.04571,-77.931259,-48.100955,35.469371,121.056453,166.349941,194.004191,133.850548,-78.0789,-162.853036,-201.316017,-153.445652,-144.546804,-151.269025,-154.941743,-129.628107,-110.90896,-143.23255,-185.508796,-199.93526,-93.483147,-40.372527,-36.569498,-63.827078,-91.957325,-130.575993,-309.961875,-410.711651,-369.619678,-193.138844,-124.869562,-145.854942,-224.532203,-334.531409,-315.005608,-218.568053,-127.882015,-63.740255,-17.538659,-74.306789,-207.517849,-241.391063,-252.266824,-108.823935,3.92971,121.266315,98.589952,4.807663,-7.827532,19.936187,22.139167,9.743677,53.035182,84.579283,40.959976,-27.709295,-80.92177,-63.904485,-102.906013,-159.712548,-90.975345,157.907119,199.423753,59.434101,-5.788281,-39.646391,-55.92527,-74.435328,-44.175217,-26.793614,-13.830877,-38.144368,-112.528916,-132.585913,-136.413246,-86.521447,-52.018842,-6.536854,8.517363,11.821838,-15.057147,-114.879867,-151.574757,-109.461196,19.082575,86.744554,168.811562,140.376559,15.11933,-11.982103,10.273551,20.974295,14.574819,16.40844,28.952191,51.076253,57.764045,43.427616,21.100353,40.54727,163.096245,200.808145,126.886335,47.04576,-45.79973,-59.760264,-79.634157,-86.701817,-84.816212,-36.121679,4.541367,13.949263,-42.613967,-157.43722,-151.843392:-183.879542,-93.089812,-30.702748,11.450073,-26.332072,-94.634519,-91.073382,-15.204399,120.403558,196.023858,365.963958,449.191932,521.268633,459.298463,151.940597,22.52398,22.485299,170.884266,206.296208,113.270155,-0.269237,-199.419641,-242.821739,-208.418911,-33.141584,58.437952,157.36486,164.973846,95.132713,14.802886,-145.660694,-164.770046,-95.744083,-38.761738,-19.631848,-48.47414,-108.279692,-192.838579,-202.588578,-163.938585,25.455179,133.983676,277.627397,315.62943,329.8749,315.767628,290.614423,296.680392,337.312057,322.852117,299.467772,223.057717,154.659645,-19.375452,-87.199279,-74.645891,42.548196,78.142572,78.287115,23.799996,-154.351394,-214.186698,-210.353672,-171.501202,-127.466114,-133.841795,-120.900319,-128.452785,-182.057813,-334.012483,-382.513567,-361.180325,-195.428745,-68.491785,193.202704,281.962723,300.966808,236.601536,90.81555,79.050662,184.612783,274.795156,281.160751,183.270956,95.23284,-30.486438,-38.213194,52.711353,159.811902,185.194583,233.871269,245.815817,162.548036,83.379093,-58.271513,-98.51206,-79.769479,31.992985,85.421861,114.797495,73.210131,-82.90206,-146.975112,-133.722521,5.368987,58.733564,95.015063,91.575325,55.449907,7.120117,-105.396817,-94.858971,82.776579,166.624256,134.477312,68.754366,35.491525,-150.016983,-270.647095,-306.524283,-59.357733,59.416667,164.877463,123.929989,-93.834705,-188.805846,-247.025126,-221.201276,-109.906273,-5.555077,28.45116,45.511904,17.114148,-111.471465,-177.379131,-134.435695,109.510368,203.49866,283.675517,276.757841,174.76013,114.950221,84.950375,121.663312,188.270465,199.812885,209.737092,129.931066,31.813833,-129.966825,-178.496143,-205.246219,-129.415386,-107.188973,-105.734683,-99.968518,-148.881509,-223.933733,-350.994606,-331.50413,-119.805179,94.855337,134.547392,51.517806,-29.171368,-121.094151,-100.365615,44.752264,130.503123,139.064086,156.022782,113.132953,-92.146315,-153.03076,-81.51007,-25.915494,-12.099312,-1.150636,38.391023,89.41978,62.873732,-57.850601,-114.441201,-125.177274,-14.272839,33.379662,123.694228,163.295401,120.762275,42.658645,-73.17679,-71.326372,-7.047601,73.383564,110.914411,77.867198,25.189738,-4.840797,0.227117,-57.971494,-86.469345,-28.68227,138.187548,149.243389,-11.341062,-100.941885,-167.595242,-134.189291,20.518847,109.974452,93.621618,-15.454963,-74.59643,-163.018178,-194.888469,-195.947718,-70.665083,21.906329,189.121329,227.350427,186.388456,122.869596,-33.934801,-76.367297,14.62289,168.505615,180.160736,17.400626,-126.927956,-387.21084,-468.411311,-495.705313,-326.025136,-210.810844,-100.07185,-132.50782,-253.631647,-302.876256,-368.268399,-342.430314,-136.881364,26.512748,42.042551,-21.847399,-69.219659,-158.54321,-211.161337,-286.405613,-171.983646,-35.154199,214.47767,239.936509,59.136842,-70.362974,-197.481828,-165.938729,-9.446122,127.865699,171.503406,133.292355,69.649492,-14.291976,-39.197731,-68.730031,-56.182984,-46.013701,-41.137157,-72.753368,-223.365826,-322.814963,-456.21253,-434.943235,-252.997746,-81.880025,-20.265769,15.126945,-15.940818,-86.031235,-99.577721,-60.294391,25.716505,55.650572,74.227963,43.798836,-121.895943,-207.711359,-257.107506,-226.643971,-114.282537,60.894365,166.748289,240.920191,144.083108,-195.3267,-325.664137,-321.345845,-93.114125,4.844295,106.051873,94.750486,-45.460083,-122.723271,-190.341831,-177.233918,-95.174472,5.859682,52.02247,69.838385,41.113629,-25.624701,-85.607873,-242.263942,-218.658448,-132.738336,37.786512,72.92706,-9.771315,-103.543238,-226.695978,-199.232846,-27.60096,77.823754,73.983245,-17.260203,-82.659933,-195.300226,-227.27773,-211.921622,-49.739472,75.591572,258.840921,249.380107,76.28815,2.330077,-36.980444,-36.908278,13.458513,196.877725,271.384358,198.17451,63.129044,-190.5335,-253.659245,-227.740314,-9.995105,117.651838,224.682359,165.293189,-41.07536,-104.257819,-131.049535,-115.701783,-10.020326,135.737892,172.904669,147.670564,93.371745,-63.097337,-127.877714,-144.929215,-22.453578,70.306602,197.280676,173.609315,-31.533286,-133.337546,-193.32041,-170.824091,-77.463468,96.215594,174.311198,172.922606,91.224137,-108.383006,-168.020107,-116.513095,73.995732,136.256616,114.350605,64.393211,-16.212716,-39.185345,-100.478471,-128.336181,-62.283967,67.461865,76.589146,-14.420767,-62.399593,-151.117113,-218.570773,-302.091321,-186.146341,-88.620962,20.892223,-7.13863,-144.925045,-195.998737,-221.744017,-197.783047:3.129498,-49.096346,-17.687527,20.878067,-19.561364,-69.140856,-28.389906,61.382712,87.793737,114.891813,230.376436,298.642699,361.256609,329.1531,165.522562,81.111502,10.797791,13.833454,7.962597,-19.417618,-45.736636,-113.763999,-142.704804,-145.885793,-29.462925,48.294006,162.12372,176.649354,109.993184,61.224455,-15.223229,-54.306562,-142.051617,-221.197232,-240.339736,-222.54054,-187.002755,-118.256712,-108.726871,-100.587026,-21.332802,25.523985,72.768863,84.583881,127.577356,146.38647,131.359505,126.443258,163.064547,130.028811,93.779338,35.1941,6.678537,2.532601,5.569678,-64.183407,13.441803,124.470409,246.391869,238.064142,168.547553,120.715051,36.508188,14.975685,-32.218617,-125.597028,-159.102688,-142.995776,-114.909425,-103.995022,-114.355568,-99.46736,-51.386169,1.892106,199.426614,274.378355,233.149514,167.410373,97.945913,96.480167,134.45909,176.546649,200.929041,245.018385,223.402961,135.537429,141.804665,266.002014,340.763301,309.792673,194.400004,157.958083,145.13055,154.618884,147.254768,134.94011,147.059273,99.676727,48.311514,57.535848,147.125607,359.543629,395.35757,313.479964,197.101013,171.097164,261.742329,351.232135,439.76555,396.295959,235.38399,210.039193,299.260806,344.219867,342.312968,360.600843,353.338452,256.145996,193.989565,152.824091,282.552904,363.731155,375.902422,284.278376,9.423158,-115.5708,-283.209768,-326.338159,-334.666557,-313.14576,-322.768435,-361.747544,-354.121574,-292.183999,-293.933026,-311.319303,-115.228072,-4.223947,51.291946,15.558713,-74.893381,-101.594881,-81.081756,-17.678582,146.067357,151.007444,114.393552,97.575968,101.919807,87.629401,99.13498,204.625488,285.308374,267.725294,202.274899,198.931433,220.958596,219.496505,187.074187,177.504884,199.39885,258.97408,307.771724,336.207581,270.044689,138.118052,164.369316,311.912645,285.606168,229.413753,180.928427,165.704917,96.190612,60.573378,-1.66236,-13.417932,68.254315,228.399045,300.213588,329.378404,276.953605,199.762335,215.450026,232.389122,160.028756,139.652693,176.597823,207.94403,220.080396,200.039439,132.7718,80.053277,-45.195458,-83.97737,-54.05884,13.090962,13.060355,-7.135766,-0.746555,26.138951,17.886608,3.356784,43.429274,93.990884,101.374536,50.428223,-4.531135,21.447808,90.025051,57.507911,1.066369,-92.74474,-68.498651,90.19291,122.231696,-6.623683,-148.48273,-147.315742,-3.80942,80.772597,137.956995,109.400272,-32.95263,-121.562369,-177.801534,-58.542403,-11.736255,-55.773293,-120.950587,-198.067636,-223.963999,-303.420202,-250.103044,-167.631774,-34.964721,-13.327411,-15.757385,-27.262458,-109.385693,-155.364798,-103.796805,76.100341,140.367018,171.919784,154.273019,48.497671,-62.501501,-264.240773,-198.005945,-117.855137,20.682255,90.407865,143.062186,87.741809,-105.931782,-167.207018,-112.565937,43.365219,103.351904,118.13375,74.63864,39.420434,71.876285,115.576893,55.650685,17.695466,34.16462,67.500744,28.266778,-36.433519,-98.375147,-69.38252,45.536832,104.634041,94.73626,80.340396,100.66563,151.492923,138.65052,35.509771,-3.729772,-0.401087,-56.938153,-120.723306,-230.764508,-231.18327,-139.331291,-107.518567,-115.89972,-63.385154,7.657812,86.540964,52.62839,-39.136536,-37.726845,-1.121654,-26.250133,-42.765756,-55.147231,-57.228632,-40.857399,-47.149284,-190.336341,-288.342121,-378.160193,-315.238323,-242.089206,-139.25952,-147.583095,-199.30754,-227.154399,-335.153343,-374.749958,-354.375166,-348.058759,-359.116138,-370.024524,-367.244052,-353.596703,-343.433036,-285.402511,-237.326511,-237.456254,-259.696176,-273.711914,-267.908166,-261.67377,-301.699814,-255.040635,-163.734507,-16.039577,-33.416342,-187.903407,-215.37776,-99.333719,-26.714316,18.460639,-34.762994,-59.058685,-106.150208,-133.152777,-171.639382,-195.074313,-246.702751,-199.155117,-122.68375,63.02386,106.409948,1.551129,-92.043545,-173.073838,-139.681815,-38.849412,-42.751597,-58.156514,-73.023424,-91.280095,-122.39286,-126.552149,-189.370301,-217.033036,-156.184311,-46.933294,-68.094044,-189.123117,-225.501474,-228.694727,-206.256509,-132.442721,-99.324562,-85.676112,-46.260154,-56.47229,-138.916181,-191.724014,-242.420731,-128.581088,-71.932005,-2.041705,31.658721,33.223305,1.483954,-40.237736,-29.494902,69.578078,174.140566,202.614882,206.836822,186.829309,146.650616,117.426163,47.915681,62.142657,86.212122,93.249253,91.487741,131.235395,145.405939,58.76723,-9.143708:-204.918302,-174.98173,-102.909827,-13.624062,-41.9903,-133.022653,-135.734042,-82.371962,-36.338435,-12.215689,66.590517,119.520855,207.455274,219.081656,112.320021,-2.460268,-219.223318,-256.711325,-213.098282,-151.515721,-165.716052,-217.50451,-241.588249,-298.873534,-289.366807,-224.480569,-6.980033,82.919963,117.634713,82.497031,-22.845512,-77.692753,-145.642178,-171.77252,-185.917141,-189.567024,-151.869093,-13.080872,37.512965,67.663095,57.145532,23.151101,-71.128534,-97.469307,-72.613891,-29.857811,39.744322,36.721651,-65.818911,-163.776085,-140.495739,-76.626977,-104.253643,-157.107672,-157.03936,-188.66368,-130.095188,-33.910529,117.270175,99.275222,-34.817285,-70.445734,-107.712827,-136.053462,-183.653499,-250.34122,-259.859458,-174.990105,-125.796494,-128.110514,-163.942659,-159.756574,-65.934498,-33.89107,58.23388,135.101351,193.935429,137.0691,1.517944,-4.393271,109.614992,216.165603,240.112732,233.505514,198.56957,120.542015,105.375781,141.247422,178.344475,155.495757,65.483959,30.601789,21.445134,30.310332,-40.526095,-119.28993,-216.689516,-163.481036,-104.570363,-5.850426,4.942641,4.508952,32.209268,100.270544,55.487732,13.603642,76.159848,185.036325,321.828423,280.158576,101.047876,66.049653,150.540231,217.833764,223.858003,209.924843,177.069281,95.517604,69.113618,86.20594,176.054267,205.048259,180.301844,114.4363,-62.525057,-129.068385,-249.720799,-329.102861,-462.305612,-465.580865,-418.133725,-337.337384,-344.869816,-400.888959,-404.789255,-315.8866,-134.256003,-56.778145,26.413416,39.241962,-3.594504,-46.926848,-89.329842,-74.058032,-11.585117,15.518813,9.157746,-27.996825,-43.513874,-35.329066,-23.867757,14.564602,68.063942,64.476224,24.309973,14.775757,24.899082,51.70465,107.794474,95.6608,0.199539,17.29448,96.950002,163.095353,100.788132,11.863967,58.491423,188.270481,128.096425,52.354041,-41.900556,-69.117175,-101.459051,-76.454201,-12.341017,-16.472466,-3.720823,93.228147,122.174354,130.090267,109.942004,9.36061,-43.201914,-55.726584,24.502718,35.862548,-1.671637,2.684848,106.535409,159.850843,115.026968,25.209033,-104.813636,-79.146771,-46.947412,-47.711368,-89.382478,-137.580777,-130.971247,-160.339404,-235.376741,-239.44897,-99.557627,-3.093568,8.790422,-63.666963,-126.41058,-79.86033,47.413054,35.260624,-26.418537,-196.406573,-252.169425,-185.361647,-102.44638,-22.350895,-84.092232,-109.189088,-1.48856,110.273288,267.450428,269.99027,108.713645,3.988142,-72.518856,-24.698911,-4.39072,-57.694163,-126.610547,-200.914112,-200.159531,-213.938448,-253.582105,-267.14341,-197.812393,-121.478156,-32.246682,-60.547789,-194.723463,-216.849678,-100.688176,-19.819064,-13.470086,45.018193,90.499574,86.690937,-4.798094,-238.28443,-273.663233,-228.334862,-100.938372,-25.667622,58.063759,34.772795,-104.727994,-167.615633,-176.969095,-66.020335,16.20548,125.840358,115.489152,82.142675,112.882754,181.09077,137.21737,116.136195,139.502334,129.885041,-13.399252,-75.97538,-20.679692,68.040043,210.418066,235.536107,222.326602,259.344149,330.013202,435.066594,417.917625,336.529053,286.368503,239.417152,112.293732,62.816923,34.920577,71.867166,207.920888,262.838863,295.358656,284.934817,293.254754,304.587341,274.715789,146.888419,88.21815,51.389629,-5.082736,-91.756333,-183.637246,-135.041097,-36.33826,-55.500648,-175.340597,-211.346561,-188.796375,-153.322335,-148.626876,-128.072161,-95.420679,-44.169466,-74.606179,-192.082522,-228.188836,-241.449671,-282.219973,-287.553009,-268.375203,-257.67273,-254.675616,-243.386201,-163.380596,-79.483128,-43.614947,-5.564464,-12.431658,-27.555972,-44.059498,-117.31448,-86.637143,-4.762155,175.653624,200.014693,59.201341,-15.962398,17.884404,87.17772,131.328936,49.899704,64.686056,163.647772,147.135102,33.135739,7.597097,-18.501125,-108.559729,-124.95192,-3.439922,71.025095,100.32375,67.999506,-54.98103,-117.216648,-158.058463,-129.835736,-99.731583,7.451977,37.480843,-26.447698,-82.607999,-147.161373,-140.834683,-109.383718,10.228075,48.053433,-11.137614,-77.510562,-198.656874,-226.253333,-179.309074,-130.943428,-111.238252,-7.451557,31.081354,-32.916087,-119.316468,-241.402604,-168.946932,-103.378314,5.7057,40.941435,59.613113,65.132632,94.76767,106.04624,118.6233,153.26355,180.567142,187.358004,161.622931,79.101922,33.313971,19.905438,41.768863,13.820239,-13.336635,4.396684,18.934667,18.823804,10.958605,-15.118244:-151.306939,-101.742423,-51.16153,-17.613977,-24.227452,-38.457989,-52.634291,-87.136445,-47.554338,11.712969,177.870047,261.746757,346.473473,324.622749,127.77758,-2.287556,-73.082636,74.424959,107.366549,23.046815,-35.022454,-102.663246,-142.382778,-184.101013,-24.90492,74.648007,225.670172,281.570286,260.623154,165.637081,-57.385371,-118.086662,-122.487859,-95.706321,-90.261994,-98.320904,-108.901301,-110.828258,-104.008381,-49.295185,97.381318,163.195208,224.032013,219.387984,162.027394,143.704884,185.203386,245.345325,324.366323,244.140856,215.586684,162.996221,76.1064,-101.817567,-128.98248,-113.078122,-25.662034,41.224663,104.835816,71.646659,-30.960487,-53.740633,-61.540203,-59.186856,-63.861558,-139.229601,-181.457291,-217.477499,-218.179404,-227.764713,-240.054602,-206.18811,-91.332865,-44.664314,12.644502,42.639421,150.805669,204.050358,157.186874,72.487398,-11.534204,0.738414,1.482957,56.414021,105.746756,124.608384,91.519098,81.315282,179.877286,215.07518,228.609172,220.490501,184.456597,147.427474,11.472822,-58.225795,-104.753776,-47.902367,-17.432233,45.008712,91.216782,168.304072,177.073801,155.663452,125.398535,130.73457,198.760687,220.119723,188.706749,152.741328,64.522863,42.260419,105.983807,214.714728,230.814061,175.528463,135.861531,36.320768,-23.177046,-43.684919,95.973589,148.860961,151.710351,105.189601,-76.060306,-174.138976,-279.508366,-268.736012,-185.19883,-155.104361,-160.142797,-208.284877,-236.577349,-210.187778,-169.025821,-87.970352,15.682359,58.156199,91.891457,53.956977,-112.549719,-153.427285,-52.986186,27.413087,106.199444,86.542968,61.482623,-16.451985,-59.227919,-101.676247,-94.711403,-25.638567,72.844166,100.870273,87.675384,65.585218,10.168397,-24.861868,-41.613461,5.162992,126.672873,155.648921,165.431569,178.349059,142.701478,45.146209,46.291096,173.467745,287.308758,294.562035,244.291855,182.80772,22.483934,-14.138397,40.212362,71.608481,62.930438,57.097596,77.656907,129.223132,145.285308,139.247252,114.619687,69.640827,58.672394,50.177929,56.278772,68.057284,38.913528,4.137413,-9.84967,27.251879,106.155641,107.97944,118.791389,134.280183,90.202339,-0.571584,-6.342116,-16.918562,-33.676969,-14.827557,81.517328,112.314726,52.071712,0.676155,-46.809011,-43.079329,6.212785,18.961997,-25.056415,-135.220716,-156.596622,-99.804983,-64.083936,-104.260013,-177.29898,-155.761926,0.420507,79.156098,136.79969,117.234676,-8.307327,-77.764033,-84.724578,43.947631,95.06974,76.125619,-2.375958,-211.222702,-306.530654,-429.780762,-358.119939,-257.075681,-50.018201,27.647266,88.315675,48.0689,-119.665174,-166.388862,-102.218883,10.234666,32.906415,-12.799717,-58.406718,-136.071631,-173.863373,-188.983608,-45.634838,29.922218,90.899611,82.068491,38.699955,5.717915,-89.848987,-109.602315,-5.295324,173.409386,201.997673,99.233131,36.823244,29.16235,52.22209,45.256681,-2.048786,-38.656823,-93.567408,-110.981787,-168.207482,-180.518478,-176.850897,-178.551685,-127.808896,-73.105266,-82.113121,-91.680655,-76.012278,-55.45233,-64.223939,-89.283758,-71.364894,-62.225946,-95.732107,-133.317301,-187.451945,-189.187256,-152.947599,-115.6483,-19.522083,64.362649,116.002504,182.792109,152.240708,8.18977,-41.89694,-37.943616,-10.401236,0.92397,78.162262,122.693661,136.642691,93.711038,-86.829254,-168.884999,-168.757862,-60.323175,-20.329273,6.280412,-18.610314,-125.547589,-193.012166,-310.171694,-288.078516,-222.833358,-103.804917,-89.902097,-180.511419,-265.580227,-358.37891,-308.06788,-117.838585,-70.735025,-93.187751,-174.98707,-228.86583,-276.500205,-272.496654,-268.852874,-166.230273,-50.964498,151.927609,157.727377,-24.295923,-125.688296,-174.085362,-134.392796,-43.551196,47.093255,94.926187,88.584365,30.715798,-65.982502,-107.108238,-233.539057,-242.774791,-149.517555,81.144594,105.712159,-32.516426,-97.158797,-129.890404,-117.507501,-35.868125,100.661904,132.182394,47.981609,-27.164233,-88.020575,-68.733619,-49.095132,-52.369821,-32.795777,28.53677,60.404617,64.460634,5.161298,-164.043058,-182.48962,-18.022147,105.423164,95.363136,40.462982,2.240082,-95.405468,-132.157535,-112.543417,68.827096,137.394499,108.987312,63.273855,21.687134,10.727026,-67.406458,-103.616189,-13.810212,188.062613,248.583689,230.589513,166.722748,32.07824,-9.375055,-27.475368,-20.235025,-24.146574,20.21023,40.361287,-55.819273,-124.129632,-118.625726,-60.916578:forward
-11.403351,-222.540131,-296.261987,-284.567694,-222.876182,-46.784234,26.17074,-24.2984,-292.929203,-393.825243,-402.296084,-365.758961,-335.05764,-307.349378,-207.444193,-197.300659,-312.566088,-411.44108,-391.073549,-267.915373,-219.634184,-207.590779,-222.685639,-193.108149,-186.205479,-253.229023,-375.695559,-379.749873,-312.62729,-270.055755,-201.403864,-157.903659,-40.286729,20.373376,22.114336,-5.331733,-12.178477,50.955334,97.065935,167.804561,267.195489,304.868657,285.634576,245.520355,188.298788,172.029883,118.344426,86.820809,31.759291,-69.111532,-121.360004,-121.187439,-47.598424,131.213459,161.902149,136.773871,123.95313,117.690273,127.380746,153.0657,226.462621,262.114695,347.114168,387.165074,331.225164,142.723106,116.344148,197.054128,231.947187,238.341862,209.841711,103.712466,5.550099,-26.742475,-25.742165,9.655279,91.742095,129.729831,182.452719,170.960622,75.113676,-34.806207,-85.546923,-157.665687,-170.372447,-183.370096,-194.326458,-207.464205,-269.673959,-327.376331,-355.688913,-295.307202,-111.464609,-47.104667,-68.811357,-125.360598,-222.591044,-301.087095,-313.655729,-286.387057,-249.097101,-109.531889,-68.232155,-135.935846,-234.341291,-263.892702,-260.673037,-215.67135,-19.764866,106.657146,229.867518,205.925227,160.057642,163.036283,151.49726,131.298917,136.730306,219.046973,267.526257,232.172829,66.608567,9.647098,71.317378,168.688675,304.109434,310.300027,294.589916,295.832364,236.199961,83.087265,49.457497,152.638215,241.267498,332.597216,311.111705,247.045909,271.407718,257.465322,172.220285,168.255428,234.915091,256.313848,280.205757,306.593504,305.801949,140.549998,70.654572,69.711684,125.871179,283.69716,335.89502,338.764355,234.373988,152.296171,68.551855,104.147328,243.219056,288.126883,270.511235,238.223514,164.360674,30.59751,-4.762578,82.644419,167.628016,300.68898,313.720009,241.846507,166.735372,140.586466,112.231113,107.418894,143.395542,197.603472,266.098844,239.953852,117.730004,-6.755168,-46.5418,-45.618734,-13.969529,44.606218,59.181281,49.515614,-23.740695,-62.217227,-50.368173,-4.418225,56.792724,51.276332,11.687762,4.06054,-4.28349,-52.880118,-47.313918,63.741107,126.562294,180.85192,175.199197,150.20578,68.84924,10.381534,-32.399115,-14.542957,51.433538,85.22983,94.443696,74.920765,32.700991,-31.525015,-31.89157,42.641043,60.326621,31.375514,16.398818,58.973609,132.741174,123.243321,60.783882,65.774479,138.467141,147.862572,99.415152,91.925039,103.653152,29.077831,-13.371843,-44.794773,-53.924344,-28.966792,21.599973,72.535043,-68.089332,-169.571472,-265.492881,-250.806121,-177.537518,-122.112777,24.762848,94.670644,135.743303,-2.36043,-79.214167,-134.183456,-118.586415,-68.92433,-76.922588,-221.560758,-363.128775,-354.284922,-223.422553,-161.708594,-107.118542,-98.904423,-89.545201,-70.433063,-40.634404,-142.672609,-167.839245,-32.2781,57.911589,123.149378,106.543622,62.091187,51.719718,49.818911,53.700305,64.742621,120.387317,171.5305,246.003237,247.066454,182.40115,35.966574,-3.801587,37.358836,67.829308,78.963558,48.788935,-85.975002,-238.886569,-288.628472,-275.623259,-230.483488,-157.717495,-130.103063,-82.035319,-84.283079,-145.000546,-169.124637,-144.904524,-88.20332,-70.016941,-56.65864,-77.527332,-116.950783,-59.155951,-40.717472,-66.739204,-62.512971,40.980026,114.795994,182.826273,155.025763,58.566629,24.91594,39.10297,123.606746,196.256031,365.376466,413.518728,355.876629,226.644655,197.261977,238.577683,289.29454,410.172338,472.650094,475.497831,393.671764,245.60822,227.78784,223.975224,184.018053,166.987282,201.849125,234.136363,208.720516,79.786842,16.828253,-57.375975,-78.643975,-135.08558,-161.584849,-179.714273,-172.069424,-168.164443,-275.935815,-340.104145,-327.618162,-247.102052,-104.209023,-102.511281,-189.674209,-247.705883,-253.133956,-198.621531,-145.941261,-35.905993,20.218097,97.600629,82.560588,-60.284191,-215.011622,-233.437166,-97.684729,12.101012,128.119673,98.046418,-58.619133,-204.961211,-257.861033,-265.822044,-216.028135,-91.187062,-55.312072,-70.57295,-83.868405,-38.23523,27.884956,21.704836,-96.824255,-161.548968,-167.601815,-125.950203,-110.379921,-197.899959,-217.14885,-178.581105,-175.02329,-212.607187,-192.163043,-85.911135,-52.223512,-57.695404,-104.604771,-92.876088,-19.040373,-21.138339,-43.720816,8.532051,106.244615,-45.219113,-132.090118,-138.012106,-82.144192,19.622136,44.949555,41.936054,16.503666:-144.493109,-271.64864,-249.982551,-181.721258,-201.197627,-270.801347,-275.990888,-294.311434,-407.489329,-453.960294,-480.078273,-480.395615,-422.759137,-350.525231,-230.870189,-232.914647,-317.726318,-338.319248,-297.97634,-184.178264,-160.725868,-237.790021,-299.506656,-298.106188,-193.766229,-194.503972,-256.671324,-264.763365,-215.148357,-165.810741,-61.607714,-20.33907,17.627482,-24.590624,-40.10961,18.66254,69.249167,139.058631,159.225114,199.443882,220.326913,224.273451,262.221859,288.171076,288.414536,254.265358,160.667099,106.820952,27.439832,59.580377,89.374739,116.064213,134.310501,155.794146,138.437369,125.415728,153.277134,156.443177,131.052611,121.573292,160.148855,204.434102,288.763103,309.481378,247.334425,100.763963,85.054052,172.470253,203.344023,158.519297,102.278426,-2.422462,-21.775826,10.75798,88.046922,101.141059,102.62399,99.542158,53.660187,21.850329,-1.624742,-22.111506,-43.85295,-40.156482,-3.26521,49.121387,13.608895,-158.49096,-256.795106,-237.346159,-122.786861,-71.733445,-25.082333,-15.117634,-35.46133,-80.861484,-187.577713,-233.732843,-227.945891,-179.228524,-133.799167,-8.074844,25.13227,-33.960436,-163.166467,-209.051269,-172.873893,-98.674714,82.021488,171.089991,258.071808,230.484703,103.897383,42.6802,49.02001,60.989878,90.876618,264.964812,336.001921,299.588342,162.072271,117.724732,138.535563,187.527286,248.692417,233.049344,176.010845,173.676891,167.439114,84.001537,65.047446,100.151522,133.917161,240.717592,282.72324,242.399397,122.665457,119.462296,267.966061,332.259931,288.785807,231.163954,245.88282,309.281095,327.60205,173.419502,127.641477,163.260246,211.414788,297.148627,305.611138,241.417328,126.950772,68.949432,32.058823,58.332639,160.203532,208.906712,200.19341,152.294869,62.693767,-23.329506,-49.094134,4.631443,59.409746,129.577165,136.515271,102.220288,11.770322,-18.075225,22.827241,81.938273,193.5815,203.084485,110.851573,38.455179,-101.828466,-198.146485,-208.153731,-119.816052,-44.728109,19.991176,-16.476572,-125.175578,-126.497399,-68.208126,59.415554,70.403089,18.818441,1.610598,7.646625,19.20006,20.787854,18.652929,45.885254,121.546756,131.277129,84.377454,63.356147,80.914684,63.47988,26.187067,3.224899,28.14613,68.301309,61.030856,19.601373,3.391403,-13.364623,-22.767302,-22.017445,-54.537844,-84.169113,-61.659174,-2.145798,89.121693,76.746651,64.729316,73.86603,81.71424,93.410782,105.819154,95.906342,60.740776,5.669719,24.503041,38.653699,30.621008,16.310982,51.395038,94.125698,71.837693,-122.609091,-206.813159,-243.729871,-206.419759,-114.096358,-86.464584,-53.080494,-29.250809,2.200322,-97.108665,-162.87594,-194.473121,-150.278169,-63.57953,-101.036081,-316.158427,-433.682041,-415.777918,-286.143151,-221.631436,-181.883262,-205.960715,-267.187788,-256.781961,-176.882293,-163.903093,-142.871024,-10.631774,55.250664,116.371601,122.673019,106.314448,22.191284,-6.279263,48.4054,95.645561,134.07253,134.914031,148.536647,162.132991,147.995203,56.721835,32.641628,56.887938,76.507887,77.147488,41.391058,-78.833587,-216.051764,-274.302866,-295.944332,-249.177595,-88.397684,-0.658303,74.411647,28.072039,-123.833123,-157.272512,-132.6828,-96.843397,-91.811911,-85.986759,-91.764242,-104.565155,-119.963784,-145.030007,-137.213418,-64.300491,124.317479,181.37395,182.034013,134.126311,-1.872684,-12.288199,73.086213,286.649809,345.286633,366.489372,354.681008,291.152251,214.804414,207.328272,284.765802,347.475787,449.048097,470.441857,392.171162,309.360321,190.169635,140.942349,142.544503,214.408601,253.765414,305.377567,309.399675,233.995098,135.629779,86.975863,-42.097439,-93.42184,-107.37987,-92.302729,-101.736373,-123.885952,-156.316627,-191.913085,-206.31721,-172.380716,-113.992083,32.970569,70.322866,-14.439606,-188.062209,-221.106758,-165.076201,-123.541149,-34.474231,29.61905,98.216119,62.361613,-50.974675,-128.42561,-149.639415,-102.622772,-48.246825,16.515457,13.286594,-35.11299,-109.172359,-125.604957,-44.988549,17.386388,89.353222,102.852309,49.125165,-0.539722,-20.335037,-2.159774,-4.959534,3.970736,9.785044,-8.130664,-22.112043,-7.014314,47.13302,49.43059,4.446098,-27.846178,-72.117797,-53.663371,33.942366,63.746119,46.094014,-91.200255,-145.873305,-104.325019,-44.194516,29.595101,31.874485,-9.178655,-105.126272,-141.127907,-69.193619,9.351217,119.206837,135.219355,106.462258,91.125906:-203.376671,-237.478585,-232.652394,-188.681675,-165.383736,-149.348132,-170.056806,-287.601095,-446.66818,-499.234197,-532.775666,-510.94482,-368.997231,-299.053256,-291.974916,-310.143757,-312.659686,-316.395728,-289.727637,-184.501709,-148.530111,-173.689105,-229.361972,-336.380928,-343.018669,-305.206808,-202.742107,-164.069271,-108.287025,-82.591214,-46.264215,-30.392764,28.177758,111.789592,136.133861,120.060867,116.479185,181.295994,215.771859,195.083248,81.886046,67.133052,181.65787,236.292824,243.970714,223.352553,150.79976,101.000514,34.202463,47.926784,50.621471,3.389081,-4.846671,51.511116,67.930402,37.207555,-0.876339,-13.317227,23.174683,86.550989,206.436978,219.966,200.93949,192.934275,107.663691,-10.823508,5.248981,131.443807,155.897996,79.559587,22.868697,-54.331024,-125.657992,-145.665833,-68.624008,4.731583,88.915528,86.713928,32.27983,-24.122266,-154.03867,-111.753878,-24.925104,75.382433,47.013858,-59.640734,-84.347965,-100.343355,-177.888746,-206.925432,-162.052386,-113.658929,-2.953293,51.058427,42.119778,-31.717674,-212.215009,-261.100367,-200.260493,-84.247506,-92.353053,-128.785928,-117.156864,-97.574477,-121.939329,-113.499666,-10.299091,42.777362,114.26736,159.263694,207.034487,171.930147,27.077229,-25.872292,-2.630115,41.035526,75.456185,190.362386,217.911981,167.253194,80.035195,56.566073,93.722301,138.806355,195.263971,184.034426,84.49855,35.679008,-3.075154,-36.756156,-41.890528,10.966782,64.983104,202.31769,247.871654,208.181174,57.400042,-1.721135,25.502375,104.933184,257.926677,288.14068,269.718987,255.931174,202.727231,86.906854,54.991142,81.717587,137.197474,289.043985,320.295958,209.128011,25.572885,-22.36112,-6.653689,40.163411,164.161464,184.346578,77.204624,15.580933,-13.536214,-28.975149,-40.375155,-19.485355,6.811342,33.193474,26.025274,-5.498164,-103.004914,-158.787722,-136.434006,-57.394649,53.386955,32.929557,-87.23659,-138.130181,-199.827886,-228.508069,-219.168784,-140.341288,-70.969859,65.467364,81.241707,13.932838,-18.761547,8.019027,87.427828,85.117049,19.646516,10.638835,51.316983,73.978882,51.129367,-25.420145,-11.505936,130.28294,193.877958,180.656075,129.256486,80.120117,56.450084,56.021181,147.335104,179.750329,95.680126,41.720119,37.436569,46.961333,15.062908,-19.253254,-25.138596,-69.730457,-101.815067,-73.582819,-7.97103,98.217246,81.936134,58.56472,61.89313,85.52438,144.078943,159.653616,111.836762,69.354489,47.694619,88.637429,106.874911,155.796125,173.036415,155.140887,144.746202,122.087328,3.315702,-71.021084,-131.247637,-102.0306,-16.338248,-9.708366,-62.094913,-76.848638,-68.510458,-119.634064,-164.340138,-180.328104,-125.947001,4.361044,2.208123,-137.149102,-280.759276,-312.783392,-277.261382,-236.829555,-156.511328,-124.386751,-120.63663,-138.95385,-167.324457,-159.130709,-122.307092,-6.763852,64.151031,184.272526,184.532577,55.691752,-48.395943,-26.780662,110.329716,165.547769,226.500406,245.491251,218.076223,173.560474,113.463409,115.262114,130.379988,192.046911,218.877371,186.471854,129.206382,-11.49139,-195.845961,-269.230613,-250.559485,-178.940923,-13.415137,64.243814,140.452755,126.037699,16.878817,-75.648346,-62.531523,22.935395,51.890739,63.153723,54.845236,49.170767,50.969195,30.495484,19.187869,76.592485,278.870921,347.356215,303.556551,223.662606,86.770094,112.633502,192.024716,342.59168,377.791626,390.441511,367.216319,244.768873,125.457026,116.701573,199.304483,255.023759,347.656819,380.37205,355.678699,303.561739,215.817878,155.851951,136.876183,177.591354,237.224256,336.745939,333.973161,248.406055,163.151203,111.365019,14.2158,0.142358,8.323115,4.563706,-21.982884,-34.861676,-40.096699,-31.907164,-39.388165,-72.880004,-63.963534,8.458384,4.535873,-115.030422,-205.543864,-207.93275,-150.083431,-121.620935,-53.465948,5.712673,62.176686,19.046982,-102.490284,-148.236986,-146.698129,-104.995136,-65.836543,20.828453,37.671155,-32.296397,-151.748251,-156.974873,-65.957978,-37.857455,-29.80431,-18.997951,-12.151359,-13.043258,-13.372427,-58.593116,-53.155502,29.246845,60.593076,79.467674,79.337082,66.742609,34.424847,27.608691,50.508375,45.447896,3.928172,6.545759,18.926688,3.357432,-37.272374,-91.529825,-106.211317,-41.618802,11.001158,48.312295,15.636328,-130.575066,-244.816934,-235.433345,-84.559647,-2.944605,63.291785,69.824587,68.372837,53.33031:-162.96178,-283.154436,-288.976144,-250.757497,-230.432496,-166.420186,-146.484439,-242.076704,-438.798718,-492.943822,-476.37351,-460.422027,-461.421775,-433.100198,-349.299869,-351.872522,-436.469064,-482.029949,-439.276972,-255.897518,-194.606136,-208.15236,-217.031648,-147.500359,-203.290324,-289.98933,-347.537572,-304.829138,-194.579175,-148.277702,-74.848211,-55.501432,-66.23004,-85.5011,-55.54288,31.49831,32.262306,-1.034364,20.603097,120.651846,159.990352,156.428472,134.432892,112.516212,76.635957,79.352061,82.827901,54.427482,-30.331181,-65.03481,-64.00065,-46.760426,-12.609682,83.711741,84.574733,6.90277,11.006786,39.423411,106.289337,140.099033,192.63814,226.453722,328.166341,356.665024,250.080799,67.532385,55.307706,152.699815,192.161548,186.226106,153.469463,84.631172,3.938588,-41.072507,-50.005103,-9.891517,69.598777,81.706942,36.036992,-0.499423,-43.304958,-59.545425,-65.278634,-78.655141,-75.328742,-29.552458,-4.453331,-33.083407,-175.989502,-226.913035,-191.482056,-143.469335,-85.537461,-68.510682,-60.080772,-70.877505,-98.300208,-145.585298,-156.526552,-132.337849,-116.854692,-74.068456,-58.032367,-103.816776,-175.265504,-172.210953,-81.113146,-23.026258,74.836208,126.551322,224.410615,246.355833,209.207116,130.759245,118.947569,163.507621,217.540702,351.467344,371.378012,284.094471,141.760284,88.922165,107.004918,151.861177,215.407712,234.343408,224.929685,189.520028,65.530198,-87.074982,-103.119032,32.017456,120.380618,210.485586,207.376803,175.529558,177.176149,165.571155,108.788933,99.120367,150.180171,192.048485,240.560444,241.636911,191.075834,66.474465,26.410632,39.197076,73.849055,164.898658,187.789413,135.981851,67.57407,38.387203,-14.526272,-10.558114,67.653497,95.672248,60.009736,30.585526,5.43295,-36.152346,-43.490691,23.045571,61.180183,79.779112,80.125953,86.288116,17.920341,-37.519865,-65.079254,-29.028485,38.169004,40.518063,-11.799525,-49.359929,-96.553249,-52.500854,-18.138966,-42.32483,-59.357726,59.947512,147.435301,167.511751,11.966409,-31.682574,20.978096,44.229109,-1.177588,-27.243981,-41.454531,-35.361554,-30.091072,-69.977281,-50.192354,128.445269,214.379643,227.09348,191.10986,159.571507,97.598343,52.580105,71.056865,126.622597,180.213439,164.72659,97.495051,46.965965,-76.271323,-100.948903,-43.655301,53.752379,49.811092,49.787302,72.658398,99.024574,77.469953,53.786067,57.973816,104.319158,205.51282,215.895877,122.296394,67.926153,65.72006,67.419238,36.842012,19.817998,55.212855,160.27861,191.870306,131.160796,-56.009735,-127.753236,-122.534375,-80.22175,-46.774966,-51.772607,-30.735871,4.504173,35.156984,-45.460065,-69.227532,-25.183146,12.720584,18.552931,-42.246546,-229.605948,-335.595402,-333.700375,-244.625329,-185.63712,-132.057975,-134.920914,-94.162126,-42.124638,-11.479789,-89.514728,-83.633898,80.002097,182.168178,257.865849,208.85506,51.711544,48.739425,106.308768,235.119112,283.67416,315.680908,300.880058,238.848769,222.009729,258.03241,261.811126,242.834917,214.367582,190.201486,111.190132,63.728839,-58.548289,-201.030363,-253.019841,-243.972212,-188.708475,-41.651116,35.754197,115.086571,86.786618,-33.602642,-29.105984,36.758114,163.294693,189.480759,190.893087,172.776948,127.643719,115.073937,104.701276,144.654625,230.512981,437.35403,491.640749,432.220482,343.041391,163.873932,124.170948,179.025295,323.524327,366.467703,413.598628,414.811567,323.061559,199.61312,180.402618,263.167698,334.56157,424.58539,436.39329,368.677797,283.669403,143.119442,163.122464,193.010278,205.220769,209.063219,269.280965,294.258175,214.320832,37.901072,-32.568908,-86.52478,-71.873332,-19.458133,3.538794,2.462144,-32.621106,-126.696902,-203.848599,-241.894402,-268.333769,-211.56293,-30.177743,-8.860459,-149.411853,-240.635878,-217.464881,-121.102462,-93.989485,-82.043173,-43.149605,60.802353,37.259057,-161.835563,-296.512076,-278.672213,-136.643489,-67.183793,-5.3167,-22.942035,-135.347612,-268.285517,-299.298824,-236.242742,-175.49814,-63.531998,-22.979423,-37.702152,-77.530567,-124.279344,-127.986069,-104.422028,-36.339418,-44.324803,-135.393817,-171.023688,-173.328146,-84.891063,-29.175179,10.17076,-30.647123,-135.071292,-136.639993,-64.185059,-36.958077,-38.203984,-85.553879,-94.751693,-93.381897,-112.115447,-118.98008,-78.713114,-50.495551,-159.02043,-201.948483,-207.69985,-184.372831,-84.994483,-13.544393,52.657334,30.789798:-213.179607,-292.921422,-248.964214,-127.448704,-97.098011,-104.358151,-143.694391,-271.563557,-391.582955,-417.924394,-416.878801,-416.785979,-375.818948,-323.644105,-244.355225,-240.213215,-299.505949,-313.114978,-246.735356,-68.842533,-37.177837,-114.355222,-165.859537,-209.666383,-252.894331,-273.200415,-215.982647,-149.598211,-4.244767,51.850388,79.11499,68.15132,35.832428,17.694166,36.335159,71.295115,77.141124,80.27119,77.922277,80.181851,32.646568,-5.297596,-5.450476,26.606017,69.970639,55.939325,-24.317645,-39.362395,-2.011768,-19.215401,-59.023806,-96.322933,-58.039756,19.00756,-8.255796,-133.354287,-178.849394,-150.291767,-0.907708,95.193763,259.202121,308.039219,322.369965,282.113453,94.144409,-16.797877,42.324107,195.667944,196.864,109.63352,60.001997,-61.724049,-195.467502,-214.155418,-121.389061,-60.696546,20.740244,38.284413,14.811359,-12.186991,-63.33581,-81.400797,-74.110093,-58.124605,-48.95132,-11.950113,2.909104,-19.860459,-113.521238,-143.116698,-78.056262,-16.007485,67.927098,81.869377,25.12518,-26.021427,-119.252081,-219.642846,-225.225545,-96.08801,-22.596993,13.865863,-11.187213,-94.667227,-146.018104,-125.512621,-10.405075,58.910687,196.177254,249.162718,257.952202,220.796032,114.420149,28.622622,26.592008,121.391973,210.131876,365.768488,376.839511,262.827386,93.678412,64.776057,169.230807,228.168166,248.240289,225.245205,150.68656,108.904109,3.755832,-61.68402,-45.293767,27.627039,78.188723,205.35857,236.798914,180.172685,55.652982,1.103876,-10.385351,43.318695,205.028201,261.123549,228.606575,160.245492,9.355907,-32.556924,17.30896,149.65526,197.161977,258.543854,258.417372,139.86219,-36.445997,-65.273206,11.613629,57.338593,77.721373,66.403243,65.372088,74.963499,-14.083413,-246.313033,-290.613693,-145.341437,-44.342216,26.250878,2.357753,-75.901157,-215.384855,-273.004793,-202.670086,-117.303632,-47.188995,-59.65666,-87.441281,-112.12228,-188.253717,-117.933267,-40.21428,-8.129506,-20.801723,87.025262,168.362824,206.912984,78.38153,22.850915,34.601324,69.617698,87.019044,61.052193,2.224983,-10.942201,-58.080732,-93.017641,-45.590187,117.665114,172.12497,213.42581,223.423251,208.970398,96.461165,50.103659,85.760169,124.891469,124.115788,101.935992,84.728923,72.55854,-51.801595,-215.669806,-217.117698,-75.72044,-15.323769,14.324281,14.054503,34.319834,-5.372136,-36.752714,35.761432,116.090959,191.547632,163.005984,16.568516,-52.89621,-91.674451,-38.86968,0.297159,89.420872,131.376416,164.787262,135.36239,14.956879,-79.322457,-102.482361,-112.522523,-108.339314,-54.240369,-15.264279,-11.941571,-39.274895,-74.203496,-86.360657,-94.326226,-67.720455,-18.510864,32.812234,-14.963006,-161.877749,-237.97353,-262.297136,-276.189367,-242.60251,-101.549162,-41.425156,-44.855409,-76.230346,-94.421392,-80.780583,-64.878419,34.922226,120.088923,224.458336,187.559909,8.975869,-101.175377,-87.133955,77.281388,160.236389,201.744785,177.545503,102.854929,73.941774,58.774829,83.620252,113.414916,145.967523,144.712551,124.44695,75.141252,-95.99929,-306.033875,-384.643797,-323.593981,-204.98345,39.710557,129.351984,169.219329,124.816412,-2.244295,-54.243619,-23.317982,101.139972,160.294522,183.622414,146.244005,92.360488,44.5466,13.900977,107.956154,226.358113,399.418297,411.438567,332.323766,275.617413,175.497121,156.027205,194.580746,283.333144,307.895431,341.881888,342.12581,269.505083,152.170497,118.048941,150.311403,199.607087,334.749571,405.091799,414.016046,336.883992,158.299157,128.638672,168.567311,239.443419,258.00947,268.316578,252.695697,174.260893,56.442303,31.744079,103.62407,150.39113,151.085835,113.258458,16.767374,-13.006324,-16.450332,-37.542475,-48.23684,-3.774045,45.194673,112.313062,92.22858,-45.998831,-144.185686,-120.010687,17.835691,68.773156,135.343911,172.360895,154.480369,68.900299,-121.780361,-163.79799,-141.628104,-43.041284,21.567688,73.657654,36.722057,-98.715337,-219.48375,-234.100305,-111.040426,-24.028723,36.828733,5.970711,-97.015021,-133.396698,-149.980812,-110.756387,-68.568161,16.644475,45.024223,54.08282,16.048787,-98.290934,-132.38197,-108.40033,-40.1522,-21.992367,18.124948,38.763574,-9.321403,-68.723364,-156.600107,-156.165443,-138.061568,-112.901459,-110.137936,-139.838223,-168.850329,-238.676636,-354.525979,-398.27062,-301.668894,-167.156752,83.061905,133.565465,68.967382,-5.849563:-69.621605,-228.108842,-256.311824,-219.025627,-195.334868,-87.523691,-12.897809,-23.93395,-222.875833,-282.81078,-295.869995,-305.706054,-310.291915,-251.014498,-79.340369,-46.060524,-169.445768,-371.218405,-369.966419,-186.942157,-113.290179,-111.714336,-142.927176,-104.042023,-54.937529,-124.499976,-284.614069,-294.282756,-230.130954,-190.347255,-126.815544,-112.108983,-59.854523,72.72582,130.66095,135.715847,91.217497,14.603711,8.344865,86.236958,186.07716,176.953672,126.104429,134.806909,120.795252,51.357415,-112.204315,-150.944315,-167.073678,-199.630406,-226.513073,-236.396996,-173.115044,47.233034,113.202952,72.500983,0.533008,22.167495,136.889078,164.634928,175.091074,223.999181,353.370414,347.135591,150.016137,-0.772592,31.317651,156.832056,169.938033,144.232897,135.011337,69.704423,-57.90135,-88.356462,-10.677863,47.975367,125.970333,174.575218,263.090322,258.362399,147.201572,1.711855,-40.684052,-40.668189,-18.520328,-3.88665,-24.760618,-100.771129,-205.575305,-235.473936,-189.739631,-151.697785,-109.705391,-83.855249,-56.110753,-85.268053,-183.267546,-223.818919,-195.949262,-72.394789,-27.224098,-34.472488,-62.751773,-106.210045,-174.245952,-206.308438,-151.68493,-66.09563,138.008854,227.976706,291.851304,259.091691,164.901386,119.845627,118.650396,175.454625,232.098054,299.752887,273.32986,172.757758,115.741278,93.452165,133.21379,204.112196,329.30451,365.354325,367.788364,325.8593,184.339133,20.26205,-20.836439,60.078167,156.342417,303.840496,307.348394,214.010465,190.872516,207.88758,158.027892,117.720138,183.365549,270.600377,354.973851,330.527401,194.970224,13.321375,-31.121084,59.827248,155.162604,261.192753,243.10302,159.826231,57.721399,-10.515014,-25.713003,52.392935,211.396533,232.756405,169.099146,108.979907,-9.451371,-69.809496,-72.129718,4.561772,88.534519,272.456019,320.476122,242.692099,54.60376,15.41683,64.944413,89.720666,72.899591,52.218631,26.675031,27.392259,42.646806,16.03514,-15.578381,-41.685627,-5.210798,109.489617,125.115911,65.487684,0.972946,-31.234368,-70.236607,-67.433466,-47.671514,-34.117076,1.099251,6.175132,-95.133523,-231.757054,-197.497653,26.777319,112.093335,166.304765,165.763682,121.473847,11.756565,-36.098521,-33.949347,7.096209,95.090051,128.330177,113.821886,48.301006,-61.258437,-9.260114,35.247975,54.405989,39.633857,51.58405,64.884027,46.447566,36.081044,24.977924,26.298672,83.154371,211.157144,212.379474,103.593586,60.243493,33.622345,-36.820349,-66.459351,-34.976187,11.809433,68.138081,37.977065,-110.554272,-235.316669,-273.073539,-278.944139,-267.594694,-246.473876,-192.646695,-22.139957,34.6838,50.720371,-8.4663,-32.021495,-47.533661,-35.091866,-23.663847,-95.212447,-321.019568,-332.298684,-295.280537,-255.874697,-213.836585,-77.697261,-12.118559,87.052534,103.43537,22.0885,-143.898354,-172.915219,-38.795898,68.338482,166.76882,143.73944,64.592836,26.927978,22.201593,52.963231,90.186672,160.493309,180.95202,182.15768,160.978221,116.307729,51.282141,11.736221,-4.881825,18.927483,38.781689,-10.113132,-189.587009,-321.385615,-349.020636,-321.754188,-281.155594,-159.923941,-84.37352,-8.712442,-25.077541,-102.188292,-136.866665,-82.834646,96.089369,139.049652,128.289988,110.564949,64.576499,39.49719,37.753114,64.43149,95.84091,138.086933,149.722641,183.724547,180.647347,87.56625,-7.343865,1.546817,128.989182,203.405497,288.57786,290.086186,229.82148,139.832236,111.384788,137.005237,175.563834,252.645653,289.329952,312.267739,276.868236,173.705653,145.848483,171.331684,219.212097,198.185769,132.2693,137.109781,140.807358,31.22133,-32.193323,-100.477593,-109.073735,-128.368176,-142.051024,-152.886585,-149.197093,-167.209431,-261.915931,-311.510991,-342.074946,-298.073517,-118.811369,-62.892132,-130.191311,-201.468907,-163.678348,-10.191606,44.690443,33.227328,12.572874,67.774619,98.287978,14.460236,-166.628255,-179.546145,15.994709,128.877767,200.997891,165.050968,10.877857,-126.568186,-149.607737,-127.638494,-120.531639,-141.336233,-123.302457,-50.372405,-43.272873,-33.590549,37.805713,57.684607,-6.487278,-75.129823,-172.785066,-183.63912,-179.305169,-181.711398,-183.130241,-162.64782,-138.163407,-85.851465,-65.715376,-48.279227,-57.919356,-99.827261,-84.966661,-29.171541,100.850501,118.058994,63.996503,29.669072,-27.983785,-89.49814,-111.001514,-84.849752,-49.896778,-7.793751,1.653766,-0.120005,-23.079236:-189.037492,-375.357923,-348.757122,-195.106761,-132.052837,-64.113106,-75.091965,-184.83026,-310.395787,-349.446134,-363.028216,-346.192602,-257.343347,-182.534328,-95.332771,-134.940207,-313.94739,-415.161904,-383.650782,-162.12819,-28.408635,94.629857,73.563682,-13.62758,-151.776036,-232.238379,-259.578174,-202.431384,-68.566838,-21.831278,1.551098,-25.009642,-127.44246,-147.760531,-93.875798,19.823039,54.878865,93.60915,88.854512,44.266572,-39.154356,-76.804832,-82.029022,-64.213195,-32.351826,-23.849734,-45.697584,-72.868394,-131.803119,-153.310199,-137.000819,-29.080933,56.149003,156.085903,113.586708,-81.379474,-202.969643,-195.982865,-53.395443,39.687821,208.731417,285.104731,323.389767,261.682212,73.598062,-32.046294,-6.210491,141.191523,202.025584,241.332405,213.881297,43.635851,-178.616965,-220.504736,-81.677349,33.898098,204.137961,248.000241,202.058729,112.48769,-70.310963,-111.879907,-88.921198,-39.782664,-9.061451,67.117237,62.516271,-84.162511,-235.01419,-246.204251,-140.329999,-63.08593,82.932537,136.800012,100.174054,11.3283,-190.140047,-268.79532,-215.362344,-4.394559,85.807569,131.229429,74.860931,-109.658989,-209.210446,-190.796884,-44.644309,29.850428,110.801588,156.040586,280.364981,291.45323,142.537584,15.243705,39.95508,177.847853,240.764764,348.189499,368.668367,265.795769,68.002532,9.929727,61.814266,156.485197,372.887236,442.172574,383.166018,253.958921,-63.242657,-195.492435,-130.447101,119.53984,227.37146,333.297901,309.329023,148.086904,27.757667,1.902011,18.899662,82.20447,286.521647,367.186651,357.561097,277.763892,74.803779,-24.287314,8.45788,148.414472,214.567344,306.265084,304.26608,186.11921,22.82173,-46.255023,-103.280799,-59.8182,123.124651,168.352852,25.217309,-95.738645,-206.967219,-182.405105,-156.010982,-53.917494,10.432989,87.622086,91.197032,46.401185,-96.059402,-166.776059,-158.957631,-94.189017,24.714456,43.518978,-2.396998,-43.6795,-128.385368,-162.989109,-146.542317,-62.608111,11.367955,190.762249,235.394339,163.579473,3.515566,-60.734181,-115.047185,-100.704261,-7.433585,39.363214,22.28064,-37.983502,-162.951152,-205.774603,-157.456276,20.858059,78.631884,125.625491,149.951519,155.913463,36.612974,-32.391577,-80.612022,-40.425325,89.294058,115.850561,40.327685,-36.785028,-194.94904,-253.020368,-208.0536,-46.356139,31.257475,166.037072,194.031215,97.28833,-100.380128,-151.831133,-54.893761,43.37722,188.607701,220.063721,152.325357,67.619244,-96.570052,-167.088088,-140.948806,-11.01365,66.491356,176.064791,155.009152,-36.168621,-174.877761,-177.710511,-113.017981,-81.678999,-14.353886,26.862845,23.32671,-22.804656,-97.943064,-114.329762,-89.236229,18.151927,61.369371,30.997528,-45.928603,-230.667226,-343.167715,-359.946248,-288.712313,-222.481024,-103.412935,-41.195043,73.518868,92.825349,-10.55854,-186.734236,-196.538094,-29.210128,90.038972,227.487087,191.964459,-41.62934,-208.633855,-192.430778,17.319313,139.469771,243.407752,221.814573,143.10994,125.056497,87.843475,-11.980175,-40.146245,0.670636,40.036719,65.676943,28.84409,-151.404417,-355.782722,-396.871094,-281.337095,-167.467644,16.08381,69.95833,133.896899,133.526241,-25.104892,-199.037676,-171.609134,53.199425,174.729076,305.080162,286.30311,143.1472,20.67213,1.296615,103.97678,204.165191,349.383123,368.575301,304.208248,230.938964,51.660528,-14.026073,31.56736,174.055305,233.594743,301.226942,300.148736,217.092394,64.191908,11.757375,72.804684,172.022705,385.264806,449.128248,364.807079,226.927376,-15.965383,-25.104101,43.502011,218.743179,283.079852,310.844403,286.019252,164.054188,-49.717727,-133.411447,-119.490702,-44.728551,55.478032,60.177494,1.112662,-59.965297,-195.967197,-270.413401,-259.905846,-140.239135,-45.169996,112.017356,115.252385,-13.194229,-77.132172,-37.537595,85.971732,123.858994,166.253184,190.651195,172.127264,96.49866,-95.377906,-161.097808,-124.593414,26.884255,102.799446,173.555135,155.128023,15.856696,-198.639283,-256.600392,-179.189198,-90.343635,34.378692,45.268864,-51.471141,-132.145508,-209.677035,-121.736832,-54.468983,22.50181,29.767277,48.176816,50.635858,-26.5798,-165.562916,-208.100554,-154.807034,-78.630071,34.692073,46.371919,4.434824,-37.664289,-151.336812,-217.723014,-183.55349,-37.626328,3.27827,-5.026141,-22.614961,-93.809754,-235.475878,-278.70572,-192.894175,-104.192722,12.260785,32.522172,16.172096,-20.432143:-184.911412,-213.59007,-199.812557,-100.597406,-30.37537,133.269671,189.948445,114.586129,-66.238476,-95.813472,-42.228195,-4.223155,87.822124,154.617981,225.522663,198.743549,88.57839,-26.846661,-52.980796,24.994001,99.51754,190.334536,197.453731,204.996034,228.235383,211.597772,72.291695,-17.040832,-105.589502,-82.194637,27.030939,59.571072,109.351229,231.357058,269.483379,211.612723,162.209987,139.525797,140.01539,106.446618,87.620668,76.918898,20.264063,-12.481834,-51.655438,-66.029922,-80.407816,-67.817192,-85.967382,-196.895757,-240.712207,-247.027015,-183.690004,57.157926,160.247639,192.849254,51.643033,-12.876489,-44.267497,-40.958092,-16.271827,36.088768,170.274552,208.416493,200.793101,99.980094,60.523074,87.087084,99.282602,6.842723,-32.221483,25.294246,31.747074,-31.915778,-123.201117,-96.964151,54.491421,115.902481,116.661045,89.132336,71.559311,18.501386,-38.159931,-103.664238,-77.786409,54.31239,106.751378,68.172659,-119.343263,-173.827725,-80.735933,22.07164,151.943787,152.186143,78.589541,34.437813,-19.325336,-15.796463,15.149616,85.308446,93.438841,79.07423,68.765805,32.277442,-31.916914,-84.09642,-132.943267,-91.249797,52.037599,121.750576,241.120826,279.742572,265.121125,127.268033,75.073877,94.381116,118.112086,92.373601,58.695848,-11.959874,-68.06447,-82.197058,-75.001256,-47.189432,76.362635,162.971677,263.258232,238.951514,127.338863,72.981058,70.695803,104.487925,132.467743,183.869326,186.29078,111.199698,34.916789,13.900475,-39.372471,-51.266197,41.709938,125.202884,246.367177,249.190186,131.363955,52.247384,75.259842,174.711746,222.016527,305.169841,329.083963,287.230414,175.026325,119.362975,81.578665,115.915493,213.075648,230.886698,191.38012,156.669231,89.235976,10.966558,-25.227489,-41.393309,-6.753662,146.115128,228.276997,270.126385,149.077384,88.060354,66.011936,77.384936,61.497414,72.096924,163.118772,190.826547,121.729018,12.774011,0.365358,-4.718203,-33.873873,-112.939651,-126.478749,-112.885982,-111.758102,-120.421608,-121.614646,-92.205947,-21.388448,-9.564831,-35.275223,-68.072915,-163.172459,-209.195174,-173.836674,-62.646725,-34.003881,-0.726883,10.169808,-26.188599,-102.235766,-135.438445,-147.070188,-111.871692,-17.177774,3.28959,-50.465473,-95.426509,-103.908483,-84.807088,-86.253129,-46.110536,-27.251389,-36.468919,-41.860422,-47.871706,-116.240243,-168.087011,-174.624992,-103.594809,68.311441,112.224984,84.462075,45.87396,-0.382218,-19.69961,-40.824034,-103.228322,-114.941657,-96.516979,-111.52129,-225.492886,-310.707181,-325.338083,-349.772414,-337.401209,-232.225815,-160.178956,-59.972704,-51.510621,-39.494529,8.581537,29.587824,51.890285,47.12225,6.204441,-32.207897,-150.46902,-235.279186,-238.510051,-136.640054,-47.223887,71.838497,96.178675,149.982171,160.184525,90.697642,-34.621942,-66.837984,-4.23675,54.354111,104.379152,95.610766,61.675487,-5.526811,-46.818031,-75.672719,-49.592118,51.706421,93.358135,96.826413,68.307768,-8.73731,-107.8206,-155.306332,-193.570683,-176.940577,-106.525049,-87.301826,-138.184725,-256.207071,-312.826706,-341.060489,-294.148472,-152.214361,-95.035424,-57.40525,-64.089534,-78.060767,-55.497875,8.691514,160.266667,183.609015,170.853998,170.553704,150.93701,114.557668,92.514272,-13.754552,-82.431463,-123.314618,-69.249216,55.851721,46.105821,-93.15686,-148.533603,-100.962346,56.496164,107.628352,113.181511,97.129127,116.854531,154.794564,132.191991,55.798213,43.996986,65.343152,73.9864,45.272216,4.29794,-94.6979,-139.923981,-111.284974,5.861034,36.588826,12.585716,-15.811641,-56.76776,-73.390566,-104.084584,-225.390554,-279.738183,-361.337946,-404.090654,-440.820976,-425.649306,-417.204275,-489.038282,-492.289999,-346.944592,-239.34748,-98.222459,-92.422242,-192.946986,-263.077537,-224.914296,-33.921724,50.10482,51.456244,5.242271,-0.588673,41.568632,84.218264,47.173421,45.215536,111.234856,160.148426,219.059609,201.797426,69.853074,-87.62694,-149.658463,-206.700475,-199.674752,-171.546815,-171.635507,-199.806571,-187.447859,-43.597723,31.250854,-28.56275,-163.283208,-171.533253,-120.38041,-98.273886,-29.081866,61.302099,49.691611,-59.131254,-83.162029,6.184857,79.986886,113.544721,65.367063,9.221546,53.427403,74.388259,129.013841,159.063736,139.542426,96.258928,57.248235,79.549916,61.01567,2.37318,-8.00905,-23.866096,-16.701024,62.255267,97.671259:-94.561517,-122.710147,-153.119463,-173.999394,-150.10499,-23.099341,67.11308,153.170826,-33.048521,-159.290634,-207.412631,-126.773068,30.70511,69.865329,107.97677,92.356996,-57.803253,-225.149844,-245.383657,-190.155661,-160.722137,-103.3637,-54.67593,51.606377,17.243629,-55.329596,-178.830989,-208.795313,-222.541415,-202.885766,-116.754206,-64.837375,27.370034,91.340119,118.568531,100.269392,47.336156,-35.566816,-35.781638,49.734538,167.030652,181.191094,157.014436,145.667083,74.033787,19.611312,-5.68855,12.443582,-47.021158,-173.721886,-193.266778,-167.385693,-133.130268,22.360307,119.111865,212.842096,147.547804,104.200701,90.133625,100.350031,106.255361,125.206834,203.555389,235.132015,227.013179,113.616251,49.666212,-27.787137,-41.728584,-60.163176,-79.217565,-112.405933,-129.306379,-146.058578,-142.28247,-114.464541,-22.153065,43.577179,116.316282,99.580172,31.981978,-84.262698,-156.050656,-255.312618,-267.672615,-233.056846,-234.557312,-325.06804,-407.549276,-413.624438,-355.31001,-316.829074,-275.521294,-253.963961,-167.312734,-131.299603,-152.993069,-252.959465,-296.68601,-327.355486,-296.060474,-159.190036,-101.210324,-53.426525,-104.757092,-152.938987,-161.594482,-134.089195,-89.141156,-34.800808,154.153753,229.863929,226.781988,61.13102,19.459156,87.472593,106.801761,32.722235,8.233705,52.14898,54.508586,13.874056,-14.069588,44.919673,211.079793,251.78129,230.657681,213.859514,207.164646,138.752871,109.197025,150.196937,184.924595,211.87674,213.472584,200.374876,115.223064,52.944229,19.341951,54.408769,115.7773,134.13181,199.963474,235.952786,198.057005,70.981749,66.761669,154.115903,194.459828,275.867833,312.786217,281.33666,113.016039,34.048799,18.71856,95.096243,270.235024,294.638157,215.270703,158.136899,74.744304,26.253419,19.983552,91.370291,160.938603,277.934648,297.965672,274.364471,230.543864,205.239898,153.940596,136.601705,152.062396,176.843215,163.669457,130.818807,90.695703,6.966727,-57.202478,-125.77016,-112.779976,-32.147931,8.082279,21.494206,-65.164863,-101.535227,-67.646518,-23.145932,-6.588417,-28.051468,-37.203756,-34.587041,-93.766588,-180.178756,-189.046839,-133.494298,-90.899272,-32.012776,-23.020566,-11.544517,-36.057255,-76.350659,-114.537001,-78.306409,46.637829,80.589201,20.006947,-32.917372,-30.86977,4.554774,-15.88078,-48.221695,-33.452901,21.182603,32.407188,49.055981,83.738459,51.557491,-75.005784,-82.354223,21.807896,76.284183,111.11737,86.896334,28.059584,14.458197,-1.347191,-88.100043,-131.725924,-134.456552,-115.088551,-144.662502,-210.429445,-223.154107,-218.648729,-222.754398,-207.155621,-131.909598,92.256909,148.025115,88.448623,-30.065979,-56.091304,-21.612283,-3.348987,-46.104881,-93.448044,-169.483705,-170.942846,-159.306195,-115.088076,-86.723022,-70.843447,-67.163087,-14.863296,19.735783,36.41892,-51.013228,-88.293611,-48.717971,4.801516,48.180245,15.31916,-48.647669,9.32467,31.796931,-25.201157,-59.232621,-4.624723,71.513579,177.202547,173.312948,78.383991,-38.261369,-67.955741,-75.504967,-81.251747,-72.833792,-40.099587,-38.219492,-225.062006,-312.40851,-289.187827,-200.688569,-60.529727,-42.626496,-69.238423,-74.290651,-48.734063,-97.498159,-127.740142,-84.714869,-34.004923,18.801317,20.830798,65.043368,122.417826,99.940183,1.209079,-18.446516,40.595461,89.520734,105.384328,57.229895,-44.760761,-24.938784,22.801951,105.762663,135.405221,204.801182,225.335759,175.155578,97.840569,96.599759,118.017523,97.69162,40.780162,63.898571,154.935841,138.914058,13.243214,-37.692487,-30.991097,6.851433,22.482764,19.0069,3.65398,-5.166491,-9.434908,-53.141739,-192.177897,-252.317462,-322.549259,-321.393267,-278.919932,-273.809432,-332.573644,-435.822042,-460.690791,-412.862101,-351.206863,-195.185354,-137.316401,-142.911446,-230.618473,-251.647368,-165.073585,-86.87859,0.270501,19.098394,65.822263,81.492931,64.647018,-37.804303,-75.62579,18.048328,103.226557,122.534045,68.88626,0.14353,-56.412752,-103.283077,-124.29589,-101.982421,-79.694971,-69.959187,-78.10174,-100.001369,-54.455002,21.86723,-27.397702,-245.180018,-319.629425,-269.103994,-188.431865,-96.257229,-105.705642,-125.944994,-149.236782,-143.010202,-141.288975,-146.334928,-115.795415,-67.113641,40.589605,16.340387,-10.987393,17.469123,33.227187,9.015518,7.120437,69.174906,138.10198,124.961401,14.703903,-23.961259,-2.99967,25.616298,22.88545,-3.210814:-85.924186,-109.225074,-106.674183,-103.612348,-81.659561,22.87435,60.557192,26.017498,-117.032836,-172.287458,-138.453763,-87.572998,-45.299062,-34.166886,4.216243,4.669941,-93.092636,-225.420972,-205.74193,-36.647317,14.43368,44.003551,81.432976,190.725816,155.95012,67.904048,-67.693894,-74.840263,-53.007149,-54.866893,-67.700381,-56.297469,-9.94392,1.1654,15.903281,80.319534,89.79252,24.549591,-16.430607,-37.030036,-20.536291,-39.461075,-97.531688,-106.684898,-76.760542,-62.177155,-97.757317,-124.063204,-94.888631,-23.511382,6.865052,44.081911,38.548455,42.852077,55.522424,18.407355,-50.765098,-56.354636,24.656619,80.551468,145.51326,171.085436,216.867429,218.807813,157.214019,90.086143,104.100622,120.169668,79.536819,2.801471,-18.718923,-75.797816,-98.723609,-84.61036,-5.21856,53.868714,143.715937,167.143107,207.001428,209.278529,111.802084,-13.957268,-16.273367,40.206112,48.610433,80.314675,115.396142,92.941577,-60.520523,-103.279899,-46.403884,11.398841,84.366207,92.308416,49.08134,2.081267,-102.990255,-136.112901,-103.402871,23.472461,80.151892,98.509464,65.637266,16.100286,4.042041,-16.444108,-0.048205,60.618411,167.688374,187.589984,214.389899,232.713099,243.421199,184.727958,148.386757,135.562703,180.219448,324.698125,361.708503,252.197794,-5.685153,-82.570138,-2.058987,92.546301,196.718788,218.279003,223.937314,180.73603,46.391837,8.749666,50.748961,177.525143,220.141111,186.742074,113.69161,19.559848,61.497088,59.941731,40.044265,73.14712,190.145103,249.659169,344.090459,343.009472,176.002149,2.157341,24.516317,209.847509,287.197177,378.971414,407.745368,338.822479,93.583549,12.028737,40.611646,74.349775,73.025904,84.873149,131.321823,110.696952,-18.804207,-107.94186,-88.97874,10.993357,30.597985,27.227866,43.731976,87.981261,62.577962,23.775097,0.149471,38.528885,137.397585,162.90367,138.289366,95.266515,6.994766,-26.286348,-30.754198,-27.788203,-2.714676,83.181313,101.557285,47.145383,-63.900892,-106.099474,-124.379339,-116.232258,-87.853487,-63.040845,-69.907816,-120.540615,-258.955508,-338.296521,-291.374035,-88.786781,-20.215583,12.360281,11.993266,5.234847,-43.919571,-71.840847,-84.120862,-78.290182,-68.929795,-62.878435,-87.216508,-110.818104,-111.658711,-86.9135,-83.863123,-95.138053,-93.497608,-22.928822,26.440531,76.935917,57.778015,19.440182,-11.609584,40.269833,164.832594,171.66905,87.500118,35.215822,-41.205441,-21.27878,25.356902,57.305457,17.575973,-75.251174,-99.393726,-107.7279,-82.659841,-77.1846,-117.94858,-164.434681,-218.675255,-182.471182,-81.725501,-68.088296,-61.726519,-56.373324,-52.301156,-15.410545,-6.712466,-46.992652,-99.703249,-255.452479,-345.409285,-350.989961,-266.955335,-165.978986,33.877689,77.110816,50.805262,6.403045,-65.950468,-65.867446,-31.747569,105.394533,168.727677,184.050782,128.179273,-35.642946,-112.243175,-103.543224,-31.44376,9.305407,60.760624,80.850354,92.945063,56.513094,-72.730622,-105.102695,-80.916796,-81.718309,-115.330838,-153.284053,-162.89984,-216.405663,-220.436873,-226.422087,-263.423084,-232.487429,-66.349618,2.144071,37.061135,31.182998,7.808365,-22.294084,-1.674166,92.054457,120.898381,153.675608,168.455846,158.941509,59.514366,-1.657359,-27.664649,6.570337,93.403385,132.116746,141.827456,95.799046,0.489392,19.015401,42.748565,65.995747,83.368756,130.640858,123.55779,50.676767,-2.316551,-15.265183,32.09867,89.402778,184.771965,211.721483,183.974938,106.982366,-46.487182,-34.864212,10.157111,121.980467,161.970284,125.424648,62.130213,-24.22424,-65.823331,-108.345671,-150.647895,-142.314573,-166.287406,-171.318364,-103.003893,-91.505571,-196.710319,-303.472152,-293.343796,-173.177139,-115.108122,-50.783711,-37.762767,-52.797429,-90.297886,-95.497371,-51.72876,-16.990877,47.034653,81.699352,118.113835,97.835414,27.100128,-39.837073,-49.92431,72.056478,196.818881,373.959492,330.801845,63.660096,-88.677784,-101.71096,-94.026041,-108.515535,-186.148677,-201.441262,-147.968023,-115.513201,-100.225228,-111.585313,-91.758945,-34.933468,-42.620374,-85.712916,-75.60073,-6.546517,17.831414,-5.587271,-44.412509,-34.568704,5.131636,25.739107,53.408169,33.497278,-65.400408,-92.228758,-57.118042,42.69382,86.562656,135.156579,112.637051,-11.078925,-61.988851,-64.936189,-76.430586,-67.162032,-46.656051,-51.057066,-53.431762,-43.837589:forward
203.814847,345.884671,323.710379,180.595543,139.124425,142.629095,127.312599,103.270081,238.550579,286.22578,208.100068,125.120216,7.622044,1.536558,41.074333,28.13107,-35.590641,-1.564697,29.444012,-0.604606,-80.271796,-238.804252,-252.770343,-173.57339,-118.594287,-130.326614,-133.392907,-102.16002,-34.276587,-9.996894,59.365142,110.708501,170.694907,143.581333,106.808598,-48.860804,-138.984277,-197.097336,-171.853287,-107.811239,-83.369321,-124.861714,-286.337788,-355.935764,-389.140641,-304.45184,16.254638,123.536471,161.508606,193.847027,202.169496,125.889108,65.379563,23.906652,40.91558,52.445075,17.411562,-6.225623,-34.820755,-35.288925,-41.614636,-52.383551,-40.861917,7.474353,155.207505,156.325226,69.69105,-191.717291,-301.484779,-344.872965,-295.09092,-176.854288,-157.92226,-206.279788,-319.120458,-341.074329,-355.742772,-366.171532,-335.230075,-273.783929,-133.832387,-203.352063,-303.92388,-365.039498,-306.372931,-175.875447,-129.836537,-19.377797,66.94314,72.578188,70.546451,51.403325,-64.150085,-106.397213,-67.670434,-23.206698,17.59023,-38.921423,-95.951101,-202.570702,-220.814997,-199.425132,-202.645997,-249.963709,-249.826923,-226.778101,-185.731129,-213.44985,-402.954441,-466.975174,-384.93753,-296.143228,-130.395802,-37.09819,-37.144502,-128.182047,-179.047464,-198.473396,-185.767772,-136.16453,-9.594153,54.069768,77.619012,25.932968,-77.565703,-77.100565,-9.723131,15.054897,20.520398,29.421797,37.662041,1.464168,-40.013227,-77.637596,-65.372376,-27.44422,56.072238,119.164914,120.273547,0.936109,-274.190301,-311.119868,-204.647249,-145.019581,-111.740917,-126.34721,-134.159071,-149.308976,-142.421173,-92.558496,-72.730358,-17.59925,86.127353,106.699798,103.826732,103.433662,44.249311,-20.458424,-107.702704,-107.861778,-124.8528,-196.886945,-212.465337,-260.916352,-312.846147,-324.563952,-244.732245,-31.809148,35.394697,23.775748,9.895568,1.214415,-25.803734,-20.293314,39.046676,82.088821,148.081355,32.168797,-75.785763,-231.662323,-269.434909,-265.357069,-203.989985,-14.700124,99.430454,92.378627,-57.999451,-178.595408,-316.14431,-265.744594,-114.871801,-118.922555,-185.095564,-161.87606,-151.68228,-177.961518,-192.545951,-210.258665,-217.894727,-191.985626,-94.014638,-40.315643,-12.485603,-57.588504,-159.32146,-172.657891,-212.069047,-245.288597,-194.59899,-46.260908,14.182532,80.924154,87.195373,97.543379,113.69078,162.759679,189.844362,173.47743,83.622749,37.387972,40.870847,98.833699,224.81909,250.500918,232.969175,179.514087,122.715645,-87.176024,-187.116588,-211.563319,-148.827697,-21.846778,-41.758283,-101.389534,-201.508817,-240.229772,-375.522989,-441.192432,-446.285511,-410.133378,-383.700289,-415.987116,-430.648334,-476.812541,-475.795857,-341.380123,-263.920396,-209.147405,-236.201117,-280.532717,-416.844638,-476.048774,-442.622647,-333.801613,-125.30718,-90.176866,-122.959839,-218.06315,-272.505742,-401.615468,-479.434495,-586.483642,-585.8541,-489.776625,-421.114648,-448.221666,-550.323467,-579.128641,-555.436537,-500.235122,-335.2437,-245.949009,-108.42601,-89.443408,-107.050286,-143.36096,-128.404879,9.687359,78.291494,110.370984,49.992531,17.710087,17.914469,28.902275,-8.121946,-32.644722,-10.467164,48.138798,185.247405,197.099493,164.419678,47.850483,-22.820244,-90.847947,-65.525576,80.780048,184.057623,166.699503,39.335061,-23.758939,-81.160317,-94.270766,-145.571602,-155.177145,-86.561308,-108.255744,-174.5633,-260.686099,-258.371263,-198.225606,-147.572279,0.84601,124.38313,143.914617,113.196617,55.939359,-37.420525,12.147987,255.003054,349.59967,394.279778,381.199785,394.533005,374.141367,334.125872,356.464259,411.268786,452.751034,398.782197,334.057191,114.983945,-5.530692,-127.518653,-109.521054,-38.409647,-28.437517,-8.162051,38.58225,56.426273,107.395957,133.750126,175.044989,215.239448,358.790755,476.408455,485.725061,411.955232,358.4774,288.870545,280.349296,323.629178,368.469714,433.51412,375.71625,291.428812,74.77061,2.949797,49.085223,133.240424,268.693711,381.301119,444.003306,522.170944,517.77303,427.657413,365.211466,267.093403,235.830889,172.589436,95.74912,64.168336,21.491377,9.217955,-0.012487,5.344131,51.63945,116.0216,161.256611,285.99635,326.806464,357.010768,377.915028,414.709323,417.981166,468.865148,495.010197,414.872157,177.811448,122.902806,192.365166,250.815975,308.304499,304.774201,307.569848,329.421406,308.613151,224.953528,212.244073,232.168945,241.559196:248.633124,359.162352,363.137632,186.642998,100.20408,107.390877,139.309371,151.236246,164.250771,146.231829,14.231989,-76.727079,-169.965576,-132.514581,-38.372686,-43.05976,-74.72302,-59.155542,-41.379882,-28.244943,-60.068946,-135.602219,-115.88837,8.698076,-22.462084,-95.225034,-136.477574,-95.321081,-15.337125,-4.621051,11.069994,66.144345,228.782435,252.643613,193.10847,-55.883469,-184.489347,-217.732654,-139.982156,-6.446028,-28.292793,-101.162305,-281.465902,-347.360154,-391.675072,-338.29208,-95.868035,14.008707,119.06335,126.872812,103.466498,64.529317,44.908475,-34.585394,-65.900193,-48.279941,-8.854782,-24.961086,-108.529607,-145.18346,-164.830824,-149.652495,-86.490585,-43.068725,10.99769,-112.626508,-228.628437,-401.405195,-418.502869,-349.118257,-309.841985,-287.385974,-322.919603,-342.980857,-367.497135,-393.55617,-463.959481,-460.321089,-295.355848,-173.829728,-83.434346,-283.013414,-395.883695,-429.385824,-365.974963,-245.153937,-207.729192,-148.676558,-75.721682,-37.099809,-41.637453,-98.291836,-211.07785,-224.605043,-145.691773,-67.82887,-11.638683,-157.755138,-204.085876,-178.463384,-160.436911,-195.167365,-229.196036,-217.119887,-98.553495,-80.454009,-200.032865,-298.026734,-460.115675,-465.469746,-290.097561,-182.29094,-70.539588,-25.550872,16.504186,32.029566,-33.34015,-159.002802,-162.717757,-92.320334,17.909202,67.722465,56.792447,-1.080714,-74.254112,-57.685331,54.357222,112.09987,97.499597,-36.768489,-77.955762,-100.300483,-92.364881,-47.949452,-23.465142,7.821427,19.472771,42.506567,66.172908,19.517157,-130.124074,-199.225253,-276.334321,-270.171294,-226.016982,-128.738302,-94.069329,-186.39131,-241.978944,-172.770134,-93.468581,-15.001464,-38.407401,-46.9484,-39.641151,-51.480494,-124.665401,-161.498428,-171.700988,-139.050638,-91.676827,-193.988318,-280.504462,-398.743655,-393.716731,-260.168848,-164.148611,-2.644681,22.924951,5.636926,-4.865961,-15.049028,-75.394893,-80.764053,43.653174,141.145548,182.210339,-72.952636,-160.770827,-113.167506,-69.5445,-32.171328,-14.042252,36.100244,79.439709,71.77961,-58.616726,-151.661899,-201.264365,-138.152647,-64.140591,-107.225019,-151.522226,-40.946815,-17.063324,-113.413035,-179.639747,-216.581286,-175.951388,-66.66916,-53.102468,-68.538565,-84.627921,-74.075964,-20.566532,-20.368704,-90.402732,-108.337704,-53.369816,-17.554814,-46.958365,-122.516736,-119.43932,-42.892004,-9.555762,54.242795,90.695933,61.298813,-129.74299,-235.155187,-232.92152,-141.537081,-8.805098,14.868758,15.1103,-73.692752,-158.377564,-323.096229,-331.26383,-218.943208,-173.384481,-151.298517,-183.503338,-206.880203,-181.148987,-162.573923,-279.352763,-380.33243,-459.52489,-415.345259,-278.634584,-288.573544,-365.12707,-507.885586,-504.473171,-345.916833,-249.807209,-107.03609,-94.216284,-164.264056,-358.569765,-415.694945,-384.684023,-323.960358,-187.082556,-126.701254,-126.590938,-336.271402,-444.196068,-528.978947,-510.920983,-494.356174,-516.635118,-493.85062,-407.251467,-432.86989,-602.376328,-648.297906,-583.064595,-514.088074,-332.842815,-215.795881,-60.686828,-74.637337,-89.345154,-77.035523,-53.315273,-6.256426,14.603242,91.739322,139.69974,122.756934,50.313659,-6.502092,-102.348024,-81.21895,71.32049,133.333578,134.882448,59.858352,13.071909,-156.084786,-230.007708,-173.830923,-64.261866,116.267799,137.952934,91.048589,-95.255685,-164.114817,-104.12882,-30.117609,-2.337029,-43.551862,-72.205431,-14.194513,-19.850678,-124.311835,-156.618277,-89.993226,-30.099703,92.98442,205.976386,211.94725,112.17249,43.50981,-3.258113,58.974322,266.385334,339.885056,413.527556,450.549608,433.946859,310.224162,247.711036,248.09873,305.406312,398.436067,350.697005,274.911428,48.272456,-60.88346,-141.648021,-118.075675,-108.850988,-136.051659,-107.884877,-6.082561,13.063619,50.274942,85.011245,130.001671,168.61952,353.207632,444.611442,407.485083,305.899306,292.660688,334.082139,345.302079,338.662463,362.844236,433.814762,388.796574,325.042081,159.980356,99.947721,164.549891,271.199173,452.949507,552.118953,608.266584,649.098529,596.454437,415.6498,330.023286,251.654465,243.649801,185.631661,109.846228,73.573037,-9.74298,-37.129875,-37.487389,7.207762,154.324884,186.930163,196.444573,319.691795,381.506045,445.890023,480.526907,538.624249,522.058782,441.772697,322.65604,208.596636,47.648499,69.968513,191.288468,218.231216,212.233908,232.783885,265.113388,273.499486,217.058028,83.04894,58.808692,111.255135,160.962397:243.567952,333.904392,298.319632,104.17529,45.651861,63.894682,73.221561,43.808862,18.134807,-1.269854,-83.832415,-151.8546,-241.005742,-208.789483,-76.861872,-60.021761,-131.946958,-132.68229,-79.418315,29.833802,37.882691,-28.273686,-50.378867,-38.47512,-47.087241,-45.390863,-16.379387,-0.140882,44.94357,60.056695,97.455886,149.804666,247.870617,229.603393,175.196227,-40.855015,-162.448916,-247.645847,-206.752051,-67.996295,-30.334966,-97.531976,-308.095958,-384.430043,-388.300264,-315.083323,-93.750142,8.538662,114.176333,95.058652,60.473183,-11.430421,-35.66903,-17.90377,21.793676,66.709932,-6.280376,-32.496772,-12.554954,-43.123583,-214.839069,-250.415237,-126.101789,-52.864078,-50.644173,-179.204294,-253.228815,-376.309413,-400.116329,-353.735473,-311.801493,-241.594681,-209.538695,-220.251772,-304.313296,-360.444827,-425.604661,-423.822065,-326.227603,-227.806944,-98.961522,-263.369059,-371.414183,-386.332506,-320.082652,-208.109762,-167.539007,-86.28687,-65.295639,-84.769246,-144.02277,-183.886845,-246.514082,-240.483361,-171.835404,-149.182889,-205.232306,-276.380097,-260.218751,-221.835765,-246.002381,-326.886187,-326.970946,-195.534364,-104.295658,-147.506011,-312.656066,-384.126539,-436.482846,-394.481843,-277.777728,-255.546356,-217.117273,-129.430038,-91.180059,-112.089258,-162.349829,-192.717724,-158.830303,-18.6407,161.510986,203.076201,114.260079,18.400775,-85.387859,-54.436034,99.678442,170.729466,192.612315,27.514653,-61.432151,-110.13884,-71.617426,5.055738,0.132703,-62.119483,-80.490679,-67.393799,-83.751963,-108.734993,-113.903209,-115.057841,-186.311861,-236.80904,-278.141663,-190.216083,-145.175342,-158.741726,-176.558438,-120.965477,-80.063329,-64.043207,-115.828203,-142.178637,-160.606639,-168.660459,-187.812767,-184.121577,-127.575878,-74.022705,-81.839644,-322.780925,-401.52437,-375.895176,-326.369429,-189.665886,-103.7065,6.18548,-4.247842,-6.099204,3.645744,-20.362531,-56.728346,-24.336316,81.384929,121.41727,156.64603,55.50705,-37.52143,-121.617868,-79.956327,50.308378,94.561463,146.202307,174.845179,164.563404,14.935237,-101.75923,-232.477416,-218.645654,-102.608496,-26.196021,104.099384,106.062328,66.655855,3.106272,-23.926776,-146.995707,-207.248635,-151.625959,1.178175,0.702348,-123.877286,-144.087728,-11.435333,59.058413,67.872827,35.204337,-28.872621,-105.769178,-159.232126,-221.486758,-183.535758,-52.494642,-22.037248,7.358468,32.405791,25.331431,-48.350561,-103.237932,-150.136609,-133.034144,-54.807646,-5.837928,-13.182516,-186.899957,-257.053819,-282.000218,-256.775228,-182.708427,-133.404934,-73.470078,-194.675419,-281.115949,-279.812463,-210.055838,-208.157641,-277.962454,-317.162607,-266.843642,-225.122239,-314.440927,-346.71535,-388.333961,-393.226396,-302.195813,-223.219205,-106.27148,-46.396327,-34.085486,-122.732056,-217.841749,-361.588705,-354.855536,-169.459932,-65.899576,-80.939951,-334.765896,-441.373776,-520.225325,-512.284034,-470.016985,-434.806285,-302.751931,-230.314588,-297.17827,-516.780135,-556.005989,-441.173685,-334.22297,-138.482986,-84.715182,-103.589011,-187.082253,-198.839723,-151.244142,-84.69704,117.004952,206.96627,274.166908,227.364403,206.301247,164.327308,117.022363,33.929204,44.918719,150.42807,202.575867,202.712165,152.684904,131.041813,-26.464927,-110.723491,-52.087761,72.003252,251.480694,171.866532,50.917638,-230.109894,-286.176427,-100.652591,25.87059,46.126206,-0.47401,-7.668937,-5.339221,-20.272549,7.413171,68.691559,175.514583,177.617472,163.464205,202.09187,208.702593,123.379418,47.982597,7.748624,84.549307,315.844873,398.404422,424.769077,323.358906,260.772212,146.421351,113.745115,167.102748,236.940466,323.900466,292.415236,241.858737,55.631228,-62.381054,-233.360912,-256.03039,-198.353874,-127.203389,45.193735,62.598215,1.527547,-83.509053,-66.997743,77.197811,199.977941,445.061145,484.2548,431.76235,322.116969,297.362161,274.597264,260.574541,301.473215,376.335268,464.204311,296.368291,195.57592,125.363102,128.251153,177.251906,254.85044,480.417334,615.172093,624.991721,553.395949,494.282698,389.752264,340.237903,242.103307,199.532402,124.375387,75.234114,43.698938,-55.017978,-79.170692,-3.32392,72.191482,200.3527,230.974284,226.211169,235.529132,264.936827,402.687466,493.100582,596.980735,558.299226,372.017534,251.639116,187.045564,38.391453,7.265393,78.747253,163.262852,311.959799,250.115001,188.920866,157.887366,159.568786,160.731844,187.885612,268.886039,281.611568:227.872537,356.067292,362.906242,211.78719,121.185705,60.353247,72.084049,143.952107,238.430665,225.459013,69.512964,-6.230447,-28.403173,14.996162,62.429638,35.114432,-13.466602,0.337006,-10.064712,-75.386743,-111.322638,-121.030356,-79.618147,-11.500879,-66.590987,-89.633077,-46.459797,-8.021118,66.791819,103.585236,161.319175,190.751092,214.089008,137.318718,72.458914,-106.485362,-167.084525,-101.02993,-40.418634,-15.773244,-40.280551,-68.758785,-213.189001,-289.731121,-282.197258,-190.594206,-4.999237,50.499017,177.140676,287.010205,277.44364,172.489307,127.58999,93.890266,102.353836,174.796351,163.851255,88.525773,-31.847547,-52.773875,-104.382356,-115.906457,-46.43381,-3.602112,11.279694,-52.099278,-112.595973,-300.000572,-372.48231,-316.771944,-241.864401,-185.343441,-199.846926,-226.047258,-341.348167,-410.922429,-502.840479,-522.430861,-490.750152,-418.629613,-279.278144,-364.554019,-437.982108,-433.123087,-382.72095,-329.466486,-299.475688,-128.925149,3.013288,-4.469141,-82.205239,-127.138207,-197.046008,-209.024277,-193.742786,-178.241963,-162.970268,-180.00645,-198.503902,-260.239532,-279.371661,-256.99752,-236.472733,-198.269365,-208.049965,-252.849321,-361.16932,-414.217001,-529.516973,-556.39447,-479.283284,-393.20117,-214.748919,-109.567424,-96.328545,-153.480747,-189.821838,-187.699639,-162.763295,-74.331547,79.903155,132.862924,88.922427,21.527159,-29.237093,11.484707,125.944759,143.859342,67.781949,-18.739376,-29.280764,-81.467021,-142.99802,-221.95785,-211.374069,-155.305976,-83.795301,-28.364781,3.083935,-67.561747,-247.548878,-285.076971,-297.243881,-303.765632,-266.627954,-168.638178,-151.039148,-196.297304,-209.447869,-127.418242,-59.159231,8.324623,-54.466859,-76.492513,-10.909211,10.766886,-76.886442,-124.251638,-111.455222,-75.348278,-78.365945,-239.61862,-322.889803,-398.827351,-386.231979,-283.198166,-212.677395,-90.076948,-48.024653,-38.113904,-28.051117,-51.244259,-106.22075,-94.209325,3.415637,60.792829,109.293451,-8.024422,-85.862636,-166.277683,-172.9901,-135.92983,-90.885975,14.433768,53.641712,39.202184,-41.067305,-112.723233,-242.452841,-230.177896,-70.008491,-14.850486,-49.05903,-104.797358,-92.739416,-53.557575,-57.419687,-121.669105,-159.867136,-150.613647,-42.264288,-11.69481,-28.013425,-56.87091,-125.832518,-138.629137,-103.619589,-87.401756,-82.362568,-50.134082,-14.715062,28.438417,22.138067,-11.250979,-10.703009,77.147128,190.471319,201.027574,70.149473,-22.456339,-46.090763,7.753169,69.328499,86.803888,133.889438,80.265198,7.419383,-165.986677,-209.118027,-145.473745,-111.767109,-134.453431,-151.41894,-146.806194,-149.087429,-185.527635,-300.222714,-316.622185,-253.258568,-213.58308,-215.948093,-336.534649,-379.64312,-423.163586,-442.824297,-392.803232,-307.98802,-139.019092,-87.999005,-105.370204,-200.688501,-258.579777,-327.068084,-320.310768,-205.704909,-117.627214,-44.898743,-236.94559,-366.012857,-503.945861,-515.451812,-515.333067,-504.585471,-400.329671,-310.785717,-353.018184,-499.937704,-527.050598,-504.483977,-471.589201,-338.079889,-254.239847,-154.116277,-185.97954,-205.363032,-148.424362,-82.201122,53.02205,113.956606,199.993555,160.699654,113.114915,73.345348,46.548453,-78.733821,-105.394861,3.700571,99.03025,235.596513,208.05718,139.287379,-40.045114,-91.864924,-36.277989,51.903547,254.445509,283.980962,191.114007,-86.578926,-167.526953,-63.21426,37.240943,74.199889,32.152876,-15.255539,-29.704382,-56.127374,-105.459927,-88.952358,28.450305,91.874531,201.933447,261.339934,240.814255,162.632862,128.859417,52.424001,42.068155,157.38067,241.493612,340.460859,351.110694,330.922069,217.755537,146.129795,109.931896,155.99593,274.764828,293.987672,231.36326,4.416746,-115.140103,-238.626204,-205.790374,-42.532353,12.755631,30.740373,-12.460382,-45.455182,-95.089309,-82.442082,40.304583,132.35319,295.897222,349.27352,339.393267,264.761213,218.799364,180.14061,189.071984,237.89463,286.438458,361.373709,242.011269,146.651744,24.865497,18.65804,130.373701,229.067306,438.201679,566.20658,587.644049,572.739245,532.265265,408.913814,353.521375,275.126512,242.251018,153.373615,53.749649,22.913521,-13.656374,-11.650624,71.684276,127.933095,196.434988,253.633444,303.438057,420.766581,462.408647,494.220074,500.631515,533.78746,535.050313,448.689176,319.227873,253.317492,139.32174,107.893927,110.316947,145.221997,277.758297,361.318588,356.119957,304.76082,257.308108,162.483602,179.38095,360.514032,448.384387:296.903491,323.902065,285.279755,140.648095,70.814964,-1.419721,8.341939,106.822524,130.774744,69.496201,-75.324345,-102.542791,-73.294429,-56.248641,-43.000827,-18.786342,40.571643,12.535712,-22.922721,-73.05237,-69.490788,-1.231424,43.182117,84.803983,-4.739168,-64.680949,-101.866926,-77.485993,-17.339821,-5.772033,84.976538,201.110507,359.728734,209.486175,88.357955,-115.901457,-163.769386,-101.339424,-18.69631,146.491863,142.654134,51.757646,-219.000436,-331.256322,-341.796532,-239.451095,0.493264,87.595256,202.301805,223.420516,184.422292,57.378512,21.451739,50.335011,81.476171,151.900706,190.704797,181.995645,156.253641,113.049016,-57.933801,-104.696706,-1.19641,98.118851,183.621799,-5.959444,-152.435881,-376.28372,-413.022299,-329.92026,-257.549168,-164.520694,-115.106149,-101.01826,-195.145072,-304.95124,-442.037714,-434.188791,-370.176277,-321.060183,-221.587589,-307.051144,-403.087084,-482.534325,-441.052277,-290.181933,-193.424898,13.517279,50.44934,-13.392287,-176.38267,-236.773631,-260.850863,-228.831459,-149.376086,-120.460368,-126.574987,-219.680661,-268.563647,-324.851809,-327.631505,-307.014798,-283.764793,-173.780512,-96.444382,-140.117763,-354.30098,-456.307941,-510.796277,-458.992424,-335.174957,-304.904907,-296.329364,-306.997957,-309.660396,-305.486355,-276.305095,-141.238908,-68.335459,78.955817,238.298691,255.696842,106.18179,10.505294,7.530464,97.587755,248.40068,275.475597,273.086693,140.215802,24.962619,-176.171814,-220.428528,-190.980678,-142.561649,-67.277307,-75.767473,-91.568086,-84.996949,-70.871038,-129.422481,-197.183537,-242.155875,-206.943368,-169.942879,-192.580112,-209.571134,-239.505582,-202.764783,-35.646138,30.426737,47.794459,-83.071794,-148.354702,-181.571871,-180.445376,-178.277899,-170.355779,-123.310796,-67.689485,1.619213,-193.743523,-355.714611,-545.26644,-497.548955,-212.653227,-75.552529,48.064764,3.043714,-26.183711,-43.151397,-52.486512,-72.077616,-56.863674,31.772381,97.033537,179.698169,50.563887,-64.737401,-189.870948,-150.527562,-2.59334,34.525552,90.467901,185.371926,189.467096,45.199695,-57.399861,-159.308215,-130.069977,33.018158,110.865325,141.323336,83.919027,70.941692,19.643874,-31.622113,-98.89871,-83.707143,-0.947131,7.851666,-26.609545,-102.148405,-128.725995,-139.334417,-115.660407,-56.836625,-37.468531,-19.485163,-25.941782,-33.298352,-33.218021,-10.680605,30.447125,23.981313,56.640546,137.089447,103.867198,-123.162541,-208.345025,-121.779342,-25.625285,55.58014,71.462376,118.866114,49.006524,-55.85753,-265.023173,-293.147857,-220.162063,-188.964546,-165.552202,-153.947743,-178.789443,-255.990656,-282.354575,-309.720072,-302.091033,-215.386607,-148.8412,-98.229632,-213.425843,-297.546044,-470.372816,-495.485048,-298.830572,-143.065111,25.66504,-17.392534,-43.788066,-104.727342,-166.658462,-268.114955,-275.963487,-191.502956,-105.977511,-9.783924,-170.370583,-299.157866,-493.998767,-510.332894,-408.723133,-340.777024,-194.80825,-138.41497,-192.594267,-374.694397,-441.42874,-428.886293,-357.253736,-209.854676,-163.675301,-150.24164,-210.168932,-216.328433,-153.546148,-101.235121,12.930446,66.591352,155.845808,163.75284,123.96626,3.960679,-64.312283,-154.538202,-135.644173,-4.536284,53.808951,107.654758,150.287007,135.037954,-36.519678,-109.396424,-46.614442,72.474044,292.309317,238.128233,139.303283,-61.384828,-132.493126,-151.062444,-125.798282,-107.49915,-101.18343,-93.002334,-157.883232,-189.943756,-182.691512,-150.344216,-34.591105,54.655572,206.425872,182.514355,118.160986,-7.16682,-45.584889,-58.630536,-34.951801,43.792621,86.609953,138.410682,101.166407,53.089855,-83.815151,-134.746537,-91.220348,-4.438695,164.734288,173.968336,94.965721,-175.558566,-299.185283,-368.448013,-312.037387,-146.1247,-94.488388,-73.997545,-75.706157,-92.383333,-154.014493,-149.208514,3.089557,127.781253,357.192732,409.037655,368.137657,216.808217,129.089747,24.237273,39.188801,177.164768,249.744709,302.529127,235.06871,183.708791,103.031494,74.297978,91.667108,175.464973,438.953658,593.527071,594.302535,516.051563,466.250073,368.622289,315.680922,240.888088,235.942794,228.811405,131.529243,44.500616,-85.602749,-63.441289,101.533285,166.496502,270.761066,407.83726,431.01896,374.612951,350.54991,387.232469,438.690035,516.430045,507.799083,405.086563,259.583819,174.619463,33.172602,25.778645,106.40576,143.915702,242.71937,317.717029,295.083301,190.947131,137.17476,96.783051,135.363106,266.025561,314.483528:216.917505,211.620329,170.579549,88.778787,90.326292,145.775005,157.933822,180.312513,254.08579,271.887532,218.270493,157.82744,90.277301,110.372309,139.56743,109.28807,9.443749,-58.859355,-67.835769,-64.484151,-81.815352,-121.979123,-111.263755,-65.906955,-65.594072,-65.348132,-19.506722,10.928937,54.805803,73.478797,139.585279,196.944707,281.255422,246.606381,197.743419,76.333706,41.548454,74.40272,109.480128,183.245815,199.780934,134.114868,-56.826537,-115.971715,-118.476266,-53.67423,172.431661,273.786228,364.287022,351.844893,321.537328,227.997725,185.872773,149.712006,150.762391,198.518039,229.857063,192.290758,101.666484,81.742468,55.825439,51.768655,96.733344,141.820322,209.103469,194.095756,168.355575,58.939704,-17.313071,-100.200893,-93.860937,-27.273996,16.009895,-37.599519,-255.438734,-333.935369,-389.478884,-417.364251,-448.995627,-401.688454,-228.438718,-184.371762,-243.845403,-352.502271,-333.47769,-214.235588,-158.021895,-12.862658,116.301672,106.389381,41.467709,38.718915,2.170532,-36.83337,-54.484979,-43.088524,-64.331213,-125.45732,-144.946032,-175.104889,-186.387349,-176.140051,-172.795129,-167.055434,-111.417546,-81.447377,-69.015179,-138.088689,-415.014981,-495.624453,-403.18099,-333.422,-294.532732,-221.692826,-159.737288,-123.411513,-149.634982,-174.305225,-161.108471,-82.925121,42.044558,80.041275,62.817601,12.9531,-48.802914,-10.202751,107.339283,122.133559,59.59468,-65.287328,-112.001153,-139.502104,-153.677094,-206.479035,-212.543579,-124.374537,1.063014,33.092824,-1.693849,-50.580683,-101.160383,-102.360468,-108.982594,-112.125235,-127.898145,-134.478069,-124.667836,-132.72836,-135.756224,-51.447176,12.548833,69.321795,50.81851,45.465048,75.290913,80.826572,-3.484068,-57.55356,-85.335656,-50.525035,54.767487,-7.494129,-96.54487,-224.898491,-250.07021,-237.627371,-189.039808,-10.605153,148.036447,172.947156,82.336078,-14.824106,-126.259808,-76.799155,109.049176,157.447799,109.512503,-68.745374,-135.53122,-164.281191,-199.599728,-303.241673,-267.932725,-44.233184,37.141008,-13.852187,-164.924496,-220.369115,-257.452438,-221.800132,-98.314485,-71.360835,-123.300893,-187.796215,-182.344288,-160.192385,-170.75755,-205.862089,-210.454401,-141.788652,-47.74945,-62.199504,-181.153549,-229.067551,-241.803128,-223.350925,-204.941182,-190.387838,-82.597051,16.651521,40.807207,112.295681,171.063126,253.70615,236.04572,178.289059,212.654946,200.06102,57.660433,-12.272179,23.22414,114.436981,254.291598,287.124084,326.889148,277.041401,203.384385,-25.180162,-124.85088,-150.858322,-114.541978,-87.178939,-124.758621,-150.98811,-210.396447,-268.123799,-406.121596,-423.594843,-344.642289,-276.702783,-170.138603,-256.561423,-343.977041,-487.518701,-516.208684,-445.494823,-385.655034,-333.664173,-302.945583,-269.550965,-294.595521,-380.118197,-479.219978,-424.998354,-270.549594,-247.480008,-268.376873,-278.288126,-290.905117,-371.230559,-444.327897,-603.250002,-635.326298,-497.035784,-319.173982,-333.281506,-497.806482,-565.995457,-557.608657,-494.465805,-377.006206,-335.491753,-235.736332,-196.497451,-217.562329,-241.148281,-204.492601,-74.888274,-24.926025,27.729473,3.475881,-39.389204,-94.522788,-104.554289,-152.906457,-174.902028,-122.955892,-45.802025,103.277725,144.089824,145.628536,123.08453,85.452994,21.097382,41.665707,220.588761,367.749662,325.456674,53.859575,-71.703398,-123.267059,-83.073695,-45.164833,-72.454089,-171.868089,-212.330169,-208.657885,-256.059376,-296.765953,-226.077453,-106.003169,88.125364,89.507114,60.969074,12.996629,-33.349163,-164.528473,-183.908972,-47.767198,68.40693,220.993643,177.004011,115.417984,39.076623,59.312644,177.872795,222.74099,265.958827,285.577578,233.192063,-23.81064,-176.536015,-324.670542,-276.312279,-89.267858,-27.910359,-4.183561,-37.485023,-51.039997,-79.764133,-96.933156,-59.261195,18.502144,197.225771,285.817093,291.944347,227.404371,165.498514,60.087502,47.718,97.992364,130.97691,163.809475,150.622159,129.874731,67.288208,47.171903,100.918583,159.237294,292.627181,401.108647,404.247945,346.888733,321.307636,249.382497,200.531698,152.506223,169.96356,240.015193,203.887284,140.759526,54.275336,38.449496,-20.482264,-36.744025,80.573423,241.873412,266.202501,248.124056,241.812658,280.488297,318.064439,366.24464,388.447146,492.087411,448.613335,301.384542,18.501762,-1.610305,144.137447,221.299914,287.752552,276.372363,255.588358,204.482279,189.130594,215.346285,253.50641,324.74333,360.051383:294.6841,243.895135,185.802729,71.595817,65.975962,138.202558,171.060386,254.505183,351.071725,330.684006,130.309553,26.120393,-41.191087,-6.150545,119.679197,175.368916,200.523768,74.168308,-21.974789,-158.684714,-154.293045,-7.545356,69.831903,103.471637,18.24803,-30.598412,-84.791618,-71.85534,19.901547,66.542755,168.282477,239.67128,308.216653,190.389989,105.551155,-45.131997,-79.198708,-17.498432,41.965517,151.52696,215.660681,194.793376,8.344039,-109.074414,-168.854459,-80.923732,178.875961,284.348757,407.004818,377.106208,305.606304,134.550639,79.370974,110.581995,183.389981,324.31589,296.099408,208.165198,33.005186,-15.720448,-54.399623,-43.787565,46.584087,101.8548,150.268313,57.844719,-47.216238,-299.644986,-356.461456,-214.801118,-101.469355,6.630734,6.79668,-19.921528,-185.160937,-309.593369,-464.636258,-476.262349,-438.702441,-386.332504,-263.719395,-309.435883,-392.66719,-486.477016,-452.68268,-289.323948,-200.784889,-42.404364,-13.244563,-53.558279,-98.777578,-100.188355,-101.219387,-80.728778,-28.481882,-35.401718,-117.390253,-205.208831,-244.884102,-329.569972,-348.444687,-273.215243,-200.241676,-74.727924,-63.265346,-120.596487,-295.284522,-388.262317,-513.648849,-505.03627,-388.041514,-340.602522,-308.667755,-288.799948,-288.395229,-325.217144,-328.313885,-233.347976,-148.077847,76.187062,275.263426,283.560274,95.423331,-20.699354,-95.424987,-34.412313,188.362143,285.704101,320.184118,150.000197,42.717287,-136.68285,-182.164769,-158.872718,-122.245692,-76.020633,-31.661558,-0.252934,3.863433,-40.82645,-139.96415,-152.017849,-97.435565,-70.955174,-69.502672,-83.772261,-107.481112,-219.052968,-263.106234,-176.023414,-59.540811,88.665352,-25.59055,-109.917112,-171.879885,-172.265804,-180.417711,-171.927515,-89.917671,-14.531888,97.662139,-36.652607,-166.967085,-365.817893,-387.060359,-268.970512,-164.722375,20.648664,74.769929,42.607603,-101.099414,-164.765287,-160.416395,-98.860742,40.293551,99.106244,149.617267,4.054492,-118.822634,-300.606831,-326.564519,-235.826561,-129.743332,91.479911,135.606854,81.245388,-86.947257,-164.937154,-255.89583,-255.987391,-154.958842,-78.441951,37.123716,37.451741,-18.805248,-192.90242,-240.171889,-177.706256,-121.919615,-42.274335,3.633912,-9.27851,-103.753252,-160.445277,-236.78812,-234.16498,-141.451772,-80.403755,-12.746547,-14.408517,-25.260018,-43.331438,-34.12078,28.732059,72.822548,164.138925,163.278564,104.174879,-84.53107,-181.444798,-248.488116,-181.261425,83.84101,219.099935,332.556896,195.628653,81.900647,-160.804851,-240.354954,-196.110765,-112.093674,-6.591954,-56.682703,-117.568345,-246.557472,-313.602637,-401.022878,-379.258543,-227.851845,-155.929817,-108.265367,-193.944565,-262.656518,-372.341902,-383.175821,-296.188552,-224.372148,-91.251014,9.047206,24.629998,-137.845357,-293.752401,-460.253298,-409.06281,-203.493167,-128.754266,-87.956052,-187.039215,-297.076919,-545.739655,-590.503815,-471.086966,-383.380831,-223.882604,-151.514821,-216.186346,-460.998992,-544.206109,-531.377162,-462.938172,-288.390532,-192.57029,-53.168911,-124.521888,-208.831642,-298.160635,-265.736886,-102.326797,-20.513296,83.85779,93.650234,56.164542,-75.561938,-144.739065,-213.632824,-195.890855,-57.380182,45.055265,160.895285,79.680467,10.109251,-124.332744,-158.229896,-74.366298,30.633894,257.301606,307.392913,241.377088,14.468921,-113.292064,-249.081617,-228.880918,-134.652831,-104.837696,-103.720558,-166.562848,-223.494158,-357.224144,-376.628288,-208.577023,-48.028211,214.443849,164.518321,55.301449,-97.382294,-123.188067,-142.539468,-125.72413,3.354945,80.168045,122.502919,37.209488,-28.785564,-188.648222,-227.569275,-119.309423,-17.158379,128.761832,139.886443,72.005078,-231.282454,-405.471369,-496.630828,-378.773101,-94.901253,-29.300316,-36.235841,-115.887749,-175.397719,-286.816912,-300.621084,-194.274884,-73.056952,204.973589,270.652176,213.054382,52.337292,-5.685314,12.694804,77.859719,196.343026,226.017535,230.802538,141.177242,62.556514,-114.671279,-161.330978,-38.035945,106.724276,360.958236,437.568753,443.543457,425.77651,370.815342,215.405917,174.40944,207.801648,258.937141,294.251646,129.343278,26.379678,-85.633584,-85.168697,16.609432,106.476743,325.13791,445.173696,421.165701,305.650617,273.501913,283.035648,303.635891,358.796493,393.546874,418.424755,265.991346,138.544378,-33.820059,-25.492693,121.961001,205.664028,350.622566,389.808451,332.978049,151.456813,79.903772,56.271307,117.663188,318.019161,410.384889:55.773547,52.587243,23.042833,-51.74187,-83.41895,-102.312473,-77.073297,53.196055,192.344555,211.616892,138.916888,83.504642,27.348148,27.851751,7.403278,-16.70115,-30.737723,-88.852634,-153.527405,-259.200537,-278.145317,-226.575681,-181.859314,-164.542131,-251.812523,-273.413089,-197.136978,-149.593889,-122.400018,-101.450114,9.383114,61.720277,93.389309,105.911806,127.821496,150.714078,144.411982,153.706515,179.040805,212.89024,165.519423,116.427738,45.164972,23.262362,-19.641182,2.099042,192.207431,305.225808,392.739205,327.235724,290.748568,202.96926,166.338242,207.829768,263.461192,299.012517,189.702203,124.296878,81.999285,87.143521,100.166401,141.244308,275.860264,313.661277,292.685231,229.631427,206.667416,148.820277,96.457682,-6.370684,-10.883347,55.097865,62.817978,20.988671,-96.994151,-144.302571,-198.708446,-216.856664,-234.22258,-218.843749,-161.362984,-149.163687,-153.286919,-158.150863,-153.08599,-105.805882,-83.488905,-74.475804,-34.656063,-6.116465,25.680538,34.468943,32.875738,25.554955,13.350667,6.884684,2.004123,12.637045,27.485678,91.952071,119.586543,117.095813,108.641377,109.929219,83.698966,65.182672,72.874149,54.571692,-135.792862,-224.199388,-178.704639,-96.854654,-38.783575,-91.951749,-102.187218,-81.016963,-57.062882,-13.339834,-15.178046,9.831327,158.315957,207.459148,154.074294,81.970285,7.472287,49.557145,183.346373,209.39682,188.988318,166.811273,150.63578,43.468933,-29.057342,-56.038862,1.170769,157.160124,273.115481,288.570661,246.261676,208.430114,140.098374,136.291914,205.590241,234.716113,181.595043,91.181873,69.552067,27.759412,17.884074,77.376555,124.190711,167.647326,116.758432,67.881955,6.361665,10.879277,42.674716,38.648851,9.898331,32.223546,147.483719,163.039208,137.021069,78.707423,25.526243,-40.468812,19.286946,273.553943,382.062002,358.385037,268.395433,201.902252,87.890057,96.519118,188.227704,206.084143,137.893814,-16.299941,-82.235513,-143.327398,-163.222835,-205.536687,-197.609722,-63.984878,60.291453,42.293065,-60.189459,-98.714044,-153.097667,-157.031747,-109.457653,-79.226053,-48.814712,-69.223267,-73.194889,-85.536715,-135.016708,-246.548375,-224.789345,-17.652653,101.782694,63.883311,-114.550475,-210.949158,-347.466571,-382.353349,-407.888723,-385.289175,-266.452743,-133.019006,-54.043442,109.377314,158.375894,187.278635,190.647745,208.438846,257.705708,254.724588,175.458975,142.143411,127.552035,144.680826,232.672457,307.999921,455.420099,423.076287,343.231954,190.262386,146.423118,131.142741,133.857628,93.33973,14.237219,-20.320503,-94.725879,-165.858153,-336.493334,-379.192745,-350.052963,-307.536416,-237.370139,-283.319086,-351.819761,-428.546011,-378.859751,-188.265879,-139.636809,-201.665833,-269.806782,-236.583952,-164.529634,-208.756646,-345.248202,-333.531432,-189.140529,-129.73407,-79.437857,-95.673555,-116.101015,-163.731686,-194.616557,-271.245816,-306.060627,-300.016757,-186.075495,-144.995499,-191.625095,-272.745301,-389.57596,-381.84556,-315.276363,-267.879965,-107.585259,-68.423813,-130.369181,-178.834242,-123.845766,11.247508,40.883771,11.328862,-103.246591,-167.432041,-196.215033,-172.974834,-200.482338,-254.027243,-296.600885,-238.050746,-27.785843,78.735062,76.537682,51.648574,54.865974,108.120365,150.78194,267.223719,305.768251,247.144637,76.079883,12.090584,-75.118072,-111.55113,-151.089928,-151.477621,-186.865251,-292.005922,-328.179816,-355.028652,-367.749907,-385.171134,-364.144552,-241.236403,-97.636107,-65.445049,-107.974311,-145.552349,-144.323812,-106.276694,-37.486159,-11.18981,21.590061,-8.836062,-14.940393,15.797734,46.747027,148.556615,186.039425,196.862076,195.637869,164.206225,-8.656924,-120.726755,-247.91181,-223.980476,-71.830287,-12.402271,-50.688754,-203.490848,-237.378599,-219.184841,-207.76904,-168.556452,-123.320534,-49.554953,-26.782466,7.739721,60.078692,13.41029,-136.018646,-149.570246,-76.502618,-53.766324,-51.977085,-37.791701,-29.232267,-64.37984,-84.600803,1.252544,86.17862,211.196366,220.675664,184.473672,129.974052,128.081859,133.588577,130.944373,121.062293,144.513095,240.074319,201.60696,125.294954,2.03021,-9.584918,34.837761,55.446184,86.420525,149.91787,187.431161,228.115381,222.436777,232.866243,277.161164,357.205333,364.816066,389.547571,390.594459,333.754473,172.2089,122.911829,122.546745,134.149989,102.079847,14.968582,-33.141783,-70.584369,-41.279517,68.327924,100.740483,54.081767,34.462691:1.861088,96.246921,63.611016,-80.35033,-123.872907,-126.088314,-127.961194,-128.166637,16.792166,119.950582,206.838691,162.868053,5.646444,-43.940989,-55.124302,-55.710237,-69.074851,-85.783656,-113.020671,-219.356183,-283.215094,-348.861584,-333.573656,-224.408893,-141.609675,-133.453984,-88.578972,-71.17169,-88.334887,-88.064449,-31.630135,22.202961,137.597687,206.583993,216.864236,148.139482,82.940268,-2.102731,-14.020291,10.516635,57.609305,31.281399,-92.310132,-149.433124,-264.012738,-271.555989,-33.607947,137.593545,300.625758,279.289548,267.037694,241.259826,229.616318,251.636767,263.07511,223.094097,165.82789,128.779134,46.77108,38.018553,86.066405,113.117123,139.848259,164.588505,273.462084,281.398567,214.34149,40.156998,-17.854862,-38.681558,-26.039638,2.871126,5.562727,-29.19697,-138.748497,-166.271487,-153.705296,-150.558998,-171.954722,-168.81907,-122.529676,-131.985883,-160.628982,-138.994101,-75.658661,38.508516,61.743861,98.54273,149.06778,161.74424,205.995957,226.737102,185.461862,152.996707,137.773071,122.944085,12.278379,-61.470211,-40.948059,18.025262,8.130644,-93.263063,-153.524342,-191.754144,-113.056841,-81.104739,-29.34474,-28.041458,-202.427298,-310.2029,-308.803641,-229.875094,-121.671456,-51.612591,-17.219644,-88.030492,-165.376162,-207.815665,-175.669312,-114.642077,-59.796816,-24.711156,3.671789,-11.742787,-35.202338,-30.506479,-25.554561,-31.929428,-0.355587,74.782267,88.935993,75.329624,62.449243,40.942977,31.061072,42.888083,130.326883,178.393012,180.62125,98.77128,-104.373389,-125.916884,-23.669862,25.852525,50.881495,-39.72182,-113.092352,-199.961761,-185.837571,-64.487354,-2.853771,25.608348,44.793771,84.863767,131.069393,109.083528,3.982353,-43.067879,-59.258738,-34.614764,-9.273784,-70.48387,-97.041921,-141.317555,-170.586982,-166.461526,-116.702739,8.915435,90.406404,128.114235,195.047206,179.359093,36.798319,-22.377894,-13.963823,39.357888,100.538349,-50.206693,-126.130463,-165.008383,-185.48126,-237.943164,-218.74635,-92.84487,-6.697674,-20.33807,-120.59772,-189.085864,-273.784152,-235.717814,-128.240533,-154.330265,-284.474614,-312.22021,-275.028875,-167.168999,-144.835904,-183.18524,-211.357139,-181.982683,-65.619037,-43.836394,-98.430823,-150.832221,-253.164959,-296.803699,-404.411986,-432.508518,-314.797695,-98.53306,-7.02333,133.219615,171.948655,180.985982,178.059831,246.346319,332.812043,317.963646,189.801836,129.778704,120.611998,184.768649,348.326184,398.654708,470.606928,492.313982,422.535338,160.521417,52.310779,-18.194142,-16.497555,-7.086036,-42.450338,-99.37192,-210.413246,-246.348751,-342.514011,-396.07912,-427.638666,-386.930835,-265.390181,-285.067814,-340.523089,-400.117905,-375.630242,-252.069243,-199.837596,-187.007516,-265.901688,-308.577677,-343.67562,-348.309959,-339.633109,-313.18914,-222.791789,-173.952474,-145.918742,-172.178401,-153.682543,-172.08421,-250.080792,-419.810855,-451.120328,-358.495064,-209.636096,-192.16724,-272.246318,-330.413231,-381.069416,-361.952914,-293.341536,-241.285706,-54.558312,48.615377,2.708231,-151.586464,-167.896218,13.068225,142.664596,218.729136,74.679196,19.441288,22.993844,29.03591,-28.886046,-51.273639,-16.475753,43.359394,195.659266,211.761479,160.778964,61.50091,40.072734,15.332397,12.487988,120.006936,242.365534,223.59634,99.907386,56.69485,21.582193,-3.303185,-68.09251,-79.197843,-46.596986,-63.767342,-108.083767,-231.89083,-302.269978,-368.905428,-317.81321,-62.6417,135.509002,130.08619,-10.051406,-66.50486,-63.856741,-2.310711,186.987512,259.736486,292.067613,275.211908,291.123051,297.969099,279.311009,355.126052,437.110013,467.821618,310.603175,220.531512,70.361267,17.845463,-24.90317,-10.387994,64.736568,100.260846,111.405802,57.379537,60.579015,133.023813,145.709005,132.551634,155.621083,217.289748,228.775586,252.248747,294.028567,271.173925,190.051605,166.739197,162.484581,188.04234,276.859286,266.631728,216.561374,117.877562,77.84548,50.165787,83.273689,193.405936,233.873087,216.300414,170.659484,171.333219,201.628027,196.923504,147.429961,142.84459,204.98795,224.047359,199.742037,137.010112,104.373624,25.665299,-11.174311,2.762865,135.432331,210.430201,301.796659,296.432963,274.67881,306.675949,390.988716,401.33129,404.389769,438.01845,433.890366,327.443668,255.444338,229.835903,271.323436,283.924029,187.03051,165.625471,182.618041,174.492491,126.043584,128.063544,205.703801,250.821457:28.201023,115.719786,126.254559,52.523966,26.429,99.317133,154.922952,233.804899,254.514934,215.186543,73.89604,8.720068,-38.603304,-18.698123,49.590154,85.830828,126.522783,37.404107,-47.867477,-193.163991,-211.348886,-122.607821,-67.515095,-51.627148,-101.736954,-109.710779,-85.958278,-77.035865,-103.211386,-114.983478,-64.819105,-5.915861,129.203253,197.857849,187.21183,101.05524,70.803355,131.170971,193.818052,252.082533,197.144749,157.34136,60.567457,-18.159374,-111.750663,-41.073731,242.997709,352.965797,435.273449,333.553963,229.586997,104.800094,124.562648,206.526734,202.339424,157.00848,189.578561,173.212453,31.453818,-28.727041,-3.067443,63.135888,160.106226,166.947436,114.434526,8.728487,-27.768566,-50.733138,-61.96909,-68.805951,-49.270428,11.814553,5.592141,-36.926728,-129.305988,-177.269569,-305.635166,-370.615164,-416.335027,-382.414918,-313.907613,-381.010053,-420.168835,-436.942522,-434.11993,-355.837026,-272.724356,-132.645576,-87.276762,-93.642194,-58.30105,-19.42947,-60.363611,-137.417746,-230.443956,-204.638145,-113.147653,-156.587523,-185.497323,-144.867092,-113.412876,-109.62306,-110.704918,-6.88599,41.751223,-40.269084,-198.040629,-233.062224,-341.586792,-383.007441,-292.332969,-203.197808,-116.817029,-114.085176,-118.302103,-154.38472,-153.29924,-56.257372,-0.913353,93.266191,176.45487,153.903815,-6.663236,-63.265025,-10.896601,76.122455,214.920241,221.889647,145.636938,62.072856,43.518767,2.521118,-30.690972,-15.844097,47.474872,174.556148,187.369093,165.195569,132.332915,110.188195,69.055395,82.74407,148.476256,167.672103,134.564624,8.967656,-45.243486,-58.338071,-26.732748,55.094883,83.391612,95.910131,102.769996,101.122652,25.575714,-50.821092,-166.623152,-174.749369,-159.704184,-133.012278,12.354337,85.635162,34.660516,-122.666764,-153.495344,-67.402278,-0.689067,83.468462,121.718627,116.957969,43.127513,-2.891821,-0.685842,65.362611,168.181697,152.659508,60.947774,-29.850498,-67.67703,-147.65535,-203.530298,-249.273943,-197.550814,-20.500368,40.187381,2.042993,-143.377531,-221.357771,-290.475211,-262.384117,-155.995135,-110.613604,-34.834397,-38.0969,-66.496122,-97.65082,-101.747643,-95.411234,-80.661803,-12.398732,71.013446,65.630583,-44.158341,-108.3229,-224.509346,-258.951798,-237.681181,-204.673559,-155.730565,-162.258391,-144.062521,22.275705,121.406283,195.785158,191.073658,214.691693,192.510703,114.67154,-86.045833,-159.359493,-174.016792,-87.321114,167.008934,249.882442,278.185594,206.169988,168.782728,102.042587,51.276843,-40.123154,-41.453932,9.407516,-11.882326,-33.417066,-70.275313,-139.695808,-324.542607,-333.827858,-173.362885,-93.664761,-61.859227,-187.013618,-263.573982,-347.257549,-341.094111,-244.598079,-187.360579,-104.864476,-60.568355,-78.468253,-197.415677,-279.269737,-378.497904,-345.015142,-210.730069,-168.574402,-87.315187,-39.917145,-78.177005,-216.853139,-252.335054,-220.411583,-195.308976,-128.918602,-38.744495,-49.15669,-240.261157,-362.278939,-443.976877,-392.447074,-280.865611,-238.342531,-99.397926,-28.300819,-62.502331,-156.716721,-140.086966,42.012267,116.022782,88.40659,-24.856599,-64.035099,-107.75947,-112.515213,-60.077737,-8.874995,83.355434,115.417787,128.146995,72.20343,48.466367,22.826885,7.912517,28.475713,84.051404,241.630386,330.77915,308.614657,142.220404,23.097979,-158.248379,-176.095788,-144.007801,-150.442958,-234.715072,-339.00773,-363.317046,-374.478739,-373.539056,-280.65393,-187.506613,-14.720448,51.551746,41.695668,-18.547207,-60.647167,-122.113875,-117.207934,-77.731738,-44.026419,62.821122,58.127347,-8.531399,-139.114815,-137.327836,-12.744659,40.173386,77.864412,65.723873,48.745146,1.581249,-62.228523,-222.582276,-246.509599,-174.092938,-123.127507,-82.694927,-172.999153,-243.964139,-324.197477,-314.04483,-230.390628,-172.856532,-33.208298,59.125292,56.086431,5.088411,-18.080786,-37.0483,-9.001073,96.451715,111.510667,38.12197,-52.547057,-94.219179,-150.480757,-139.821293,19.391806,135.619469,287.961868,330.606209,321.308419,236.931749,164.840355,26.32396,27.303584,170.059864,235.239491,265.516822,189.283348,123.963172,-3.1972,-24.347507,60.430562,121.911555,192.431074,215.434321,214.438947,209.795807,209.703922,226.282312,248.51185,308.975177,347.484796,411.559429,369.170739,292.375155,92.72592,31.641926,108.634667,210.110898,337.731157,295.888223,231.250269,128.455038,134.086871,223.075949,253.196461,238.507582,234.568946:forward
-26.493418,-10.414637,-17.617192,-59.67217,-89.595577,-143.11835,-156.817703,-168.054921,-135.295121,-110.765528,-100.92875,-104.893382,-98.693354,-98.364475,-90.699007,-62.437141,31.095023,46.051356,1.130486,-143.201597,-205.660272,-186.39578,-118.090929,-27.927912,1.938866,14.127316,-13.275531,-43.239361,-24.13795,30.788846,105.097202,99.210482,24.778578,-155.926107,-236.147296,-239.516803,-183.1941,-33.37545,40.176979,133.398561,141.794288,125.443331,110.101929,111.218388,73.398441,45.238318,37.675309,72.26312,167.379981,100.901629,34.028012,-21.054986,-36.442097,-86.970468,-80.245467,2.300787,19.77213,-18.583592,-141.467031,-195.308148,-217.297337,-169.762399,-31.241764,10.946264,16.81876,-58.320416,-111.713613,-220.050581,-258.021923,-211.547749,-141.257935,-45.6561,-57.819793,-75.818557,-74.034647,-63.431351,-58.490462,-47.72495,22.455456,66.153656,104.87402,66.987463,59.608332,78.645434,65.914689,7.937836,18.836599,176.935637,340.296086,328.87792,170.057079,101.614573,7.74299,-31.486181,-64.657485,-53.964218,-2.928284,11.620319,0.222573,-14.526718,-24.695854,-53.67549,-45.456435,27.695073,77.67661,68.78695,28.730479,6.085871,-85.198053,-138.359415,-188.043739,-186.842408,-155.552313,-160.639281,-169.59058,-144.707709,-144.688118,-178.806438,-173.606067,-95.755297,27.291742,81.532952,145.88273,135.020065,-6.810396,-79.174408,-91.087068,-48.764738,25.352987,-19.384481,-56.364217,-70.735803,-77.633341,-119.950856,-113.071982,-9.750894,77.911952,82.122711,69.433703,68.865593,28.878469,-22.789595,-117.976095,-119.011429,-22.414439,27.376613,-14.072359,-140.97667,-162.603842,-109.615654,-82.861255,-50.284496,10.907009,40.706122,45.940262,-3.866503,-163.447658,-193.775098,-101.733702,-39.153409,34.637229,30.624082,2.556184,-60.696646,-75.191286,-36.8559,-1.148283,58.899892,122.832174,123.617058,-8.137473,-97.870344,-132.566071,-59.774968,96.094451,104.95867,3.924765,-48.305811,-45.257415,-102.319846,-161.862086,-189.986694,-141.519395,-51.928623,-77.945852,-120.983142,-194.112378,-227.533436,-316.908514,-337.74277,-268.057887,-213.698169,-211.632286,-413.038331,-495.098036,-437.238822,-339.525207,-159.216097,-100.230292,-57.5283,-38.608768,-22.263042,8.052424,20.26459,34.382799,54.441228,129.164803,146.552559,73.021698,-100.529734,-186.105919,-273.298302,-258.639073,-170.711481,-136.186259,-84.583407,-30.712023,-20.793919,35.430577,91.073162,144.059608,139.591588,182.968224,235.806184,289.178734,118.032302,-14.846886,-175.569484,-196.195077,-174.670327,-144.724986,-128.882896,-208.40093,-238.190134,-214.500046,-205.008715,-261.668877,-287.790007,-329.3431,-385.199246,-424.95916,-219.424034,-147.442485,-242.770155,-332.44676,-346.915173,-282.809804,-201.720147,-216.243694,-214.944771,-195.38247,-212.964135,-335.223975,-398.486118,-435.587053,-410.038678,-260.393679,-122.366343,-142.524997,-311.493539,-373.649911,-339.021389,-283.19369,-227.435344,-238.499495,-246.304307,-236.193096,-223.127184,-271.504542,-334.381635,-420.256566,-418.154825,-323.352727,-123.644524,-21.459213,87.780387,87.972792,115.014446,185.963052,309.906602,257.171596,214.975539,176.45077,147.560365,55.428154,41.895994,113.314229,151.895474,146.573042,77.481581,52.577563,28.175298,38.089746,126.936154,173.228908,184.836598,146.604629,121.627562,32.313453,-36.564072,-182.068203,-204.902429,-95.723371,-8.44693,143.41542,206.539756,177.35343,50.942558,3.932078,36.110371,104.919822,201.7132,140.479737,74.685096,-38.530537,-82.557239,-145.707609,-135.96257,-52.475438,-18.587982,32.532051,62.869847,45.761119,-47.834453,-85.734511,-13.069865,76.049508,150.345089,52.097652,-11.655417,-112.607341,-136.985244,-166.645157,-203.121859,-327.055709,-372.768856,-299.55629,-117.324804,-71.198191,-136.332248,-235.596013,-369.718299,-337.547101,-128.488561,43.596682,43.991972,-48.353798,-74.313856,-112.68887,-135.570046,-53.417947,54.52699,271.299862,401.32066,421.878115,368.199816,308.907222,237.716199,249.951395,313.093771,383.806004,389.533283,281.080694,189.275922,69.745502,96.32563,283.239041,362.089196,350.85792,179.250066,85.880248,-66.288625,-110.189853,-88.335177,-44.683251,41.450353,130.649616,152.904144,99.033334,37.27258,-36.237875,-17.425425,90.463257,150.24254,233.068602,242.776867,240.098271,199.061818,141.901787,59.149982,59.211883,25.112973,-44.869571,-36.464821,38.064226,40.091208,-75.357238,-121.493121,-50.84166,36.937343:30.48015,-28.264152,-59.338652,-98.591769,-104.865516,-169.889334,-222.170858,-195.994362,-16.120153,32.914168,-36.765104,-126.586939,-254.720389,-242.150494,-107.162578,-41.584305,-8.540342,-118.148669,-194.37255,-313.012173,-335.814062,-245.339359,-145.988638,-2.664068,33.935436,27.261427,-60.349744,-104.441675,-60.388973,5.770408,55.915754,30.387356,-11.191215,-58.191293,-94.443355,-97.011848,-40.205007,137.815921,212.27141,258.816631,155.856082,98.529509,84.780753,103.543658,119.282691,127.664172,146.667123,144.70969,115.697326,81.155508,62.272944,-40.692285,-101.907843,-128.810551,-101.808066,-17.988512,53.566252,45.026008,-63.477335,-131.560688,-200.216118,-167.04369,-36.97169,3.499347,-3.378753,-77.575838,-108.409003,-197.428768,-268.7774,-321.332283,-263.259383,-95.904904,-53.922869,-78.370011,-105.04495,-91.569727,-51.111077,-55.062249,-103.39936,-80.04911,87.524427,128.625699,85.197969,17.522937,4.229576,23.620919,75.398012,248.404611,357.622238,333.085551,193.575641,115.93379,16.396155,27.000587,104.027999,125.389976,128.581218,101.391672,102.037171,122.565227,100.043792,18.287886,14.034461,89.665072,91.727625,48.521509,10.594945,18.78185,-36.714661,-101.34875,-192.033523,-184.589434,-87.048724,-71.83366,-105.998176,-126.660919,-114.929005,-92.067147,-66.169036,31.518726,104.476132,94.290373,38.318892,11.864632,-95.225146,-144.042704,-92.895903,-25.433302,6.621208,-84.80263,-119.869935,-160.541894,-179.92286,-156.530892,-92.265817,53.556455,129.386648,144.410444,105.054044,48.873104,-42.086333,-40.965145,17.451353,38.815352,72.167459,153.860381,151.964268,-12.677727,-99.599781,-127.355502,-88.689367,7.242204,92.94448,114.85962,106.959662,65.229906,-48.426298,-45.889821,90.55783,154.468524,185.804469,156.770637,153.711901,113.996411,64.856071,37.728231,86.521315,223.074275,242.033888,177.232815,31.533033,-2.710292,-19.759862,-23.818187,-50.442937,-62.836087,-17.54223,51.221917,31.976832,-126.246337,-210.399974,-235.812655,-168.400205,-2.019515,16.085149,-23.603917,-101.458823,-123.507909,-117.628376,-102.493353,-123.807043,-148.634246,-155.246073,-246.174207,-327.963308,-377.915831,-312.540484,-90.005608,0.107053,73.721706,59.734138,29.545748,-48.895513,-86.881105,-127.580399,-99.243231,52.216855,125.262147,165.287174,21.957229,-92.331438,-258.54864,-252.771951,-67.729477,26.148327,61.864839,-17.624955,-58.64095,-74.637207,-38.479051,42.963758,53.742899,57.819408,77.741367,109.44818,33.136085,-47.591307,-208.806222,-250.070528,-201.33275,-130.750836,-26.257415,-72.121977,-133.403235,-261.125927,-312.42493,-344.547427,-318.943598,-275.702542,-279.567012,-258.838477,-170.092743,-142.479821,-218.804585,-293.695327,-275.875121,-178.50378,-71.927729,-173.783047,-235.613209,-330.674321,-372.559136,-364.533092,-305.173619,-239.038672,-255.572137,-219.077842,-121.267335,-151.03244,-300.371523,-328.962394,-284.14827,-258.854512,-226.82271,-253.051791,-296.348477,-373.507707,-396.599593,-432.758295,-436.786306,-400.234203,-369.532369,-270.517919,-88.946179,-13.762561,-10.319584,-45.351472,-2.050628,77.818818,264.234949,350.839488,312.436429,140.147931,52.414408,-45.751094,-46.449098,-8.542102,0.954832,8.86836,2.45683,-12.135455,-25.852168,-8.835021,64.782329,101.679609,154.136628,105.797689,29.94086,-94.725682,-128.058867,-215.449886,-251.625501,-183.511754,-96.292582,12.599674,22.783473,19.032481,-32.389037,-62.255502,-40.389523,17.845403,172.908333,212.697413,142.176141,-96.114853,-192.242362,-206.02579,-133.738245,2.843141,38.958498,98.293863,86.020744,31.043807,-58.494875,-51.510347,73.261813,173.546403,313.656338,241.063821,166.798581,72.124661,42.473976,-31.810235,-57.652803,-56.131403,-43.937153,-4.839435,15.630583,-6.462469,-103.115319,-144.466827,-139.949744,-96.794437,62.116917,222.574741,222.909053,65.803221,-27.125912,-134.509322,-117.510843,88.588488,226.311257,415.000624,432.706818,402.601839,336.587181,308.241197,295.97838,320.23962,355.029765,363.144246,361.485611,295.372972,236.923954,152.503461,173.739549,337.398661,414.821305,443.861315,309.311302,220.850631,89.348036,59.709731,97.603,144.478827,201.927656,198.136827,197.822145,201.951683,172.849388,93.90324,110.622753,240.835501,300.614413,366.114536,321.164755,269.979305,165.15093,110.317839,20.523297,9.936085,35.672299,0.701065,-41.794717,-125.244368,-176.40998,-266.665485,-245.079603,-44.527237,62.682399:38.54987,-45.701458,-106.584224,-174.894453,-154.804021,-112.608983,-135.081076,-144.145853,-48.747144,-22.551386,-60.836063,-117.43176,-227.009519,-225.53985,-125.216453,-97.322878,-136.662153,-187.806158,-199.714854,-241.43895,-271.947895,-242.747981,-172.37053,-39.499545,31.836238,42.66229,-12.584626,-37.602993,2.508651,43.027522,89.716109,72.547004,-12.921558,-25.903408,-17.79192,-71.526753,-100.553054,13.037348,138.686962,283.504208,139.348334,46.541604,0.992219,13.559644,29.40707,51.681033,113.723446,130.154231,123.833583,87.934386,54.260696,-60.658646,-110.413274,-135.004202,-120.44049,-70.07512,-43.72295,-47.564659,-93.593162,-150.545727,-240.569268,-205.39086,-48.237382,-6.665363,-33.884246,-104.570468,-136.171014,-216.400697,-245.534343,-208.151525,-152.217566,-12.268345,35.300858,-4.47845,-104.812518,-137.491437,-156.633245,-145.797567,-99.521474,-52.264487,68.30775,79.308672,42.405097,-10.17811,-10.146454,15.257013,46.948027,166.18033,251.835782,253.224242,186.475115,134.308026,113.751745,168.242525,264.370715,261.920144,208.376628,168.530152,159.588353,161.923043,169.472722,134.619915,77.789578,-2.587934,22.577871,28.170245,36.858633,38.940463,-43.033532,-105.124828,-166.901455,-160.596142,-108.476507,-84.466196,-83.986832,-85.39057,-90.112289,-85.256377,-67.776111,12.138911,46.626948,4.217431,-78.966041,-95.062433,-150.475632,-171.697151,-123.453581,-75.536798,-56.248792,-158.014403,-195.824076,-247.5515,-281.616568,-307.085371,-281.906524,-162.672499,-17.419342,8.1681,-70.386875,-130.806527,-165.914087,-128.481797,-47.908804,-20.788249,88.026969,205.3256,204.499696,41.614173,-53.809442,-73.557945,-27.985921,17.35026,43.415295,68.295422,101.92729,95.373853,32.371268,1.753652,10.281569,47.860043,131.125074,178.170634,184.592023,149.462485,106.6401,50.916346,87.081119,274.53266,296.692781,191.892473,-11.714109,-48.895234,-22.418096,23.782239,82.041083,58.709884,-8.790026,5.215989,12.315044,-46.226751,-75.955217,-15.092471,47.103563,121.925289,122.467138,99.77556,43.475629,40.180505,120.845527,157.848367,95.621845,24.066061,-94.620069,-237.914156,-298.765822,-314.342767,-275.031367,-110.974343,-14.0473,100.262629,47.072033,-29.143149,-163.153086,-195.231075,-159.076008,-84.465665,81.632322,129.989525,148.975531,68.378911,-13.395165,-206.50814,-237.484706,-63.969238,43.529851,96.099669,19.711517,-46.268629,-155.836194,-155.764603,-79.30384,-36.405177,17.679953,2.613102,-100.812439,-150.64544,-151.042474,-214.081144,-279.290824,-326.815656,-276.930137,-120.651183,-90.756804,-143.941478,-281.313281,-347.92505,-449.016001,-438.474942,-272.637433,-174.586477,-81.050354,-150.815153,-212.339219,-314.975947,-329.689467,-203.083528,-87.536741,12.181103,-153.466064,-223.11616,-232.957488,-240.467066,-242.935825,-178.576873,-15.882062,0.672268,-62.495096,-64.851825,-65.16867,-162.214434,-224.411759,-252.503554,-218.907461,-124.160836,-95.746495,-122.402222,-234.77342,-299.550492,-332.92968,-278.826466,-175.777135,-177.062181,-163.331359,-23.835696,20.042626,-40.521347,-81.376774,8.352219,128.693741,383.018463,461.477901,393.202356,172.494943,79.154072,-6.226577,-10.80145,-53.745638,-89.692652,-96.086666,-38.50078,-25.484803,-48.678949,-62.535991,-47.754479,-13.258679,118.563874,180.069565,108.866631,-179.630117,-319.828655,-396.451219,-315.6688,-99.828486,-50.090598,-83.570233,-103.976019,-87.801896,-95.519609,-104.085854,-35.711739,41.634345,201.471151,192.369368,98.362829,-133.796702,-203.65782,-199.647357,-139.273442,1.841265,38.680109,28.282777,-3.781198,-6.246416,-38.086738,-69.066472,-12.961463,83.411603,225.111435,197.679086,152.543838,25.594263,-55.299405,-152.986248,-145.210475,-43.019308,44.207166,182.378276,98.722047,19.505401,-52.222485,-47.30846,0.611325,43.208398,154.662193,188.091463,140.8946,43.870949,30.384023,-41.2442,-103.128741,-71.114993,51.980178,286.156324,273.248646,227.74311,180.597286,167.017111,128.113615,122.077507,170.605639,205.736693,186.603491,83.922239,39.888757,59.211312,111.60172,214.895672,250.829088,313.64818,323.298244,279.791858,90.971567,-2.905813,-41.908761,-1.090525,121.958676,231.529505,250.028769,172.519324,86.847462,35.755111,124.355247,320.188626,345.89097,320.777254,285.384723,254.508002,160.423139,109.859336,71.349233,77.716113,54.933567,33.875501,38.011803,-51.165463,-147.013066,-234.41835,-180.189413,26.405632,125.877802:10.518147,-36.445301,-86.855266,-187.505945,-210.147088,-178.003578,-146.805642,-105.626633,-63.689999,-49.963019,-101.375902,-175.266279,-313.463245,-315.567021,-194.349962,-123.055963,-33.844861,-88.189552,-142.896204,-179.648009,-182.706304,-188.537529,-162.99952,-20.338747,142.304293,153.253943,39.956148,-4.79673,22.120411,49.635615,68.119821,74.189096,61.968803,-19.039723,-59.325247,-94.1781,-78.781387,72.766327,189.804436,319.705082,193.046484,109.09206,69.14545,72.139863,20.156192,16.943689,117.477374,176.204074,208.342143,85.401061,18.500899,-25.703093,-31.943848,-82.538751,-112.988229,-67.384664,60.778437,56.329356,-79.639379,-162.994561,-265.010936,-239.495936,-61.514353,28.040137,99.218788,13.648888,-48.075354,-170.28602,-231.841223,-262.304939,-201.873197,-7.959023,73.325265,40.128887,-70.941959,-106.094795,-90.581942,-54.002445,-17.067131,-3.131976,99.329073,148.842609,109.481909,-0.368616,-30.842664,33.843111,121.479254,267.250009,268.41301,225.326591,125.120938,91.269537,86.150922,112.518854,146.760738,142.797643,127.092954,98.74628,85.6717,60.323387,39.0521,5.73808,17.116745,91.479455,135.538726,124.360306,112.605328,130.909103,112.919176,53.037685,-73.221612,-89.643559,-20.255303,7.440307,-21.436433,-109.392883,-146.303683,-130.362407,-77.957499,54.859392,117.388839,79.642018,-46.045195,-100.593401,-204.781244,-216.547858,-122.920773,-78.454613,-80.66464,-124.770008,-143.685904,-244.010597,-326.774627,-409.872967,-371.525402,-193.342441,-37.236645,-7.121009,-18.838398,-35.353973,-53.40026,-50.73072,-49.019645,-50.342869,-6.966543,38.313268,21.778228,-78.452954,-115.185195,-94.157631,-64.437513,12.444633,138.186837,171.352622,119.791188,55.599863,-71.981406,-83.471049,59.14881,152.419882,195.092563,69.693341,21.984581,0.760168,-4.570837,-1.028228,33.018179,161.425466,238.258497,202.106189,52.769438,-0.007814,-33.047721,-21.089288,37.73619,55.277056,38.647446,26.209003,15.027372,-94.623449,-154.974392,-85.742175,16.336895,154.405469,212.631144,217.902964,113.306366,14.890302,-100.200733,-73.800927,10.167782,11.103881,-53.218643,-191.189785,-250.733079,-277.671015,-264.564944,-175.805553,-95.711094,19.518325,4.738378,-18.438963,-60.416982,-80.89936,-87.058719,-60.638665,34.538987,79.3419,81.773409,-65.942181,-143.700991,-210.897114,-204.42159,-124.599844,-65.999425,7.527419,-4.105873,-26.525482,-43.517307,-34.662191,-28.53781,-23.256753,37.81559,68.559925,56.196154,2.037699,-23.343786,-129.175341,-210.883461,-290.270604,-265.502927,-212.847208,-210.86777,-207.846449,-233.677523,-293.973533,-437.80823,-454.839123,-387.17402,-340.858606,-229.964276,-131.94998,-143.278919,-320.784292,-394.817506,-280.316134,-146.102786,-30.094156,-143.257133,-188.282633,-182.336607,-174.491278,-214.755431,-231.930561,-181.175028,-130.715026,-40.203893,-6.468082,-44.882675,-186.894508,-226.496361,-154.199283,-94.044416,-106.699934,-197.330722,-194.89155,-121.759004,-124.964029,-285.341333,-367.255929,-356.869656,-287.18548,-155.500124,-75.323839,-50.829648,-32.741214,-15.706583,75.866518,137.25254,257.881299,252.34196,184.683863,73.431757,45.977623,-27.313396,-57.290626,-60.540092,-54.030632,-23.531667,25.375651,28.69791,32.136888,49.665439,56.10918,27.703153,7.195506,112.11535,121.405813,-70.909017,-196.830185,-275.328026,-228.104139,-97.677964,-38.91107,82.634415,118.144817,96.564534,63.362478,45.347928,6.186839,33.901789,180.268967,169.054279,73.495091,-117.258262,-159.344422,-142.313011,-91.366244,67.480978,127.137378,106.164845,24.620833,17.211422,10.829686,-9.851795,41.179908,138.574424,254.720256,99.528444,-5.838643,-153.158561,-215.940481,-328.495046,-351.490064,-307.984033,-250.992602,-131.702665,-66.44632,-61.734419,-168.846094,-260.744985,-298.731652,-220.281927,-37.560451,-21.908418,-86.358154,-219.0977,-259.428866,-291.110962,-264.214,-141.831827,-73.846776,102.926542,225.443885,198.450234,15.686881,-69.993731,-67.145368,-5.551961,47.989835,83.548814,128.013314,144.069032,101.916914,29.323993,45.620334,172.274747,241.561997,331.115261,299.474432,215.017563,-51.101254,-156.166738,-155.450594,-94.193834,6.676858,94.607808,131.172266,139.814982,101.986941,34.165097,51.856718,170.253837,226.968408,265.742728,215.660359,194.79482,158.742957,118.80633,62.684828,67.07164,54.282396,7.084967,-6.328096,-44.788274,-85.64553,-188.296774,-192.194238,-10.026797,108.686653:10.11218,-95.63701,-132.075539,-178.012239,-186.261921,-153.238228,-113.450539,-26.786708,9.671118,-3.086493,-104.420381,-181.647874,-255.555091,-225.579317,-169.325178,-168.271705,-134.767012,-118.019702,-157.29324,-286.544236,-329.743177,-266.832059,-182.48809,-53.490583,2.249581,10.717241,-51.20395,-112.058145,-161.73932,-118.022511,9.190261,44.926055,49.67489,-5.098122,-47.633136,-141.423966,-150.597309,8.347385,136.611852,261.039143,161.775382,106.96914,46.247949,2.811326,-90.142849,-78.075479,68.226531,149.485996,207.846369,72.195628,-14.594476,-77.731616,-52.524765,3.305826,10.976709,42.317479,83.738924,65.242961,-44.179161,-119.286482,-243.642789,-228.2157,-13.823631,90.602896,97.893304,-32.416525,-95.53102,-259.22687,-316.282121,-245.270355,-161.168869,-26.396679,20.056936,2.475698,-59.888664,-86.359702,-108.800916,-98.494991,-55.555822,-12.620629,111.447879,108.133001,42.197987,-91.513064,-104.269251,-1.913033,67.816801,213.812833,342.801292,341.420645,213.724956,130.474191,61.959792,115.789327,297.316725,355.705817,306.988729,99.022583,23.256837,-30.227521,-35.075187,2.146332,40.223852,108.899372,105.180313,71.92622,45.753781,63.678017,57.504167,6.197011,-113.149357,-110.539131,16.266803,28.91974,-43.641766,-194.479659,-197.162921,-41.528811,37.060539,82.801652,33.281034,-28.656801,-175.261456,-228.019314,-265.17433,-230.537584,-93.14587,-55.334709,-121.855965,-267.175947,-326.426671,-398.090951,-392.351934,-306.8649,-263.143112,-166.495724,-26.858413,14.142907,-3.78932,-47.385678,-138.428825,-147.05618,-70.052586,-19.660122,41.856225,44.723231,13.422207,-104.482432,-140.257267,-87.294657,-35.427176,42.626319,104.092607,118.601323,68.909284,4.882608,-98.181085,-102.60911,-19.322198,56.219026,155.419792,117.658683,85.094598,-9.248009,-61.366802,-45.506421,20.847728,130.310538,137.426211,111.331623,47.209393,12.392074,-16.435482,22.058461,130.634637,144.574358,76.312152,3.831829,-5.009788,-38.387119,-64.982585,-21.954191,56.877107,230.808445,312.918676,310.19652,222.61661,156.016308,112.144803,141.462833,161.978125,144.273661,88.743364,-72.560087,-164.052258,-263.57722,-256.149482,-100.685145,3.331678,107.936047,75.350883,35.437839,-63.875273,-116.74817,-129.627468,-58.445601,125.267174,157.176516,87.160207,22.912727,-11.023004,-140.295146,-170.051006,-72.788825,-9.19795,92.686445,155.261588,114.822889,-21.993281,-44.028729,20.428074,68.581152,125.798778,146.697676,200.658122,127.494289,17.521062,-202.670575,-247.656345,-170.488773,-85.540763,54.939009,35.271531,-24.513128,-144.410042,-210.490417,-329.437568,-309.764556,-97.975084,10.558816,63.650859,-59.354791,-135.392918,-305.136666,-345.165218,-174.702355,-15.230579,174.316654,56.148269,-34.631498,-99.452984,-107.555533,-159.06131,-156.448104,-20.776044,73.999037,156.063699,56.64432,-24.164987,-166.446147,-197.172391,-196.962198,-189.827827,-139.730341,-80.72238,-93.829993,-201.729282,-254.053917,-272.20517,-247.224406,-201.774878,-175.891003,-53.830665,47.294577,34.888313,-72.060654,-96.158833,56.840986,192.93115,384.350707,347.953462,262.203771,108.6446,64.559414,-1.947371,-27.089391,-55.223276,-74.221698,-121.346683,-96.305181,-71.827669,-45.939453,-29.37666,7.845517,7.632476,20.845774,46.58998,1.470578,-189.712294,-282.458362,-318.935808,-232.601889,-3.46051,43.49094,2.908739,-47.232189,-66.872193,-111.50902,-112.730119,-23.433244,57.686547,203.631213,198.386182,128.225353,-80.625714,-157.09706,-113.633002,-18.053282,150.016435,181.386708,129.603539,81.851347,78.789002,-26.558115,-95.883675,8.97864,170.855111,343.774127,172.505363,78.848826,-9.516391,-55.170188,-180.887424,-205.215767,-107.550154,-15.03554,147.431523,188.648429,143.657902,-35.782558,-84.799723,30.784596,131.689147,250.921946,197.224131,104.883212,-70.120413,-106.588811,-124.857125,-121.779189,-57.676902,-4.466753,88.856878,107.552836,69.194152,-50.928319,-80.009937,-10.756675,48.274356,90.079759,64.195104,52.180325,-21.460981,-71.297252,-63.718312,0.170456,138.978486,185.887089,196.327247,98.85942,39.081016,-117.376121,-193.800573,-172.616348,-84.040652,51.574038,96.659427,123.986677,83.074622,-11.173484,-100.933585,-27.790991,200.611411,277.419546,277.860792,108.663957,42.07237,0.826246,-16.887144,-32.378401,-14.055007,-2.613287,-54.461985,-93.038551,-202.380526,-262.404263,-327.147281,-303.325509,-144.783273,-56.211924:0.203596,-8.014926,-57.463772,-156.307256,-171.331283,-144.755835,-128.927155,-114.35522,-73.434723,-71.128711,-131.960025,-153.234038,-136.493575,-119.590537,-72.496498,-24.38497,68.657319,30.670724,-16.920124,-98.556475,-124.841962,-88.44124,-40.63524,-2.304958,38.49461,70.410173,57.788282,27.070645,22.708173,46.280204,69.778473,63.899627,16.911697,-112.382488,-174.979716,-227.162422,-236.318008,-162.338894,-47.632135,140.722566,75.570626,28.310899,40.331865,40.106738,-46.433589,-67.236915,-9.705314,27.902739,80.72907,40.786947,-7.46333,-29.605779,-1.233176,33.461118,24.420598,2.181542,-46.657143,-89.321384,-154.028607,-189.140789,-274.944801,-274.162762,-128.022473,-38.719906,13.833171,-99.833257,-171.646319,-270.758223,-287.05603,-242.725715,-183.260356,-42.658796,-20.495857,-45.272005,-44.949808,-37.326889,-69.441511,-68.16492,29.928991,89.791362,144.01398,108.980906,81.415572,40.873461,22.275952,23.234894,76.278608,233.247029,275.289265,241.016575,141.998614,95.680671,2.102257,-32.851557,-34.507691,-6.256117,34.836749,-1.342703,-28.301842,-69.039447,-76.807478,-23.715179,36.918599,142.247331,172.315031,171.469774,176.456491,174.70143,108.971395,59.65634,-25.478068,-54.016816,-49.527582,-28.317042,-28.32367,-31.299705,-48.506343,-94.11661,-95.953383,-50.737054,37.473131,75.568039,111.476213,106.54848,-12.818771,-101.936535,-164.897036,-123.02821,-25.374785,-60.578395,-106.589837,-197.091857,-260.991365,-400.272098,-411.933355,-264.194107,-84.538906,-43.071803,-31.550637,-33.946875,-3.170133,27.249396,45.366688,38.108214,86.83357,92.615353,34.33332,-92.434481,-115.815116,-79.375773,-57.545021,-58.568689,-30.866868,-3.627072,1.382726,-26.166151,-110.573137,-140.24768,-85.64769,-11.744646,58.922251,-59.324985,-124.861318,-164.226729,-149.554346,-95.355972,-70.399738,-26.33147,51.070354,75.625078,49.941268,27.247717,42.250014,89.135581,225.886612,269.884744,225.781949,129.254838,97.387854,10.063837,-21.039629,44.343069,109.366996,173.261206,196.433407,213.586589,155.929233,58.154968,-135.254089,-147.580002,-17.167057,53.458123,60.574623,-153.023394,-260.952063,-295.98567,-237.585788,-74.421886,-6.808314,39.334622,62.756496,95.281477,148.715443,145.556378,71.967739,48.409408,121.934857,189.046159,229.026827,71.390003,-18.590663,-75.895507,-47.304749,33.561273,61.201805,146.087066,251.196113,267.818051,281.144272,282.343405,245.486765,256.452695,409.022918,478.716086,483.136664,367.997899,279.832876,116.642057,68.162406,-2.072008,-24.751328,30.820858,136.075092,135.008801,45.667456,3.875546,-25.62735,-18.532409,-10.455556,-8.593024,31.959076,11.726411,-47.996382,-169.29326,-191.498459,-119.585657,-43.218591,87.081323,155.561093,154.50382,35.492604,-41.118056,-139.925047,-189.002826,-260.469569,-232.714833,-88.111815,-64.622527,-115.698198,-219.055193,-249.986189,-232.958453,-179.119538,-95.735316,-120.68089,-130.787997,-78.273788,-53.64018,-165.431391,-283.607988,-411.098165,-364.338174,-137.080835,26.893807,54.362684,56.83974,57.082175,143.066934,233.105897,358.802593,284.166287,227.217985,209.270077,218.166642,166.151496,129.658774,164.469917,221.783969,238.731974,74.317388,-1.959431,13.098421,81.930891,175.97231,181.170183,156.157462,109.144688,76.300169,-18.460402,-94.475053,-239.554879,-222.942034,24.3164,143.961245,201.391652,146.01329,117.197153,75.905159,75.558215,153.123698,223.490571,328.521079,234.453293,104.763221,-81.631701,-61.284083,69.909431,111.535892,180.660754,224.566491,291.870976,284.169335,245.30994,145.060982,110.399118,114.955513,157.252718,208.556099,90.892681,-1.556451,-139.465826,-178.229849,-233.481966,-250.433318,-265.718667,-259.483479,-188.629747,-120.094674,-129.99209,-208.861238,-233.961417,-195.013656,-150.619158,-20.608001,113.993367,93.691018,-91.233492,-163.45521,-192.693421,-173.29019,-92.014451,-28.498623,141.675328,250.649077,240.035624,133.538204,82.020494,68.917076,94.102422,133.49034,178.293835,194.306851,147.113054,91.786596,20.984836,43.959577,168.867396,212.546906,183.73344,14.693235,-85.747478,-226.722732,-262.763638,-283.68228,-263.295892,-143.12071,14.902481,49.08462,-14.723105,-74.409185,-152.280622,-167.055259,-121.599954,-48.19496,91.540747,51.971467,4.998397,-31.531109,-40.419228,-36.149817,-12.072052,-10.777573,-81.771086,-95.734449,-110.22926,-155.445444,-273.964459,-268.256671,-83.496658,22.70953:35.027211,-98.363365,-186.130435,-243.665535,-207.021089,-135.257458,-128.807816,-105.551594,-32.06526,-17.594681,-98.418478,-192.203869,-357.142644,-347.442856,-142.435154,-34.411655,39.306811,-58.697991,-129.14906,-252.762193,-295.741948,-286.866018,-228.857358,-66.58025,52.898706,49.883079,-72.964073,-134.531783,-134.32538,-80.385518,2.383283,7.537081,-7.592872,-52.590434,-87.864277,-171.080224,-203.009884,-104.974794,24.290021,185.714982,107.436872,53.165136,-17.693708,-57.361316,-127.313917,-95.428898,132.245672,232.945863,200.262549,-18.332478,-87.242,-87.146569,-51.353852,48.310494,91.815544,110.203264,94.230977,65.570037,-92.104831,-175.598413,-229.945062,-215.505349,-138.830682,-73.456063,28.946264,-13.287777,-67.888457,-179.306967,-222.875338,-203.836525,-125.031007,60.876742,67.720065,-6.912982,-155.320917,-188.351361,-173.596352,-138.580427,-44.832698,13.442236,124.22988,128.177679,83.283213,-64.695517,-128.026482,-77.947588,35.242355,232.462907,227.581069,183.86695,106.957746,65.611132,-29.491878,-43.858427,31.568008,88.738328,136.775251,29.082482,-31.589051,-94.292365,-124.79147,-157.282258,-116.27294,51.47367,166.965587,175.563018,139.539803,112.648582,37.177301,-2.326656,-44.311993,-38.440649,18.271925,53.971864,31.474416,-78.920494,-118.802691,-87.253064,-41.225602,47.562806,89.199912,68.151914,-2.389766,-47.90492,-193.808386,-244.999258,-198.912159,-134.72206,-84.571117,-211.337862,-293.054106,-442.83992,-510.307412,-516.005708,-436.616359,-222.778168,-95.7699,-114.670063,-229.31865,-245.097802,-146.236094,-72.054871,4.07033,5.503201,28.031249,47.176922,17.520286,-87.751987,-125.798186,-124.254912,-92.996329,-9.463576,81.093841,110.349948,82.401227,7.562195,-205.479149,-243.74207,-68.149987,57.169855,162.000271,87.115456,2.668893,-201.386316,-243.887174,-140.202802,-65.070357,42.076068,120.047551,100.129058,-47.635654,-99.429029,-60.201309,9.337733,151.192517,191.091242,168.321647,45.129071,-9.321637,-30.349255,7.798067,144.535936,206.632716,266.048182,306.302556,321.850556,253.361723,160.294001,2.722113,11.800687,151.027497,194.415355,123.847974,-97.976385,-205.38629,-288.771728,-250.858039,-61.72389,43.037055,173.102409,199.059192,174.568503,62.966032,-3.191973,-68.73213,-42.42792,94.344666,171.071766,240.324438,154.850363,100.045184,27.532307,7.322204,32.897256,80.33039,207.355598,312.525431,314.332353,206.991475,134.098388,95.27864,166.01004,374.318983,442.757097,479.336505,392.93642,298.933082,60.366692,-27.545005,-1.71175,71.688266,136.505139,86.612923,45.776803,-52.760492,-115.657442,-225.218986,-223.942911,-95.929942,-8.013361,128.12624,124.03676,36.961397,-234.55254,-309.311224,-165.076581,-14.731679,178.328374,171.266008,114.095261,-54.074679,-113.014387,-134.633308,-123.046461,-62.656241,-8.186644,61.388904,-49.499408,-152.304677,-327.258239,-349.799569,-225.683398,-130.820112,-13.775555,-25.646652,-78.645089,-180.832502,-207.622682,-270.872558,-297.720921,-253.74838,-186.859238,-51.111226,-33.044053,-68.748471,-118.682557,-96.264361,65.020984,178.374212,339.305113,268.585258,171.643754,22.261892,-5.447093,-6.882505,-3.60811,10.324751,37.026353,80.360676,46.255372,32.099576,38.391822,29.255696,-16.271385,-13.146949,85.320243,121.634525,41.657636,-228.657034,-348.655107,-397.636714,-290.983377,19.199186,110.881584,122.481755,56.95229,41.624249,30.104291,12.824494,39.699792,117.471444,281.395905,254.874251,158.807028,-85.378954,-155.216529,-90.827846,6.113064,184.391272,235.139082,260.45457,232.617774,190.216485,39.847274,-28.950764,9.330985,127.15797,350.817337,314.106083,211.832623,-13.274454,-110.469561,-256.263833,-276.21341,-160.930596,-52.567253,126.869806,123.047807,54.06653,-111.229041,-150.696906,-76.307119,-2.654066,115.810905,176.325283,148.779624,-38.302474,-150.004718,-262.29159,-232.303661,-51.348178,57.438416,204.146566,120.506681,23.430728,-145.011484,-200.652847,-152.508851,-36.864614,153.045483,103.487464,50.527796,-26.846813,-89.976501,-221.093582,-196.658524,34.195448,134.499911,143.751474,-41.593162,-140.473853,-254.695855,-281.091361,-277.587777,-237.357102,-112.353934,-11.801119,-2.173095,-84.850438,-149.287228,-203.981235,-162.360697,6.583476,73.291755,98.492165,20.800352,-34.803613,-132.485623,-149.285146,-70.478792,-0.477718,60.214147,-28.979484,-107.363305,-272.874939,-333.367018,-364.068851,-311.996531,-100.819115,-7.077932:-69.824744,15.549396,25.586748,26.033184,27.524697,-12.449489,-41.588492,-21.172118,60.435776,53.82057,-8.818778,-2.31478,92.438407,153.058998,238.265549,241.84193,213.960333,138.146803,86.379235,37.177278,26.695788,7.949067,15.736888,66.166146,137.696622,169.227895,192.919183,190.061604,186.204285,181.246435,125.637553,68.257091,-84.399596,-228.405201,-266.662618,-268.794798,-262.263063,-210.019461,-137.901922,4.065367,21.598276,18.254179,65.380439,82.834728,12.410176,-35.152662,-61.922524,-62.597519,-77.360996,-76.07087,-63.059357,-66.672875,-99.870596,-169.628555,-192.899517,-215.947828,-169.907258,-141.358435,-124.983594,-138.203661,-205.789253,-230.662189,-175.883747,-133.105513,-154.591883,-208.174221,-195.693924,-170.281772,-167.792511,-117.16491,-79.918594,-28.130223,-22.466477,-35.316041,-33.651866,1.114363,113.755571,161.147289,199.838965,206.563427,231.846367,263.341238,285.760508,313.474513,293.392532,225.947205,210.442597,216.643013,234.937878,234.34278,201.105013,169.707512,2.409398,-127.917192,-241.020856,-174.074954,20.493452,2.486385,-67.307656,-131.01356,-132.666687,-90.244025,-6.718968,160.593551,140.673556,101.40326,59.76377,60.615961,65.690802,56.064324,20.59102,-2.620759,-47.614672,-97.872479,-118.647129,-134.129473,-159.050435,-245.023937,-263.102148,-235.650754,-163.24955,-115.246356,-17.295776,20.172523,-6.696799,-75.825468,-184.832722,-179.933494,-131.146485,-132.152732,-132.436146,-160.651909,-215.441121,-306.420578,-300.513215,-261.107383,-222.5207,-194.299664,-138.113558,-102.131226,5.524169,68.823715,145.55347,146.632806,123.660138,54.33705,-24.470307,-196.022953,-245.079316,-277.406546,-265.834209,-163.923876,-59.987009,-66.780898,-136.705969,-147.633444,-178.026917,-229.763902,-301.519236,-276.819946,-210.124569,-316.451522,-391.175836,-424.898184,-397.802324,-337.279465,-306.181598,-198.562454,-59.630552,-24.007572,-29.563509,-46.176757,-39.61022,9.335399,157.867867,191.007489,115.864169,1.31189,-23.833703,0.393901,45.321403,172.701517,221.103975,204.361983,140.006691,138.302022,88.310154,0.408526,-192.655952,-222.247934,-136.853382,-95.423563,-141.666814,-249.243184,-247.746494,-135.21777,-74.998239,33.162516,94.997874,194.280359,201.942102,175.791908,151.383509,160.674693,148.117883,132.407548,114.888596,87.741264,20.778781,33.65993,40.772595,3.950558,-21.806507,-1.550566,51.456215,148.114368,177.539454,184.764567,227.186485,244.683289,220.81607,219.759325,314.615482,372.756112,442.775413,374.758847,277.129038,111.893771,90.049618,114.229486,115.72058,89.199383,104.08681,112.772251,94.831258,91.023412,114.603218,113.657698,49.874173,21.383258,11.057671,-34.169086,-60.777186,-102.235473,-125.944371,-107.757397,-43.896149,141.245681,274.334529,267.575784,123.502781,48.163825,-40.647361,-78.554833,-154.226303,-166.993866,-126.625371,-86.33923,-94.864397,-159.678286,-193.693731,-172.024213,-113.529313,-32.282179,-28.523873,-24.930885,-15.383297,-14.479383,-22.118944,-18.381011,-17.690906,-53.893358,-126.586192,8.231075,114.025754,195.264173,175.460591,157.202484,185.613442,285.607288,365.852199,384.872046,364.420417,327.910321,234.271756,210.360685,242.387129,248.422169,176.080283,145.277261,156.004067,153.952499,148.741591,162.68387,166.904198,162.688354,153.644667,114.467654,-6.3261,-56.900894,-122.808713,-114.161256,62.624406,196.678462,347.518359,257.539568,180.780042,90.097947,87.366509,182.459289,273.683858,391.330177,300.215601,221.519879,157.845076,191.932253,267.944958,280.319128,268.859287,239.151142,205.447865,285.549174,325.014845,300.799072,227.045639,70.944931,59.924544,139.096121,87.874202,2.111193,-127.873945,-155.062304,-210.003552,-244.777423,-273.447737,-253.149588,-157.302053,-94.611325,-109.895436,-189.846636,-227.19412,-243.759901,-213.146846,-117.139781,-21.015574,-10.862624,-85.24174,-124.597048,-164.600291,-164.472051,-83.272521,-2.808314,170.432692,217.501094,169.575661,19.131892,-28.236972,-12.738959,9.773951,-1.054636,22.076619,59.522312,60.523114,0.112119,-96.238155,-70.870117,60.374329,98.905697,45.545817,-102.351015,-179.027152,-302.54597,-337.620262,-348.442579,-322.976627,-220.40102,-122.8707,-114.032567,-170.42633,-216.626987,-309.822844,-330.509551,-273.169415,-207.677006,-59.289654,17.727359,5.156904,-69.101509,-108.196285,-153.597754,-147.285061,-91.591075,-38.524255,-36.753834,-104.96859,-174.939445,-329.720068,-350.655181,-232.574436,-168.094194:146.394527,110.423442,90.332368,56.669473,21.63529,-49.943279,-72.813078,-80.957586,28.468517,74.77903,88.717182,103.165474,152.880368,164.827713,164.922661,165.467602,166.733185,66.986543,-3.437878,-84.183781,-104.85642,-115.342865,-106.274371,-80.072309,14.578887,70.850323,97.640692,74.67842,25.725472,16.198174,20.275842,-3.905734,-160.973439,-339.503947,-384.698742,-386.352503,-348.874342,-190.113162,-106.317138,-53.408479,-68.540013,-46.712475,44.132698,65.202632,10.205158,-19.821249,-50.196678,-69.919369,-72.386124,-22.821953,-2.71647,1.675308,-25.463104,-99.08947,-112.27442,-76.101265,-35.191111,-56.402985,-124.305624,-137.383062,-152.30405,-150.959602,-118.852503,-114.039716,-126.326346,-135.254588,-150.780625,-195.03311,-199.767646,-120.135363,-65.563694,-22.446469,-4.628059,11.973337,21.85424,12.042816,40.343005,103.620849,233.653054,250.288982,217.184211,199.035577,208.959616,207.645143,178.498194,130.839759,137.671486,199.185447,277.230699,266.253895,141.15946,79.152876,-39.77927,-102.68458,-149.917519,-112.112042,14.792574,19.779182,-20.761511,-66.36091,-73.980154,-73.498855,-49.779024,34.381648,92.970186,85.335805,35.344656,5.063464,-73.758984,-90.776829,-47.731597,-32.525866,-95.816825,-187.022064,-183.472892,-128.841767,-131.993789,-189.982817,-221.312138,-242.743062,-106.065843,5.54813,175.232656,182.132771,-3.391861,-135.996366,-238.732193,-179.964777,-10.780509,17.482486,-4.36748,-40.643494,-71.150564,-147.98894,-162.193552,-147.918558,-137.365822,-131.424441,-95.240183,-67.541546,-53.074631,-67.594157,-70.649096,-66.643839,-89.744393,-137.324633,-168.199063,-229.906559,-253.998749,-293.876569,-296.386459,-230.657064,-173.399344,-185.499421,-200.379734,-169.271135,-139.316374,-196.453973,-364.732788,-377.484505,-246.908177,-244.219001,-309.340763,-388.705035,-385.561887,-324.811011,-285.668906,-222.233461,-137.15182,-105.615345,-142.752636,-186.737178,-156.910948,-76.34477,34.433168,30.885187,-9.643114,-70.832043,-107.921404,-132.452013,-115.199178,-38.377593,8.63786,42.557259,-33.946254,-94.512889,-218.535402,-266.333191,-305.958716,-289.614443,-246.514912,-251.450312,-281.127767,-304.831124,-295.707711,-209.536581,-180.279054,-180.733459,-157.075578,-46.496915,28.860067,28.705016,-23.236169,-45.133988,-55.429704,-47.220233,-32.94693,-50.762805,-129.614003,-247.844366,-313.71161,-359.861394,-322.344349,-229.810443,-215.032025,-194.566832,-160.712801,-158.851536,-46.027447,73.188595,171.458816,128.741405,87.889039,135.376624,264.668349,206.951935,125.624343,39.011026,25.082041,-44.22946,-75.761885,-51.731859,-52.076375,-107.731666,-196.855732,-192.118023,-184.501982,-209.274017,-290.711912,-330.84429,-311.185869,-159.78069,-118.288391,-191.833041,-272.542735,-384.399559,-383.078609,-251.194853,-59.999541,-15.067276,-53.663969,-112.158783,-246.928266,-297.379226,-367.419378,-390.626324,-283.477229,-72.533207,-62.280836,-223.230262,-296.937418,-278.360416,-213.362068,-121.818747,-133.142456,-166.339138,-213.219308,-206.741336,-179.521781,-183.995822,-234.041097,-248.850656,-183.610659,2.796446,115.693477,238.821223,209.18807,107.561207,107.312809,190.028619,247.63404,247.054518,226.525439,215.920171,183.132712,173.530751,230.596723,281.931265,303.828551,180.32234,114.850868,94.232634,124.570441,181.524354,207.043487,225.85676,134.524511,62.593641,-43.787837,-84.041654,-157.764946,-148.216089,8.292792,110.010822,239.589905,193.466906,118.815278,-0.687865,0.12731,120.71395,189.545522,269.467487,289.859036,257.383105,123.44623,80.328323,98.345917,116.497264,89.143189,77.018143,162.056345,247.122,236.332196,206.686879,213.663245,251.51578,265.116376,229.451636,147.030939,92.288816,-46.595795,-111.880952,-221.224385,-271.831484,-354.488511,-368.664528,-288.767494,-122.844628,-69.405238,-117.046724,-207.42149,-316.819303,-254.506465,40.043692,188.312084,147.583834,31.436069,2.78141,-78.400242,-134.512111,-140.719121,-54.058335,205.645568,347.095247,338.77819,246.527849,194.177676,118.256601,114.276668,159.403363,216.972277,233.690926,216.396994,161.512737,-13.134737,-58.959428,4.414235,66.842521,118.083046,-9.774772,-112.96911,-285.825965,-334.275584,-347.657469,-329.960754,-261.76457,-155.602736,-133.35003,-182.746254,-224.703349,-246.302402,-204.822904,-57.625757,3.94029,43.126903,21.744948,19.637021,20.464639,2.777857,-33.464936,-41.981034,-53.114228,11.541419,63.226442,77.08232,21.353101,-129.49316,-168.198424,-111.463667,-50.270521:-77.520035,-113.866427,-117.847232,-53.371898,-9.552669,-1.972972,-36.616652,-76.355855,-47.384965,-50.855517,-105.074965,-119.881883,-86.502456,-46.994767,48.027883,96.871835,152.110678,60.241336,2.734768,-29.929824,-40.798693,-87.713857,-82.171217,-0.092907,78.496661,100.169499,97.628934,72.30081,24.692903,25.153934,69.707566,73.748536,-24.723641,-117.478058,-136.445801,-173.709378,-185.027064,-127.560635,-69.596836,3.561262,36.732908,74.209073,144.726808,120.839549,-0.761694,-11.648517,45.75621,51.131832,29.533568,-5.967798,-21.633481,-37.73037,-49.706578,-31.710278,-0.588752,45.329251,49.785469,26.110277,-63.85551,-115.382333,-220.280981,-245.183936,-159.343269,-89.735721,-68.844668,-167.072625,-180.69342,-141.786722,-146.413386,-158.396704,-131.143563,-60.34749,-70.453832,-111.688723,-137.183036,-112.133313,-107.625102,-114.055983,-26.828334,36.287165,38.643344,-71.822996,-97.605836,-97.564859,-114.359539,-115.61893,-55.168484,86.687892,125.22365,123.763139,94.935064,61.691989,-40.767249,-82.42528,-84.829576,-64.593108,-15.072074,-9.038734,-34.552123,-36.135753,-10.889764,-48.192246,-89.439926,-17.317444,98.512324,71.673656,11.031298,48.692112,131.875812,111.01149,-15.586133,-59.287404,-29.475072,23.467205,17.01239,-47.43539,-87.418437,-82.751756,-44.146524,-10.652698,-27.390521,-32.175682,-36.429964,-71.448212,-245.907595,-304.51038,-233.274743,-174.328628,-178.308172,-270.015162,-276.760092,-232.860815,-259.656451,-404.214354,-437.163557,-361.862818,-245.120782,-211.125923,-126.751193,-58.134241,25.799345,20.061475,17.382729,60.955397,152.081913,49.784901,-40.100465,-167.271888,-197.518138,-171.641931,-150.694696,-159.478143,-54.077225,24.833609,81.269296,51.972817,-92.31223,-151.968247,-108.534837,-31.151942,51.47175,-59.593798,-149.078665,-291.730482,-316.809517,-259.621689,-221.449881,-211.958933,-171.295936,-125.36446,-67.293895,-64.905483,-55.515919,-13.768034,131.608967,177.670649,167.371146,111.244166,90.137289,60.120502,36.566134,22.632115,56.620168,128.479161,173.674698,211.182283,199.211875,96.674573,-167.879873,-209.581217,-98.572163,-64.877246,-144.250584,-209.334083,-203.228975,-161.358481,-144.834535,-113.317087,-88.267981,22.03857,222.952062,253.810028,98.837726,11.104653,-52.889872,-54.514302,-28.454105,9.100388,108.839367,115.357998,73.994841,3.624068,-7.940427,22.881481,66.129597,158.446186,146.897473,115.360634,130.121579,159.594686,155.783952,163.670399,305.237554,385.758918,423.81598,326.207629,249.623926,71.410134,-12.752705,-84.133822,-50.038269,99.232647,157.056474,110.923431,-21.150538,-43.372077,12.930119,43.957446,16.640643,-30.34127,-81.719709,-61.61898,-55.920502,-86.797902,-102.141314,-60.280339,-5.714486,115.021815,193.110229,181.571843,71.203156,12.700323,-78.297203,-118.613144,-152.366363,-110.025876,35.885268,2.910997,-67.298737,-169.325115,-218.852425,-271.634589,-225.030035,-108.617996,-127.545821,-153.022784,-148.740128,-135.855077,-176.446455,-217.947864,-226.358797,-166.224106,8.213352,37.544354,7.264844,-45.948993,-58.666094,49.953372,163.639361,314.53227,310.409747,271.709643,176.059558,156.85716,160.254759,150.718609,145.875147,187.735693,264.040129,143.183837,66.921127,42.302682,69.408332,105.562297,105.189207,55.287591,-17.163794,-51.473455,-106.686961,-122.590361,-111.532614,-55.168434,137.105318,210.740903,251.202188,209.27547,173.404166,108.996388,96.270575,150.929998,221.993663,319.175512,246.61813,186.717174,109.203319,100.946377,105.665449,116.702817,202.651512,262.641355,310.524662,261.472372,249.518058,270.251,256.558108,146.918872,118.193675,175.363083,200.441205,154.693522,3.70418,-79.20599,-244.633396,-285.074679,-211.699862,-131.04575,-7.025317,-33.777765,-90.709606,-191.56278,-201.595607,-120.902195,-64.092044,12.12923,24.797305,3.453782,-23.928775,-23.915005,-73.755094,-108.21324,-82.740082,-23.849161,124.157897,213.302284,178.382117,-49.525194,-166.442683,-190.373045,-106.573353,21.635255,58.485135,92.142237,106.869159,45.016199,-102.039713,-102.265643,42.023163,114.775239,170.771416,79.461824,-27.369445,-268.244469,-338.953776,-291.044698,-189.351651,17.162411,-13.923967,-95.615128,-143.408322,-121.55085,-156.261155,-198.797749,-180.159205,-106.472981,35.698963,68.39825,51.505573,-42.217591,-89.637458,-64.254317,-12.361554,8.623352,0.303662,-3.432411,-122.75805,-210.513668,-319.736986,-310.156828,-153.567545,-73.209454:forward
-76.278076,-55.124017,-44.986557,-59.241519,-84.421191,-67.819134,-14.099328,112.891536,170.994105,163.134705,147.480383,152.478395,113.021862,65.483886,10.357889,20.171679,42.783591,-36.696453,-88.748226,-136.826952,-142.566589,-123.596986,-89.572489,-20.052213,-0.649928,5.400845,34.055988,49.417996,94.40978,129.000208,137.947727,110.789734,109.892533,111.177362,76.778096,-33.533519,-76.067246,-36.726928,34.432187,162.686599,166.72873,134.057563,95.465147,78.332635,-3.942037,-27.452278,33.058485,88.794578,162.704541,147.434433,110.441475,-12.292972,-83.389917,-159.216874,-142.719749,-32.227223,57.401893,48.130735,-54.454342,-128.235755,-269.638977,-284.247622,-153.112009,-43.403176,175.384097,243.130096,206.325411,92.138633,32.980082,-6.18126,27.624155,111.959382,155.106365,134.995114,-7.812558,-89.641702,-149.542905,-122.679127,-27.166789,19.478191,71.350532,60.880176,52.304376,17.761232,-4.486874,40.4096,113.839531,287.285923,388.353258,384.122992,336.828845,309.630334,202.400059,136.856928,67.875993,80.533402,151.341005,115.669043,34.401613,-110.793902,-117.337957,1.713462,82.024195,163.7081,161.298034,166.133323,171.506451,152.916168,102.151944,91.092577,92.471897,98.682199,162.168291,308.743771,358.133474,305.668948,236.079123,210.003885,277.148081,445.749852,557.059872,598.07547,646.769718,628.986547,523.554806,492.981895,550.271915,609.056085,664.951991,563.61981,480.40631,316.196238,255.878728,238.092233,268.441384,317.458252,251.215204,161.193089,-28.89132,-104.572652,-196.764627,-185.377331,-98.326091,-71.560083,-50.545816,-20.508499,-11.015579,-40.40075,-63.572058,-57.672222,-42.951808,-42.202294,1.173128,43.627893,35.06869,-47.140141,-220.074015,-230.269156,-121.077021,-72.178257,-81.755761,-162.725424,-195.450082,-289.395892,-347.059285,-369.687838,-335.679478,-268.50947,-235.094863,-228.968814,-251.839613,-287.908562,-358.893162,-360.067812,-287.183953,-220.323118,-54.865102,-21.185665,-46.661588,-28.071591,18.294151,80.893004,68.929138,38.760756,124.207479,178.026863,187.013029,130.468638,-6.327846,-53.442531,-126.760637,-147.047166,-114.898904,-72.061268,-82.642258,-166.690789,-229.839692,-327.393242,-326.212426,-211.869331,-95.40991,-91.570959,-133.980327,-117.764344,49.973481,156.232587,207.204128,148.032745,53.138563,8.587413,-59.683066,-284.684058,-373.490234,-355.390777,-266.315043,-92.457985,-39.838877,-54.533335,-162.426462,-251.541089,-359.73825,-333.670997,-190.022644,-115.632554,-49.001376,-175.554379,-274.229918,-420.546788,-457.163385,-481.852565,-471.361657,-356.216854,-193.007424,-165.33509,-232.539196,-294.166938,-428.506287,-493.290538,-545.639356,-491.89338,-231.275868,-80.838306,-146.199458,-390.726212,-466.479814,-477.223007,-440.431862,-363.431973,-330.204834,-315.05832,-345.212428,-436.968544,-641.43701,-651.258476,-522.654985,-449.712613,-326.850551,-280.807434,-266.653621,-189.425596,-156.482293,-154.876595,-163.769903,-137.267453,-103.604814,-127.730409,-257.760205,-327.06259,-404.556782,-425.748594,-413.147667,-334.694406,-136.343683,-137.032642,-200.372262,-382.092134,-476.081748,-524.026365,-445.291377,-188.085147,11.329878,51.976353,13.629359,-45.491455,-182.918334,-231.526577,-239.658817,-218.963231,-213.794728,-207.897452,-167.883378,-103.57449,-148.338768,-348.223445,-395.685095,-239.251148,61.674825,149.754044,117.097982,45.342931,-17.045377,15.389836,109.567044,142.545785,212.931727,277.771986,277.496521,176.373184,83.994437,-74.321867,-117.820744,-154.47553,-58.576569,-3.972331,2.813824,-13.86779,-39.236741,-69.753811,-164.728213,-170.181237,-41.852847,-9.088764,-71.03738,-198.674455,-222.550408,-163.137934,-97.962018,29.877078,104.693199,114.24845,70.982314,10.200727,-146.825673,-181.63996,-100.891973,-18.567151,153.485251,266.746349,273.270267,184.867946,117.229666,51.675654,67.106143,107.882592,78.299905,61.183606,96.948559,122.631319,110.83314,100.332589,148.11004,191.412576,230.663553,173.126645,136.036634,69.646486,57.521193,181.132509,287.985317,376.998097,272.002049,206.429542,110.456884,58.50166,-40.229495,-44.239946,61.684623,156.337738,335.926886,333.747715,293.027382,222.112393,177.828876,126.992515,153.438948,268.886289,354.281454,366.241796,341.039465,305.990562,170.008107,84.607887,-30.811176,-38.347822,4.21503,15.392836,0.407817,-90.5509,-144.052793,-135.779837,-79.531855,27.192674,98.798544,123.860952,97.021507,28.308055,-103.620013,-94.547488,-21.71841,-42.92653:-122.558027,-107.144924,-100.431545,-214.296433,-272.333856,-190.475317,-93.041211,15.780968,17.990356,4.248563,-25.42971,-12.844436,81.158097,119.005149,78.999235,19.330557,-60.225896,-111.058463,-150.551227,-191.401482,-184.815013,-158.678886,-146.98343,-146.554482,-145.131481,-118.586517,-105.282835,-133.667365,-93.834833,-12.631214,79.01211,66.389138,29.934629,-4.982632,-43.874829,-186.533055,-232.388837,-126.659974,-23.37578,111.259012,137.152022,112.473517,15.490393,-29.857675,-98.883596,-106.698349,10.732592,109.10845,173.575949,57.882984,22.925909,-30.566116,-93.943487,-160.499464,-120.596373,-18.410533,17.749964,16.515586,-47.991182,-101.835883,-188.678407,-206.776659,-139.570175,-27.354683,257.749861,332.732537,263.836797,82.289599,45.726505,110.663594,144.994886,95.400253,-10.360972,-37.514015,-62.62924,-96.684977,-140.631163,-96.340199,41.702054,83.033147,155.923341,235.931455,238.602471,157.29871,114.294612,131.49803,202.343819,419.466518,530.504086,494.915285,402.737164,400.125517,367.415405,304.418574,190.895531,179.014099,184.479302,137.327007,110.764621,65.614734,61.039246,131.855809,198.244218,312.074345,302.935793,285.468044,291.290406,269.523854,149.059878,111.11445,163.065596,227.672721,343.774868,359.784773,327.420404,253.48282,241.985808,318.984044,379.340798,445.26519,518.202155,575.443526,628.346197,601.994269,551.371547,560.164424,593.745183,605.793221,617.933382,570.00221,499.470061,297.176077,232.06108,271.338002,326.678287,338.662865,217.835279,144.277993,-29.117803,-130.569847,-250.479989,-222.414939,-42.72894,44.988038,112.090879,77.267075,47.00638,-54.924133,-96.393527,-48.713454,23.4418,114.836432,49.283198,10.717685,-29.135026,-76.124133,-201.552447,-225.756814,-201.587811,-179.591358,-145.561643,-137.415471,-160.440476,-284.344281,-340.466494,-355.815902,-344.542856,-337.518323,-305.776563,-277.056621,-230.615324,-230.001256,-261.086425,-268.216604,-207.457292,-125.254854,74.846904,72.687087,-13.834465,-141.184693,-146.531037,-98.382085,-65.083622,-21.686122,-5.046048,15.346564,41.271402,27.252185,-40.66937,-87.708385,-172.164824,-173.107387,-105.573291,-124.140285,-175.078085,-357.113141,-464.419607,-497.898169,-412.478544,-225.568587,-221.370791,-280.697336,-347.737886,-327.1633,-173.295315,-55.889291,111.753432,117.582017,9.717978,-119.386258,-183.44547,-363.951216,-453.177731,-491.074061,-411.347496,-164.027921,-91.246866,-148.341494,-300.964082,-344.684106,-348.258552,-322.040115,-220.568519,-154.585371,-106.316058,-253.242588,-342.437331,-435.369861,-427.889707,-336.330256,-282.783533,-167.73442,-104.303846,-138.426869,-285.954813,-348.579438,-402.542613,-418.551496,-436.571284,-392.132228,-214.946425,-161.174946,-213.077831,-388.017866,-465.384572,-513.895087,-485.563793,-393.42372,-353.318634,-358.447796,-375.867317,-413.449635,-545.510851,-580.647255,-515.606722,-436.058933,-261.611311,-146.147327,-131.467531,-151.413388,-149.138416,-70.423925,-41.15686,-80.237008,-124.733795,-154.788096,-277.121963,-349.650101,-474.848546,-512.757319,-470.150289,-370.473244,-160.209517,-205.29066,-304.537647,-504.420123,-572.663789,-547.003779,-439.506151,-197.293823,-101.295599,-96.184048,-130.81624,-174.036065,-256.762792,-244.469761,-86.646297,2.826031,56.06809,-30.724276,-72.90946,-145.657159,-187.125064,-237.453649,-226.178511,-120.131494,13.502934,53.986359,112.272376,128.546201,78.117903,41.960625,112.861227,232.895869,466.49785,476.322857,399.668021,179.570522,81.231786,-46.242738,-89.262735,-114.639066,13.143404,102.347189,180.518815,158.714271,92.276161,67.615328,20.550885,18.981225,57.809438,39.539483,7.009329,-77.996068,-82.031913,61.059734,130.483286,158.715125,155.966297,147.009455,67.075339,4.270636,-89.856594,-89.409364,13.734289,83.474535,197.26408,255.399832,244.740052,174.668292,151.078598,114.16651,92.013719,105.833523,189.548213,232.151312,283.07206,259.647612,123.749895,70.527725,98.540345,180.821947,337.522461,328.508147,297.508591,253.068816,265.589619,395.36892,465.693412,497.437145,389.273606,318.643175,179.946223,79.510043,-122.40114,-136.558733,-1.517105,68.502328,138.354012,124.802344,91.634432,26.205227,21.647338,74.874635,110.729963,171.181385,185.769807,169.014441,103.799855,51.430066,-79.972833,-139.248404,-210.103225,-209.154218,-146.877878,-125.706642,-158.926174,-315.128226,-392.303903,-366.70457,-273.483148,-99.147388,-25.655393,-10.449194,15.768342,9.643211,-88.550251,-149.625564,-174.285712,-143.824774:21.936776,-35.508126,-68.644915,-174.325873,-231.282619,-221.074282,-157.405258,-29.672497,-38.205655,-87.252523,-95.13278,-42.218941,23.161063,15.693766,-14.859556,-38.446615,-127.728094,-177.31473,-184.01054,-257.257037,-320.623673,-389.993213,-366.556566,-238.385677,-133.831564,-124.572281,-194.084192,-233.448819,-189.698415,-122.416995,-27.498848,-19.715637,-61.041002,-124.190005,-165.129012,-252.523676,-249.37339,-101.912826,-12.53668,57.905813,-10.930568,-47.527942,-98.776008,-130.476547,-142.857031,-82.664853,129.550269,207.428448,165.490465,12.329775,-34.998723,-135.000174,-190.405027,-188.789818,-131.623215,-39.885324,-20.450885,-18.500987,-58.837031,-103.085295,-156.747967,-141.895526,-26.912648,59.235706,203.120239,264.105848,257.159952,163.611174,119.602858,105.97203,113.773335,96.052075,6.021906,-36.935975,-51.035608,-41.595624,-13.974366,17.045091,103.000615,148.031398,215.535296,177.674708,129.140453,73.00685,82.811616,158.561503,207.129506,318.240676,418.093917,421.220798,361.040066,353.496995,360.229619,319.055916,192.737304,181.290814,252.477004,236.164834,178.388297,36.360411,4.795274,78.076992,142.067019,220.069259,230.406847,229.6163,232.469215,222.71227,180.008251,162.312617,169.069425,195.353219,213.713444,153.615476,135.315359,174.973591,217.43361,287.850303,309.132819,355.178653,428.674472,467.078954,516.382563,530.575701,565.197716,588.056437,641.607257,652.417069,577.055658,422.461158,340.674082,196.013752,160.979534,223.658437,309.6702,452.62723,375.833785,262.427913,25.97327,-45.042919,-46.897438,-2.510449,98.169037,141.954492,187.451848,144.876983,106.713642,35.928904,30.667316,136.236507,220.236323,289.627746,184.156046,141.753154,96.901407,35.854985,-132.369562,-182.848501,-185.474395,-148.751097,-43.764661,-11.083514,-67.861955,-258.491351,-317.697542,-304.55308,-263.000964,-210.479757,-228.816431,-232.099691,-228.0915,-242.759864,-247.55602,-208.366119,-64.06744,24.357699,162.837397,150.528877,98.413571,22.672797,22.539077,47.626308,43.518511,11.324401,51.525126,98.233629,148.656719,124.626759,-0.544662,-61.783124,-103.814997,-82.127952,-33.647452,-91.170604,-149.809639,-273.602078,-325.901018,-366.60665,-332.106481,-185.010882,-143.537335,-181.305561,-228.800666,-211.6791,-149.141732,-122.027296,-40.733241,22.676974,82.463881,-54.874686,-157.92263,-342.917884,-402.125974,-388.106177,-316.352153,-127.211466,-23.288688,-29.043933,-125.143195,-187.344537,-234.580191,-204.354621,-96.902227,-46.952912,-20.773124,-154.060607,-271.100656,-457.806515,-455.32308,-298.550444,-209.486204,-79.620086,-48.898393,-70.886771,-156.695365,-217.50246,-368.090272,-433.084675,-428.275152,-337.725092,-137.493118,-182.693924,-296.59067,-544.087091,-608.874609,-555.080836,-477.198288,-357.813933,-345.933482,-350.587773,-367.106676,-405.079265,-483.287037,-481.874173,-399.21516,-331.626533,-174.785754,-109.387004,-136.572863,-174.238532,-150.407774,-90.017745,-71.705493,-28.62356,-12.929,-37.407118,-131.373291,-183.986695,-255.558319,-262.650249,-205.357402,-154.49778,-109.424166,-139.478651,-169.791399,-349.216752,-465.547918,-516.990352,-430.541099,-187.669184,-71.948238,-76.532144,-123.894457,-153.109886,-181.268904,-163.818411,-65.955627,10.575629,100.02735,24.669085,-21.636833,-118.125788,-171.090631,-157.99977,-81.968627,54.179487,79.41315,77.994981,42.780918,7.122283,30.3751,113.879552,278.942355,318.463831,381.36329,420.129648,385.861553,201.39801,82.444633,-131.467405,-196.109898,-146.829443,40.374845,82.397682,47.687849,17.732521,2.119288,4.577779,-66.021349,-125.066628,-176.661385,-137.241753,-110.911821,-111.637103,-114.923993,-29.330588,35.67728,112.091777,152.245919,162.355887,80.813244,-7.297129,-121.870054,-109.435745,-7.795322,47.576296,123.800144,152.918561,143.625335,64.144556,16.487538,-48.365289,-48.870487,53.353174,128.851039,107.471226,31.045304,8.66967,16.326735,47.522121,139.10641,207.739145,375.551255,405.81649,347.178201,219.171061,205.222939,302.559185,386.137362,538.063875,522.967303,418.345716,128.805374,3.020863,-122.428234,-127.641963,-102.529802,-72.131863,11.041417,23.076219,-6.885077,-100.833631,-108.71127,12.245901,85.902419,174.921834,139.367157,84.805074,9.35919,-18.712415,-91.311074,-121.792263,-147.127296,-132.374883,-89.520334,-140.273304,-195.703405,-295.073855,-308.802293,-224.003289,-144.053215,-22.637553,-2.291895,-8.018224,-43.212071,-62.930581,-60.58071,-56.021986,-99.477655,-127.6154:-50.116362,-45.39235,-5.314852,4.521546,-55.766768,-109.972349,-60.767045,28.099363,7.638244,-13.449825,-36.810145,-41.99712,-75.345141,-110.451507,-179.594487,-176.184966,-99.085783,-116.923118,-182.776797,-292.962648,-289.471504,-199.912132,-147.289536,-78.742996,-90.412706,-92.390705,-45.126618,-14.116998,11.321604,-3.517626,-32.964341,-18.848938,24.28371,-38.376901,-100.784007,-191.626301,-199.963416,-122.057477,-53.460461,62.931734,94.699372,62.148295,-60.869673,-116.616499,-163.332846,-124.993328,80.306904,181.546642,259.667124,227.02999,180.37506,11.8503,-92.695417,-211.43434,-199.4382,-133.638575,-74.789305,-46.544063,-80.785555,-143.957795,-244.226759,-249.517374,-143.840868,-34.121773,207.741663,262.256837,204.535986,93.707302,75.805143,54.482509,39.148429,23.990992,6.760056,-17.870157,-87.01296,-116.948597,-119.673089,-86.911411,14.532398,67.560447,139.208893,92.680751,38.647943,-34.487314,-41.255779,-12.565868,20.3258,147.154739,247.167888,236.747413,156.79682,116.267671,24.048221,-31.119068,-87.943394,-41.622376,153.322224,217.253606,165.606262,-15.126545,-87.944691,-77.872062,4.885868,189.726799,223.861669,203.051481,185.095155,170.665861,95.489983,76.321716,137.480892,199.188076,321.119476,352.385174,323.045788,229.436356,203.77834,235.846112,267.387088,334.813625,448.96561,506.838803,549.756007,520.930795,439.983082,438.263127,534.695669,583.963306,582.086488,553.158718,548.181068,408.044125,299.7534,279.655815,369.803823,525.511722,501.024604,417.892956,199.270569,116.955171,72.141454,87.872796,110.046644,126.776582,206.919071,219.989643,196.3606,160.186387,148.497082,126.573464,126.877225,188.982866,265.771422,264.889233,167.016725,83.743836,-30.821743,-9.486512,124.768026,166.718022,125.999074,17.299667,-23.904215,-135.105378,-199.543396,-212.365765,-159.208414,-59.11485,-47.095143,-63.761658,-95.587646,-120.69675,-190.901002,-201.584905,-145.825714,-83.099674,91.691355,160.503839,139.43365,110.074304,112.348647,104.912452,105.861833,204.599642,331.070846,337.431657,287.367733,252.701684,143.316213,74.528281,-6.495076,14.982436,98.766033,72.59327,22.224048,-114.427577,-169.975679,-174.885735,-138.597969,-82.173865,-106.835915,-132.662921,-150.461334,-157.798631,-188.143011,-166.6314,-19.293241,54.547292,106.150052,15.294023,-77.594316,-323.237716,-424.357902,-411.630851,-308.57307,-111.688374,-69.623378,-91.110869,-152.584313,-189.29618,-262.481487,-278.805756,-210.290041,-132.557567,-62.95689,-220.828496,-314.469599,-448.251024,-489.510075,-445.666863,-364.989524,-198.687396,-97.059624,-90.586427,-156.049434,-207.845936,-336.099324,-399.929905,-475.673047,-469.488452,-343.265995,-242.792304,-293.272347,-501.942114,-564.431421,-526.630719,-461.688713,-352.804472,-328.467262,-331.732922,-357.141082,-404.776959,-519.006131,-528.411323,-466.999556,-424.825817,-296.793148,-215.004446,-228.153709,-270.382062,-261.870243,-186.719803,-156.903753,-133.846152,-57.720604,-31.808916,-111.568809,-193.181714,-310.906079,-334.263996,-332.42236,-285.017712,-106.494356,-23.599469,-55.992053,-266.828113,-408.653953,-542.2799,-482.23968,-228.847686,-112.714504,-123.273315,-155.53797,-186.22616,-284.019803,-295.66841,-205.099495,-153.267586,-123.739573,-139.793422,-124.28594,-126.895669,-189.751886,-305.926453,-282.02153,-96.773369,68.287561,91.322695,21.162861,-38.022154,-112.420058,-86.996155,107.708555,214.256326,290.798219,234.097991,203.731829,116.996516,34.581975,-125.745132,-156.389969,-127.334404,-56.684932,-33.566029,-32.835827,-51.379146,-99.540902,-117.546848,-168.83243,-198.579216,-194.018916,-113.551159,-108.217658,-221.708107,-264.764624,-163.103905,-71.73863,36.438883,76.085948,63.022523,-69.799412,-166.835941,-293.552333,-284.387613,-151.650007,-75.490108,57.626244,182.479679,196.337716,56.296349,-44.371211,-140.033298,-122.5659,-11.799262,53.086724,34.526317,0.558205,27.285818,94.440837,93.990014,113.056659,170.568784,227.086939,112.959988,72.59661,70.67734,79.93484,136.896504,201.633447,340.965068,311.782547,229.524147,34.614443,-70.386871,-225.859502,-216.237921,-42.012317,53.730087,141.685655,105.713963,75.332792,50.998839,58.590627,53.098179,35.416005,74.305731,238.360457,280.662044,188.45669,106.724272,-11.02481,-51.639044,-125.909102,-135.159877,-62.409443,-6.71596,-41.012921,-196.874821,-237.950686,-141.571303,-71.456862,-27.86968,-22.653971,-28.583259,-64.092292,-89.24788,-139.78095,-132.939129,-64.399167,-64.24154:-96.555055,-169.258675,-188.576344,-209.778342,-197.882691,-113.486312,-67.355768,-17.909183,-34.447924,-73.039569,-202.482809,-263.850658,-286.48717,-252.8072,-162.273073,-115.342153,-96.403565,-219.273111,-291.858186,-397.321786,-419.343009,-361.797476,-291.456599,-169.586512,-181.071486,-210.019828,-235.229019,-239.175887,-209.136824,-161.797384,-55.80831,-30.215582,-52.44092,-140.287121,-223.364248,-416.334925,-440.869027,-254.350699,-121.491285,12.120071,-40.252782,-90.76187,-166.415771,-197.05049,-250.364831,-227.87478,-44.594161,54.04747,115.308853,39.12631,-16.216292,-175.770495,-261.527341,-311.544035,-255.559927,-121.5729,-126.730134,-156.957205,-210.839627,-250.163301,-311.358591,-290.720047,-133.203181,-18.504778,179.574633,204.167565,157.017606,31.153608,-10.778948,3.210667,43.579998,91.052529,10.761092,-50.390422,-134.982929,-170.282933,-210.155006,-180.767848,-19.057562,86.831389,214.78742,99.110075,-3.717703,-161.425763,-192.06124,-148.438336,-86.371829,94.893153,190.730961,150.031486,-19.022397,-75.128457,-55.623272,-18.453024,-0.761342,-3.01958,40.981986,86.265446,68.869671,-65.589971,-143.114308,-219.653855,-191.507446,3.123133,156.315794,162.737807,79.277708,8.634763,-82.773572,-53.772964,81.970773,111.964567,88.45787,81.700062,68.1235,-8.894737,-32.771454,3.000095,47.899994,186.596446,310.397715,328.003436,323.212893,314.503819,303.640492,325.591514,443.79069,495.072637,455.925989,328.97829,270.102448,125.221957,78.3346,171.931277,290.355247,494.774639,447.78927,336.634741,121.312952,50.311739,-4.652894,23.840461,183.900181,276.940831,303.513603,138.814554,94.471625,133.022386,178.858673,268.694905,322.460234,434.024208,407.073901,335.496052,147.677556,45.338292,-85.23832,-83.051569,31.106709,123.52139,232.584438,94.977529,-6.618809,-179.470663,-233.388586,-186.320702,-97.843125,42.142333,-30.430356,-123.059118,-259.249685,-279.509346,-239.927472,-185.610209,-3.829869,117.424351,280.30282,202.17487,123.330144,75.813752,122.014154,204.784879,208.583661,282.214382,422.965644,413.081875,244.657684,165.319778,89.861531,63.739464,39.801704,91.321215,247.769648,210.903803,126.210038,-78.937202,-146.453627,-92.316001,-7.38429,62.418493,-31.911955,-56.478442,-51.925177,-78.534415,-148.962322,-137.795067,-1.609426,93.012054,198.7966,89.000733,-32.919694,-296.421233,-356.417683,-254.294276,-145.216181,35.018694,83.83716,66.773828,-22.895008,-86.554397,-126.217877,-74.716939,61.388396,106.110661,74.346414,-154.350884,-277.721706,-432.096284,-445.458491,-312.747463,-208.433809,-69.17362,-8.069838,7.851678,-80.188891,-181.059773,-313.122973,-321.462193,-306.610375,-264.500391,-143.835328,-170.270965,-231.516,-375.350667,-430.166891,-413.88778,-333.950312,-148.727481,-147.358999,-198.411596,-298.198316,-349.407334,-391.27562,-353.77503,-240.337471,-197.357213,-131.954471,-104.271909,-108.478298,-116.106058,-109.048787,-76.434743,-42.334396,88.443117,139.508126,83.622409,-88.939179,-149.684521,-146.614872,-101.603907,-18.240711,32.37814,149.478456,128.686273,56.43458,-177.509772,-304.360862,-426.434109,-393.3496,-189.359882,-52.854923,-53.457715,-129.940698,-192.042475,-281.0532,-257.086109,-45.888056,85.463083,190.298349,116.266814,105.379676,101.026179,62.330136,2.893527,32.006469,179.489252,310.89915,344.292262,315.02413,255.79244,181.148472,208.95529,379.992055,484.920475,573.466067,441.344243,360.292728,251.092672,219.051457,161.663075,116.7968,85.130685,186.296685,215.991588,188.652981,153.773539,82.498253,55.22383,12.918021,13.23636,57.858221,-19.955256,-130.495133,-302.720035,-271.215767,-2.63403,117.659582,197.060615,213.793304,204.958532,61.876631,-55.344465,-176.633375,-135.644082,46.166897,120.262462,171.750515,143.343759,92.045205,-77.03109,-131.757394,-115.143299,-78.393699,33.540898,122.852786,100.967425,-46.338935,-104.928316,-72.178858,-3.588536,130.863448,191.898553,276.698625,243.005077,208.001371,170.872516,172.260581,232.429443,290.352019,413.415405,412.500667,327.071051,40.717518,-103.119194,-255.70682,-251.564343,-134.127895,-54.222391,41.00389,2.355461,-57.956092,-191.712626,-203.098609,-99.856348,-43.514946,40.011667,67.60513,50.408461,-23.777725,-80.598197,-190.959474,-237.298474,-305.9628,-282.135209,-132.541352,-134.411119,-225.785641,-396.189728,-393.935428,-229.959035,-147.02653,-53.63687,20.479367,6.966675,-176.707811,-270.290053,-283.220207,-228.073874,-128.593673,-108.559571:-68.19578,-61.377392,-48.359997,-38.937987,-59.66402,-45.756561,0.632501,58.634122,95.58583,122.736674,136.936774,91.463153,-140.321207,-266.316241,-328.350988,-257.446715,-123.808473,-184.761334,-236.318124,-229.461932,-186.866257,-160.823427,-167.602328,-119.652571,-78.701857,-87.804198,-97.612409,-78.631443,-21.892281,-14.397614,-57.041137,-59.879418,48.698127,85.286889,15.961071,-160.582508,-190.737594,-66.07057,28.394021,121.506081,120.304756,90.558777,-36.625029,-116.127957,-231.581639,-231.288387,-104.025037,-7.675936,115.314969,35.730949,-39.332278,-149.132775,-173.452025,-185.711222,-189.830687,-213.548456,-254.516781,-265.959105,-254.910616,-266.926513,-375.533507,-417.992831,-346.094849,-236.997658,22.116346,136.704787,101.593845,-58.512372,-109.576453,-61.622455,-14.461117,0.565563,34.111943,53.088495,-60.763235,-175.32837,-319.869908,-307.252948,-170.795044,-94.403963,-21.753759,-71.537298,-116.944056,-241.1046,-292.600668,-250.531571,-178.094574,-77.127256,-18.209418,5.187876,-5.874873,-38.337375,-108.330964,-125.416924,-84.105504,-15.966704,108.807528,27.216454,-60.398377,-209.82553,-257.808044,-233.265953,-163.294645,-52.669139,-55.249401,-68.130713,-42.545674,-30.183222,-102.309453,-156.035965,-175.541867,-140.672796,-30.354209,74.086737,86.292596,-5.462573,-48.768628,39.811104,128.948962,230.857931,295.878906,345.744654,390.422569,337.694287,158.908382,131.217339,245.399206,304.249384,321.219231,315.461169,295.605386,127.156824,28.784018,42.409821,138.863601,263.801427,201.466425,138.653554,21.099747,-26.174557,-86.360538,-88.616243,-37.531641,5.9033,79.376612,85.94526,79.863338,-16.120896,-113.867456,-227.617913,-194.968094,-19.816336,110.836666,104.531426,-44.236399,-147.811582,-240.047806,-189.493925,-50.653967,-36.687766,-118.290629,-187.094429,-196.962995,-284.897685,-357.837753,-391.046266,-336.852109,-201.317937,-139.538143,-150.00851,-234.21771,-294.865057,-419.639885,-441.910078,-347.116321,-255.971666,-63.077534,42.625194,58.94813,87.3194,108.923293,145.392072,159.753793,240.404547,359.160549,368.228284,265.138933,200.697883,117.598057,82.271068,7.61089,3.261796,86.375263,103.066153,53.26577,-60.559221,-87.132231,-74.960439,-54.86051,5.011439,84.865088,111.360098,105.891231,80.722485,47.365119,52.457436,87.477955,126.046117,233.204002,189.436958,106.025891,-78.590987,-160.127424,-177.756202,-78.776093,171.166175,213.949037,139.133599,-42.910312,-93.552575,-139.956061,-158.919062,-147.933438,-94.21651,33.695236,-13.907983,-105.025775,-348.633147,-471.505003,-526.627981,-421.123967,-126.689885,19.137547,15.919403,-60.25753,-118.247474,-232.004681,-252.476529,-238.817286,-205.462607,-34.762296,67.99518,15.667091,-183.011424,-253.804407,-263.038121,-234.253723,-181.577582,-74.024973,-25.264856,-77.448781,-186.886404,-390.119145,-410.606389,-325.185333,-263.972263,-181.322414,-163.84308,-145.284588,-120.96999,-137.09409,-150.649282,-123.229375,-10.368237,57.32702,44.419075,-32.135434,-94.107621,-202.202498,-205.001081,-117.243706,-40.986142,136.722501,186.692198,130.252798,-94.834102,-214.861743,-287.824092,-202.432937,84.616938,206.196354,175.453754,64.026142,1.076189,-138.605699,-176.274513,-93.483303,-18.670073,-5.140859,-69.0294,-44.274088,30.114595,14.938285,-51.951918,-31.785087,148.339243,317.100456,325.643965,230.709074,172.683942,93.471191,104.582041,268.673195,366.003982,450.763977,435.359085,413.687786,307.291581,218.363732,51.018698,25.043398,98.269902,170.846045,177.350018,155.809458,115.252072,2.837506,-27.278722,-13.530828,20.244044,123.996262,169.524292,128.202828,-52.029622,-127.036264,-89.959053,-1.995279,147.314721,202.819088,181.016824,6.61444,-104.332454,-199.9229,-164.039074,-54.495228,-15.50928,123.661973,316.260097,327.50392,120.952112,2.582837,-67.303941,-39.746525,31.61765,89.578682,98.638175,64.829948,35.618342,-16.071928,-16.145565,85.365214,152.857849,178.426334,135.736874,143.683335,116.531743,55.194444,12.706612,65.326415,157.061063,110.994422,48.415325,-113.621145,-190.427581,-243.429792,-190.597931,-6.429645,77.247764,178.050368,143.542123,116.307893,119.293696,106.157199,-14.686001,-72.238537,-15.954633,226.722379,312.94989,289.785211,197.663281,-27.840176,-106.8131,-133.910826,-95.800405,-33.576988,-77.83139,-111.94481,-161.615867,-180.724833,-134.9954,-68.362707,-13.644372,-51.358634,-31.674617,-11.259291,-72.691345,-214.000618,-209.134439,-134.980429,-152.229414:14.803681,-21.366532,-55.67811,-144.045415,-185.630622,-175.67792,-104.227779,75.926392,125.038353,79.371521,-111.62499,-229.101764,-380.20997,-372.682694,-246.421063,-179.982569,-140.127451,-230.673799,-293.444939,-420.26711,-475.190699,-475.169829,-386.243153,-133.418001,-61.026613,-106.57484,-212.986519,-229.614446,-188.329829,-158.857411,-89.698388,-31.011426,63.214126,-22.976529,-132.771734,-366.909217,-407.810485,-236.535976,-94.732275,89.999584,101.69231,44.563938,-159.531127,-271.318216,-402.031804,-372.267405,-136.916028,1.182567,189.497983,174.263536,62.839775,-282.030454,-402.073044,-377.922479,-296.387884,-170.567617,-123.972032,-133.127591,-262.707518,-374.99194,-534.519971,-505.614158,-249.31462,-105.382419,65.362318,78.404944,38.142104,-123.868513,-199.64554,-207.619119,-144.641826,10.731899,64.363373,28.346569,-114.563924,-199.069286,-321.262541,-306.621919,-88.493135,53.049524,178.712613,20.940996,-96.807592,-299.405234,-360.513358,-322.795609,-228.883505,-16.565992,55.74097,19.63254,-103.379194,-164.150955,-278.010554,-300.182798,-166.221581,-15.180507,222.661666,88.272443,-53.735604,-247.201489,-287.056388,-272.495187,-201.942862,37.904608,151.328278,108.859189,-30.566361,-84.305457,-153.67597,-147.224094,-37.410797,18.608215,32.567744,31.218855,46.097133,-31.894155,-112.465225,-149.319896,-74.821424,144.918317,289.176486,310.07816,233.51459,145.13186,11.558961,29.063924,205.300974,302.797019,406.941387,391.303376,340.226756,120.00171,15.351949,56.882135,192.028487,456.56989,477.700733,384.064566,106.146062,-24.119313,-104.008505,-29.303428,167.94514,221.868078,244.148276,210.294353,167.237313,22.49479,-26.525475,1.251526,50.341349,200.350976,336.26502,316.414206,75.050705,-61.135472,-146.075156,-97.657402,47.517618,109.92923,158.058366,88.346227,24.967776,-166.082327,-265.153414,-264.250996,-142.31294,103.858618,87.374759,6.564859,-169.133052,-247.663083,-332.235732,-305.097989,-107.089795,36.817644,281.263139,292.514272,223.284508,42.397396,-10.337932,68.10829,167.337195,377.32437,498.643853,469.074609,266.726347,170.92504,108.56013,110.454216,112.432789,139.904465,239.36491,260.082484,206.829476,-37.789609,-147.439328,-131.673162,-39.165008,143.455908,220.115717,216.496388,96.81321,-15.074361,-159.456233,-129.943503,38.895837,111.205211,192.683083,165.035777,94.057244,-106.09207,-185.34441,-188.629722,-104.321304,111.927434,205.272527,178.063104,-20.823246,-149.883065,-270.990616,-240.950098,-70.928758,50.174726,197.346896,28.908748,-123.53539,-458.207066,-572.372791,-475.551757,-300.167101,-15.92312,49.969663,51.224036,-1.518209,-83.765651,-294.429564,-351.949283,-286.256235,-182.096269,21.658937,31.797951,-53.323382,-305.707532,-391.524465,-365.920807,-283.529326,-84.47266,63.205972,72.801933,-64.982241,-170.142685,-320.416703,-339.898408,-259.086029,-183.341291,-57.521057,-1.080079,7.115374,-44.625985,-84.215433,-83.791066,-46.272252,62.909751,168.002675,165.158939,2.785266,-114.278827,-229.041751,-199.194484,-58.40851,35.959462,218.568875,235.052175,163.200562,-120.155012,-280.57155,-413.236381,-329.343792,19.845643,155.933383,80.046915,-134.984919,-218.173623,-318.533453,-294.585379,-60.673116,73.498413,142.744246,30.593814,21.164894,26.865113,-20.085507,-79.210089,-14.484068,264.868496,450.24535,437.122659,282.243573,185.103591,58.932866,81.496403,303.868259,450.359011,603.850276,487.624795,402.329978,276.534085,225.065006,134.84766,106.093486,145.35252,291.899851,317.082006,201.258754,102.564118,-63.174147,-96.745599,-41.253138,35.481539,165.203233,126.117555,55.652602,-112.698438,-155.597648,-59.363142,39.238436,183.757544,208.289663,187.718781,57.052157,-69.67471,-282.332434,-271.611899,-46.737331,90.247094,308.745566,340.721464,259.054328,5.099628,-87.949161,-122.227103,-85.814819,49.548274,157.451407,153.081494,35.605183,-45.060945,-124.739055,-92.751726,68.863718,152.294179,191.097566,97.091674,62.019604,5.500443,-28.028785,-28.399029,27.798209,215.938823,317.348476,263.989605,-18.553699,-191.303945,-385.399632,-338.140143,-58.337973,63.62666,148.414165,117.702374,55.503322,-175.937684,-267.529359,-261.739212,-199.378151,-9.982261,190.023469,213.009149,78.426784,-38.385618,-244.153346,-279.294965,-218.331381,-156.224079,-34.675216,-28.664625,-83.9091,-246.566888,-298.899571,-203.191633,-95.693583,7.574478,-17.848457,-28.512655,-91.884457,-159.67839,-255.572186,-255.403387,-203.505115,-160.529121:52.821275,83.437384,126.965596,232.142164,226.665258,128.727847,112.542816,187.48798,260.904885,275.260311,255.513307,191.324678,-28.396114,-118.813199,-156.90682,-116.121073,-47.595691,-83.617218,-97.004164,-104.106497,-121.314522,-136.107599,-108.373151,-5.39935,54.59299,47.722128,-0.259564,-19.97029,-4.961447,14.670491,-9.214993,-5.987812,141.012603,228.030059,197.644119,67.594497,15.282551,53.226401,112.864127,168.318179,165.329134,131.616442,-9.832984,-80.617735,-161.917529,-157.462136,-44.126885,42.034783,166.416306,94.602795,3.845347,-122.086701,-128.459595,-102.88576,-102.350455,-125.180891,-142.280223,-122.571274,-46.810059,-55.621236,-145.289495,-131.746401,-5.833226,33.175394,59.272505,76.508642,66.094918,-12.207358,-45.924887,-33.955592,-8.367452,31.888943,56.261708,48.525056,-37.208887,-115.012305,-286.717902,-332.229881,-286.161502,-222.716093,-138.807753,-188.11299,-218.159601,-251.007306,-278.382296,-323.966943,-306.935615,-200.286215,-124.982134,-109.403453,-53.388546,-13.959463,54.225462,77.510171,49.311505,22.977657,65.924884,115.596654,99.514257,-14.67444,-113.376198,-275.207006,-278.855698,-187.879161,-148.719732,-155.898007,-118.390989,-64.69985,-33.536859,-87.872389,-212.014515,-219.24209,-128.664792,-89.826611,-117.189642,-182.90697,-192.271512,-119.047492,-54.413632,37.383466,89.971516,111.271698,119.765645,82.094534,-78.174688,-126.642779,-53.548933,1.895442,26.775691,-9.42662,-53.242271,-191.937103,-241.752093,-217.589502,-173.990133,-123.469472,-117.186849,-112.167336,-85.531472,-86.112957,-126.879497,-132.787257,-87.757292,-58.228876,-26.762309,-71.49414,-115.143579,-208.866617,-245.001764,-272.828148,-275.059925,-228.64288,-100.75283,-81.522181,-195.76825,-272.122521,-321.446257,-280.050357,-156.707178,-116.177125,-86.204067,-152.151259,-219.24102,-323.780369,-351.896239,-411.223913,-437.704504,-398.939766,-262.412693,-220.083132,-234.951204,-279.243221,-383.794632,-412.445989,-397.291399,-361.940988,-226.999908,-47.572431,21.114337,75.077699,76.315447,105.082906,142.732261,241.836592,337.240309,339.659504,221.901896,148.727397,71.317403,59.079927,-3.652655,-58.246271,-128.774369,-171.491211,-199.455227,-240.676028,-257.701086,-236.952661,-173.29219,14.96995,176.935147,219.760014,188.763827,115.546546,-47.479717,-72.216523,-3.379106,32.843796,84.168471,144.129338,154.006257,79.132527,8.06619,-61.264367,-30.383438,99.43562,175.597488,143.190793,-19.527298,-86.212247,-158.097177,-178.680015,-166.16164,-119.559603,24.005706,60.840172,0.06068,-176.89372,-227.320388,-205.255653,-153.506151,-8.112795,102.180923,108.462544,56.043164,17.341124,-116.734576,-200.253381,-234.588016,-148.712022,123.085431,258.858959,234.773246,130.985451,99.427442,75.49826,66.388233,96.281511,192.591975,214.102574,134.90653,33.281347,-142.560729,-142.155952,-24.471583,28.361429,64.472434,19.775281,-1.893692,-10.627194,-14.501039,-14.990711,10.293215,133.987251,218.483485,183.441751,25.13123,-50.055473,-156.079825,-169.959059,-79.553798,9.790584,141.588951,124.939142,111.71579,93.70663,60.501321,-16.507763,-25.715188,52.438563,142.277386,134.212953,93.350459,91.06453,50.104278,11.516073,18.116958,68.718432,137.565712,125.494482,129.630953,103.088551,56.03664,46.326478,107.389894,248.243386,302.140272,272.408979,132.692912,76.735228,85.17336,130.673355,188.056724,186.34196,203.060849,262.352766,287.538449,263.422549,185.640467,3.477107,-24.067646,28.854688,47.904312,25.627914,-29.007629,-47.199566,-75.54979,-82.408725,-42.87205,18.045909,130.462534,36.030851,-41.628234,-102.244864,-124.920908,-214.860958,-229.369766,-139.140385,-27.019536,-14.289824,-66.231025,-123.365448,-249.941825,-252.3168,-98.558331,-8.239818,100.299355,141.788988,137.723904,38.314022,-50.171983,-187.098388,-213.737122,-176.493433,-46.240376,-5.902098,-26.735742,-70.671489,-136.3122,-139.278617,-114.292359,-97.001676,-83.141152,-91.692361,-62.339484,8.77866,-8.576497,-88.498187,-88.77703,6.12085,37.757307,-19.598157,-110.401688,-87.473843,-20.632989,-17.975147,18.02218,83.19875,215.074697,218.367438,185.459565,100.593658,53.329804,-20.4926,-49.943459,-79.822239,35.647051,140.061276,301.926782,306.458153,152.063292,56.329061,-24.734374,-14.570601,29.5435,33.756308,22.476368,1.083672,4.963206,76.250096,105.977942,61.572045,29.326969,46.684264,62.663422,45.056923,-17.646472,-45.999968,-64.438308,-41.38844:22.738499,41.176073,65.992482,102.901512,102.291433,98.796539,100.976952,163.444513,302.734193,334.318423,255.211562,170.968007,-15.978547,-100.110798,-210.739137,-233.416857,-253.375306,-264.256965,-242.480453,-143.630081,-87.696716,0.214769,20.705658,49.592099,113.399932,138.374423,169.791184,181.705911,167.928697,142.103743,69.506515,52.163105,132.338027,217.232536,215.315917,136.930378,73.322973,53.553619,126.432723,259.207582,213.378303,151.668956,65.215082,41.252814,-8.254132,-15.122644,39.124304,88.178609,180.4166,130.931289,41.401876,-130.16288,-160.045967,-123.078583,-109.019505,-131.805725,-94.929225,-33.727966,65.228049,40.264786,-124.08847,-164.206117,-52.221471,53.51546,243.968137,274.501793,205.586294,-4.546901,-85.223137,-113.117811,-75.276634,37.453966,123.689411,128.218839,51.057685,-25.303751,-175.904962,-203.729691,-166.816493,-135.099196,-102.290079,-117.281143,-128.068109,-180.150862,-220.207784,-214.987355,-150.510805,-1.376458,81.306208,97.397143,114.582932,118.570082,94.392079,72.267827,32.282605,32.518008,81.105866,42.988638,-28.989132,-172.128503,-197.324781,-138.706965,-106.58957,-122.683391,-169.426604,-166.203057,-53.426905,27.075579,68.701824,21.502289,-52.764392,-42.01927,34.08442,78.822614,78.524199,80.116653,88.471584,118.276177,151.379885,288.502632,465.675112,508.038656,527.705731,529.79056,436.243296,350.017724,263.702844,287.223432,364.351627,304.454977,228.154991,83.253004,32.578071,6.396881,29.816728,114.73038,102.194148,14.068158,-167.7439,-205.627811,-233.998053,-222.084144,-114.024415,-68.173333,-78.403838,-99.200061,-100.124905,-208.502567,-291.624427,-348.098018,-332.911234,-276.040309,-174.310461,-125.913738,-106.859092,-153.294322,-276.192952,-299.049664,-272.214394,-256.445431,-273.35356,-343.201008,-367.871001,-406.396306,-430.705374,-423.710917,-371.784044,-243.160182,-188.615601,-192.898898,-234.908648,-277.793622,-388.636491,-420.569933,-404.542057,-356.350404,-217.412625,-140.804357,-109.968062,-52.614937,-47.675641,-50.906305,-34.055963,87.016989,262.277954,294.241837,219.383086,157.997196,62.894634,22.276381,-86.477037,-133.439389,-130.52186,-101.680284,-124.317609,-200.495645,-235.004023,-271.147606,-245.337051,-79.811811,81.903477,107.999646,115.611039,127.182793,139.506586,128.723517,87.965974,75.622364,115.952035,141.110957,100.877178,-65.525268,-152.852863,-180.615722,-104.489288,77.542484,122.498665,84.748675,-45.23002,-111.686158,-202.883142,-205.391413,-118.97588,-57.911574,36.222738,12.368514,-46.115286,-194.659012,-253.66072,-283.025901,-258.826404,-164.493356,-47.214992,-4.80714,2.554181,-53.849678,-223.444976,-267.858168,-229.090905,-151.722633,97.770558,241.729395,211.49277,34.493986,-49.760663,-100.476384,-73.795229,-1.35154,59.037939,74.827697,18.219691,-61.44007,-218.7307,-237.531943,-151.484465,-84.59362,1.679512,-45.777043,-73.666871,-21.925913,27.214244,59.512511,52.514598,63.135363,89.477176,73.175201,7.463903,-6.936728,6.586264,10.630393,19.744636,59.619768,166.941252,138.807136,80.839825,-65.646054,-126.014629,-97.127605,-19.282047,106.608389,171.851749,192.9437,182.166537,159.097603,118.27342,88.374944,-27.7226,-82.807437,-114.824219,-88.534593,-45.448235,37.790194,2.519372,-173.576598,-202.175075,-14.004135,221.146499,236.677999,111.65935,50.984623,32.687908,57.416857,93.509372,100.624563,184.81809,317.938097,312.326306,138.594331,42.68375,-49.224021,-52.804225,-46.942601,-43.491893,-36.820966,-33.488498,-50.506119,-99.353356,-110.894514,-124.629362,-116.800277,-50.419768,-28.410127,-45.340281,-138.866439,-207.803443,-279.38306,-264.812183,-191.735287,-74.093089,-16.205603,-13.07862,-74.483775,-215.756921,-236.919929,-132.84957,-51.649841,69.22538,145.467034,152.037347,77.371445,22.757777,-87.947963,-156.595123,-216.710345,-92.532812,-47.30863,-59.876428,-88.70521,-152.885524,-157.57946,-74.824194,-29.278328,-36.914723,-104.760174,-98.778813,-31.800269,-20.111865,-17.949608,11.103306,89.269419,85.017486,53.325688,-8.40808,-23.713642,30.519971,97.265199,194.070818,223.883228,320.179491,362.777356,338.523294,273.834766,242.09855,163.716768,121.85844,96.925515,225.336069,316.950525,451.328151,453.03173,298.064845,197.127576,88.948344,99.862129,169.884924,166.557022,165.168337,185.204675,180.895303,189.448837,209.134467,192.227829,166.83856,202.566631,291.3174,269.095881,88.746386,11.361037,-31.658014,-19.916809:115.193239,191.487721,211.500547,135.658827,66.864273,97.184348,191.03215,307.186709,295.757114,266.143042,135.449743,36.350202,-189.391327,-268.861445,-229.954774,-134.72118,16.075917,34.913213,21.688558,-109.851329,-212.71255,-255.248502,-159.903871,75.599628,109.562802,58.451935,-40.438442,-72.398228,-94.407833,-78.853813,-36.702934,-9.136125,112.271073,147.49384,73.745291,-104.678632,-132.276342,-31.772304,34.273066,62.875303,28.503455,-5.631549,-130.667319,-179.475473,-189.279927,-158.135227,-46.191548,25.938304,148.276033,136.633192,65.614361,-152.70975,-232.555227,-216.512604,-171.182922,-139.497037,-158.281609,-159.946037,-168.29053,-221.570996,-357.110878,-341.891496,-153.486549,-61.633657,56.824582,84.768814,48.220421,-77.056394,-123.409153,-120.930502,-91.37022,-9.611005,106.61962,139.15839,88.947606,-6.623066,-259.081734,-312.091169,-167.601086,-52.024696,10.78914,-121.773315,-141.695167,-116.34719,-170.34808,-308.313731,-295.100993,-164.335028,-78.561284,-58.29669,-44.802827,-43.620027,1.461307,48.438638,84.678107,69.263192,91.97507,150.075485,141.892419,6.354335,-84.235271,-127.245398,-72.514311,34.858443,40.28999,14.761034,-21.257629,-15.010203,-34.504345,-79.72848,-146.419851,-133.03603,-35.247433,18.736152,1.086247,-77.544132,-108.065333,-121.826569,-117.513927,-68.444913,82.713655,160.431479,202.743505,146.528961,-36.856632,-87.249954,-43.334707,18.617398,162.202237,239.263582,200.980559,-3.564196,-77.781512,-0.37133,106.765059,247.562292,207.436412,155.485451,109.236918,93.602446,-25.90586,-84.77767,-53.557769,19.476935,126.660482,101.253496,58.921283,-96.467266,-184.004871,-224.881984,-168.450786,-5.063979,70.882637,52.053544,-51.673248,-122.984022,-243.681947,-248.283577,-154.745745,-91.97308,-22.805396,-102.096729,-160.851686,-283.787821,-350.280037,-362.25872,-278.269651,-49.698668,32.965029,-18.443356,-197.319523,-261.76784,-291.226194,-271.272687,-198.850688,-148.514555,-23.972716,26.402637,30.64563,62.101427,58.872909,11.887206,23.522732,181.373057,363.472138,381.476909,263.967853,181.847066,72.800392,49.716576,9.499535,-10.076314,-10.361435,5.579377,-0.553248,-73.773763,-129.049713,-164.488733,-108.30191,75.291955,143.470581,137.062162,139.960808,106.692709,-95.010831,-163.698138,-78.940925,-0.770731,78.088923,91.294083,74.874482,-21.85627,-83.421122,-125.107344,-75.799308,95.243016,184.069021,169.525384,67.773837,5.268667,-89.986148,-103.757152,-75.291868,-42.527638,40.481526,42.381097,-0.638119,-177.846641,-277.566331,-312.581766,-240.507122,-77.044718,-3.222409,4.40209,9.187515,2.948732,-45.057802,-66.665535,-64.524562,-26.027466,115.603942,134.421789,77.647391,-37.653058,-76.078325,-100.943996,-81.265737,-11.191712,37.732594,32.528072,-54.344076,-117.737986,-234.37012,-262.846447,-185.542214,-92.775324,53.999793,29.723056,-8.513482,-44.699755,-41.191822,16.987699,43.066915,26.309423,36.234175,49.280557,-20.244712,-89.804075,-172.937832,-164.092075,-79.702822,-11.743479,116.614792,95.341312,47.111,-34.363883,-88.452533,-244.640576,-279.310512,-127.661996,74.12842,96.445603,-12.333972,-109.793683,-225.040815,-217.83548,-131.071902,-59.621924,58.614782,24.619762,-11.900673,-39.359209,-47.617419,-47.032407,-2.331481,181.177131,303.09174,271.102132,104.94961,35.174646,-6.795823,41.713858,214.199347,257.932202,222.301851,155.583529,138.687113,149.915677,153.529598,112.871854,93.462278,88.154459,35.804343,2.328884,26.722028,55.135635,-26.202624,-111.924945,-150.704817,-90.477832,33.252508,62.620578,31.854715,-115.097838,-172.029656,-112.630495,-38.106785,18.527258,-7.297707,-12.056693,-46.134495,-92.978394,-182.808783,-174.937126,-62.162862,2.531767,140.146527,199.140271,169.555246,49.249199,-26.835394,-149.663378,-152.366619,-5.900257,138.467292,134.921412,23.839337,-39.833959,-103.348398,-91.295487,-4.427839,59.761508,139.068778,81.480464,50.823943,0.143331,-37.404232,-33.67834,22.08546,126.011199,144.756651,123.738792,38.055043,-29.004672,-127.674644,-117.999917,-34.98589,6.244531,79.281723,77.818162,51.774614,6.356739,-31.444532,-143.739349,-183.966755,-145.314172,43.186928,123.935144,152.67033,97.573338,-90.945326,-159.392204,-132.747779,-67.719632,65.136706,90.919229,43.61979,-60.963243,-69.17472,-1.043046,17.10172,-49.630216,-85.802206,-51.688815,66.427513,99.977562,7.997774,-86.595801,-182.439374,-148.148953:forward
163.461418,193.290473,183.450419,173.104399,171.893636,203.249913,245.704537,357.555216,448.425668,441.465304,326.230723,251.547861,106.650607,59.84893,52.359984,66.417354,56.466335,-10.721161,-35.840227,-46.11051,-39.253445,20.521091,71.259412,168.54215,203.728591,186.230527,120.497137,88.719442,56.073168,62.269024,55.924422,23.190987,-52.613666,-129.311741,-168.706571,-206.418042,-210.099158,-209.712152,-173.928785,27.121934,198.55136,187.698683,80.335727,54.067433,65.456268,94.254152,174.156978,200.633397,226.421135,192.964691,125.271519,-64.68977,-118.068778,-77.82731,-37.671995,15.449534,92.432629,114.422606,59.775072,8.78558,-95.794277,-135.404914,-95.409828,-26.851711,37.968006,-66.435389,-118.353978,-127.308278,-99.326712,-8.29979,39.796797,85.015789,45.146974,-5.654977,-126.546844,-156.047988,-101.872576,-40.421026,38.91101,29.038679,-34.881435,-60.388118,-61.665112,-120.044665,-178.828422,-218.507809,-162.852442,-6.396986,42.372495,27.187029,-2.497246,-22.541544,-106.022279,-145.629601,-152.885478,-124.099071,-51.925948,7.042579,29.829918,27.491958,-21.935593,-136.462587,-130.145947,-30.152631,-32.14744,-51.393429,13.262132,62.830505,54.923462,32.08554,52.63674,70.548707,63.939673,87.563845,128.283205,153.307677,118.478265,54.380227,61.956786,110.822629,74.3407,36.371563,-13.365176,-48.555407,-163.70003,-199.818534,-160.863144,-95.141704,52.608787,53.704762,-3.200113,-84.643904,-92.489325,-103.54669,-120.300543,-133.588253,-68.893012,-36.555775,-25.637587,-46.791569,-87.378905,-67.75318,41.452434,85.115923,91.805494,79.07589,92.597578,111.191414,109.259322,104.304872,91.412276,91.127061,175.806161,185.968775,100.906911,54.042047,8.699232,19.948401,126.238708,185.08767,201.327931,112.847169,81.129184,19.074239,-30.052491,-68.150794,-38.942213,74.905495,208.363737,221.904568,150.709879,118.611694,44.032581,-14.614528,-99.89077,-108.925997,-109.694429,-116.677761,-93.310683,-48.018139,-70.159663,-89.441572,-47.821212,35.786653,56.832511,43.037396,-23.834983,-57.463388,-133.385728,-181.20756,-217.428088,-186.386635,-118.666696,-134.176575,-153.505859,-195.194354,-218.802566,-208.818544,-169.840449,-62.368798,29.906687,38.617855,25.9957,25.813283,28.170814,42.313864,97.72642,124.651529,185.242785,166.869476,117.809676,17.425447,-30.5986,-58.452892,-10.15013,123.633764,180.034361,170.703709,109.720731,72.696434,0.957882,-19.35051,-33.494845,-46.385332,-57.453514,0.590526,25.28466,-45.84925,-130.620657,-226.38874,-204.140281,-89.881013,-37.794868,-59.501382,-90.583264,-87.24386,-119.59272,-135.036171,-88.484553,-45.508781,25.860144,34.978023,6.500604,-40.654562,-21.477448,104.099074,177.053314,259.304394,240.955495,213.301506,151.641135,111.610843,31.474843,13.692398,28.197644,57.079103,147.912779,198.238968,185.087963,117.954525,80.777021,41.728482,56.969873,138.579809,189.848293,182.34897,98.42332,17.788451,-133.165014,-137.29631,15.11553,117.98681,228.696422,153.887132,98.716073,33.65323,13.750451,0.469489,1.976746,-4.728433,25.834445,52.491327,83.978487,81.008011,19.124954,-34.478004,-111.951609,-104.466165,-59.452798,-109.030381,-131.74545,-117.540305,-123.279225,-202.290271,-239.1088,-232.596842,-140.344169,-120.013703,-158.972941,-179.893441,-205.326331,-216.337244,-182.320599,-124.007179,13.041679,26.097193,-8.391956,-57.952245,-63.563351,-8.260444,42.846556,81.660544,58.09497,60.076666,80.14367,81.433837,38.340757,3.597959,-12.330511,18.656577,78.546593,15.030284,-52.721755,-208.276988,-286.399954,-346.139772,-309.344608,-184.290197,-59.93101,-26.050886,-69.431365,-131.1196,-231.000892,-237.106108,-189.288457,-162.411968,-129.868022,-166.42406,-189.412328,-199.647615,-209.041627,-243.536804,-238.851694,-149.310622,-32.139467,-21.060597,-96.021955,-133.326155,-143.411211,-120.397588,-57.785622,-22.686805,58.639488,72.218562,58.448603,43.535223,33.730395,31.250376,45.751704,47.078889,-11.335729,-35.700445,-14.210648,23.321728,79.114349,93.004325,140.170135,189.34943,291.956902,255.119076,199.685548,125.76308,89.264475,2.151417,-12.049751,57.094748,162.005265,189.564507,190.653119,141.205607,-30.764603,-57.466148,69.366765,121.436895,63.715533,-2.792507,7.338178,-34.730709,-125.240366,-291.991032,-302.776595,-205.053028,-100.076972,-92.645012,-96.071509,-76.807695,-116.527378,-185.260925,-199.916265,-107.393329:97.789848,-18.488299,-83.956219,-77.087486,-10.66687,133.049745,177.220837,241.939372,294.677163,278.59492,201.395542,177.41726,115.749674,59.026979,-12.037938,9.181698,91.491204,61.258831,-1.690892,-134.208183,-157.455785,-72.093141,-3.722027,93.062909,168.11569,185.791564,106.777868,41.458341,21.477868,52.096823,39.36378,14.265863,30.771369,3.072576,-62.556961,-197.993764,-222.051178,-150.818409,-75.154288,103.82441,223.461913,218.702996,126.15147,91.115806,111.640229,140.268041,143.267624,143.60485,239.151872,260.692256,164.210474,-108.891996,-189.651172,-169.429835,-114.969336,-6.053561,102.97545,137.879106,104.433174,25.850258,-164.287913,-194.770232,-90.437639,-25.300974,20.574379,-7.95113,-40.704012,-146.902416,-181.444566,-94.635518,-5.381521,86.568808,25.215668,-30.81611,-140.761791,-177.004591,-169.215876,-140.664604,-83.212386,-54.656037,-46.917297,-145.034761,-199.407126,-283.561427,-317.186403,-280.897822,-189.257927,9.759426,71.658471,69.674731,38.553955,-12.798803,-151.885525,-186.522718,-129.268448,-54.822046,62.604725,70.523823,83.877955,137.467017,129.158076,48.54743,28.44969,34.193538,-14.655287,-47.180605,-69.77685,-77.932795,-81.541716,-54.405199,3.774909,11.00616,8.530665,-27.294049,-59.824141,-125.584426,-133.827144,-28.856595,58.673302,172.998047,167.92451,137.98323,61.810828,13.930589,-100.187694,-151.479297,-148.033634,-66.795242,86.054079,12.57873,-45.791923,-85.269611,-87.520507,-87.489168,-97.608043,-130.353853,-94.207892,-75.74275,-69.928495,-60.64896,-18.09147,3.346759,35.015503,54.143251,90.640487,110.396743,135.127683,169.364909,146.532841,112.278018,141.341751,229.387754,270.153082,269.305845,218.669941,157.66348,-12.196904,-66.339499,-25.622845,34.269302,101.888487,64.309298,36.305977,0.650332,-6.723756,7.664425,27.841642,124.772479,233.297182,227.03198,160.46627,134.779678,50.185925,2.041872,-44.748306,-59.701372,-139.869905,-219.636501,-203.423537,-124.948691,-107.059718,-53.161342,11.87306,116.678382,36.172813,-61.143117,-209.960734,-229.504982,-226.00038,-237.116801,-262.21184,-221.523498,-52.457594,-36.825531,-92.279948,-165.291402,-159.217722,-109.966487,-92.303497,-49.41702,2.325765,3.965526,-10.204338,-8.540365,29.593364,70.379332,137.956598,138.631336,116.939912,117.621085,106.701828,11.737213,-39.924398,-13.218626,47.642787,125.992669,121.122477,112.671088,90.522783,60.953246,5.755147,6.84085,38.150669,54.553225,57.257349,-20.452232,-53.637661,-81.034131,-98.77067,-120.303292,-96.675141,12.13901,75.733559,69.668817,30.718905,-14.634949,-141.089772,-161.452488,-73.0906,-14.555302,31.847131,17.579916,3.779935,-46.579438,-63.978737,13.480177,113.555388,307.809349,330.344314,268.351534,103.411179,36.311313,-13.564533,11.046024,90.648892,133.827362,215.798873,184.206801,121.546853,-7.062769,-39.233319,-9.537095,34.716347,107.167467,127.570232,106.247803,-58.163442,-171.326245,-240.527749,-157.428287,87.926672,194.63825,334.753165,267.697533,179.108569,75.219579,76.790454,102.876432,108.753655,108.012294,75.582463,54.330942,1.901989,-40.221663,-82.60054,-59.16665,-21.93247,-27.714182,-22.419122,17.284535,41.342889,9.144397,-65.000017,-176.927221,-169.855065,-117.752159,-129.505817,-135.276679,-107.676679,-119.923155,-194.836604,-188.74541,-51.773673,23.023387,61.02891,-21.083504,-41.588149,-3.579413,4.877681,-9.325384,18.709202,138.485052,213.560264,226.538273,221.639618,196.140869,106.686919,73.937364,81.165272,104.430652,143.827666,136.780956,90.954816,-111.634703,-229.685575,-313.089556,-257.364003,-75.210002,10.373077,-15.54441,-137.193822,-200.733842,-268.918371,-251.426012,-169.512061,-152.335818,-139.200807,-91.329717,-104.39071,-211.189327,-253.444588,-223.638399,-154.720416,-32.151495,-27.123122,-52.503726,-115.469842,-143.231186,-153.428569,-127.364895,-53.913286,-18.749064,32.184231,1.708868,-19.508525,-10.93905,8.68828,39.330652,44.596272,44.817482,17.818242,-1.291664,12.521983,32.652962,22.834686,14.821758,86.526194,169.626445,311.712171,269.222048,202.222438,106.442028,80.871823,16.034518,8.710251,100.148222,174.630222,187.180141,198.075227,173.576519,70.881617,49.417626,106.407752,137.16167,115.292779,31.595715,-4.015428,-98.731992,-161.446362,-198.792105,-153.404901,3.862368,81.444853,32.249468,-100.876164,-117.519401,-109.723985,-112.087014,-48.2775,40.132299:46.177922,14.174939,-42.177145,-122.060331,-114.53675,17.493131,99.162243,204.030272,237.642668,230.736071,153.39355,93.705911,35.622199,63.522205,148.205206,150.423365,67.450058,10.458711,-0.954908,-81.025943,-131.967709,-120.374723,-64.235325,55.007819,134.152765,130.947104,54.475345,20.045233,-22.060945,-52.266056,-67.441951,-12.016088,133.120479,80.202296,-11.117337,-158.558546,-187.619189,-126.470598,-34.766368,199.258214,334.067456,320.130815,213.145416,182.702806,203.641651,215.288767,207.581126,228.674015,303.967079,239.417084,141.608671,-105.489604,-206.888046,-247.719384,-181.62306,21.868753,142.853888,140.626076,40.581812,-41.982256,-195.855152,-230.321814,-213.189718,-169.961651,-54.766107,-24.350187,-28.869618,-2.633713,15.315632,53.189901,81.54885,94.655957,-46.746591,-124.770812,-166.807957,-162.281741,-189.799169,-209.998364,-189.685632,-142.985962,-69.292647,-158.327506,-242.290629,-346.281907,-336.398243,-214.350845,-133.561825,-18.133991,-1.490858,-14.36565,-82.690657,-138.308816,-213.639768,-206.737424,-106.657295,-38.540951,28.434107,53.276401,93.030413,135.557734,104.978466,26.791529,32.924599,117.25015,106.187843,41.741851,-78.838369,-99.919236,-102.217251,-98.581038,-82.708674,-69.614341,-40.730552,-64.669661,-89.455167,-127.771606,-133.777759,-90.115262,-43.8989,32.734936,43.141761,11.756915,-91.54429,-139.623953,-195.55967,-180.673604,-91.318577,-40.878443,57.386168,51.683183,8.473483,-33.730078,-25.261425,-8.126833,-4.129028,0.938428,52.126392,102.093028,160.442431,132.21131,36.906462,32.864757,100.672857,128.313455,129.062593,144.898861,187.223378,233.603337,214.594605,177.088038,176.624061,203.216073,254.287617,270.683176,194.22546,96.231893,-52.568472,-48.11533,63.006905,116.443504,143.873282,106.970621,103.322436,102.760149,90.907216,101.918768,134.706581,209.307148,193.672659,138.978838,30.930149,-0.235057,-27.747612,-23.655204,3.921909,8.630473,-54.710662,-155.768651,-162.271664,-108.957041,-92.900479,-77.436537,-44.698964,44.012755,22.638093,-29.982356,-147.023035,-192.981634,-203.716847,-177.036067,-151.048946,-133.708142,-30.063494,9.98472,-24.830595,-144.714603,-176.359444,-70.47134,24.349728,134.455905,113.817198,78.643653,38.75121,37.825255,27.841483,27.383359,80.044857,117.539574,153.169922,131.181278,108.705221,48.170516,18.878888,-0.891869,15.697341,117.230607,219.921719,216.426881,126.289036,77.777081,39.992592,60.907985,148.496853,177.624602,151.33176,75.803859,27.076834,-104.658534,-149.008572,-87.181102,1.57567,154.384855,160.575296,121.520586,44.404683,12.072317,-45.364608,-65.455595,-77.202244,-58.004703,9.171393,-0.627506,-43.250858,-97.503053,-73.774486,57.959255,142.814972,288.24556,281.487273,211.454484,52.128481,-18.773887,-142.500587,-149.468203,-4.432112,86.26744,157.532224,87.53638,22.24626,-110.387376,-147.706296,-133.790912,-89.891669,-2.94205,1.110767,-25.351719,-163.997546,-255.243434,-279.971117,-193.80147,23.668241,123.656842,280.498747,249.209791,162.934685,-27.164479,-90.155221,-100.220919,-53.553807,52.523703,57.547628,16.178603,-85.764141,-121.700702,-130.418128,-92.16482,10.580785,31.824029,24.86436,80.90508,126.291054,85.217107,1.06146,-74.99362,-37.517531,60.643879,46.21661,-3.782609,-102.247757,-129.308271,-118.321966,-80.063736,28.070337,73.690637,117.113899,112.094206,96.393703,42.067055,21.393608,42.326632,75.434666,154.734796,246.630824,275.002236,228.786623,156.603935,28.490133,18.630353,82.782312,120.851764,168.687223,142.245126,81.539864,-129.277576,-221.232905,-229.794175,-160.309998,0.523058,48.420083,12.362033,-104.77921,-154.576379,-203.575834,-188.679675,-65.521529,-8.244547,-54.050201,-174.202452,-198.065146,-262.747444,-310.090837,-287.953943,-188.275399,46.481494,93.011036,42.830078,-71.777373,-106.579735,-146.779528,-141.647601,-40.597489,33.705085,96.431722,-23.216385,-98.377915,-164.479465,-150.132117,-67.252646,-16.909303,52.142576,16.144217,-10.849874,5.620889,11.812111,-3.306314,27.813069,170.601341,242.650697,329.502473,287.590707,220.614258,94.475358,72.156978,84.074801,90.779944,168.982923,316.107499,314.807625,169.416826,111.486115,103.657646,124.135723,176.030499,217.452509,283.537688,226.729375,163.320479,15.602973,-42.126741,-22.445281,39.704637,118.714073,107.085466,101.334921,91.662923,76.269218,53.804359,60.638411,122.954727,182.768405:22.467149,43.793344,16.522004,-31.91242,-19.546551,86.767675,150.80563,215.485755,206.543755,217.56048,257.061943,230.767263,70.945968,-2.641332,-47.81318,-33.483644,3.438075,-36.585471,-80.153258,-125.204403,-121.729468,-100.152763,-78.603015,18.435151,111.690515,108.748952,57.728986,42.932352,36.846306,24.764889,-32.112635,-39.989081,20.336255,-1.444505,-69.579989,-162.958782,-155.168269,-83.190295,-24.805488,146.463602,266.549958,259.96126,194.698932,176.181699,158.264859,159.066811,203.09461,238.652067,285.536562,227.455668,147.296021,-48.819911,-102.140792,-76.617741,-42.002806,42.811161,146.396135,157.133898,19.549999,-102.162682,-246.828329,-221.099696,-106.050776,-62.642468,16.585359,-12.031652,-71.492447,-151.749481,-147.463677,-44.178539,26.661497,93.103507,33.477431,-21.394462,-149.980661,-202.242097,-215.640243,-172.341165,-58.931435,-18.880276,6.875969,-100.450428,-177.636879,-264.182728,-289.515407,-296.035962,-240.106032,-78.158002,-13.948479,-20.011007,-87.318995,-157.964867,-294.743527,-290.087854,-114.43275,-24.299463,-2.146971,-55.987338,-33.332837,31.378473,16.108798,-50.50694,-54.934026,-4.913246,34.683433,28.625214,33.910755,45.555675,0.999513,-31.873233,-23.707228,-2.812533,23.800233,44.721476,52.17484,26.165936,-12.77952,-49.043452,-26.191244,35.783473,84.636215,89.671567,29.641474,-35.008214,-182.047399,-218.961787,-183.821482,-138.026793,-50.959358,-21.596462,-31.010788,-47.383189,-42.132331,-18.868991,-13.158452,16.4784,117.91243,140.573427,45.26678,-30.556632,-106.433275,-76.647926,82.230275,151.825073,185.702062,204.221813,255.83798,334.899729,309.314253,222.080114,211.819572,205.142618,160.442389,145.757162,136.982918,126.275837,53.682342,-2.341866,-50.426385,-5.316447,128.809805,109.064367,70.403946,59.508132,84.692065,162.64802,190.095847,199.940446,194.881686,186.294231,159.018829,134.598257,40.196613,-19.356475,-92.917003,-83.588078,-42.136039,-105.985395,-133.521223,-107.72552,-95.248569,-86.484626,-51.986564,36.742899,-7.765893,-69.275375,-157.978851,-180.623568,-197.501298,-168.723286,-39.046784,24.323823,89.857055,42.018528,-10.414374,-112.368109,-145.535341,-84.136467,3.618212,120.744718,161.255335,188.538723,215.154511,186.881465,84.313977,64.351816,113.148217,144.978597,174.864564,170.945153,170.814521,142.710598,99.782154,46.992581,72.633191,195.942152,290.712037,281.72252,179.795194,138.283238,130.935644,144.294307,154.816904,164.966141,183.979474,90.749276,6.841143,-147.879131,-197.957445,-196.183156,-136.482536,15.880323,7.512723,-44.459113,-67.565372,-58.307286,-141.173733,-200.541301,-171.465231,-83.73084,45.378842,-58.972461,-144.517139,-171.342521,-96.526677,109.915262,176.48179,191.860962,163.139528,151.276708,124.98023,105.591343,45.107634,18.589621,-1.753727,-1.413993,24.101093,61.99337,61.124247,17.638586,3.832654,50.787675,81.538846,78.560237,73.704082,81.204377,15.118153,-72.953409,-206.799715,-177.30986,43.593718,153.866175,220.701967,130.726199,84.310093,1.521955,-29.252884,-16.848538,13.83491,35.826064,-2.868344,-13.107868,-21.541509,-47.534031,-97.25434,-75.967429,10.565319,22.849504,-16.614531,-25.625401,-10.282107,-33.435344,-91.456672,-157.010691,-117.01152,3.46682,13.184992,-30.399668,-117.12208,-133.006096,-141.745505,-131.445249,-43.618098,18.9871,106.460604,75.830504,51.896754,49.933045,48.470722,41.024468,44.680997,52.424039,110.922473,161.455865,188.962898,131.058804,-41.888837,-71.312786,59.853119,159.675389,243.75944,160.660715,105.701319,-34.174157,-136.112929,-276.329142,-262.153773,-156.442627,-132.608844,-157.777617,-240.409311,-282.397628,-312.019044,-292.316241,-229.12147,-194.68764,-131.697442,-164.618567,-207.125541,-245.800452,-235.135197,-204.019946,-195.417426,-133.639548,-28.926368,-9.684845,-32.338039,-54.468139,-86.972677,-66.157048,47.578693,96.925119,117.271971,32.226849,-12.629365,-42.196952,-27.866367,27.869343,39.469142,11.924256,-35.641318,-45.088852,14.632652,49.622841,47.671151,53.844802,159.979467,236.754111,351.194503,326.843184,280.891395,188.593806,144.932114,112.58375,140.534446,217.663414,227.642319,213.854424,183.828554,170.900516,146.444162,151.006632,229.938836,271.174385,235.467125,127.389826,111.961405,61.144243,-13.141584,-117.581596,-114.676472,-80.059062,-4.453022,36.387642,43.505992,20.704263,-18.945857,-17.526065,76.383534,149.219126:17.042347,-18.406954,-55.145785,-70.128298,-45.560531,27.335492,68.377991,142.813855,137.314992,108.689557,92.113197,101.440731,55.122422,5.48102,-49.17857,-36.76503,28.026081,7.340347,-38.06194,-110.841727,-133.777621,-153.231214,-127.495852,29.647723,202.608047,206.713563,57.803265,-14.259311,-9.517709,44.243514,103.260655,94.881234,84.643298,87.451974,43.875101,-137.381344,-185.724309,-69.869702,14.202219,108.527988,189.238335,202.433031,172.156719,156.590646,151.892105,179.084896,270.81748,295.803938,295.690609,252.775538,172.708133,-97.770726,-187.172863,-133.263407,-57.869529,27.757359,32.321778,21.608821,-53.801409,-133.973884,-255.605861,-231.300783,-83.927407,-35.474297,-57.366611,-137.991226,-136.899315,-85.788286,-71.347946,-30.5668,11.124107,93.845307,64.653019,-6.658741,-160.711976,-189.652626,-154.891631,-136.004961,-94.142809,-36.823222,79.514264,-32.361647,-162.017554,-347.186469,-337.316925,-192.22643,-141.742623,-122.827211,-81.660193,-49.921565,-66.751467,-135.103085,-245.423678,-219.372305,-86.571097,-44.146153,-39.905369,-27.39839,-4.646599,-23.044386,-51.458609,-34.963302,6.291208,91.30574,132.127863,131.237436,107.15257,70.391299,-64.01658,-116.958378,-93.997347,-37.566985,39.698351,47.405587,48.830584,4.091448,-44.559186,-82.089299,-40.563987,90.317428,142.390996,118.31473,5.939709,-69.95934,-230.310408,-273.45876,-206.044473,-117.481363,24.600047,-5.61017,-43.863933,-63.619031,-48.87368,14.012685,43.868003,75.094207,113.301083,134.766759,129.823285,83.334234,-6.91751,10.933668,126.100442,162.301524,176.219555,219.816702,257.88963,274.420427,238.771457,160.660688,154.89772,202.883829,238.179012,231.358514,176.263114,123.643575,4.398269,-29.58912,-42.258659,-9.541211,129.5416,189.150097,169.771759,95.337188,63.992518,86.982448,134.686465,166.290239,84.197987,73.467424,151.20582,157.908285,30.93983,-17.56114,67.113573,147.93484,120.900708,-132.094284,-201.490788,-141.699685,-82.194033,-25.361582,-18.294707,11.119819,34.275254,13.664259,-119.329703,-202.363516,-233.376297,-172.73012,-49.000275,7.744252,149.707064,211.169249,186.166527,42.787752,-31.401238,-17.913823,59.075914,186.299859,185.247219,151.866891,85.005124,47.411601,-7.192309,12.009617,83.037803,89.818089,71.917399,86.338616,111.180473,130.032337,102.964557,43.746276,44.327285,138.865984,295.042483,326.857529,229.56418,148.729181,84.456056,112.201771,192.895296,220.179714,197.65055,38.106779,-39.456439,-163.199708,-216.146082,-166.87263,-50.161877,161.226999,164.763551,130.961245,81.451345,25.306816,-144.887034,-168.839882,-62.153556,-5.936556,15.514776,-53.78325,-104.180819,-187.568793,-179.540526,-8.307466,104.203434,219.132226,199.628827,169.915671,79.910923,15.395295,-87.095847,-94.231014,-60.892532,-39.127036,-4.1091,-37.157404,-63.390148,-122.599739,-149.778193,-123.850228,-71.951565,19.796171,-30.689596,-125.506603,-302.942425,-333.026273,-299.12912,-240.352738,-39.821556,59.631202,99.932719,-12.260593,-33.202725,-43.500813,-83.463291,-139.090876,-113.686555,-12.247201,11.169816,-22.247181,-110.463816,-156.0922,-220.022416,-201.06939,-58.752559,14.050605,72.199345,68.284198,54.223239,-16.154919,-57.924798,-64.840497,-17.493628,73.603473,24.340109,-23.422516,-44.90216,-36.580736,-58.335976,-58.424697,2.108016,39.900309,135.18095,210.697469,187.01971,44.358185,-3.825683,8.213891,15.057604,10.573675,120.285234,167.013975,76.107624,-33.675145,-171.522839,-143.541713,43.430003,143.310678,271.868986,204.232394,100.095219,-141.520089,-236.569459,-280.498278,-237.012122,-130.926885,-77.380638,-77.054127,-119.886959,-166.453514,-279.119975,-287.295336,-139.28537,-43.278749,1.088743,-157.058081,-235.078647,-294.047572,-284.32778,-195.617984,-127.617087,20.301408,88.782734,59.381885,-41.18771,-79.376869,-96.240359,-56.55623,83.13262,128.516547,102.45011,5.92762,-35.885149,-117.873128,-145.670324,-90.376041,-19.129876,82.784893,21.810771,-24.35265,-5.637602,9.615924,-48.068637,-50.34962,126.424838,250.04198,344.068207,223.472618,160.257588,113.924398,116.203494,125.406631,144.477565,234.350319,307.844376,299.433919,166.599614,75.46289,6.514675,44.601895,164.705932,223.517845,284.314054,222.338355,177.667655,69.190788,18.73288,36.139229,95.072327,190.273607,191.162357,179.38829,157.770708,116.183467,-4.880576,-19.299282,86.483622,160.0275:183.190208,171.615201,169.573153,190.927114,194.151253,186.929892,201.582797,253.926762,315.063541,346.199186,325.997608,257.368585,96.268801,58.426285,68.724286,81.062832,69.738353,-36.074816,-96.937974,-94.336354,-46.287854,24.328013,47.581405,123.606963,188.981335,187.470008,126.56815,84.083184,45.413931,68.197454,106.710391,94.235702,60.601045,-32.096908,-109.584875,-203.025294,-199.689479,-166.716775,-136.672605,4.417512,135.370451,154.793001,143.831306,137.564167,142.176564,165.021191,269.22753,310.719657,250.2399,65.466708,26.19558,38.005269,10.528541,-72.528505,-65.220084,4.102167,23.19103,2.138779,-68.845372,-98.706398,-135.854763,-135.520336,-108.309919,-84.574262,20.864408,89.484825,63.197679,-30.359056,-67.998019,-74.035644,-19.935969,98.628573,55.625328,1.508121,-65.9136,-59.958684,5.075139,39.710669,85.25185,92.246639,88.814323,39.373,-20.740151,-148.173507,-183.524444,-156.208274,-84.189016,51.749716,11.432681,-42.259565,-110.28661,-130.495951,-157.617798,-146.363211,-57.169685,7.120644,83.07122,7.126306,-44.047267,-103.285329,-126.217586,-127.819499,-94.501092,-42.093115,-93.213774,-118.839421,-36.278401,47.421659,119.927994,106.435428,117.604676,162.40936,278.377362,284.360281,238.423401,151.962742,123.091775,91.926408,84.773446,46.269872,48.981288,74.390256,63.435307,21.112892,-52.955123,-68.810668,-82.256048,-72.006018,13.982837,61.127644,35.669453,-43.560797,-74.056322,-52.800092,-9.545027,-5.224396,-59.810749,-43.589471,33.745995,39.685577,-31.639105,-58.779047,-24.000402,25.856569,157.022121,239.728053,246.017016,254.300294,265.234615,259.325332,224.008001,145.182187,151.297647,153.468772,81.029351,34.399884,-16.181298,-20.094715,72.488534,151.468171,197.690664,78.498038,17.964291,-43.887583,-31.562156,85.772188,146.246134,182.280218,161.526018,132.527349,58.556618,43.637573,23.55219,4.590572,-1.741828,23.164701,65.006931,-5.718554,-47.24393,-103.731775,-142.42294,-177.585996,-138.702624,-16.129968,21.379049,-12.434836,-91.414424,-81.321259,-9.696139,-6.596881,-52.808122,-43.146024,29.40939,-3.062723,-35.879155,-62.654475,-81.408729,-73.880486,-19.963678,91.698203,146.817627,145.572997,87.3294,67.112448,83.271358,101.442618,134.318368,141.507812,119.500105,70.460328,62.693198,81.367011,74.518822,51.634244,75.50128,170.276044,203.533324,172.809753,56.374884,7.317033,-39.910914,-45.973579,-48.536242,-46.223379,-44.593306,-102.420002,-139.525394,-187.774763,-230.883046,-355.387947,-363.78942,-206.36331,-74.763403,-79.2816,-119.525089,-138.108943,-173.174242,-142.102848,10.496903,65.206529,79.519939,3.020087,-49.709097,-101.814591,-82.897757,26.143334,84.868529,124.833246,78.792222,68.661566,80.075047,58.634681,-52.923911,-88.790745,-47.497564,-7.51441,54.406884,101.713785,91.786585,36.815352,31.167614,54.726218,57.977908,50.470571,109.952135,149.299189,98.700147,1.177824,-164.859753,-172.520827,-69.666265,-10.474765,63.693874,46.824234,4.049553,-79.747548,-106.322649,-116.108127,-97.620921,-46.723877,27.925289,49.361553,-2.255251,-56.794035,-112.318684,-89.07801,-20.961587,-18.614375,-91.593151,-171.768306,-183.538413,-182.379965,-197.402017,-233.323885,-211.805761,-81.69987,24.806488,23.048085,-45.637002,-74.403942,-101.214332,-109.981872,-115.734182,-84.971517,92.509506,180.594569,123.606351,-4.504171,-4.421162,83.733062,113.320567,91.97499,114.844895,150.24778,146.537706,93.079683,-26.304217,-47.211013,-15.653152,27.124789,135.228071,152.149533,113.952657,-20.463372,-83.869038,-150.260421,-166.364996,-161.945356,-92.866742,-71.898478,-113.396266,-163.514925,-241.886813,-235.627638,-168.824951,-140.267182,-67.688609,-31.967608,-59.380222,-142.874873,-187.513503,-237.822232,-200.751371,-41.215221,52.960077,38.123965,-61.603971,-93.385708,-83.016706,-52.311017,18.988153,44.854115,94.810905,108.822022,98.372846,74.252154,54.62394,50.723382,96.787112,199.935934,139.812719,61.120884,-21.256327,-1.819902,50.286134,73.888241,190.078067,276.327469,398.133373,354.047632,266.238763,93.241156,69.483633,128.667296,157.781291,146.187612,138.569619,152.00728,189.483739,194.238331,149.33622,147.564945,235.246642,255.036257,138.439631,34.530246,39.550042,2.147894,-64.279877,-175.341236,-189.369904,-120.402938,-9.107666,1.961977,-24.61852,-30.655423,-66.981345,-102.262622,-132.218036,-94.981952:49.687288,30.954811,13.011789,17.703248,31.565729,75.99417,111.749167,182.515416,189.792525,174.277129,151.60995,119.840684,-4.756938,-46.903483,-47.054346,-23.533294,2.709204,-68.548226,-99.796182,-124.612444,-133.079821,-94.2477,-47.238301,52.380666,135.820192,145.371157,80.020907,27.144895,-25.249271,-5.683888,59.727366,85.955875,134.827432,77.073992,-2.075011,-149.728444,-193.496673,-194.598159,-140.53122,43.985764,191.053235,214.575857,178.68176,138.569828,71.374751,73.400083,176.462959,235.44705,250.794721,159.494138,105.881296,-16.237755,-74.70506,-100.119666,-65.230567,32.343504,82.115409,48.157364,-114.551222,-193.634618,-261.771899,-239.967483,-131.504938,-80.484876,-23.970709,-39.794271,-68.833616,-136.665459,-155.515297,-91.145071,-16.986241,57.084687,-18.806531,-60.008313,-120.612797,-145.699293,-126.670033,-81.557605,11.250088,60.784899,153.252398,75.604752,-33.262351,-230.469214,-263.526235,-169.259263,-88.47863,10.769538,33.768801,19.105566,-88.206761,-172.408737,-277.627648,-241.902184,-54.894782,29.575221,107.593803,74.215229,45.717187,-30.369292,-87.973838,-120.911358,-64.615174,81.29995,130.708671,103.641799,42.562773,50.566364,94.664231,100.663009,121.70228,149.881734,164.456369,144.181848,170.700635,209.405462,181.677894,119.114146,116.591931,123.826416,123.873728,123.081811,47.047915,-39.801147,-202.763409,-226.003045,-122.104088,-27.03918,86.253462,-19.742348,-89.903865,-142.962369,-134.8884,-44.057767,24.467998,100.96763,85.960202,75.114519,47.544728,15.37118,-27.59842,7.132631,113.081923,139.366695,207.022559,307.06657,314.6167,228.849492,178.273947,132.364784,123.030742,115.262061,167.458552,188.101398,107.499239,19.353776,-101.488448,-85.440915,58.14813,125.237762,168.980302,83.813743,21.969484,-42.51481,-22.049828,134.00558,231.747561,311.175624,218.04481,156.66187,88.109025,74.02033,24.301258,3.115464,59.370227,128.818793,181.006461,22.209171,-67.348181,-165.031625,-180.971061,-154.777026,-115.236204,-5.688893,59.605947,28.139169,-121.081332,-181.700422,-178.080444,-103.055609,94.633753,163.214025,191.501469,98.446866,39.026088,-82.776799,-132.896415,-91.076726,4.280399,186.499882,229.548303,199.629348,129.589166,113.029095,59.261529,17.945639,-6.809705,19.667292,77.253825,98.408551,98.897275,49.943505,7.937497,0.674326,57.588184,206.008147,245.47533,211.802363,91.966848,29.570307,-27.068166,2.404722,118.590904,164.110699,177.330922,42.738105,-53.332429,-246.119655,-322.837546,-290.061913,-163.982065,83.667182,66.398284,6.962298,-58.737665,-78.334792,-140.441009,-152.365475,-75.986882,-1.106879,133.267226,44.784406,-72.849207,-212.50285,-186.611638,-11.195408,80.140305,166.137689,129.595321,111.987659,104.264738,60.097897,-99.859689,-126.672706,-47.365565,-11.655893,-5.828365,-14.782694,-12.621891,-69.092992,-131.026451,-172.957099,-112.733088,58.53119,100.678866,70.257871,-44.84011,-120.70351,-256.325653,-263.369787,-127.729039,-48.635259,34.509017,26.769236,6.921109,-48.645801,-78.954946,-92.870319,-82.11949,-49.092671,15.391817,29.077365,-57.809968,-139.975742,-226.06418,-196.726512,-67.873857,-0.107579,78.814746,1.87,-65.82863,-154.860332,-169.969126,-113.184832,-41.218933,59.866424,54.750644,43.355841,-35.258517,-105.695549,-173.243431,-146.512743,-55.928298,-2.772906,132.714736,165.686827,127.171802,75.272644,84.329166,110.869587,111.074333,120.158974,151.338295,154.474277,87.96359,8.366419,-137.587376,-127.772125,53.324666,161.93893,299.160621,196.454215,79.146613,-101.9295,-143.760567,-164.411825,-156.16743,-137.067535,-166.176163,-186.456013,-181.180331,-178.23799,-221.994391,-236.943204,-177.538296,-101.129259,51.425207,-0.677009,-90.803678,-250.416578,-289.155158,-234.116162,-143.874861,77.959857,186.170775,165.923219,76.175768,30.518567,-58.658973,-60.355464,67.987217,140.880109,160.751145,69.59094,23.674067,-45.23103,-55.320701,-16.207124,10.12105,52.853367,114.709398,128.906499,73.109468,30.453069,17.455262,38.67744,113.007558,200.446468,404.520345,364.912966,259.949979,79.300796,41.01538,64.183613,113.023349,226.579193,229.403199,157.755386,-9.845671,-47.004899,-28.875559,15.797129,133.179779,161.989372,120.500982,55.35169,48.380974,-6.570417,-73.784589,-154.398134,-144.34741,-93.312024,-50.359768,-32.563159,-20.627721,-47.223062,-123.141567,-109.706735,52.83695,139.015341:161.705053,225.306044,252.785694,288.402275,294.850646,313.367732,340.746799,362.079636,334.15067,339.525092,363.573431,342.617551,210.738162,146.615762,135.013665,176.058463,235.828474,174.952663,121.08653,58.018264,45.426419,59.336732,100.123979,170.773472,159.432655,132.908477,72.195333,61.055487,101.058764,138.657155,178.087421,171.200299,125.959375,-1.435149,-61.93527,-79.624811,-81.236043,-117.89709,-106.692791,-28.030683,35.786253,53.659224,55.829228,42.745369,58.417093,113.345791,247.538283,274.99926,196.569331,45.238847,-1.820875,-60.744963,-92.303487,-129.421974,-134.176993,-140.184859,-108.433983,-80.457145,-71.926818,-104.809298,-178.211787,-183.018597,-124.704964,-78.218079,12.442885,0.302722,-46.53267,-115.01052,-127.227773,-98.644807,-32.022767,115.188123,78.104544,26.999054,26.26727,81.183876,172.433135,176.719024,163.120845,173.486506,217.358916,165.817343,100.292558,3.570754,-0.2629,85.502764,134.81135,145.231237,108.911422,92.39783,53.180599,17.525656,-116.400578,-168.0776,-119.027233,-55.208779,15.945082,-25.50751,-67.870771,-102.301175,-86.954309,-61.550591,-80.684868,-155.711618,-138.276645,-86.792073,29.771253,69.273154,82.478017,87.574357,184.635905,251.926316,324.905304,334.113456,333.977309,301.195557,248.374727,133.073768,123.839101,190.502536,225.604609,214.370383,147.51057,107.163042,26.660077,-21.27539,-62.044969,-31.924845,36.282512,19.263237,4.757379,15.241708,21.382271,-3.769451,-21.923145,-51.397854,-45.520167,-31.711068,-16.426111,-20.215244,-62.895479,-81.898715,-37.420635,12.08781,88.078125,127.881156,135.409006,101.450649,58.654385,8.210806,24.585496,92.093917,113.684997,77.479654,-32.607111,-64.436942,-58.609647,-26.543996,108.143622,194.489999,293.175805,258.102837,204.419061,63.923938,29.959312,95.205105,137.229123,126.185178,98.043788,118.323825,160.500545,137.30865,23.053744,5.112745,99.224055,139.890692,124.468782,41.914978,-4.469898,-72.155651,-112.390182,-186.773516,-171.23267,-14.860976,95.687885,82.557559,34.723889,21.143346,-31.302515,-58.558865,-84.216001,-85.105301,-31.059471,24.644511,7.911571,-73.653396,-110.481154,-135.095497,-115.864726,-35.723711,11.889648,-16.492961,-93.669436,-88.980757,-67.000047,-94.928748,-156.547622,-157.075022,-159.244047,-188.471844,-172.860073,-111.026138,-107.434991,-171.316609,-212.81004,-196.767573,-49.165569,-29.487711,-157.504697,-204.963875,-143.201397,-93.176253,-93.107156,-124.841029,-129.799141,-113.503409,-117.540405,-152.230685,-207.414538,-299.858985,-274.250335,-153.441855,-122.986301,-131.576903,-116.872637,-90.615412,-56.559005,-63.329007,-71.590948,-41.914437,65.620857,87.368224,57.339959,39.621903,69.913126,156.19141,192.872183,196.540169,157.60153,151.770161,54.816862,-43.397511,-162.340691,-138.247901,-28.24625,0.088891,3.136695,-6.631213,-1.737075,46.748135,66.360883,28.660175,-10.675308,8.787315,124.094653,104.229762,-119.616021,-240.083881,-330.112588,-288.031534,-134.295706,-60.140682,68.910292,61.151588,-7.094855,-136.298173,-161.162193,-123.918818,-92.758478,-88.361081,-87.151158,-67.158555,-87.783904,-136.591594,-197.943051,-192.060633,-174.810731,-174.109763,-149.427541,-118.825529,-103.527895,-58.953069,-37.975279,-13.697669,-11.649959,-4.78325,86.892092,140.648414,114.235393,31.038131,-134.965734,-155.032389,-60.638418,-3.534313,53.76729,66.188106,64.437578,33.578158,-1.60059,-71.302769,-89.670052,-103.245379,-16.094431,59.771367,108.689779,69.814578,-27.858272,-54.65288,-31.965975,10.102967,117.978858,156.310056,110.351114,-26.2413,-73.758389,-113.568021,-110.853548,-90.083023,-74.364944,-67.823828,-63.859361,-70.997612,-74.640078,-48.513665,27.486745,50.676695,48.821885,-21.805285,-54.565998,-54.87643,-48.909011,-54.534878,-29.715495,72.974715,96.887306,67.909756,12.7792,2.132601,-5.19252,-7.4768,-23.759066,-34.667173,-11.480309,60.74009,95.05708,115.444554,89.265199,41.706727,59.367674,156.483271,218.711024,202.90487,86.202236,24.737609,20.748511,95.553319,266.264965,291.916175,239.32643,185.727139,167.684187,127.597715,94.743409,34.396171,37.38175,82.530991,63.860512,31.947334,13.465922,35.384806,38.345348,6.960199,-14.448127,2.487696,15.653148,9.222881,10.914053,-16.496816,-37.711967,-41.186259,-40.175771,-84.195707,-103.353743,-90.185999,-83.987415,-87.242874,-112.16269,-136.616233,-142.010027,-102.680387:322.048443,311.87523,314.342253,337.049974,327.27884,293.522067,292.847164,333.343866,426.627175,453.006936,423.726425,388.559159,299.813389,250.757269,168.196569,154.850408,185.031892,149.621647,112.771066,100.938244,114.235529,159.033927,205.115639,270.155247,222.964597,178.245611,110.082438,118.168438,193.956364,213.915784,171.189409,122.567128,-10.482125,-166.959247,-190.927466,-99.758944,-68.88269,-119.412381,-136.037746,-60.593005,65.145156,101.231558,104.657888,78.083112,11.052136,14.077176,110.848161,159.836905,176.686266,84.865102,20.45888,-106.205221,-150.861035,-158.330886,-144.071013,-143.857661,-76.062058,-14.962847,7.962703,-55.866742,-238.225324,-288.000426,-214.352478,-115.54498,49.152372,10.084347,-76.880126,-236.143833,-272.796658,-258.493943,-206.306764,-60.560088,16.161974,15.690909,-27.349824,-53.750645,-65.63602,-25.956723,97.141615,110.815136,35.458538,13.672681,4.367069,-102.447196,-160.606801,-149.223584,-84.192614,32.101758,71.991325,83.289575,53.39219,-8.684739,-137.667541,-156.372289,-120.267666,-102.517949,-92.729203,-54.78374,-31.151546,-62.249662,-118.974112,-206.202072,-217.984948,-220.489916,-170.335916,-114.494868,45.035634,119.989586,139.791387,93.846348,38.447776,77.939281,250.261871,347.22891,344.839653,227.166494,140.058566,70.159993,91.031077,133.747957,115.986058,88.810691,42.611562,13.877942,-117.454781,-176.995705,-146.72662,-88.536938,-14.608533,28.696816,39.801633,-30.551073,-84.785855,-99.10907,-82.918881,-131.86168,-209.966485,-221.752409,-170.271433,-121.877763,-65.006523,-70.724993,-88.997684,-60.675682,48.082692,62.104565,22.705411,-29.655921,-3.812706,116.408739,163.253949,196.09651,186.667637,144.581907,21.255856,-7.973643,22.362156,55.553403,111.115303,130.809175,158.880116,105.242161,54.821407,-0.464733,-14.758034,-74.128593,-95.300046,-39.841763,83.170293,118.927568,137.794675,119.532938,-17.080458,-82.934924,-56.923916,-1.444422,-4.206409,-144.913839,-163.875982,-98.419419,-101.208139,-143.958739,-105.556542,25.591486,79.40963,68.750853,3.08529,-20.806482,-53.057245,-63.673342,-36.927051,-13.384862,-14.974873,-72.399077,-105.373396,-193.739914,-249.071946,-274.143661,-220.195571,-79.33979,4.011797,27.770606,57.517477,60.761168,30.523842,12.237001,3.41895,5.1405,16.817989,-11.920083,-49.562521,-125.835498,-156.324348,-131.685656,-80.292827,-21.644661,-6.544431,-9.880761,-60.044504,-74.71333,-60.729311,-57.886059,-89.894217,-109.44768,-129.2746,-130.437081,-99.647891,-52.060357,-91.12086,-204.376863,-209.236716,-137.625861,-80.33114,-48.738029,61.891874,95.252108,-7.695652,-81.357889,-70.096409,-11.806908,89.192988,149.337739,153.976595,128.340077,135.101501,227.15781,271.788416,284.428836,263.836468,222.459169,68.772145,18.942314,14.439273,35.914441,136.329761,201.518051,248.792763,187.498357,156.243923,121.048538,104.989874,52.155659,42.865308,117.393832,206.092295,198.567299,61.37894,-27.359213,-125.21043,-119.065679,-22.338757,54.871751,195.664324,173.537432,102.365743,-42.346442,-74.538938,-34.1231,-0.210949,30.752683,46.056585,59.327498,97.223564,87.640964,-24.621966,-71.290986,-45.066938,-5.740039,-4.7164,-93.540129,-111.809745,-74.671376,-78.020572,-133.581135,-125.271129,-64.054389,-51.76693,-51.698192,-29.164186,-30.007318,-121.842705,-175.320232,-185.399054,-152.612896,-78.22871,-57.251021,-71.257146,-111.334079,-129.983212,-124.450643,-90.066548,-3.912995,82.002595,115.7337,76.302224,6.342995,-58.165028,-22.598482,26.777812,19.807109,59.044075,57.151698,-9.618003,-135.282803,-145.45575,-136.237977,-164.949149,-209.254925,-81.0988,9.121605,92.01799,56.394138,-96.261735,-144.337158,-120.109521,-77.414538,-3.476227,-27.401375,-71.529897,-110.826485,-98.437333,-76.343731,-72.88854,-43.119854,-19.164336,-37.051842,-65.550229,-45.267641,-2.90765,-10.756789,-61.835683,-75.638392,-29.65673,67.338907,126.785671,210.215301,194.297302,109.572256,78.565362,13.722125,-37.057385,-29.04615,50.640376,82.522406,58.765923,41.195119,75.693971,132.253377,265.29656,240.962987,193.129002,150.695121,122.463236,18.712651,0.183169,40.956732,48.194409,44.704532,76.441674,88.689798,37.716181,11.751501,54.662799,96.937972,133.869153,125.988888,116.825977,52.17605,-15.079087,-162.403181,-195.368789,-115.503933,4.802297,4.220071,-28.042644,-15.334022,-43.863817,-99.151118,-150.419624,-115.037432:171.336845,158.751058,84.804614,27.599247,85.892647,253.378107,292.924097,235.368426,180.334331,199.981498,221.872113,183.186111,68.406844,45.118786,52.382567,44.337848,5.434147,-45.968561,-58.493315,-36.575337,-28.884027,-46.426201,-61.980714,-39.371173,69.451388,89.350135,66.268952,68.506604,90.953253,98.273611,94.251706,65.590403,-42.039683,-102.302806,-97.114778,-151.672702,-217.97669,-205.007958,-100.940458,64.155742,51.446584,33.3204,30.559314,42.480065,82.919334,111.407234,173.184771,181.711745,96.05379,-3.352187,14.965688,101.767894,98.484221,8.214805,-46.341792,-113.792143,-75.158588,-48.942293,-52.12926,-73.526649,-114.106842,-114.846991,-55.05401,-4.127503,54.218984,-61.866175,-126.425751,-118.203829,-93.377167,-86.778917,-52.381247,47.709347,34.181517,17.42489,-17.49486,-56.601356,-77.452149,-0.719432,223.512102,265.242557,191.235708,105.799518,74.876896,-3.21051,-48.581186,-88.35434,-70.739925,37.216825,138.795934,104.743765,-89.932391,-156.365459,-174.267277,-149.256062,-18.133509,49.54067,67.359567,15.57004,-16.189228,-76.647127,-97.397749,-123.556826,-124.326009,-109.105484,-38.023079,25.899599,173.224381,230.907003,184.567243,114.74569,169.889369,274.341279,365.593923,346.961725,346.885923,277.243223,192.031528,70.681886,80.125802,156.664825,173.69118,166.658928,126.765867,79.613706,4.160307,17.164501,45.186769,20.511399,6.047967,42.346308,30.471741,-7.054049,-12.251259,-22.189283,-33.767243,-23.267675,35.839696,55.197202,53.316452,33.432461,21.896549,55.991043,112.876211,111.983132,143.485589,192.758131,178.390774,128.727423,116.688723,68.650351,21.859248,-1.42062,114.366858,126.565677,28.032204,-19.757468,-75.207848,-70.168522,40.068137,88.600512,118.636726,164.93153,165.85936,97.44459,85.246989,159.252908,188.270548,160.456657,137.801614,137.805717,99.081956,52.951029,-73.70894,-106.942074,-26.279879,41.911326,93.482995,43.496843,3.849744,-115.661909,-179.24126,-186.403435,-130.790326,-40.555797,-37.087055,-54.636463,-46.778185,-13.688254,29.486119,40.097633,88.570615,105.370002,75.428418,23.277244,-12.82172,-153.055733,-221.693403,-195.391804,-107.28326,37.493145,113.363896,125.53688,66.94065,38.658601,22.614871,-0.615286,-80.489611,-101.732464,-92.859014,-97.979786,-92.812968,3.282113,42.316734,12.425908,-11.950163,-6.655799,16.182062,4.307538,-59.58868,-77.310294,-68.632834,-70.171187,-101.989296,-105.133795,-38.041428,-15.62952,-67.672152,-218.017487,-280.263697,-354.55804,-344.014865,-175.898202,-4.836426,-12.098381,-125.819497,-155.134724,-118.050628,-68.75255,35.802156,63.358426,78.679177,72.137392,40.089006,-22.570291,-14.433547,33.450868,33.946207,16.555618,78.003564,127.074164,110.102851,8.909255,-226.287846,-264.883713,-158.400416,-75.504993,13.5226,2.313527,16.311803,39.426926,-5.499699,-101.028042,-93.483592,-1.091764,93.131222,74.201197,-91.820659,-159.884435,-199.329405,-187.761674,-89.860802,-22.55521,52.92512,43.745462,32.20793,-28.629867,-90.556899,-177.825396,-169.488259,-83.911858,44.700273,61.705315,-99.90027,-207.378494,-252.928682,-178.261465,-4.591702,16.152783,-37.966019,-88.844519,-103.344689,-91.095994,-69.86993,-5.682604,16.698153,16.350687,38.777555,58.00159,21.166539,-42.291645,-131.200115,-115.629879,-21.413102,19.347936,94.928819,165.952628,173.174019,143.163185,127.951199,136.281262,143.419856,120.879131,167.881226,208.622586,148.227554,53.936289,-105.412059,-134.524244,-78.383179,-7.393344,165.713744,205.349834,122.706157,-113.389585,-172.817633,-128.871433,-99.151704,-129.773959,-145.897327,-138.660232,-175.478553,-209.834711,-217.552133,-177.132655,-95.504195,-72.165362,4.688677,38.093255,15.518402,-31.369086,-64.640243,-135.766894,-111.357563,45.909223,110.143163,90.963987,66.651304,72.691432,44.40772,17.102911,40.128757,84.294857,155.883785,155.498544,110.991532,-26.753529,-65.700773,4.037698,72.51724,144.875106,162.084793,154.62261,107.84769,95.714409,113.983993,130.130782,162.532369,198.56548,310.302915,256.663016,165.847299,97.127831,129.221,173.01571,173.35386,192.41638,207.381364,164.31451,19.068406,-11.542764,18.485625,36.087363,79.041599,98.194794,61.769051,-22.614231,-51.714664,-96.30372,-113.400757,-84.725482,-50.89591,-64.447118,-116.661266,-120.526821,-93.172196,-68.073296,-104.534649,-164.679525,-162.885698,-63.93166:forward
-147.705528,-147.298817,-132.407986,-82.475739,-79.810694,-104.127975,-98.50047,-43.359137,-34.96219,-39.086883,54.436354,120.547098,127.485822,72.206938,-58.951767,-101.294813,-69.820389,63.746804,90.845675,23.282415,-11.527015,4.107673,23.597345,14.590232,-2.740305,42.975624,214.355935,250.260424,141.166465,56.873427,-16.213451,11.756661,133.58999,213.92289,201.813161,87.055688,35.712578,-1.114925,-19.340559,-49.17187,-1.526086,16.741836,-41.300469,-107.811955,-217.101471,-247.399316,-276.46772,-258.355618,-140.453898,-10.422922,21.015116,16.48027,14.591994,56.707286,79.834961,73.80376,53.009225,92.973823,232.835927,254.030222,150.517356,88.201452,67.752118,95.823062,112.418206,113.544372,155.565246,243.831445,254.284225,204.973732,147.792079,45.465438,48.217666,76.185255,128.175849,139.692151,119.281275,81.318339,-13.890816,-47.968912,-108.653391,-85.294063,-14.90537,51.983705,-7.541772,-169.32802,-177.776052,-14.426568,89.498036,68.910673,59.256497,89.226089,88.848383,25.773633,-111.303895,-113.511163,-31.788654,10.988381,19.97278,23.100555,30.450534,67.154234,67.033603,33.458076,24.122166,23.647988,-21.800693,-54.030527,-21.245247,31.301372,91.356784,90.755389,52.894493,36.313384,49.030078,87.046577,113.178071,107.800792,42.666693,-77.064633,-42.363579,-12.360863,-15.880973,-56.543786,-126.359786,-116.628566,-64.46985,-37.995976,54.584682,195.983863,254.485698,252.707393,215.180396,166.266566,148.087853,126.258737,176.979806,220.207501,293.526947,304.675342,257.49556,213.822955,164.969468,178.636856,249.198034,258.061429,208.222354,93.597736,71.042665,24.806486,-19.585235,-11.187728,92.763411,102.148921,71.023298,63.346994,67.86048,71.855892,54.334006,20.183765,-90.339369,-101.783381,-47.153909,25.057011,27.842672,53.368601,50.129442,-88.88232,-225.636746,-210.648816,-66.797788,-4.958327,-9.179919,-61.742929,-111.496991,-66.983292,68.512362,113.639689,106.48401,65.964299,41.304177,-2.10465,-30.809347,-51.367023,30.578077,70.178302,115.637728,116.342478,65.262512,34.255725,23.105584,50.998324,112.058435,168.489509,213.423027,270.193256,264.791392,232.845987,214.388249,189.65123,152.087147,104.867317,71.892851,109.009152,158.961841,129.255914,69.736651,95.636359,140.403581,94.249055,103.023799,169.130023,176.33383,102.457114,50.327438,32.153362,97.893357,120.752536,125.606494,89.797085,-71.051061,-163.9849,-223.294466,-168.148943,-54.130126,-61.516703,-68.868611,-46.607035,-24.439627,-2.64772,-23.947243,-96.43256,-129.051634,-107.108342,-22.449632,-29.02984,-168.264658,-228.006025,-262.221202,-276.033894,-341.582101,-321.593349,-255.59846,-180.722322,-202.783728,-211.635627,-176.398284,-126.213461,-112.281809,-108.273607,-94.181281,-80.92878,-71.110889,-74.882591,-54.7717,-38.450133,-33.253281,-21.588567,13.819747,118.23626,130.877956,18.039478,-58.660216,-169.741542,-221.750662,-202.345907,-102.172274,-77.841165,-134.04779,-190.88356,-300.183585,-310.423171,-170.663184,10.698803,31.146723,-76.90925,-135.013859,-164.435359,-176.764626,-215.034846,-130.135714,-31.973289,131.070339,139.628036,61.237835,29.956327,35.794492,47.119273,36.626814,59.54087,96.491445,145.911781,133.165884,24.497315,-72.000085,-273.645722,-333.990179,-318.062495,-258.751771,-242.727137,-278.112868,-321.330195,-385.170778,-366.030576,-266.194309,-251.054042,-274.530711,-348.770995,-396.877066,-473.735519,-484.056013,-444.629997,-389.443109,-348.846969,-220.67704,-174.350295,-177.00499,-204.572972,-199.782707,-135.632088,8.99387,34.162482,25.330144,-27.28746,-76.245426,-175.198403,-207.394765,-199.491514,-106.149188,-70.035465,-56.80169,-40.241458,90.335184,175.340691,308.47511,361.271365,398.82722,284.763987,211.023075,156.436097,187.207261,262.515847,265.838982,234.016676,240.753647,253.687785,263.971389,273.74422,307.400153,305.640329,280.639707,281.585096,250.829533,136.952975,71.7674,-35.113015,-32.847934,42.275849,19.896848,-135.649808,-172.195865,-141.224336,-78.862476,-59.356709,-28.401597,-26.900373,-60.630866,-53.538714,53.6946,153.761462,167.086911,126.447132,84.33476,-15.49679,-63.285835,-88.330203,-14.126868,35.067777,120.970324,135.729807,123.960706,111.16708,74.382718,55.403914,37.84959,74.866881,82.517603,16.3333,-9.161783,30.993624,51.83546,61.24526,116.336014,172.475149,262.218281,235.978794,96.160119,64.45834,115.856732,161.010223:-77.754474,-95.050983,-119.528243,-118.870243,-91.632011,-77.507407,-114.034847,-136.492066,48.536297,150.858589,204.358061,165.384815,49.219593,-20.043309,-157.310056,-179.367519,-69.873687,114.693393,170.823166,142.106838,82.621326,-12.615627,-28.98798,-11.424676,63.924774,121.569695,180.90894,168.336248,112.331259,79.698589,48.216983,57.263748,107.75351,181.101678,193.499557,140.518274,102.071637,50.630488,40.311847,66.514073,112.085123,123.615892,70.722235,0.25115,-139.047302,-193.600468,-269.165385,-266.798822,-191.610065,-131.257961,-118.163232,-95.08684,-77.252101,-59.595145,-71.128719,-55.327983,59.063875,110.028116,161.46391,163.900383,111.794258,67.224678,27.950313,40.836973,37.735902,39.601071,72.151917,83.562264,47.296878,-11.046849,-1.485,91.606493,132.964776,110.548447,63.989962,64.496852,100.677442,98.905612,32.13443,1.436394,-31.534903,-20.886882,9.337293,41.850999,-7.022994,-183.112031,-199.461961,3.299755,145.643087,135.833799,126.509922,134.550337,87.480384,24.165379,-123.817411,-154.025443,-61.952694,55.234591,58.440288,8.639962,1.306165,29.78265,28.18974,-26.399498,-16.315331,22.502608,34.89609,-6.45446,-40.003367,-3.412758,81.264329,91.467145,34.834391,-32.068291,-21.231696,62.150365,81.43925,21.31328,-28.8028,-88.100473,-64.871513,-28.758943,10.122715,-14.625455,-89.399147,-89.645653,-13.010049,18.465961,26.175209,53.675775,68.085661,57.701582,55.510713,68.162954,55.800177,42.048061,169.717736,240.663193,235.582448,177.598752,134.538173,160.888288,202.02614,206.224862,181.796939,124.857394,104.006253,83.951433,77.68871,28.035905,-7.125626,5.889569,70.906187,77.138144,104.489827,129.725216,132.932902,112.525863,96.790536,109.769805,130.52481,162.483345,189.011953,235.771215,249.811249,215.569011,163.398614,14.940641,-118.608299,-119.983602,13.829089,84.308361,128.10291,107.087879,33.958929,27.508427,117.957218,176.152562,155.0477,65.055248,36.290357,22.412739,-7.376919,-61.790889,76.566094,158.369771,169.700368,121.185349,38.130679,4.096601,-43.593435,-21.582035,100.056413,222.184871,262.368047,243.744884,186.163722,62.025783,31.79916,28.058393,65.099111,94.611645,114.420336,73.225706,-45.362443,-44.920618,75.978484,114.246577,81.02933,53.609076,74.6877,142.421476,150.223653,47.451139,-23.00708,-19.100305,136.070174,183.417891,129.370257,49.480925,-138.221082,-239.516381,-356.735708,-317.055952,-133.472771,-38.304678,-36.041091,-20.276783,5.130523,-0.347287,-38.895077,-128.386213,-174.674489,-150.401801,-40.250476,-13.971173,-65.240813,-126.322201,-266.684856,-303.001155,-308.618518,-318.74134,-304.111234,-267.843809,-271.990737,-253.221446,-214.088673,-148.549585,-119.351756,-89.513654,-38.693737,-54.653705,-106.42136,-94.117553,-14.804358,-3.464916,-74.022408,-58.365961,-12.930063,-19.357064,-88.701265,-266.28678,-319.578234,-309.817338,-262.763977,-237.762995,-151.940405,-123.359276,-186.313033,-275.644001,-406.49477,-359.042979,-109.558777,14.296832,7.247246,-60.132716,-109.408023,-233.940821,-286.424886,-260.779873,-80.203652,9.383062,106.709541,102.651045,34.43105,16.12959,70.050141,112.185445,159.547352,231.550554,266.403271,208.736142,126.10396,-19.617293,-56.434639,-81.890855,-119.16879,-137.482906,-165.362072,-188.842987,-252.039483,-290.917285,-337.516946,-327.182813,-306.359907,-309.797904,-321.211268,-407.988549,-455.564075,-501.258647,-511.100771,-501.038694,-426.943105,-379.369791,-321.96263,-322.419304,-313.304765,-285.328884,-215.756186,-177.749485,-98.802237,-64.34056,-80.322899,-157.938581,-201.594614,-278.077958,-286.651526,-196.115387,-54.086796,-5.240536,-1.914008,-29.83208,2.838701,74.111042,209.625753,251.997163,313.609355,341.042836,325.922051,235.809801,186.420867,133.810157,140.73967,191.600482,221.702213,236.031505,229.378398,199.795829,150.832278,142.702191,148.20254,149.56905,93.965215,-27.226706,-83.718711,-119.735481,-99.609367,-124.523657,-184.269921,-235.459462,-160.249964,-121.495522,-84.362041,-89.854651,-134.175113,-168.886636,-184.719104,-118.719945,69.595929,80.455706,45.620066,41.021816,34.954621,-48.533829,-77.081818,-58.187298,21.08111,83.270298,148.383561,113.380672,40.37734,48.14051,53.660256,35.99695,68.793787,190.571344,209.217239,126.492113,73.892182,45.834499,71.980746,149.231554,237.790977,275.008546,261.071761,203.776432,41.011579,-23.361853,-31.604848,28.175022:-68.083599,-7.695507,30.834088,69.572895,59.528656,-0.482877,-21.804291,-13.486549,23.151863,65.464714,147.229892,133.004534,-3.034194,-80.919976,-141.424136,-99.762056,51.675912,139.194625,139.932669,101.360948,82.121822,55.135322,48.609501,56.945187,119.554594,185.303848,270.934152,240.733005,87.360393,28.267722,50.028792,95.056754,132.418394,192.940748,240.444369,264.186837,235.169082,130.26951,76.408142,69.418047,208.040285,256.681408,177.23388,93.502562,-25.022855,-85.023477,-223.40251,-251.441962,-204.199752,-123.673426,-100.734829,-137.116617,-184.536893,-259.393202,-256.38066,-140.104811,28.853941,107.181997,201.828144,195.314312,105.06639,47.524555,-30.405196,-39.10015,-44.787947,-87.885847,-127.072446,-181.739824,-162.074687,-107.263634,-107.615433,-75.197108,21.239231,60.59179,93.044558,84.461867,41.365681,19.660621,21.881377,37.428967,8.113268,-18.192796,9.304184,34.764922,-1.446055,-97.372687,-113.172328,-82.019322,-5.309492,47.405803,112.720784,89.058207,-51.295195,-120.790058,-168.584876,-144.611024,-52.399164,67.43219,103.603856,38.614432,-33.230285,-161.658311,-202.072214,-157.568674,-23.892363,4.180365,-50.74925,-92.640917,-98.277782,-75.999867,-39.050362,-8.622774,71.905073,58.335363,18.619823,-52.482921,-82.644864,-123.187029,-118.789555,-96.471543,-66.216875,-37.508935,-52.893789,-106.353648,-166.335112,-152.686521,-120.442246,-112.57382,-43.801213,64.117615,64.0297,-38.95783,-72.99693,-35.45867,-7.458882,22.858787,81.889426,103.399366,82.288723,52.288661,35.541712,53.762956,108.713649,148.280784,205.827091,165.949771,122.182024,62.346732,48.080225,-30.902397,-89.210961,-100.486059,30.943514,86.470478,122.390515,111.609626,73.651477,61.26912,57.52003,62.490974,98.575585,169.652244,180.834486,132.567501,117.314711,138.313098,149.384712,140.246053,60.306821,25.04746,63.127377,110.722433,137.854073,114.646331,87.867142,103.435764,157.361965,205.518597,210.422778,152.537669,96.294141,-3.648404,-12.944137,58.26948,142.764145,169.037691,155.271719,109.854084,25.100682,12.776546,47.553742,80.607192,145.799611,224.923169,239.171917,143.455493,64.134667,-24.85735,-8.689768,87.17395,122.430497,110.916851,76.511575,39.083006,-63.687698,-77.824229,-12.262045,14.724743,19.747602,74.527958,111.098402,127.457339,127.14339,135.528131,123.565362,95.105283,125.660209,128.324989,19.331938,-64.408311,-164.850334,-182.289105,-183.762828,-149.343642,-30.997717,15.6796,16.125751,32.158383,20.481453,-86.726129,-124.63064,-59.529032,68.546293,124.451174,158.485062,97.452183,-87.496922,-139.275278,-160.887984,-161.717599,-143.411227,-82.268629,-59.512296,-72.313768,-104.029941,-156.679936,-151.425626,-93.412785,-73.410961,-68.871541,-58.104909,-72.884244,-96.751161,-85.943841,-37.832967,-14.852913,-14.133026,-46.748573,-59.903692,-99.161436,-138.1437,-267.288075,-321.570522,-323.826967,-273.059585,-241.450377,-183.208373,-190.905322,-268.195627,-301.404177,-262.188702,-185.024295,-39.282891,-5.345258,-20.954874,-65.109212,-87.606756,-169.807702,-208.51314,-148.126669,44.328286,109.41595,133.804931,131.335287,128.715137,109.227976,89.611179,122.512882,233.005371,299.431706,307.925576,264.159083,198.38951,45.632829,15.140649,11.838746,-9.631964,-13.199699,-47.796307,-77.302014,-128.340291,-177.88086,-283.421712,-285.39719,-224.141675,-194.645437,-205.78109,-258.939723,-274.650091,-287.699672,-309.974434,-346.660297,-307.228221,-284.497265,-287.423335,-300.701504,-303.131343,-296.306096,-260.236214,-222.577311,-132.447197,-68.119682,-51.184843,-71.514856,-133.921081,-283.670511,-291.289903,-184.051028,-103.542657,-82.681131,-59.198817,-49.707057,-7.335577,13.046141,58.301501,109.175848,216.844036,213.999562,183.392144,122.966345,106.359671,97.36412,118.205013,240.719366,316.812654,291.069478,165.764041,112.465858,58.778506,29.073691,-9.164594,11.398315,68.748979,38.269042,-10.282463,-132.770612,-183.12905,-197.726161,-162.748855,-110.392853,-104.54436,-89.759597,-73.961245,-84.344199,-92.046413,-80.308771,-34.60766,-2.273609,64.186327,83.270565,75.945109,104.164086,121.333199,59.482091,9.022329,4.050474,143.568838,206.166665,167.20997,105.08872,82.437447,94.13721,63.660715,60.427814,133.986517,215.713346,209.881883,87.533724,12.095112,-56.604107,-36.480523,64.281584,151.689782,168.156574,147.279653,139.079605,139.767882,113.008078,29.249175,38.711581:-70.529446,-36.263233,-25.633474,-2.093126,17.446716,9.033709,-26.262273,-43.030657,60.983367,120.613802,201.093865,215.122628,177.409884,115.413053,-51.582303,-94.976424,-14.998518,153.53251,189.519354,139.741939,91.895389,27.301754,30.757171,87.911099,124.358726,168.17439,285.212798,277.463993,129.5931,56.164011,24.594815,69.435908,171.309305,182.125382,166.356662,146.517451,138.853366,100.396533,78.142049,66.778847,61.447554,46.449097,-13.209118,-56.233526,-129.098219,-162.772,-239.265895,-254.877647,-189.169987,-46.336824,9.340681,12.030965,-20.790409,-60.75761,-56.215049,-16.689421,30.3197,68.710938,149.478464,156.508605,113.346228,101.566223,114.979839,108.83086,37.448513,-27.38522,-27.616155,40.312095,80.142421,63.318404,16.598677,-41.079036,-47.533604,-39.546279,5.524223,14.147204,-2.457079,6.385504,7.04872,-46.54821,-184.939386,-182.372955,-145.452605,-139.157304,-177.412889,-235.270556,-225.721566,-126.554273,-7.86144,7.04863,-43.324158,-75.521049,-138.416799,-188.857656,-270.246334,-247.671862,-123.908642,-35.428039,-16.824083,-50.641691,-77.539259,-64.666276,-41.538581,-43.060858,-75.287479,-82.149188,-99.945059,-123.812241,-166.97811,-164.420019,-99.838368,-39.967677,70.113798,120.194364,132.97568,87.553016,32.329602,-67.989025,-104.176526,-137.397062,-119.627652,-112.263647,-155.259537,-222.761392,-353.000092,-347.414725,-202.795632,-133.317329,-76.96147,-26.977305,11.129515,87.765485,121.58733,95.218627,18.709987,-81.502329,30.014874,108.358514,173.105314,147.746846,93.064789,112.001508,196.485535,223.036012,232.540133,216.696138,190.062598,95.912457,52.2857,-7.256306,-24.809106,-19.405542,19.961566,43.769348,81.170056,75.976444,13.993814,-15.226227,-3.13501,27.533315,47.725039,30.644203,37.792581,54.267755,52.10098,24.673916,-7.91116,-109.663539,-150.776835,-110.042407,29.997112,85.668533,114.168948,92.573894,32.536349,32.8989,123.513607,227.422938,242.786957,152.686607,89.427041,51.251377,55.802115,78.612704,187.060718,233.040886,203.170563,161.855127,143.301182,148.672905,141.020033,143.305995,149.232839,199.548614,263.006344,335.665502,290.57117,96.758506,28.253822,66.676875,212.903206,238.778845,127.507298,41.294295,-13.170782,7.840912,29.913707,32.706668,55.854829,140.012883,207.049972,276.420057,260.529207,199.321566,174.309716,181.818829,228.630611,226.664509,147.553064,71.924757,-90.581645,-143.296339,-156.768738,-118.608266,-15.15635,57.986013,84.71643,117.77606,130.63607,126.331448,100.223639,63.550731,70.021801,67.924831,72.355878,63.91311,-31.32981,-86.924251,-155.898596,-176.166562,-144.671084,-59.658848,-51.892433,-87.007811,-91.377454,-50.354709,-40.690506,-60.783029,-24.98422,-4.746101,12.878656,32.008271,81.957614,100.318165,131.486065,129.116392,31.281712,-38.611984,-2.529726,60.981819,14.621945,-161.394838,-220.861003,-268.231999,-300.526694,-291.199171,-239.325951,-251.807959,-333.525625,-351.875826,-331.232066,-297.284281,-159.015463,-24.578704,-21.259515,-95.084924,-122.516197,-182.392577,-214.079979,-133.030736,62.690858,113.353576,130.242605,124.411933,101.961233,97.233785,124.653191,128.116477,85.823322,143.062569,217.439983,279.62179,225.651845,-0.523815,-100.0415,-113.611547,-51.176756,-84.678209,-203.098457,-232.547907,-230.495668,-233.153029,-269.443913,-267.917817,-199.752429,-170.504338,-190.337036,-236.60947,-253.190563,-305.026023,-336.206839,-356.17986,-335.023485,-302.730746,-234.658702,-250.505515,-330.507923,-333.622634,-263.010913,-228.709842,-189.222079,-100.887168,-53.369846,-96.058337,-190.15631,-384.37005,-416.510151,-316.02474,-205.292395,-195.988051,-174.877747,-130.794546,-10.59628,44.229166,160.331675,212.47546,207.934075,107.061105,72.229763,47.921943,43.878279,30.200282,40.044691,123.29336,179.713249,181.783253,158.466844,143.068777,122.749591,111.811679,57.40806,13.28826,-44.645236,3.008819,39.531849,13.292676,-49.083684,-135.138383,-129.24727,-86.204602,-92.296009,-94.995196,-96.484386,-116.456193,-128.841222,-101.698268,-40.77489,-13.706069,48.776122,120.902186,153.747507,185.202449,191.634278,179.946403,136.178201,29.970912,57.691432,117.501579,200.945279,190.94855,136.741005,117.923435,83.239255,73.091357,97.727582,166.961792,168.331992,48.107644,-10.324051,-13.082461,12.786647,77.458669,183.799996,251.461091,338.954133,310.649401,149.421759,79.598787,51.329347,94.684669:6.664475,126.403033,161.940756,147.218153,95.142968,-58.78957,-101.976897,-28.639852,113.446861,162.949008,174.324995,116.642407,-41.894131,-96.917596,-143.730973,-133.034779,-47.574087,89.199316,148.158967,150.972241,95.60551,8.541054,20.878102,95.288477,100.16879,107.286125,180.334774,183.465408,44.399545,-30.731308,0.604053,90.464495,217.634689,234.779972,232.360461,179.503068,127.957191,50.014613,53.643577,114.936992,143.669995,151.733187,152.303352,122.792396,-1.010274,-84.949019,-205.196548,-208.295473,-152.173042,-82.285915,-51.893227,-52.996628,-83.601667,-146.013052,-155.69395,-107.002438,-18.226959,22.454089,40.733471,17.249332,-17.594526,-18.495183,-8.181258,3.261135,37.328577,9.104788,-53.369052,-151.363312,-131.426419,-43.96497,-24.767898,-6.239619,21.706296,45.506655,95.548267,97.146623,22.940667,-44.109578,-140.950865,-137.398156,-53.142523,19.939419,-0.512541,-158.089556,-228.820607,-247.361023,-217.175127,-147.670401,-72.199286,-47.001953,-64.63204,-92.457655,-177.28831,-242.59153,-307.86401,-268.111426,-103.195197,67.320363,99.152604,-16.760696,-104.215655,-178.621482,-171.857016,-96.438085,19.352324,44.997474,-10.216186,-73.387863,-177.479836,-187.803519,-115.800747,-54.4734,65.679843,146.195964,142.268013,5.898242,-86.267997,-194.943598,-192.526038,-136.079393,-119.625276,-104.021413,-106.116667,-161.440044,-259.122848,-255.23793,-214.204194,-207.565292,-171.395407,-70.032717,-46.907927,-69.086449,-86.756788,-143.367064,-170.756813,-143.379761,-60.095555,-21.348845,54.083981,57.504363,-14.052378,-32.04653,35.804591,83.563444,131.410344,177.454944,192.055349,125.197824,47.656546,-111.158856,-157.268951,-126.146187,19.867606,82.892805,83.005445,31.63862,-40.156517,-40.612639,22.525289,60.550733,73.639298,107.356934,144.61674,155.164023,116.236511,22.255044,-0.417133,27.61814,85.874405,111.02217,168.535506,202.002711,216.71827,174.053709,88.906743,104.405201,227.288079,350.816979,369.417075,255.064957,165.698011,61.508019,55.587995,107.094663,175.357147,194.752886,193.720863,175.185621,141.420905,140.798196,154.112604,170.104801,225.965217,279.350768,293.830474,242.734789,162.116629,-20.346342,-58.037884,-2.091647,93.028928,112.158923,48.116858,-3.433502,-47.652064,-53.606336,-53.498042,-27.869751,57.613214,174.132231,244.619971,291.23182,237.940953,112.954912,112.243651,207.694939,258.423537,258.987229,215.27969,152.676273,12.127227,-33.999942,-59.78045,-25.035672,92.31572,139.008172,150.877982,201.470035,207.317389,103.973958,29.847141,-0.924155,115.040637,175.374314,197.134268,141.605326,-40.632709,-128.744507,-188.161468,-138.078981,19.761499,63.510762,19.686823,-87.2116,-102.612001,-78.533197,-51.974529,36.108528,76.114892,61.547605,23.505248,22.207508,73.303714,113.813406,142.363044,96.95065,-50.956215,-35.941667,12.448709,-15.900235,-82.502837,-179.04284,-192.271133,-198.801089,-202.584674,-176.146718,-114.956672,-129.902456,-272.073869,-363.132474,-403.231786,-320.548809,-84.634803,83.781685,101.393844,16.072286,-32.617628,-69.788099,-67.929813,-23.621291,130.789378,218.984688,243.190876,177.412484,70.307618,62.52546,114.14157,166.317395,231.042266,210.825363,221.586161,241.851236,197.338889,26.661365,-40.532486,-76.954194,-23.650196,-2.510659,-53.41305,-98.423534,-158.944232,-201.4776,-246.569409,-207.285997,-132.502654,-141.975442,-144.769556,-123.565778,-106.859092,-108.08282,-132.826478,-181.849318,-216.299259,-219.159905,-209.138447,-222.926313,-266.287328,-279.099979,-271.116494,-242.211788,-141.472127,-24.880254,-4.95116,-112.706066,-212.996933,-367.920079,-371.20771,-233.338532,-110.210319,-86.035126,-54.557751,-36.480342,-3.540932,4.003244,16.668202,34.075548,103.333965,197.866731,213.242172,125.226891,63.58899,39.929579,73.567014,176.716461,288.912722,318.758543,255.04432,171.03357,6.957842,-52.982323,-139.139117,-152.471106,-96.152355,-15.205786,-13.050818,-111.848847,-182.409151,-273.346867,-263.126681,-128.373031,-5.428923,9.257807,-23.687076,-47.692759,-79.521986,-88.764589,-60.885459,-12.634608,83.28327,120.046497,130.804726,168.76953,184.468641,124.690376,52.200156,-31.969655,98.784793,198.510385,242.280591,180.979897,75.693676,50.128181,2.847497,-8.347626,47.816446,163.708637,170.106463,40.923779,-45.981952,-153.320778,-151.764832,-36.945341,176.201516,272.3397,283.531792,210.319403,97.768232,72.222671,43.679586,58.69238:-84.327475,63.842743,85.889513,62.93793,37.636791,-38.569248,-73.390926,-42.235256,24.064435,24.939804,92.159337,179.86947,286.389923,240.604589,23.920162,-47.088388,8.620157,105.279329,89.176778,10.945515,4.917291,21.011496,5.447228,7.52614,118.048605,163.965732,165.348149,124.962624,35.832748,17.91848,24.974331,41.334297,107.461638,149.786775,150.502861,131.508514,104.3868,20.739493,-10.507768,-2.096786,36.626769,27.761964,-39.979945,-70.075645,-108.56599,-140.597774,-227.257199,-235.010699,-129.788343,-12.571559,17.363263,84.007617,115.639896,61.203927,-1.92743,-25.902093,35.261845,60.557816,130.315721,149.233923,126.314377,118.377877,115.758352,96.249316,22.196799,24.813943,68.711503,152.881081,190.907462,274.756826,275.662625,133.967659,-34.079375,-63.792281,-27.64889,-12.12002,-32.504414,-59.208785,-146.0295,-193.410336,-227.461738,-157.267734,-120.224394,-119.848739,-143.299297,-162.976878,-152.963926,-117.611979,-106.641137,-92.280269,20.401691,79.523151,39.178203,-63.072585,-239.78317,-244.621028,-123.989131,4.443475,32.609358,1.199826,-33.455715,-43.343755,-16.001149,25.434247,17.775795,9.990279,5.475139,6.737728,4.587535,-6.144211,-24.690688,-8.07541,79.130802,157.23272,158.045459,67.12217,21.982339,16.118807,12.978365,-93.574214,-244.837849,-263.028938,-191.004179,-181.980334,-254.231702,-256.26251,-115.759126,-40.651788,-1.414757,7.730768,44.138148,90.260334,72.523893,-5.5775,-58.245457,-97.872775,18.599223,68.109529,68.052695,42.975785,3.45103,-3.294084,34.164978,73.117039,123.108294,102.604647,67.804109,-40.421965,-89.501843,-177.509402,-232.887463,-288.423652,-220.033942,-168.885642,-83.377123,-48.185035,12.615594,10.389322,-78.711137,-115.527818,-141.858343,-165.829436,-163.92744,-149.128901,-140.250259,-104.207611,-99.355923,-146.521975,-170.9312,-128.495894,24.217308,70.049923,28.483949,-31.16118,-81.525153,-46.080856,36.335525,21.762122,11.571575,33.385703,48.054248,30.168678,3.022701,12.482254,75.989666,75.23882,29.517375,-2.736875,-78.903563,-111.420505,-111.009156,-51.701882,112.538397,194.527321,207.90616,203.796088,187.562678,157.182026,159.973875,229.37968,293.592904,276.832091,205.899445,180.511719,154.459128,132.515197,72.97663,78.718889,186.020249,308.130901,325.43507,265.752395,235.481707,179.466703,137.812299,125.718256,105.259727,31.804343,-107.274788,-133.031451,-107.817604,-83.295325,-69.506304,-63.135241,-25.335067,23.300303,60.864743,128.438887,141.279663,144.344331,148.146601,159.716262,121.874479,78.463845,20.768531,31.446832,76.550023,60.84794,-51.078505,-90.861121,-60.836735,-2.131516,9.761907,36.376646,50.161819,50.234706,35.850351,23.619561,51.329735,63.05986,118.245457,164.143169,216.524514,224.625206,284.021691,316.553242,302.382408,292.029561,318.207772,321.983993,271.917719,135.687895,73.524213,6.609788,-8.575613,-38.606612,-119.181291,-155.950868,-216.603062,-238.284756,-264.798677,-239.297697,-76.069769,48.363208,26.875339,-97.312665,-124.439987,-116.911018,-136.641626,-158.25922,-17.382934,70.189184,185.756154,197.409948,119.865366,65.947837,5.347902,-9.705699,-38.797846,-3.291487,65.604102,194.372944,178.563583,-47.419918,-175.204505,-238.665548,-145.056987,-128.270883,-145.389902,-155.035213,-183.962886,-193.262278,-157.212903,-119.433212,-63.313731,-17.51997,6.480451,-48.22836,-130.612493,-288.63726,-328.073001,-325.431496,-274.513354,-227.291332,-121.823707,-103.818029,-133.647211,-146.863998,-117.792872,-71.320417,27.067624,43.014908,33.428582,-6.193773,-52.674737,-155.453262,-164.719121,-75.336271,-14.884306,-30.109459,-32.596117,9.342065,114.900838,144.480987,169.926389,197.505521,271.044876,213.788258,131.314274,13.518957,17.71446,67.563756,76.116821,90.054645,117.105737,126.620564,118.499165,101.362402,103.021048,120.61283,101.353855,65.702299,21.092823,3.76868,-26.493466,-88.179255,-73.367185,2.511402,-3.27452,-84.039717,-95.809632,-65.895286,-23.835356,-34.596721,-30.898825,-0.537179,7.185918,-0.591295,71.17147,199.777306,243.809213,206.810312,138.240386,7.078727,-28.722346,-22.838425,-5.667222,-15.664384,-14.77819,7.245918,69.701803,88.374191,58.938175,24.834636,-5.392483,46.024403,55.722802,-27.031895,-67.928732,-34.772876,11.319809,71.822058,127.062704,169.391205,241.261274,248.74781,203.71958,167.573057,154.919056,197.446785:24.496799,104.979687,125.728403,70.78739,7.224344,-92.620263,-94.47835,1.928951,120.201024,163.043228,216.968158,204.827753,92.886516,31.345135,-31.655832,-30.689549,20.309712,90.854372,109.395302,111.307185,96.31931,7.292315,-45.296742,-37.251645,96.563204,138.138784,113.50905,74.884908,5.57269,-37.967979,-116.647495,-97.751812,72.274559,238.411593,253.54386,143.824398,68.856318,-21.974296,-32.539183,11.009993,70.156878,81.457866,83.387289,64.877234,-60.568474,-148.478039,-260.491137,-260.991572,-188.561878,-81.958816,-29.111366,32.67053,29.713746,-38.407435,-67.772567,-48.448085,-54.112493,-69.60004,-39.47843,-15.017637,-8.103101,-17.085733,-23.350263,-3.343194,64.125926,101.850141,104.713523,72.008141,42.374364,-14.8782,-18.643199,42.022671,67.716063,61.801478,55.425622,27.324748,-97.688139,-142.421919,-121.183981,-80.539575,-43.5961,-89.219551,-106.513496,-151.2281,-208.732036,-315.496865,-313.511717,-207.838584,-42.742347,33.890299,70.192361,19.77917,-115.626729,-161.858061,-178.261161,-139.687282,16.505405,125.641111,116.417164,6.867581,-62.41144,-171.855881,-184.668182,-70.283344,92.039891,115.982548,65.308374,30.885891,-24.855103,-57.978886,-91.876022,-60.315509,78.776706,196.512618,202.005316,86.930477,15.280072,-71.324833,-88.63497,-97.831833,-189.356362,-242.363556,-247.085047,-244.204141,-324.619039,-355.124041,-291.766686,-225.889573,-91.305468,51.121921,91.856624,30.894666,-38.803922,-154.353805,-185.368028,-158.258697,-32.520622,51.101802,168.188562,135.77363,-49.601803,-85.758632,39.831461,123.764205,197.11061,177.477562,146.000829,40.522079,-18.763001,-104.059688,-121.195656,-101.459046,-62.617206,-39.616022,27.252983,51.738753,25.006217,-18.92717,-60.616281,-30.213574,43.746717,78.830586,95.450202,71.4433,36.380632,-7.300473,-25.745116,-84.381959,-46.037105,44.318116,228.062348,250.429775,169.52791,112.274697,21.269449,16.148629,148.069598,288.427193,269.081994,113.074806,55.533204,40.871914,59.436381,101.094273,131.184232,158.440474,253.331819,277.288753,170.693916,68.179528,-7.679494,58.73411,206.473232,229.588309,236.178791,245.447202,210.871673,67.535522,25.613769,99.200819,231.743512,264.903671,221.898077,147.14506,21.730212,16.983148,54.48281,64.574468,119.520806,247.582631,291.109755,272.63277,236.381826,191.604576,188.847116,208.222687,234.229557,234.026594,153.173296,64.863288,-89.986288,-109.618026,-68.994911,-26.914714,93.542604,193.915865,218.453015,206.886136,190.236153,173.420056,152.527131,83.410706,105.270098,140.745071,130.225937,89.155445,54.771582,58.454927,19.244677,-13.955839,-24.123458,53.664238,75.820759,17.201806,-24.68771,-36.599371,-15.674671,59.347394,187.445346,227.276616,175.298104,110.062794,34.973301,52.704514,168.083905,226.602175,243.617683,144.836874,103.791649,62.237347,42.093865,12.037516,7.804467,-16.363187,-61.629935,-86.835042,-142.824566,-174.085527,-229.849392,-244.221403,-237.012005,-196.926005,-34.420236,61.931918,36.522086,-93.802229,-144.265719,-163.30642,-146.9826,-62.163634,96.520675,168.717104,195.323925,150.121784,59.378334,37.98377,30.358843,42.937254,89.261273,173.202034,221.521949,194.40738,109.744185,-58.974409,-100.835366,-105.234465,-78.250672,-75.310831,-96.619758,-118.26688,-176.890049,-203.444805,-187.278392,-144.869399,-74.644094,-60.322936,-69.098542,-121.831573,-155.830666,-221.423081,-262.754707,-313.38913,-201.63806,-116.015321,-66.854575,-122.922699,-257.623018,-275.922334,-206.463818,-148.519992,-45.184677,3.359029,-15.579785,-121.825534,-170.088638,-210.228675,-198.918638,-90.794133,27.585802,28.773372,-39.429317,-65.957723,-67.07796,-28.492297,134.944017,219.036644,266.899056,180.666434,119.500486,-2.156428,-36.37586,-10.212896,33.361684,117.508117,169.859831,178.487222,97.555025,20.786028,-59.622122,-64.137483,-86.910887,-88.06552,-42.124203,7.543234,20.250866,-19.200861,-62.707933,-135.70943,-155.51474,-138.013905,-57.627665,-16.189401,-19.313877,-83.852871,-202.990656,-198.968765,-79.560427,-1.213995,81.741964,103.737013,135.309237,167.859611,145.391932,82.769709,62.424578,29.428398,-19.663493,-31.827012,14.852228,48.507354,34.945074,-24.952894,-141.115378,-150.131131,-111.685396,-75.322198,-82.245197,-164.562467,-194.0488,-163.384267,-130.539202,-48.258148,86.724223,154.834005,220.731665,214.592145,133.615183,63.110384,-32.268146,-7.187684:12.133693,46.026382,44.665616,22.970258,-1.704262,-74.136443,-107.673771,-120.448129,-52.634555,0.938584,144.787846,194.454143,174.621459,133.143921,54.49529,27.233424,-13.925962,-55.885698,-52.132778,3.884453,6.012437,-116.227242,-193.702572,-205.463025,-91.026293,-53.284127,-16.508448,-13.839685,-61.58394,-94.184949,-92.010022,-54.389143,-3.46307,-37.472805,-54.689071,-76.838074,-80.878191,-59.369331,-52.892998,-77.919316,-136.464518,-172.13288,-219.112603,-228.693561,-199.898017,-149.774681,-56.073536,-46.433148,-43.459748,43.192708,94.572135,116.94973,87.889208,12.29535,-14.912754,-38.763966,-84.487427,-108.930734,-50.405713,6.311243,43.46292,33.587722,1.684907,-18.853011,-46.727036,-9.010955,47.596675,176.093293,221.633402,266.855532,252.055051,124.857993,-35.740827,-80.347248,-79.810226,-51.124041,34.06053,61.429461,4.90682,-53.777345,-121.120146,-128.180497,-117.210868,-47.847327,-4.744027,22.463737,10.191689,0.8239,-38.848368,-62.827604,-19.592348,18.381167,16.522689,-17.60808,-97.64354,-125.842014,-150.99248,-141.730519,-102.255651,16.367487,47.729492,18.879422,-6.496781,-2.112995,46.986889,67.475559,62.495788,33.612108,5.272167,15.661976,3.187648,-14.747754,-7.036989,38.572778,55.509509,67.778142,70.223818,65.76209,43.686563,-19.035179,-66.994274,-104.465643,-194.927807,-232.821932,-217.4543,-145.307391,-1.60105,22.127637,0.962201,-31.694301,-27.244643,-25.740888,-47.497864,-98.970986,-117.965604,-80.272861,44.943886,64.074309,-21.352013,-57.438819,-30.637438,-25.206724,-91.485951,-118.653119,-122.743449,-132.985126,-162.605851,-264.503634,-312.291191,-359.784191,-380.947412,-436.465609,-428.147681,-393.456635,-312.680854,-275.780638,-207.300338,-194.906227,-230.911699,-250.050164,-259.418144,-238.726899,-213.486466,-205.930464,-223.047153,-189.679192,-139.314749,-118.401162,-191.077615,-174.938452,-53.569246,-21.59879,-63.002989,-94.408142,-89.715278,-58.126413,-41.468862,-104.854021,-104.052035,-41.470696,-22.493816,-69.346331,-126.827908,-152.12547,-46.036107,-30.691531,-69.565768,-88.263497,-142.130101,-182.726597,-205.347459,-155.594916,10.329408,140.59919,177.30042,169.111652,142.630715,168.671797,227.105448,303.035187,211.526633,153.01362,149.565805,176.680095,133.988113,69.132357,4.252435,34.70906,140.485202,160.802762,142.639811,74.154521,24.388905,-47.590783,-60.673866,-43.858955,-34.021054,-68.282931,-124.79419,-122.812004,-145.26174,-182.818944,-182.119076,-116.567937,-12.83688,-31.008081,-17.759048,77.551001,109.938719,102.086646,95.218431,157.512512,212.82107,187.173031,112.555937,93.345966,95.191622,112.868438,172.754778,202.347255,208.619416,197.067865,198.756306,206.112141,230.001453,266.859225,247.821944,237.33102,279.183787,278.692711,297.337502,327.883025,366.694504,374.742834,429.341686,469.768795,487.998473,473.316933,495.477391,480.726293,413.957606,320.258709,351.039176,419.869535,244.655402,126.539399,62.614248,109.305034,156.30892,115.545263,10.259119,2.6193,67.229379,64.329322,17.847475,-76.375548,-84.095463,-22.523355,-0.970091,-28.703908,-16.720509,33.578386,126.062183,126.628645,60.9121,26.391681,-37.181401,-69.596666,-68.920659,92.668478,191.107853,234.765803,157.883984,-32.919995,-82.474456,-94.519321,-34.496671,13.831486,39.473899,-2.485701,-50.454722,-18.979339,60.918212,77.198944,70.577616,96.516403,121.205623,98.817963,48.36268,-56.350838,-71.592495,-0.210692,35.090861,37.528753,107.818278,122.78855,24.883953,-28.776227,0.642579,79.836664,221.616871,243.650744,235.4794,214.340772,209.147818,193.103912,154.860588,56.536175,90.271681,139.169463,186.10165,199.655773,294.107995,351.946347,385.488245,370.433606,311.76469,192.196979,125.101218,15.578355,-4.615207,26.676921,32.389691,1.497362,-3.87544,-3.403982,38.907419,85.235768,142.8285,149.892307,174.361501,179.568711,152.436305,120.817391,105.196304,72.727697,78.016678,111.24976,92.520839,-16.632245,-53.099388,-23.709068,11.80995,6.317095,49.658721,86.464706,49.928539,-1.73657,-9.910666,65.850171,78.490046,7.402335,-44.224052,-93.499708,-117.599168,-243.213764,-347.578657,-332.306298,-230.512175,-199.565967,-182.481439,-165.534442,-104.887073,-93.846156,-176.911883,-245.397608,-201.190371,-47.197978,-4.420279,-41.060551,-88.635094,-103.943237,24.394796,99.00312,151.881759,119.086894,25.524871,-3.769354,2.32532,27.700748:-187.488736,-114.996917,-61.403566,-22.310815,-49.238224,-105.061625,-117.486342,-103.428377,-47.042008,-5.79034,125.930629,181.71555,207.972671,191.977554,92.789106,14.652527,-82.157104,-28.024258,24.977162,87.953735,84.592061,20.177829,-22.902938,-11.239847,92.415582,100.419574,49.616333,27.493474,-17.580661,-45.980196,-65.703252,-28.428581,119.301837,151.51484,84.751333,-54.278692,-57.209002,-8.858002,-27.980903,-72.253257,-35.912096,-63.110645,-203.984083,-256.401291,-241.94974,-196.404995,-157.645162,-159.394437,-77.005116,64.25974,95.997338,82.192447,71.84376,63.312798,43.463354,-9.378585,-31.562166,-24.296295,32.665331,45.012881,-9.11109,-27.190812,18.485314,53.408576,78.400197,104.533039,158.88469,290.582146,323.481931,295.189122,249.193381,160.684225,70.200046,49.531125,102.499757,114.265227,55.28837,35.869525,14.689097,-27.983515,-143.686301,-166.297652,-120.396954,-2.375894,27.372037,30.519432,27.725818,80.880453,148.764143,132.436925,98.076134,112.712657,89.523402,30.411856,-92.694245,-112.274456,-66.626748,-18.236784,2.104517,53.207602,73.926143,82.016219,68.838154,31.325174,-7.243976,-15.881588,-9.221249,-9.225069,0.922183,17.349925,47.500125,55.733838,32.145062,-23.811981,-15.118166,88.80841,137.764945,118.074229,47.556078,-81.97777,-109.749279,-108.239449,-126.560018,-158.838098,-160.070937,-86.018675,73.848522,92.645199,51.313174,54.909565,74.78191,79.773994,69.969424,59.975401,52.983267,47.126493,67.641079,78.833189,104.072905,103.03205,49.507314,11.825092,-13.271824,7.843136,20.673117,-48.765017,-72.495321,-57.08497,-54.026612,-164.065961,-239.470442,-233.441783,-145.52603,-154.349954,-181.773945,-154.297205,-81.128241,-81.804011,-152.209832,-183.556756,-228.02657,-286.511392,-295.495228,-267.533201,-244.966938,-163.22651,-131.147304,-249.144099,-411.321583,-367.316607,-134.410299,-71.604362,-127.531306,-174.075832,-185.66312,-169.205185,-171.80574,-161.291114,-119.428461,-65.736781,-79.580521,-123.855898,-145.092314,-163.423086,-73.395685,-26.382502,-47.857337,-92.434769,-114.370088,-100.02429,-118.725465,-137.362623,-101.020516,29.209111,98.851339,195.221596,220.087824,227.264644,211.80738,198.400836,190.787961,160.944522,84.604,53.512208,30.340924,38.303057,46.020259,41.325969,39.476753,64.859667,84.299929,86.400659,62.280959,-34.425667,-100.88377,-185.525984,-172.865075,-157.261748,-135.166622,-140.538992,-175.321,-184.730787,-190.662134,-204.305032,-251.570235,-199.367238,-120.069222,1.116638,14.868545,8.548416,-2.32566,-51.857319,-104.899426,-103.632886,-12.718123,43.802146,73.293407,30.973176,-102.685176,-126.92387,-75.75566,-29.298688,-11.875774,-4.586414,-4.482027,32.027947,37.451276,20.429814,88.324449,124.599363,117.328744,104.205065,135.160805,155.237956,135.034507,115.169146,139.643331,245.480343,306.544134,367.74902,342.514192,234.06209,182.358128,99.383923,51.763651,43.997278,24.900072,-3.817631,-57.890019,-60.034708,-26.092194,14.589874,105.67318,66.830216,18.384503,-35.202419,-38.392365,-60.406378,-94.927982,-136.550624,-65.55221,-11.920751,75.956082,94.543808,87.595324,79.159608,6.023061,-64.579189,-152.192508,-84.601065,-16.988804,89.68009,97.689763,-12.035931,-107.941597,-222.324077,-186.860697,-159.849097,-121.55333,-111.161175,-107.794919,-111.927143,-105.707917,-69.841404,55.881925,82.979819,38.798115,-34.770307,-40.558366,-78.912156,-119.219831,-114.880083,0.633301,47.03872,118.412838,130.413287,64.147737,25.432932,48.552524,108.540634,228.41119,251.566692,253.414752,295.083082,307.487104,239.004695,167.295614,60.043249,88.480501,141.636886,234.827664,242.696819,230.708585,266.363829,454.307255,545.976702,568.016645,465.245165,402.511009,234.654313,177.382628,201.108623,237.810389,246.901125,182.522045,159.005185,189.391508,246.053529,365.317321,394.677882,401.116237,389.109421,314.476061,185.85963,132.132702,62.168879,46.742471,66.316456,81.211958,61.478297,-9.105622,-30.754415,-3.082584,36.268227,121.398063,127.671349,21.244762,-18.001726,78.128077,212.771537,215.484249,129.443328,80.676485,-18.13904,-62.525383,-101.27441,-96.324829,-60.944437,55.551468,82.075129,36.542454,3.380008,-46.0435,-59.415656,-13.725036,55.420138,45.726725,-5.09459,-1.656729,35.428416,37.914834,35.890416,105.922937,168.04332,210.40255,140.571435,1.857713,27.595106,174.080715,208.453533:42.570816,96.270843,105.277945,95.280246,54.421448,-96.895319,-163.78067,-139.166342,36.31224,105.57328,195.027192,202.511723,122.448366,76.959402,9.960526,-32.301241,-82.156621,-17.848975,17.731401,2.196543,-27.319939,-51.555147,-62.947804,-99.074733,-73.749248,-36.428353,55.935361,83.937317,29.307694,-42.911002,-111.86483,-63.652229,44.174296,24.318693,6.561353,-42.531076,-91.187046,-161.434651,-135.948022,-4.674121,-17.631112,-93.411408,-177.328533,-151.378503,-87.638442,-78.934882,-98.764132,-131.768882,-191.197886,-95.027734,5.887145,105.319476,81.899402,-16.344609,-79.170291,-173.462834,-132.269596,-75.501367,0.502819,-10.752304,-29.235555,0.440182,24.528124,-2.203604,-5.901567,100.114724,152.090197,172.912431,149.695321,124.154591,125.249278,109.557602,56.464527,9.149838,-50.880692,-57.868876,-98.02369,-111.432295,-89.942539,-76.469798,-34.362499,10.033124,-3.341005,-108.838353,-173.437334,-221.414892,-187.419342,-72.798302,-12.565923,-20.187364,-61.060899,-88.533211,-148.0218,-158.765447,-128.098934,-92.875287,-42.625906,-27.052922,-14.294553,-23.055869,-47.498726,-29.272197,26.324196,126.564471,163.093225,143.79707,25.206929,-21.175553,8.365082,37.517176,-19.126093,-58.876125,20.481848,190.347783,209.441164,108.657647,55.889724,1.809148,-42.451372,-174.972276,-245.775425,-233.480646,-171.223658,-165.765179,-174.964077,-173.357186,-199.292896,-188.755731,-24.593609,126.574425,149.741176,97.68433,25.868127,-127.073867,-161.397354,-107.489422,-6.720161,33.800364,66.412779,38.438942,-30.087169,-26.88608,19.714929,38.967075,45.42007,27.068985,25.155354,-27.559976,-101.132897,-236.816713,-248.336228,-191.96278,-152.261816,-142.885657,-94.280136,-62.329025,-49.590252,-73.363955,-147.767921,-165.657422,-74.25347,72.827874,83.419115,20.280168,-5.468963,-17.521585,-5.126005,-5.455229,-116.210668,-136.046051,-19.199983,48.081852,91.231336,79.452278,13.884946,-15.709494,-0.657354,46.452495,69.029719,93.416187,73.410188,-9.578467,-32.330722,37.374127,141.311611,131.605748,0.031864,-65.177471,-88.86278,-68.509689,-19.130985,40.89887,204.055404,216.158542,177.917082,113.257258,80.98306,52.390367,81.345221,178.05623,198.356676,182.85579,159.822938,128.091119,10.980627,-21.856063,47.687351,129.466126,275.780947,308.399301,287.020417,216.557379,184.581031,158.469793,154.974044,115.763817,35.011208,-0.865174,-66.560738,-99.770236,-115.665881,-98.216672,-59.318544,-41.029416,-5.005128,29.103233,88.04536,258.294019,271.477838,133.014321,86.260475,128.379203,84.707525,10.91761,-31.668956,6.290095,67.865876,80.069742,103.280669,129.531312,200.301521,154.87629,102.117909,77.939583,128.583972,249.777375,241.090908,110.880918,99.999542,157.872177,268.704931,273.778056,249.762679,279.481664,368.988573,367.96301,302.677666,327.759172,373.803378,404.814155,370.808326,266.617926,221.376174,159.42868,70.09561,14.924972,-2.806522,27.835884,14.465484,-45.787483,-157.66499,-162.570264,-58.870952,47.063638,43.483741,-67.176555,-139.759218,-194.157539,-162.198574,-73.484174,45.982017,128.868357,201.219974,157.635671,5.389454,-50.64076,-57.092949,-11.719769,71.322469,18.141057,-2.529437,70.670627,88.062833,-32.388192,-100.070026,-108.659499,-91.37319,-104.435817,-96.903283,-88.780408,-73.274759,-45.311247,27.229507,43.702001,-22.498105,-80.446004,-45.593266,-7.016955,-68.344582,-224.307883,-250.253057,-214.875392,-132.664319,-96.988393,-69.631851,-69.741894,-64.642919,-65.11616,-70.183315,-35.310667,99.366915,129.934332,102.307836,55.491763,41.851033,-28.044707,-74.546407,-55.040954,94.597805,143.609569,124.452477,82.87276,76.209272,135.215008,259.471202,257.115503,127.700222,29.956296,13.666073,-11.050763,-15.382033,-11.97528,-23.002395,-23.739888,39.139205,51.470951,29.996061,33.816995,81.612367,87.094502,26.862195,-10.382788,-46.685764,-19.776709,1.436869,-32.859878,-72.614559,-64.173666,-13.098343,71.956239,21.523141,-28.21808,-69.393294,-70.286216,-51.66605,-36.549987,-37.531983,-38.997571,11.395078,92.635083,113.892705,92.358007,56.544175,-35.325152,-66.530498,-85.405183,-116.346394,-115.228177,-66.05082,-62.107656,-98.061238,-91.859075,-77.546204,-121.101663,-210.482194,-107.906307,-40.364536,-65.812265,-132.836653,-185.839545,-144.95951,-20.479516,23.581193,47.002622,151.396648,178.424663,101.207332,32.159772,-23.342854,11.917932:forward
37.691069,-90.352104,-95.745408,-24.41899,25.546657,87.539923,111.487301,215.894337,320.513741,336.243802,256.284937,186.381358,137.712311,157.879863,196.584192,219.368734,248.083444,148.967495,76.732028,15.605813,18.77171,3.611464,2.964768,54.881487,70.857766,57.406843,27.901072,25.301045,83.269105,132.082493,198.789622,197.488176,130.806421,-12.735377,-110.07525,-261.136632,-276.172918,-188.419137,-130.936561,-82.912266,-62.188278,-37.027801,-19.356886,-42.429023,-85.282463,-79.72657,-59.206662,-76.479794,-171.104224,-248.08718,-269.388165,-260.397853,-220.751933,-146.384466,-139.968978,-195.0541,-254.751563,-264.742004,-330.702639,-370.744274,-289.758385,-177.251958,-8.457902,17.427709,3.769595,-37.716988,-40.831044,-8.895949,-8.446031,-109.51402,-163.091147,-126.451803,-30.350801,-32.113155,-105.488421,-108.333108,15.652289,89.610927,157.550749,145.964586,76.488486,0.8228,-57.346693,-165.547483,-148.681297,46.938946,152.311093,197.764796,67.048473,11.169743,-57.24012,-69.2232,-13.608579,45.802005,204.61663,270.310118,229.174214,47.407272,-29.915758,-155.849293,-205.123643,-231.359476,-193.899757,-98.793276,-57.053947,-59.231887,-136.338392,-169.752189,-133.122858,-93.472849,-5.645414,57.713127,143.626677,38.972658,-64.73754,-267.630132,-329.974843,-321.714441,-254.508541,-72.896352,15.431,1.561427,-89.678431,-125.200856,-86.769594,-22.03948,125.526148,183.097182,207.082758,139.698283,115.118689,94.613499,74.973681,8.274342,-37.669248,-130.306185,-140.806473,-129.000664,-161.738586,-194.003992,-191.225205,-133.033228,83.304071,194.997258,261.035391,94.810944,-13.263679,-124.362468,-122.483886,-103.954815,-90.024269,-22.729111,27.382419,31.62284,38.517866,56.720722,111.620952,145.566779,216.418446,206.313599,85.389143,57.033041,57.710468,-42.643175,-98.017854,-71.669824,-16.935224,34.473936,22.232112,15.776153,-9.134387,-16.918772,2.079365,10.127988,30.114166,57.224614,110.091274,88.56204,35.276046,-36.913882,-12.021139,69.626891,91.634905,100.575753,58.973319,36.750199,8.088809,14.489424,110.780601,158.040137,165.829144,162.582259,193.400319,219.036182,217.168168,238.16287,272.227772,336.824554,329.035515,232.232557,197.925615,211.784985,182.175721,129.765989,99.915975,170.06055,348.620289,370.724452,289.071148,255.784912,244.406497,196.338423,209.079052,273.948804,278.825664,232.633047,158.631882,131.472546,85.582817,74.973951,137.176572,189.044471,248.19937,235.199505,123.296437,36.584663,32.046149,25.13986,24.73698,99.218589,149.289265,144.126395,-28.196981,-119.245827,-194.299496,-178.005701,-64.012454,5.722113,58.87168,35.754008,10.008667,38.061663,48.121895,128.601423,181.394975,176.053352,144.467121,153.024007,157.534032,134.736227,150.147095,212.407769,364.22458,408.518792,468.615916,493.595567,449.775797,339.884363,269.163164,93.222496,31.909027,23.507265,74.545702,163.257454,24.638152,-80.941589,-144.067945,-82.927479,152.771539,269.114631,334.427502,273.488228,166.877979,218.206486,218.174208,107.130065,56.683656,18.194642,8.551526,-59.500159,-126.167329,-109.592908,-114.343299,-159.70333,-164.873874,-97.944714,81.248477,138.078475,127.227917,63.724136,15.291403,-78.257991,-61.640272,39.129759,54.385673,-1.248581,-24.690178,-7.850645,-68.345435,-150.533398,-238.844434,-219.167275,-161.034427,-146.518181,-107.630484,-91.679205,-129.987367,-263.489191,-304.320851,-237.916609,-146.566192,11.862783,-4.388962,-75.658857,-243.234173,-287.134876,-226.128598,-148.428426,31.12581,108.521025,151.747097,116.061717,118.170427,152.046343,167.623318,162.682767,155.96964,181.242376,173.242319,148.387038,87.690011,69.056842,138.676608,200.243112,247.001754,239.25663,191.534882,71.47913,2.033539,-78.084919,-70.092798,20.198026,69.973816,66.99977,-61.217976,-110.99657,-162.81624,-173.432833,-128.664597,-84.511362,-12.763798,18.644875,48.158265,4.126568,-27.292156,-63.174318,-46.956233,4.024264,13.47411,28.992716,50.141676,56.974549,30.144772,-7.446251,-99.519757,-147.340225,-182.667757,-160.642528,-120.903885,-138.82726,-184.048522,-322.604859,-355.75442,-272.605637,-197.942488,-147.81857,-231.274618,-252.285157,-213.223454,-168.477529,-75.17654,-47.954028,-23.515928,-14.135271,-50.828469,-127.636896,-137.622822,-105.601317,-56.625568,86.842601,136.046793,172.380303,208.261993,201.096678,51.234199,-53.35082,-120.70875,-62.060973,88.689681,122.212783:-63.108013,-157.267163,-225.03211,-316.707279,-294.765341,-141.047973,-38.152435,136.536862,175.732113,160.198499,85.834591,39.745275,44.410812,94.295344,184.051886,212.700987,207.035839,63.711143,-21.244353,-70.326702,-28.553007,51.24747,42.844821,-46.016773,-47.460236,2.646793,76.328925,79.250093,106.415162,159.778943,222.266975,171.76549,33.852682,-12.523093,-51.193911,-151.121094,-161.223043,-73.334984,-15.833909,8.930308,-12.63108,6.826473,23.888798,-14.812182,-92.59899,-78.880728,-20.439461,-34.068688,-120.922651,-196.139872,-226.346549,-265.042573,-268.982756,-207.961922,-159.040571,-134.357102,-193.085043,-226.474921,-275.626319,-279.297712,-247.865112,-219.495127,-150.262581,-108.879156,-52.749188,-112.721777,-157.127529,-141.946384,-70.405631,31.547529,23.484981,1.412395,-3.290938,-32.000194,-109.242954,-104.172538,40.213175,145.879638,300.348487,306.06715,201.340127,36.272081,-44.37287,-47.035349,55.539458,280.792422,330.26756,308.100884,252.124049,213.163669,93.580788,44.113472,4.189919,39.80582,253.289958,331.042773,227.774152,-16.269484,-119.196992,-268.474978,-288.315939,-201.907353,-146.308812,-113.365745,-102.690921,-93.076789,-103.866309,-104.308069,-76.768409,-65.984029,-10.083413,46.093753,82.061924,-84.296969,-180.8517,-276.299207,-290.370047,-280.760918,-237.114766,-113.452843,-69.007579,-83.345589,-144.058501,-162.851176,-137.494363,-106.908318,-20.336482,36.729688,127.580907,74.867606,-0.719801,-75.902083,-49.840668,18.72158,18.520858,-44.162612,-69.639739,-77.673208,-167.93513,-221.003339,-219.78307,-164.375003,-38.853841,11.828039,69.172682,-16.570073,-113.773226,-225.311685,-198.245667,-80.130218,-25.433279,39.452114,35.809147,25.404523,-8.289368,-20.090072,12.236345,55.238727,192.372056,249.266184,217.164411,85.810842,33.129502,-17.945227,-17.061768,5.906735,33.869451,139.840521,201.363085,167.699423,20.989333,-16.181031,15.275734,43.384582,128.00678,170.768559,159.81347,78.006804,42.588984,34.097422,67.784872,131.866332,137.732963,81.201387,-23.259599,-52.079547,-42.621317,-16.808032,72.779526,125.032983,196.28121,194.487533,110.563223,107.956518,171.812274,343.62858,400.667951,418.980691,386.302095,240.172755,133.962537,167.78379,311.29671,315.964267,172.82476,134.628321,246.742071,312.088551,273.229321,155.011592,132.240981,175.053393,226.317354,292.393087,298.947585,252.51315,60.200616,-41.575448,-109.01129,-55.479659,132.975759,192.954836,233.597795,239.527507,177.821339,87.647627,85.60761,147.944582,185.20832,243.753322,271.193267,301.061959,141.241864,-0.056734,-153.417445,-106.69981,78.427072,135.362304,164.086384,142.134985,51.945362,-25.63059,-47.894659,2.317557,58.958888,115.813757,113.431706,78.111785,18.54443,8.291649,64.431715,142.203586,324.107469,371.025238,396.57984,401.752617,367.086416,249.058525,168.589649,60.018287,64.037947,131.005985,149.985451,118.887043,20.960412,-40.79431,-134.723141,-129.810868,47.212491,181.709896,321.101781,281.661936,147.822272,99.865168,64.407156,-31.19198,-55.636885,-78.636883,-89.141096,-116.93762,-190.06988,-215.616027,-208.529514,-183.763929,-83.78331,-6.128022,118.93063,116.439164,14.986618,-80.185176,-105.484214,-68.541783,-10.287653,65.173964,42.731839,-62.866294,-29.524899,14.693297,-95.385105,-221.149423,-314.341443,-253.669746,-118.605875,-119.704245,-166.964202,-100.940585,-87.731958,-169.572733,-201.166701,-129.135104,-70.317411,-22.147087,-55.395118,-127.851096,-312.810452,-321.307484,-127.032026,-23.109266,87.084723,132.409248,231.411438,218.811996,173.613562,141.118062,161.837327,178.619917,175.907928,180.896671,123.290961,93.900697,105.025846,143.432635,244.976964,290.509362,350.798943,336.709934,219.123455,132.019005,101.799684,-7.239331,-62.90282,-32.855469,41.893499,93.107586,-58.67593,-132.90159,-165.976197,-141.432619,-52.558945,11.419564,129.822405,170.810242,152.165622,-13.892798,-49.157848,53.540751,109.992496,138.46587,138.837743,124.940272,101.986397,90.586993,40.282478,-6.382919,-135.230534,-191.035691,-227.234957,-226.150628,-230.738926,-250.334939,-288.337394,-366.982681,-355.289841,-229.601869,-176.483942,-184.749736,-285.333332,-324.974953,-316.398916,-258.706554,-141.577489,-126.761991,-140.132588,-142.429299,-139.184682,-152.018437,-172.095129,-175.175025,-117.035211,94.695533,186.706828,202.558695,67.831847,19.547091,-16.396394,-31.41939,-50.301252,-21.852258,100.447937,126.381604:-178.17571,-325.469347,-364.878285,-352.970849,-297.752722,-178.017693,-132.662983,-38.453368,0.92822,-9.745906,-8.942671,0.726108,12.650718,45.105499,174.597405,212.880168,133.890597,-9.889396,-38.602173,-37.296354,-52.581869,-93.516243,-68.616226,30.87582,39.082589,15.964115,-3.54587,5.300206,56.563096,107.470839,166.899147,123.448383,4.688986,-37.349967,-71.419106,-162.505306,-199.615007,-183.761022,-121.216095,-41.710872,-84.023861,-82.329523,-57.717217,-88.366809,-135.090678,-78.882554,94.390064,132.512363,84.54143,-72.229634,-149.804783,-199.648947,-169.115126,-19.737463,50.41416,-9.472522,-163.83964,-191.80473,-179.795963,-143.168351,-54.158551,-25.945716,-3.235862,-18.284711,-87.059438,-131.201036,-119.461814,6.669158,69.562017,37.58059,2.461177,59.524265,29.994522,-71.358952,-208.416808,-155.680764,46.827553,100.705925,136.108552,134.437528,59.768261,-71.2637,-130.075531,-103.745697,-6.704938,186.154785,229.028996,216.896748,157.046486,122.683269,45.130991,10.577348,-35.71379,-14.191548,155.811486,208.73525,69.267659,-108.885501,-138.973195,-220.71749,-283.386682,-307.792292,-239.855589,-128.651276,-179.54991,-188.641743,-157.131439,-149.421729,-124.378404,-79.675837,30.833448,32.836443,-54.22277,-106.967421,-136.754571,-209.209977,-231.974675,-247.749132,-237.294715,-169.467304,-79.014599,-50.994221,-77.11477,-113.147722,-166.152076,-175.511463,-115.987928,-55.80551,-13.825693,-101.170397,-107.440387,-38.549806,-28.215555,-1.333681,31.160241,-27.942913,-183.221106,-242.335538,-338.835185,-362.586109,-325.594966,-272.931384,-171.686588,-142.673349,-102.209708,-97.677115,-136.650748,-202.190982,-180.751405,-84.422304,-59.724469,-86.185765,-95.844479,-92.456449,-143.576867,-162.041847,-55.14039,59.509291,262.038409,289.811991,201.832496,107.07951,78.656022,98.299982,152.982807,232.793126,255.071652,324.400761,274.972653,178.557955,-13.805224,-44.394197,42.240504,108.364498,170.25858,151.64848,66.165404,1.826586,-9.098292,86.04469,166.067401,212.219613,178.902176,107.676779,31.606033,-21.552818,-107.730974,-101.615134,34.622805,128.323683,216.450121,179.474382,90.589808,181.236414,238.741145,249.547743,224.22999,252.340259,323.409845,386.99764,243.02165,182.506841,150.318404,120.91306,23.435805,33.804114,178.305916,212.725995,141.328155,38.782945,-5.895608,-5.376032,54.381988,186.096935,234.51137,258.986742,121.501474,29.107175,-48.98516,-3.535792,188.771645,273.249252,335.748058,312.083331,217.706588,182.28958,176.090177,149.331543,162.457077,286.786446,357.739891,344.830135,76.551941,-58.97824,-98.932308,-26.959277,88.01895,112.104775,121.58778,88.382808,-7.275421,-82.948106,-127.177716,-150.791978,-128.00037,-56.706176,-13.766141,-26.8374,-139.929928,-128.707564,-9.980982,30.281043,141.663181,242.449937,404.336695,409.816267,308.299332,159.863208,91.89995,71.662063,108.589378,137.764667,130.04243,90.077072,-54.143788,-123.493117,-131.65557,-67.922041,116.468594,203.517997,267.777332,222.18574,141.65372,172.418488,148.87594,45.801442,25.512855,67.801934,87.15731,-5.384765,-164.345179,-195.574216,-188.468668,-179.589918,-119.825671,-11.957432,233.681036,224.621647,14.36856,-30.258197,-10.82189,-33.171199,-34.32974,65.350101,113.29547,63.894668,-52.057725,-75.478418,-136.597578,-189.700574,-256.487856,-242.235399,-146.773138,-118.989163,-154.671189,-186.487501,-184.234615,-134.726383,-95.50946,-45.119284,-29.466304,6.094182,16.400156,-23.299888,-192.552702,-236.04433,-99.373771,22.585785,168.590549,185.957298,200.095621,207.395464,213.593518,235.809783,222.468022,185.459012,207.923255,267.636179,220.982838,168.170667,92.296956,116.663666,260.605448,313.241877,314.874259,287.838976,256.948065,257.764863,225.855213,81.946564,42.451692,145.120148,215.767514,147.411442,-62.113667,-110.580311,-109.306314,-78.918549,49.112611,124.400405,159.556647,117.733623,46.566347,-13.878035,-39.581973,17.77948,85.449303,204.82043,257.693805,343.497463,306.897772,222.157498,64.392402,36.587032,-43.21979,-120.611933,-194.438955,-171.685783,-139.545482,-300.604537,-406.455992,-397.304163,-296.243523,-143.124655,-139.394289,-237.602623,-333.267344,-361.267854,-357.075938,-302.544413,-157.271828,-101.912031,-56.692864,-91.882837,-203.166367,-187.784198,-148.866005,-68.798501,-19.453156,102.780552,163.247929,216.76295,140.756411,104.018313,105.2882,107.679329,89.525914,109.624593,201.055319,205.777177:-84.103555,-210.554275,-233.997434,-174.493863,-114.590189,-23.648585,12.178588,90.006549,110.309602,102.832382,82.385657,82.367289,125.753157,144.51633,168.624621,194.65951,222.406338,125.715498,52.9072,-52.013588,-74.264099,-75.552974,-40.204299,97.763107,177.233286,180.175553,166.929999,165.829237,204.798933,233.963627,246.951932,219.994193,121.164861,2.468033,-39.119909,-46.342511,-44.163325,-86.912946,-100.323483,-90.300379,-99.248442,-100.299277,-106.877777,-122.989256,-124.89163,-91.260567,6.083423,22.459972,-53.736881,-161.838307,-198.22024,-186.898193,-134.69737,-18.550574,8.10821,-46.057388,-135.431444,-149.253113,-157.833957,-157.475013,-96.582512,-38.70573,52.226241,64.942712,59.644712,42.269373,20.740977,34.184879,76.944499,85.08711,51.475447,30.858757,8.060037,-43.277814,-146.064804,-135.953944,-18.211463,35.144353,83.498821,76.492159,2.878081,-134.745531,-208.612839,-234.040446,-163.947327,19.590892,77.092518,98.559191,70.678068,39.596745,-69.13348,-118.318669,-148.594486,-108.308071,106.351502,210.951112,205.848182,-7.705056,-109.072642,-242.123597,-278.071879,-289.76579,-250.669461,-132.120363,-117.891886,-126.233678,-121.178096,-131.04294,-175.805049,-175.191549,-93.437127,-63.636204,-100.730069,-170.840176,-223.69582,-350.22534,-367.910036,-289.73674,-235.593361,-178.976933,-174.274107,-179.132664,-243.428137,-271.302198,-195.64984,-111.851883,52.955008,119.532003,158.689362,69.082342,44.947323,84.224897,99.249455,48.677932,-5.179493,-119.172901,-170.098133,-174.412615,-258.895663,-338.499392,-368.623468,-274.424009,-39.710828,16.102014,-2.710603,-99.461176,-166.590067,-262.169262,-259.802723,-220.455745,-220.08464,-209.310494,-127.963275,-97.450068,-122.773276,-129.059221,8.477347,112.547741,232.583652,235.437375,183.649841,114.596313,86.291359,100.756912,121.671366,101.723047,98.911428,184.438358,181.270299,109.773267,-3.075553,2.452813,46.090939,39.115794,16.007768,28.45219,79.41652,80.686894,43.195419,-1.038423,15.774345,44.472214,49.62811,29.160832,-91.222693,-138.795791,-83.632047,-0.621019,123.258206,121.998457,68.861729,77.476321,159.133625,201.574738,195.451613,180.333457,187.979301,259.756058,307.522117,279.331043,122.327912,91.255733,93.676431,68.510772,23.043979,58.389033,185.22658,209.010737,149.78797,72.044854,37.910673,25.50284,71.326962,185.236862,225.65308,282.708376,240.323893,163.519681,18.191968,28.327817,212.65431,309.326484,367.634163,324.657695,183.119494,114.252599,130.382841,193.672027,209.207716,230.535693,242.833786,176.899278,-28.387814,-108.10871,-133.366448,-93.314416,-14.21536,-12.611434,-57.834743,-71.975477,-29.267863,27.598706,19.314303,44.101682,99.378163,177.180752,172.262442,71.878077,-71.419602,-79.538576,50.956705,132.235935,229.248216,248.674374,311.273913,348.670125,338.02662,191.682984,79.570997,-66.963206,-51.235823,46.965089,79.330809,86.432974,-13.262513,-76.992425,-97.721795,-35.707811,133.849013,203.654823,304.766179,324.044739,294.891039,245.034054,202.712428,119.294856,120.51704,160.400197,148.899489,45.735576,-33.028269,-27.041507,-22.294379,-49.507935,-45.957339,29.475859,217.382838,245.873281,182.095143,138.219186,110.303737,63.10028,101.273432,227.443347,241.039198,183.965808,148.027483,129.860464,-0.962874,-86.162607,-131.146892,-100.916994,-76.182616,-89.435865,-92.906137,-87.378245,-113.866939,-135.430835,-102.156652,-24.422689,9.160262,84.025353,89.003187,35.911704,-129.135616,-168.562812,-81.927819,-9.765947,117.04156,181.748358,283.456294,288.205725,280.761741,319.024701,340.669161,304.33166,273.004604,282.688982,295.65884,272.540394,179.744041,141.637108,158.140541,179.660098,176.450153,161.604339,128.655112,119.101103,89.066736,-55.498156,-93.423335,23.324178,90.949059,-8.035629,-214.563747,-235.1103,-189.975776,-181.539986,-157.611868,-127.261336,-56.410218,-15.876631,41.434965,35.767733,28.593892,62.701816,112.724135,200.122773,215.528813,262.093316,346.517963,348.674234,231.749972,148.767477,16.753795,-27.793281,-47.164551,-32.270697,-56.586075,-197.219114,-280.630868,-295.218937,-215.348517,-93.34736,-94.741395,-125.584677,-146.941539,-175.115375,-233.769591,-216.95487,-72.419422,-2.738774,40.042242,22.79883,-55.617435,-75.520152,-47.490359,-15.170368,-7.414879,88.513703,155.46133,169.757526,62.367196,32.716285,24.981648,28.610372,51.583259,76.115828,152.799305,169.068484:-99.979273,-204.987936,-238.357027,-221.764118,-172.492054,-48.160091,-0.412466,10.105478,-26.053034,-36.879524,-82.556638,-100.467988,-30.534916,55.039806,199.889853,196.505163,39.857287,-115.114245,-144.713154,-78.647442,-7.414443,69.132178,63.204018,61.631434,123.018991,143.881794,119.828486,112.82743,206.608995,265.047072,232.523537,157.119527,50.805099,-21.151599,-70.76091,-121.395111,-113.842685,-40.802961,10.27933,25.041174,-88.183199,-143.575386,-161.875524,-127.255166,-45.26322,-7.229399,71.222773,86.414942,22.60631,-95.380567,-139.354857,-132.397067,-79.391905,23.83012,20.585337,-92.039464,-160.262261,-167.204298,-176.455436,-153.892825,-74.319272,-50.123298,18.289631,65.578869,66.970917,-24.425929,-26.641212,92.881112,153.33217,146.224887,119.558151,144.445902,96.573479,-4.630337,-189.87831,-191.058754,-64.252278,-0.842828,94.432719,105.093432,9.446785,-183.717038,-287.141887,-297.399344,-178.620836,63.926214,104.788169,52.49909,-40.451789,-83.389074,-124.353592,-105.117216,-47.100822,-2.387903,149.997321,193.613872,132.414704,13.197686,-42.296699,-151.572956,-184.995599,-177.677257,-152.440992,-109.568167,-63.778604,-48.773279,-121.211043,-180.976209,-213.414304,-178.037403,-68.506527,-59.379898,-163.620718,-252.590661,-294.856343,-353.137056,-341.356112,-291.278946,-265.969646,-206.098385,-187.96078,-198.452645,-235.472978,-237.507266,-176.443057,-124.246839,8.278059,61.763121,69.231825,-32.041991,-69.795911,-58.255911,-34.624364,14.048968,25.770282,-41.076855,-142.717194,-182.33941,-297.102619,-345.239795,-308.197222,-231.041981,-88.146027,-75.860492,-158.838314,-228.579488,-245.990599,-251.526502,-236.653229,-175.273011,-132.389671,-92.112045,-113.73679,-137.943746,-237.10894,-255.272636,-111.050165,6.842394,204.87253,263.113071,280.938417,189.005337,117.236754,52.854682,84.52286,175.810894,217.909767,283.618426,218.643026,133.842362,-18.865055,-37.371894,48.035081,109.166218,168.166958,151.872758,61.173363,-23.003512,-36.335916,41.602728,101.641281,162.987419,162.503469,89.654576,-32.541851,-72.037921,-55.219763,-9.442426,70.712378,91.739302,135.382624,161.324441,169.125622,81.485506,37.353147,91.332861,166.954429,261.473007,279.679412,245.009843,100.617986,55.102134,61.589906,53.287854,-30.33652,-31.801828,105.316568,139.497876,18.524621,-101.893056,-110.217583,-57.656913,-13.642073,81.686923,120.266245,138.683384,115.995486,100.55709,40.957658,49.246641,210.478986,308.425971,401.829539,374.85165,265.831157,255.627061,256.771534,237.020309,256.168153,327.13565,340.995127,316.577631,169.589521,47.316886,-105.778455,-94.758607,15.589155,66.509807,90.323207,60.105715,-6.980751,-28.920122,-46.12168,-23.165428,30.376767,116.428229,118.421651,23.403555,-41.046477,-9.945521,62.873965,82.214533,210.853025,324.566611,429.754369,377.665473,206.40356,58.140822,-9.931555,-54.390178,-3.300403,142.01803,172.518725,97.902562,-88.881196,-170.880502,-190.181552,-116.309522,86.281171,165.410815,236.904266,225.566438,173.710996,159.713783,141.479926,98.922238,109.155036,182.653095,186.80717,40.125696,-103.703787,-124.407254,-142.566427,-147.068979,-125.623484,-80.55436,43.738389,60.087472,5.370484,-35.917291,-63.56963,-95.687323,-61.33568,101.937499,168.652009,113.55736,-66.75882,-131.252151,-219.093287,-250.802092,-285.748693,-274.369103,-174.094184,-144.736765,-212.377438,-275.475373,-261.728907,-157.905988,-105.646213,-79.850837,-90.190877,-81.014963,-12.229355,-16.724186,-200.913683,-291.092475,-241.730593,-138.073583,-7.263669,3.667568,77.485058,198.49328,207.108633,155.737075,141.353197,189.10031,228.499637,221.852838,130.765845,73.902162,-46.984215,-52.50249,77.95553,150.060179,190.706012,159.022441,93.266911,42.440646,-28.330414,-179.951683,-170.691821,41.815494,132.627056,40.379722,-188.489138,-236.456521,-254.011751,-259.866705,-190.007049,-97.195646,56.744804,60.12571,-49.314731,-132.441962,-117.808912,-1.122986,76.373451,214.032151,259.082135,304.989439,288.648173,251.832001,139.48658,78.924082,-27.965204,-57.51874,-52.262535,-60.333462,-150.192523,-324.659313,-428.727356,-460.321202,-369.307192,-175.327233,-115.775387,-95.399394,-214.44816,-274.995287,-269.88359,-212.281371,-121.752368,-98.267702,-25.744969,-3.96536,-59.255854,-150.35573,-177.190853,-105.625208,-11.803884,127.756754,150.970482,146.32249,48.039657,1.880342,18.623452,49.986596,64.888059,63.323803,131.575779,167.016197:29.454503,-119.129262,-121.907739,-76.908346,-28.681318,108.238043,150.141206,138.550654,102.90633,100.224839,112.800604,134.054641,189.138263,198.665868,212.507612,232.164061,213.886634,82.697649,38.063458,41.143262,56.765223,70.472459,66.237261,48.744046,34.066175,33.968175,99.296176,166.158546,245.898735,219.792379,149.169532,140.642113,74.723251,-88.216077,-175.83262,-295.684414,-286.849516,-145.894835,-76.546965,-57.248058,-110.468856,-120.600749,-152.706145,-178.378209,-184.207355,-158.681397,-77.112949,-38.284284,-75.683532,-198.917286,-190.918371,-65.233625,-21.823875,-16.039622,-26.560791,-59.910578,-93.777799,-113.735378,-200.650462,-233.822416,-153.926029,-42.310682,181.954364,236.368052,252.27553,215.77339,163.740855,78.422031,66.974547,-22.237546,-83.542534,-52.424403,16.678056,-28.465558,-154.155828,-149.579039,-43.773839,-13.148498,-11.518773,-17.107898,-43.857592,-137.105932,-200.779964,-203.290486,-129.137659,10.506514,42.00258,74.887216,77.135246,41.174436,-69.159029,-95.038219,-41.01944,25.072407,194.168604,263.31439,257.933595,94.221115,6.464333,-107.008194,-110.901775,-49.128812,-22.670854,-61.245365,-120.90498,-85.414166,-37.831916,-97.157239,-256.000852,-268.379822,-131.44418,-48.773134,13.76836,-32.110861,-78.935444,-165.49224,-167.412356,-113.777129,-98.9798,-89.053741,-14.915969,23.319405,-34.667216,-117.584514,-180.962174,-131.856826,45.970914,143.466792,270.148131,263.304801,255.079298,252.159343,209.435419,21.269956,-51.629114,-34.559546,-8.043682,-52.117003,-140.437757,-144.14214,-85.350614,-33.26727,105.768868,164.826258,161.21166,10.637337,-74.623849,-159.242,-151.805168,-112.354653,-87.867995,-12.272716,50.733845,71.700533,93.091948,105.619637,145.488879,153.789592,167.765489,178.715169,140.055102,83.061379,73.141415,35.106836,23.044374,65.845125,99.158141,119.143177,39.408738,-19.976511,-78.191543,-59.423502,32.076621,69.679618,95.690903,99.941003,117.511094,108.939804,80.245975,76.336606,115.66197,136.998167,102.258152,57.79156,83.879319,82.240788,71.057962,101.743622,213.742691,246.913693,244.310292,232.736964,209.191048,182.291413,170.487832,163.278398,166.139499,173.660044,177.053343,140.04036,58.526452,47.313046,48.279178,26.516434,14.086968,54.116302,153.351093,174.782284,187.998849,204.45464,185.930312,155.709724,194.56295,304.277281,324.862607,296.024495,207.157546,161.541731,105.824138,114.918286,228.327731,295.533559,356.459894,340.75991,226.976865,112.16579,87.152885,98.132549,119.989396,137.810413,134.738965,118.126953,-7.836226,-95.023018,-155.461204,-133.06793,-134.945617,-160.759378,-146.369152,-93.457552,40.685009,87.725788,84.210095,201.064246,309.494369,389.824488,346.66657,220.601454,122.742182,101.008479,98.227021,119.049522,232.465918,298.938799,399.765416,432.403668,417.778759,264.985314,149.328456,3.663228,24.218525,113.633763,128.244541,122.919588,70.741832,32.796695,-8.057676,14.73079,157.223383,232.922582,291.272824,274.301995,230.480215,246.32658,235.48833,149.235345,136.880589,200.571342,211.559581,148.203355,98.769106,87.834967,13.982494,-37.905505,-95.166239,-97.591705,-10.96789,69.89685,165.405995,107.409798,34.423067,-73.776373,-59.191675,24.335141,52.534119,88.333362,118.660054,122.13666,-5.813361,-116.608753,-239.45208,-235.887065,-186.290098,-166.921118,-153.403658,-201.409894,-255.543263,-295.357974,-238.753755,-95.86601,-64.77762,-51.040869,-70.690062,-120.826671,-253.803758,-280.095922,-206.264529,-136.937643,-12.931245,29.033213,74.734618,102.260345,118.293473,162.807347,173.961932,135.495188,125.672312,173.219253,188.209326,173.511431,113.966236,64.734078,-22.470899,-28.069309,67.740853,125.742074,103.415044,-67.664772,-155.854563,-263.7927,-248.970307,-88.493536,-21.402859,-97.552092,-315.539574,-349.84539,-270.853419,-240.352142,-247.209025,-248.021398,-191.22923,-146.101468,-67.975965,-10.568561,-13.918508,-75.737919,-77.129718,-2.74491,23.6933,53.446236,109.931868,117.845496,67.848581,45.766234,-25.390213,-104.139342,-192.499046,-156.580629,-72.275702,-125.473003,-195.737006,-307.989966,-302.902703,-196.358457,-157.076927,-164.562249,-179.19253,-160.001685,-69.26601,-23.52954,28.664684,46.505952,89.082295,97.054601,2.590436,-119.138132,-122.867065,-64.174711,-19.395824,108.690901,160.098196,134.379479,30.634742,23.520987,42.575594,22.633188,-18.227886,-10.581021,48.059999,84.250227:-18.285205,-207.845386,-232.427522,-173.725425,-126.285421,-16.157488,60.194219,169.564066,112.775135,59.650766,-33.493011,-39.449443,103.34153,203.998322,309.920124,295.828877,139.72648,-64.779503,-107.387283,-62.851712,-34.330509,2.250709,41.620782,107.787306,92.051914,92.666368,137.036767,168.368685,233.060265,255.953273,266.220798,246.002783,133.459587,-36.174169,-113.454011,-156.078004,-108.745991,26.922529,65.608728,22.622916,-115.60145,-167.285876,-222.596253,-227.350587,-139.529415,-60.006304,66.099786,76.674303,-13.106605,-119.992327,-132.827892,-61.57643,-6.520911,72.448776,83.883629,11.50631,-98.311721,-118.789498,-141.401957,-143.654374,-59.859068,13.987858,139.007167,161.886091,122.738632,91.803362,92.978661,100.703028,113.67961,129.062915,119.812531,74.787264,-28.97564,-115.309424,-279.39393,-276.194009,-84.42502,18.456772,103.898515,74.068298,-79.421754,-243.952179,-316.429726,-299.058191,-185.221839,47.050465,96.19466,74.341899,-19.663784,-73.421133,-172.626678,-187.243514,-108.707018,-23.515464,191.141731,247.932822,151.583362,-37.76753,-104.668834,-158.850689,-144.359981,-70.210069,-34.02641,-11.028827,-59.127044,-97.082401,-205.73074,-241.085031,-206.283774,-165.586438,-82.680665,-58.911666,-103.919735,-211.812671,-252.19577,-247.093949,-208.483465,-129.577066,-98.125665,-77.909872,-130.168099,-174.026037,-254.426525,-241.901769,-78.641725,12.158137,101.032515,110.467401,97.016943,41.333203,8.01817,-47.856144,-60.439687,-7.558112,38.173561,37.879411,-45.201258,-79.812483,-187.91754,-258.857769,-276.721533,-189.384355,9.228015,27.175214,-95.738985,-192.103246,-213.004323,-212.552477,-176.349327,-85.36222,-66.569224,-121.206989,-189.629344,-178.145559,-133.678201,-106.931753,39.436767,135.633894,249.707275,255.547097,206.178419,122.107524,76.126206,57.542204,88.590101,133.467681,153.3015,218.11382,174.743905,107.850835,14.001802,15.044638,76.004012,107.48246,128.387211,112.364852,41.104102,8.540731,10.787375,5.316493,6.503422,74.41305,139.079862,172.361433,21.446306,-25.908741,23.990056,81.430117,180.41638,215.914091,261.789306,254.015829,142.55323,47.764954,55.7102,137.789229,177.197886,258.874169,301.188441,267.441677,118.58914,67.356789,3.711254,-24.235956,-25.092511,31.275043,180.492852,209.869266,164.856272,93.923215,63.205327,22.617119,27.311074,85.802989,119.468989,139.36656,139.979993,139.844789,77.78709,66.769154,216.520021,327.157398,438.615504,430.51021,372.053367,256.119278,175.56342,118.544279,170.712921,320.366138,354.659438,258.989338,55.953163,-19.580347,-93.545178,-102.452453,-76.484196,-43.306813,27.038896,43.615114,63.090854,82.927001,59.280087,32.856357,93.526642,304.042129,365.896939,280.040548,85.425906,44.648375,81.24105,124.018361,244.197661,316.832377,417.231784,416.691393,315.640709,128.649898,13.963935,-108.233362,-54.520188,148.979175,194.469066,124.542814,-6.947705,-71.385822,-156.8145,-123.327018,96.136095,209.807074,315.548495,298.455113,222.582651,182.620957,154.439052,106.466443,110.093605,175.579946,212.299003,182.533336,56.781272,5.327384,-91.452653,-131.244205,-131.809515,-75.516424,111.391739,178.144277,163.568541,23.311138,-71.44042,-196.985888,-161.635128,63.363983,165.250338,195.65882,48.446437,-32.949288,-167.74435,-214.544123,-230.613541,-209.777692,-176.800158,-174.460001,-216.051569,-324.098928,-378.445571,-374.067785,-296.174058,-78.221458,5.74986,59.108579,-0.399593,-77.776666,-324.156429,-416.17852,-383.28172,-297.168582,-119.674233,-50.162646,24.83478,20.417594,-0.211421,-30.573039,-22.626196,66.05164,130.451711,187.38707,104.200665,23.114891,-148.37655,-192.8036,-155.105276,-86.87998,52.787271,63.224493,-45.526425,-181.673838,-256.994301,-352.078592,-305.32441,-70.36899,5.31208,-103.236498,-370.03037,-441.653502,-447.28921,-427.971805,-359.078105,-303.957169,-170.153784,-109.169534,-54.677034,-96.442938,-123.59562,-90.462542,-25.232965,99.428097,145.824301,239.303407,250.479629,185.260345,-11.144845,-71.574953,-81.177977,-72.789201,-53.022778,-34.427051,-33.279406,-180.062874,-285.51357,-341.477606,-261.813777,-72.109955,-32.24032,-63.403231,-156.37141,-194.021984,-210.179628,-177.682884,-55.51913,-6.137251,12.3624,0.328624,-32.739168,-119.300718,-169.276657,-195.195943,-151.826746,42.131202,149.925149,202.129367,2.581143,-104.879898,-205.023675,-195.363919,-85.013911,-18.751709,88.440828,135.654037:66.968428,-22.190998,7.811133,83.681744,114.993547,161.345608,159.339213,89.142086,14.780269,16.583152,34.623603,31.472451,39.230575,53.511303,118.960757,150.137949,105.297728,-0.430446,-29.213843,-57.704363,-69.653486,-96.212174,-98.862726,-58.998651,19.690938,66.676702,111.426325,102.644437,106.07555,113.05727,101.457162,111.56924,134.03977,55.320182,3.80038,-30.270511,-20.590278,-16.538878,-18.726035,-2.465785,55.780078,74.230818,18.070349,-15.085565,-30.528716,-57.531346,-115.770664,-92.817362,8.023295,33.516836,19.454101,13.253586,23.567297,23.525577,14.266903,22.214472,65.37825,54.257592,-57.069345,-98.944628,-24.682018,77.628076,236.744742,248.667862,229.325497,229.94453,195.470918,111.811947,98.846868,19.81694,-49.253244,-110.167671,-154.752093,-200.475882,-239.530123,-213.121979,-111.118402,-57.469695,-2.13,-4.702334,-36.981437,-108.768511,-153.602358,-176.208338,-141.27883,-63.55255,-40.949792,-14.377829,-21.387735,-42.582994,-102.79188,-103.769575,30.961301,133.535737,284.375875,307.253249,254.553401,187.785587,178.013898,162.816388,143.03489,102.552184,98.363332,67.953986,-38.076725,-72.10813,-94.238658,-111.879777,-160.104656,-166.149023,-78.313488,9.665983,151.126019,144.648558,106.674695,63.89805,73.958883,129.031812,156.077598,163.590718,127.767239,105.190627,50.29427,17.220602,-35.061817,-35.861242,34.958117,96.26601,227.965542,328.359414,344.185033,303.000064,248.435189,54.858738,-55.928012,-199.459377,-215.141839,-176.532952,-66.311633,-40.642646,-60.221069,-70.845045,-5.55962,61.862773,133.297861,136.185515,153.289709,166.447039,149.763308,86.971738,63.821069,101.695558,180.812402,209.675114,239.285757,227.402607,167.602043,160.14808,188.167881,170.249786,33.560372,-34.617975,-12.464285,7.836779,-12.427688,-61.092642,-82.601823,-114.357251,-117.886722,-121.890184,-185.910158,-231.74043,-195.748923,-98.124657,80.914409,99.012634,67.996558,139.227249,168.595553,138.683258,137.254843,211.991003,243.464659,255.709912,266.462752,272.537152,237.223117,208.1757,222.873579,260.306057,307.145481,306.466617,284.289333,294.85985,299.498644,236.58222,186.797973,158.018506,183.020674,177.852443,23.170233,-59.156697,-131.500611,-101.031012,51.974778,106.299699,121.889291,138.002059,224.238723,223.974242,169.241482,68.892742,65.676983,135.524828,171.819671,230.256419,276.695057,261.253267,147.026733,113.484108,206.083289,280.299734,335.622828,308.504025,189.761321,134.823777,133.809866,85.781869,62.985528,94.575408,120.097308,46.763506,-185.191286,-268.827328,-279.737161,-248.581137,-239.577764,-272.489966,-302.279881,-249.19941,-55.428541,91.544801,129.487952,181.885803,209.702884,242.781368,228.49279,146.227602,81.172338,67.216916,36.717301,28.68823,53.493154,80.781419,186.247586,239.330669,213.874249,62.468554,8.525657,25.465425,82.983564,174.864646,191.023023,193.004622,114.032004,67.632221,27.730834,22.936665,69.244712,126.93026,201.132131,182.524263,100.630678,118.676581,159.907513,183.098299,146.9364,73.229142,77.262093,106.877055,45.854146,4.895223,-49.853411,-84.205879,-211.490938,-270.433602,-214.518704,-114.24993,9.924377,-39.037288,-102.323711,-207.916341,-189.060966,-51.233181,-6.022283,-3.693081,-40.397684,-77.323625,-200.559848,-258.574441,-308.074891,-301.494321,-251.794384,-224.435847,-214.759583,-296.171156,-342.139808,-310.702634,-236.790714,-153.192816,-154.573045,-157.31355,-233.899745,-263.918981,-201.781646,-167.489573,-190.688357,-191.329453,-81.050559,-34.727998,-65.475112,-97.088552,-90.771275,-141.388483,-192.390015,-243.892969,-218.891074,-115.993392,-113.236109,-147.750869,-203.194898,-213.330342,-196.109382,-179.63982,-162.831372,-155.987053,-136.115189,-173.276786,-242.995211,-388.374963,-387.242853,-253.14193,-201.853362,-214.781253,-267.572336,-268.478632,-262.841263,-280.166351,-308.449231,-301.792494,-255.143664,-220.243042,-173.239116,-192.8757,-226.513172,-271.292745,-235.14236,-98.040334,-62.396999,-82.524166,-112.387148,-119.797236,-133.707088,-120.680205,-95.874239,-114.382897,-122.703656,-90.743924,-53.759587,-27.807629,4.62099,37.945763,18.086052,-28.142137,-19.692549,26.016732,1.56958,-8.81163,47.478885,81.58061,127.185662,154.433621,193.371563,190.464584,120.518308,37.110837,24.950704,5.24769,-27.719742,-85.160707,-71.977325,-5.098169,-26.909419,-65.074825,-133.259918,-148.879924,-109.770888,-72.713701,-33.35755,-15.865206:77.45748,-65.257355,-50.993334,12.292974,51.40314,150.791153,190.252541,221.452554,224.376775,220.012834,160.463648,129.072484,123.29887,117.750094,97.189955,106.5869,127.403549,93.100317,50.726285,-59.537176,-95.515399,-85.647344,-54.278626,7.092192,22.590822,19.172412,10.149953,27.272606,98.710545,100.093263,44.477445,43.478922,108.416526,83.792816,-8.789328,-208.516317,-243.127789,-182.535439,-123.064889,-15.793138,43.984721,48.272435,-8.913425,-59.93568,-144.292417,-153.357207,-99.562208,-65.349669,-75.388266,-148.381187,-159.415348,-133.06417,-129.86811,-161.758131,-162.522837,-123.291879,-142.371725,-182.726189,-313.456174,-374.387785,-313.382758,-172.790576,123.086298,179.907804,87.417685,-49.525829,-82.601496,-116.893302,-145.692072,-226.450652,-234.138521,-147.865118,-107.140713,-141.118346,-242.552256,-259.572257,-158.562526,-71.426129,24.230661,21.595737,18.204499,11.682773,-27.496303,-90.884931,-80.66271,-32.747843,-19.436015,-19.24762,-56.621106,-75.3139,-76.531566,-52.664854,33.099875,82.258395,198.361635,242.928139,225.864821,142.277002,87.81319,18.0627,25.268943,17.041139,-7.538384,-20.608683,-15.622425,-39.50732,-127.917266,-142.894656,-64.028466,-14.633216,49.226804,97.183339,192.036992,110.510601,19.258825,-134.957282,-174.180712,-167.893626,-125.795411,-2.464271,74.290934,81.189056,7.374191,-58.680085,-77.497786,-12.372268,128.577639,162.490521,170.730841,161.486067,149.180673,97.429154,69.914192,-29.392863,-109.671238,-201.158682,-159.549789,-132.27975,-95.706661,-75.319958,-14.508786,17.314533,109.056324,178.472629,289.392743,268.670003,186.786831,-38.47161,-98.04217,-41.151347,38.628975,183.455734,204.791748,189.19385,194.758081,215.478676,231.385692,216.209061,164.164372,130.736,28.215666,-53.995045,-63.625947,-81.227869,-97.201102,-130.599092,-149.193734,-174.805177,-140.446437,-91.23324,-53.390643,-109.405585,-203.270119,-169.597159,-48.706482,-17.056848,27.683713,66.563623,51.091016,-15.322609,-27.666684,28.007476,82.958393,160.114411,135.094538,102.686766,21.394061,-8.680445,53.222445,124.686279,199.817481,191.952403,132.92313,91.598876,89.21532,131.916176,165.434982,200.76117,206.826391,191.390468,138.598261,126.197474,101.854945,75.390446,80.865863,139.139908,284.28744,318.08987,288.01899,254.534219,229.580676,145.221042,137.940543,214.873163,246.736356,226.966171,190.597737,195.557782,158.827576,110.086262,68.896233,82.604487,116.293353,121.340216,55.888509,-63.677592,-106.744512,-155.314037,-160.63818,-111.275507,-62.51641,-33.213707,-220.87918,-322.941089,-366.033153,-324.206662,-196.947796,-145.318174,-102.968037,-82.331694,-4.25423,23.914632,8.902694,46.295212,111.270903,179.971351,158.055129,104.567109,95.545477,108.44821,136.987685,142.394378,167.637381,192.928039,251.871241,277.264962,303.890607,260.142396,183.071364,-4.459665,-47.094538,6.832298,66.460889,123.043722,45.742905,12.781267,-0.396778,0.481719,98.529502,203.590057,332.75129,310.599715,203.87081,151.152985,127.527907,72.158768,77.414925,139.695493,154.557212,93.856792,-24.784813,-41.971239,-26.368259,-44.849211,-100.725387,-90.741316,27.13965,108.498981,211.668847,129.730598,13.498614,-168.222857,-149.97193,-17.712198,16.04261,0.097411,-33.383554,-38.826316,-128.015349,-209.563571,-274.784056,-238.23355,-132.168706,-89.686032,-39.362325,-111.288266,-190.278602,-299.881828,-292.715398,-184.639354,-122.457642,-58.967216,-106.41761,-144.142613,-179.800134,-176.984573,-131.927089,-93.78187,-5.166487,41.978944,90.457729,41.849058,20.510076,71.769104,109.664132,56.542694,1.695864,12.617905,107.29331,125.248382,64.237219,8.789904,-33.507095,9.334045,144.971081,172.016267,110.782469,45.56047,14.743621,-80.49898,-101.064534,-26.909757,26.10179,36.722416,-75.710314,-110.768615,-77.360906,-58.715295,-78.620975,-89.85249,-52.403347,-9.816122,17.5832,-41.002362,-62.547118,-110.528459,-132.842801,-125.009374,-98.989403,-47.583778,-19.828364,8.39943,75.594688,65.033479,-71.415626,-123.460185,-79.539214,-45.475313,-43.547518,19.504707,43.245286,-64.245504,-140.014919,-146.609481,-100.116106,-77.48998,-141.499077,-136.059588,-27.963783,29.397898,97.133614,108.949306,95.697503,94.804736,94.793448,26.948831,-16.937736,-72.059908,-52.804055,77.847584,139.666529,178.627545,181.653291,194.26171,160.029823,102.104388,12.716624,13.039231,86.340335,129.536683:-9.019914,-47.069717,-41.946519,49.849955,130.19424,225.358663,211.509295,139.553106,77.706136,62.349312,64.160856,79.455365,126.441638,145.002431,174.27456,170.96255,67.846181,-47.66519,-43.48099,40.954208,59.568433,24.930425,15.666462,3.180813,-59.533841,-50.529819,87.273517,176.587812,261.031105,236.974062,184.406491,185.150981,142.262232,21.077229,-40.974662,-115.221218,-112.537717,-67.710392,-47.981208,-34.991253,-30.868095,-33.698093,-68.769328,-76.439245,-69.854604,-94.496491,-159.21039,-147.286676,-46.962424,70.236734,123.040231,166.166324,130.546484,-5.311534,-38.921019,-9.289473,34.02086,37.357487,-25.925192,-60.915139,-8.12342,64.100791,167.336553,196.954318,272.652345,292.689373,241.997299,117.304858,84.285953,-14.298316,-80.407776,-133.03418,-129.55507,-146.284028,-198.857033,-198.20233,-110.908576,-63.943088,-6.97406,13.987488,-4.700844,-131.842065,-217.072654,-303.999493,-269.507904,-144.850264,-96.285825,-23.666826,-36.969775,-76.304644,-150.607379,-155.89666,-40.542685,55.466845,185.02747,203.281138,176.602051,69.119377,20.171765,22.15761,52.974826,70.549695,71.863713,137.804485,136.304749,62.474698,-87.293882,-121.370168,-161.095359,-177.695006,-137.417933,-76.21644,42.142649,40.262952,-22.470805,-137.198667,-128.66399,-17.100201,31.298711,32.003006,-42.239566,-61.754437,-46.105864,-40.259646,-71.95932,-65.513642,64.190092,126.929768,126.421419,112.406482,131.959281,136.004108,98.67567,-37.955633,-93.615876,-103.258532,-68.658636,-42.988919,8.579543,-0.627748,-92.095363,-148.000997,-182.725171,-139.148956,-20.489786,-16.777744,-38.892001,-24.828281,3.159678,29.375499,18.842813,-13.977798,25.696195,63.528269,66.375869,51.914105,97.819951,137.794937,162.993496,136.742789,85.747848,131.097897,127.049867,25.845042,-1.31896,30.471207,54.810573,70.583435,15.738014,-20.477768,-82.371336,-90.294512,-27.858084,11.886559,48.058451,44.436647,50.363487,132.966968,142.869784,93.84308,92.79913,106.804798,110.078595,132.320716,101.272921,81.515768,52.205961,47.443759,138.614382,224.874763,346.976939,345.247925,237.14002,139.729031,135.466222,163.999656,175.917226,215.004395,229.909497,180.80031,68.961835,29.372516,-33.385833,-52.297623,-5.817366,38.777433,119.252115,160.378464,213.755036,204.09296,176.92781,84.019199,44.274445,60.291607,109.153307,192.151253,242.800588,242.297356,133.548945,91.234477,163.984201,219.615009,271.451669,296.746227,335.020218,278.711587,224.793854,166.635108,193.45279,257.500379,225.281418,60.431116,-24.393176,-36.130648,-119.01091,-174.07674,-214.424899,-216.387046,-193.315798,-134.427425,36.984608,89.825254,59.907727,61.211608,139.276202,317.029795,331.505708,208.447704,91.485595,77.899425,69.940451,43.626685,31.957004,88.045834,292.422317,370.898162,292.802172,74.600295,11.207773,-43.063812,-22.624611,129.128006,206.985752,208.433204,14.792697,-66.764966,-64.197269,-3.687914,140.539401,202.584546,245.926094,224.307333,180.938886,187.57957,178.791877,133.972493,128.097295,161.896421,182.989971,177.324123,87.45743,53.289833,-22.30693,-102.618756,-221.609188,-195.495457,-33.198032,34.779509,53.026574,-25.873325,-67.999292,-90.185557,-39.243346,122.747556,162.154161,119.117479,35.619782,-10.005745,-147.763274,-229.502999,-314.808858,-302.759102,-214.997822,-167.683857,-168.255024,-279.45897,-324.672397,-295.076003,-216.184056,-57.708492,-19.622305,12.285356,10.314114,-27.208499,-143.678847,-189.443315,-210.32599,-182.889831,-74.741203,-26.944964,2.285543,22.247353,26.165825,-15.145255,-31.809191,-14.291519,14.517455,101.156568,80.57319,-4.152737,-140.418457,-136.019299,-72.066871,-58.826279,-23.960037,13.147175,14.91008,-151.600128,-248.830009,-320.524681,-274.18961,-121.921934,-64.655837,-58.23955,-233.948928,-334.209453,-426.009348,-405.07099,-264.822051,-187.873117,-86.995618,-47.38682,4.109824,-46.52646,-91.963024,-97.498341,-35.547165,94.618676,109.164065,114.886714,148.328404,127.819813,19.982626,-29.181054,-106.52865,-141.178518,-135.17421,-94.729281,-53.528609,-85.15088,-98.301613,-105.827568,-105.500955,-88.146325,-64.753417,-9.368507,13.550941,19.542308,1.673392,-27.217741,-32.887978,2.105964,56.513852,56.242109,1.421286,-64.391308,-82.527852,-105.227003,-93.301434,0.709039,45.086957,44.858668,-36.353229,-75.792256,-124.386203,-143.464661,-150.139994,-113.26199,31.776736,94.939818:forward
-9.195722,101.370445,154.860065,192.527912,182.634681,98.432351,28.350798,-54.659591,71.602437,151.346479,129.918163,47.243871,-101.600973,-132.030475,-121.792554,-114.407162,-108.445593,-130.077606,-172.396832,-246.079638,-239.223655,-149.762085,-105.9665,-80.048625,-61.84945,-33.193847,23.577759,30.681766,-9.095398,-42.1888,-101.633357,-120.223636,-88.670646,22.470562,65.918328,70.580177,43.122771,6.184782,-3.002681,-39.416037,-72.500117,-84.82659,-72.871738,-50.615144,-51.026665,-66.244592,-61.865691,-45.384345,-3.43621,48.321044,63.992587,52.880419,39.767091,35.274546,31.091289,-0.562366,87.922233,214.409309,424.689606,401.935936,168.533996,64.747513,-62.707235,-106.931644,-140.354142,-150.673001,-171.568655,-231.74848,-251.116979,-250.010178,-236.863502,-159.075761,-13.51222,35.889636,7.173942,-67.509285,-223.798291,-248.692549,-240.180937,-251.777484,-265.840978,-179.119211,-104.784224,-27.966932,-36.623529,-28.871803,-17.140208,-44.630311,-10.501132,60.168624,229.05997,295.753386,313.070352,252.923447,99.988524,61.128271,92.027287,153.221451,165.483199,176.074377,177.65278,131.064907,69.769814,-60.919133,-100.464092,-103.515151,-113.515862,-102.723653,-25.644061,6.120685,-63.59527,-134.456673,-166.531967,-85.274497,-20.85084,135.298369,183.615411,162.679069,94.507102,-49.085832,-1.694247,82.063279,218.771409,209.797211,35.274522,-55.755323,-171.465371,-207.791241,-140.136744,130.956492,251.884785,331.515481,301.259555,189.073422,136.338429,108.065715,164.577851,177.003869,137.109312,71.942722,-113.711588,-161.381891,-108.350339,-55.383266,47.221561,117.737968,128.641421,131.483187,116.692699,38.769184,-11.32005,-80.054897,-58.063201,-27.895802,14.645663,11.330599,-51.008361,-99.441268,-238.150061,-308.297324,-333.322937,-266.329056,-250.018824,-243.670354,-228.645479,-206.580137,-247.434969,-391.841191,-356.819792,-247.945949,0.268844,61.940738,13.632094,-32.045808,-78.188083,-99.294263,-92.726951,7.476961,33.800864,-10.15375,-39.239553,-65.722734,-102.470338,-182.137992,-60.309296,42.378832,189.692372,208.411299,99.609928,19.396087,-72.430052,-79.060359,-38.760936,-30.861787,-46.70517,-88.80867,-126.59411,-219.34069,-253.766185,-239.340072,-78.068956,-11.610315,-25.222853,-66.050814,-87.446832,-93.386881,-207.692561,-285.148529,-321.953446,-238.061695,-208.224205,-169.897776,-156.874048,-181.602422,-215.493869,-264.123024,-274.997667,-281.22522,-226.784159,-163.914114,-128.039318,-190.982678,-361.822592,-390.201631,-321.339494,-259.357715,-222.21884,-123.316271,-92.051873,-47.229386,-22.050222,-34.797171,-85.148094,-51.472454,121.844954,182.206516,136.044481,65.511838,-76.59589,-129.052631,-92.208876,92.293595,143.111921,43.185154,-55.371626,-177.818227,-204.197332,-187.658893,-92.753814,-66.656036,-81.08439,-104.799611,-157.480814,-173.876902,-165.663794,-150.8911,-130.09406,-136.898803,-136.232018,-72.194256,-18.461709,22.012339,-26.402292,-173.272275,-191.137206,-174.941007,-161.043609,-155.82123,-188.330248,-223.330211,-252.387646,-231.919226,-134.859497,-40.62121,-23.812121,-40.977633,-52.705717,-60.324372,-67.194747,-87.736639,-30.078438,5.932249,-1.269116,-12.407246,42.784286,82.237793,88.580447,77.209744,101.528146,148.518209,176.621424,228.439954,219.403753,125.674256,67.538738,-17.897438,33.569277,119.084312,248.341274,218.346905,42.485403,-17.573824,-65.482145,-86.527095,-123.906749,-89.294,-17.142095,110.514627,78.217147,-126.16425,-202.192305,-180.433387,-12.428205,56.361446,112.76515,112.373196,106.285594,133.029814,189.670084,139.907058,-76.618698,-74.0019,-4.987824,35.545483,25.165025,50.154865,47.065165,-17.496885,37.282829,108.417637,223.835416,229.527259,114.100112,51.21128,-0.676286,-14.219405,-16.051703,-11.282629,-50.154304,-238.664533,-330.250231,-322.053798,-253.011783,-190.700586,-185.110257,-125.340126,85.754342,158.940553,145.566348,95.428459,-44.731468,-129.727218,-220.10291,-219.797659,-218.301411,-170.592504,-142.543141,-127.227538,-114.471678,-21.370034,89.936488,101.087188,36.499088,-2.327709,-23.131238,-11.396507,-9.053912,-9.694248,50.206074,105.758352,107.928239,87.512449,77.148373,65.543394,42.896035,-17.297218,49.050134,95.618882,134.435503,139.131544,77.651294,28.040097,-27.185616,-37.64743,-37.642853,-89.005003,-138.025459,-154.056592,-110.687104,-18.883384,-10.380265,-61.095449,-41.975818,20.853483,134.191229,137.864923,94.509578,84.851346,79.579149,78.112783:66.526016,254.394606,362.364673,365.488302,251.367061,51.104466,8.310563,-66.103463,-40.539858,28.845214,91.523627,43.786456,-144.719317,-221.099762,-249.531494,-232.142396,-201.107654,-164.510867,-147.120567,-202.992564,-277.138206,-337.534963,-289.390734,-139.06364,-33.639784,1.706724,44.61025,44.902183,22.411436,-0.778316,-78.876773,-95.744751,-37.355391,96.035078,160.28398,150.904721,80.29431,-37.395847,-67.60933,-82.487629,-24.513932,-0.671466,-20.977394,-60.681739,-152.047981,-177.985854,-143.483946,-83.979777,59.08792,151.233309,170.447892,148.816848,112.384274,63.142691,67.977298,110.993753,232.105386,336.894778,442.580222,354.715943,25.575961,-88.966079,-155.933155,-150.045161,-130.061837,-152.12477,-172.85719,-193.306404,-175.89294,-155.052706,-159.870634,-79.92436,43.545237,59.152686,51.444429,28.080372,-89.91439,-145.598001,-171.9426,-146.987077,-72.968683,-24.86308,-5.194655,-23.80836,-49.647517,-28.723318,-8.310405,-17.586617,26.600403,91.208843,193.86115,198.414996,170.080696,150.053885,67.062203,30.068145,45.77476,117.823766,145.781664,185.071623,172.092689,44.667208,-32.217008,-157.296353,-174.361705,-106.220304,30.547726,7.640981,-156.581959,-219.968539,-268.253897,-234.291806,-33.735917,93.695875,99.09822,113.633593,114.109446,3.583137,-72.604904,-79.216054,90.900587,178.822982,244.910959,192.540258,-7.387534,-91.952788,-211.940119,-252.687846,-200.125326,27.830208,130.737822,203.061502,184.084652,67.575448,-27.891641,-128.43595,38.718539,103.881711,-4.288272,-119.126674,-288.888281,-334.137706,-330.073634,-267.811818,-81.893824,73.626021,122.462859,93.00201,3.884152,-199.851956,-258.155132,-236.838722,-98.668237,-27.52931,29.375172,4.744251,-86.803674,-136.385189,-244.824728,-283.860457,-271.171169,-247.090501,-251.165728,-253.317882,-268.836894,-343.10162,-381.462522,-408.578935,-298.351947,-201.287537,-54.016809,-42.629745,-122.05545,-183.170481,-287.84601,-290.580637,-143.470556,47.058879,84.203131,42.537835,3.235664,-101.158533,-176.549607,-237.912739,-50.974191,59.321253,173.782265,173.843334,73.745595,1.905377,-119.080221,-162.126158,-154.485259,-14.685855,31.123473,-8.671466,-55.144813,-150.080099,-208.713096,-244.078307,-89.710863,-28.107711,-54.436436,-105.050587,-165.297309,-192.269364,-295.388138,-321.402745,-252.780876,-164.955475,-137.565238,-91.642875,-105.705218,-252.909532,-330.22286,-351.412603,-220.932165,-146.706234,-47.184604,-33.00416,-128.02362,-236.417728,-436.787698,-455.439316,-331.615214,-255.211079,-256.505092,-215.958212,-151.22323,10.766745,38.83414,-90.626614,-181.016643,-111.977635,119.258429,169.093572,27.004873,-96.950796,-198.523905,-155.469566,-37.790697,32.445128,57.474761,-13.274736,-104.151601,-243.803355,-269.267402,-220.018304,-99.36917,-63.822127,-51.791312,-56.799114,-55.134006,-56.734791,-111.296604,-147.663901,-160.841016,-78.515004,-10.355961,128.327718,169.48622,144.712262,82.607002,-42.325102,-57.893435,-47.873142,-40.470907,-45.276657,-87.58362,-114.883121,-149.756728,-143.069223,-71.428948,-11.221386,29.494452,138.723071,144.368205,17.558266,-45.933013,-26.232752,86.907005,115.329845,127.923007,128.586265,119.526175,108.423246,93.737063,117.331267,212.445192,193.38782,153.218313,131.679696,116.091804,7.337655,-48.628858,-80.542773,-4.773678,54.027253,144.741985,144.474489,33.087025,-41.835894,-148.296438,-176.430917,-179.76764,-57.158583,40.737214,127.999158,82.151067,-36.214766,-53.452883,-26.1371,-4.477731,-0.451421,77.378519,154.247132,289.378921,329.519868,306.985594,210.914707,-42.597225,-29.168458,45.80369,55.49191,3.532172,-39.12769,-43.622192,-80.018003,19.819685,130.501709,243.733991,198.330912,17.838839,-62.062288,-134.803513,-120.127703,-75.07693,-169.87239,-256.271039,-408.031793,-441.925269,-372.076434,-313.886028,-282.974136,-253.65952,-163.491886,114.787963,201.907888,138.349602,40.941568,-115.39793,-148.356068,-139.80539,-87.753451,-58.392076,-41.326405,-74.700109,-163.860499,-172.723438,-87.845228,18.65983,44.028617,50.873793,39.620119,17.516284,21.530551,46.854653,51.443208,70.81441,155.617239,208.737852,224.322095,176.288067,79.29719,46.576514,34.844771,117.639734,136.459401,126.605347,135.392501,108.133608,43.800569,-78.571837,-91.61993,-30.563939,-28.58472,-73.357535,-108.882598,-75.231872,3.183307,16.825537,23.115153,66.189298,124.070208,253.95992,266.534997,188.851881,134.336972,29.811078,11.905367:135.924376,266.830021,355.654132,409.104178,329.688503,84.049678,5.241753,-18.901146,35.386879,59.126541,8.176145,-81.697328,-271.297082,-327.578664,-413.473003,-440.065987,-341.772076,-159.089173,-134.264852,-234.935444,-304.235898,-314.230034,-250.069104,-107.595651,-40.920828,-16.596657,69.007541,109.042045,104.344187,49.980429,-95.223854,-132.06754,-67.538216,115.211598,178.1207,122.289562,43.173986,-44.974115,-44.485244,-11.21938,40.502241,66.176115,57.510183,14.937117,-106.290975,-173.664284,-250.047379,-222.256202,-59.076445,57.405709,56.53064,13.336519,8.424558,13.088255,0.57507,-21.471295,100.200466,211.822416,312.490998,250.653153,43.874389,-22.544951,-31.014286,-0.231204,-13.873148,-114.433165,-119.224539,-84.100569,-98.748116,-208.714847,-246.721229,-129.262739,72.17807,114.892441,127.988965,87.937866,-56.924797,-95.898595,-111.782281,-120.65844,-110.414366,-93.574309,-92.539077,-70.763583,-47.61106,-22.996063,-36.255178,-45.677102,45.733895,106.4846,182.569393,195.744499,216.396661,209.056698,114.088852,76.550691,123.149997,140.404462,72.10101,-83.946575,-100.744482,-94.526714,-153.210169,-312.768097,-192.068842,-57.93501,96.963146,82.779093,-38.355281,-106.653308,-240.43292,-266.138279,-133.314169,109.168523,199.305226,239.999369,195.164697,27.86195,-61.115685,-120.324146,30.358875,123.558514,173.911073,105.246534,-104.91689,-165.999834,-177.194686,-176.014124,-148.557557,-16.645292,69.686646,204.444762,200.042754,-5.997501,-133.314451,-220.370266,-81.540313,-3.592654,-26.641182,-117.880063,-278.5527,-312.878952,-297.12717,-256.0184,-114.693549,-7.787915,-28.569399,-123.719155,-127.486929,-99.638583,-129.242566,-179.707053,-71.164337,-17.490638,-3.503836,-32.749536,-114.508499,-166.106381,-302.146389,-351.446263,-338.527282,-290.33036,-279.527025,-252.07142,-262.805152,-326.507876,-330.721215,-264.863229,-139.404805,-80.879131,-31.296496,-30.257087,-51.452209,-107.858214,-323.656538,-386.404475,-203.135793,130.001157,180.580819,74.336998,29.49964,-5.399007,-56.558768,-159.659855,-85.142937,-1.830509,125.337237,116.307415,-55.889869,-149.449048,-218.783698,-196.660926,-79.26196,60.772565,111.249356,130.052193,92.079798,-39.662779,-101.062613,-125.882937,-69.351222,-62.049621,-88.822802,-100.97986,-98.444205,-106.603224,-179.791543,-215.641083,-226.621073,-132.92904,-66.317593,-43.238266,-115.57849,-287.874052,-328.731838,-316.021473,-211.324406,-133.502942,-15.947359,-21.808435,-160.034045,-250.617132,-409.946684,-454.718104,-381.780151,-229.743579,-190.345499,-106.653026,-57.276841,-68.099285,-138.899848,-234.683317,-97.654584,17.708026,175.513323,165.864489,-25.787669,-121.937088,-130.793197,-81.932204,-29.799579,56.137293,100.962076,30.162811,-51.77916,-146.02634,-160.127042,-129.590918,-11.555603,39.260701,41.225521,3.719699,-50.145348,-47.497533,-33.797146,-40.751029,-56.416921,25.910792,115.478747,221.569956,194.691555,86.925815,48.412052,19.139241,33.45343,36.418524,34.581862,26.202749,-22.388068,-37.421451,-19.15457,-1.461088,14.616949,40.81411,91.660078,193.082348,191.281431,85.250427,22.545709,2.070367,113.280776,165.691718,196.244192,166.60687,67.134813,53.244988,127.305864,170.118865,218.168691,200.063677,173.730566,143.073458,123.744207,18.244733,-52.336795,-107.548577,-17.753017,32.998926,111.783318,146.817346,129.988396,59.603639,-126.343952,-204.2212,-212.444595,-17.996871,52.500542,28.716108,-12.579887,-93.308479,-148.17569,-190.006966,-74.381383,-3.218163,107.413382,144.377222,192.889917,215.480264,217.997629,171.458024,1.372191,-71.69519,-49.093234,-48.578761,-66.004962,-43.702571,-53.282957,-142.789902,-67.651085,18.736424,47.813098,-35.476986,-213.393348,-255.759664,-303.093977,-308.241497,-270.470724,-274.507507,-315.687459,-472.704805,-532.35414,-470.093338,-386.478467,-270.114802,-231.061903,-196.113774,-74.813241,-19.913461,43.605269,36.344015,-97.601456,-176.885024,-205.980726,-70.244361,2.945819,20.982657,-31.875596,-139.832263,-150.829455,-64.083927,-1.678154,-3.515849,65.080586,127.228583,163.510146,125.333486,19.904704,-4.724456,67.475146,238.015456,291.610945,252.646941,193.628606,86.961432,34.788572,-28.113892,29.743379,65.376409,66.261238,41.522475,-11.787158,-30.156935,-52.189088,-65.169502,-59.590882,-6.598702,18.226392,68.687596,87.131016,50.690463,12.985399,30.462164,113.839915,146.878334,208.155403,228.004116,221.58315,179.423376,30.366797,-24.91636:52.99549,155.013188,256.155452,381.114784,343.304533,125.46042,32.200339,20.730873,104.390672,105.480292,44.751435,-2.513801,-152.632699,-223.881268,-283.634054,-286.175671,-263.704468,-237.144151,-239.015993,-247.257258,-234.267116,-161.71781,-132.953238,-128.594432,-79.223486,-33.813708,30.843604,47.742777,43.761975,21.395441,-60.635841,-107.483544,-84.133606,87.124555,127.110939,36.041687,-32.617045,-98.641768,-124.432018,-187.668089,-171.257488,-150.090164,-116.560496,-104.596477,-135.477093,-174.011941,-203.676688,-164.916182,-15.975533,59.931942,45.77607,-45.097865,-91.590083,-120.394419,-113.209687,-85.309038,57.035156,192.222379,420.569653,411.638328,169.122484,54.631505,-9.625406,8.762033,15.955055,-101.24936,-163.678498,-195.69508,-180.477874,-163.022112,-164.465823,-123.654885,-48.121126,-42.588172,-79.049115,-119.161627,-224.766675,-254.445612,-258.259864,-237.592671,-126.950184,-35.054854,-21.810746,22.376137,62.248651,96.732311,81.336621,98.566089,201.60367,236.618588,276.902702,297.965965,316.202786,294.567305,219.233728,179.521446,93.88035,39.978316,40.097579,70.495052,67.118891,-15.089289,-67.797089,-117.301319,-68.10734,-23.518585,37.637802,26.012157,-65.281757,-113.544462,-193.622323,-219.073441,-186.485941,-65.594873,15.404769,184.752301,223.168908,147.397318,70.322426,-28.733698,14.087553,78.229502,211.869711,220.749913,59.292775,-55.323558,-208.484411,-230.304962,-174.956756,-33.325758,63.455146,224.623764,231.277635,112.084945,45.16255,-14.987933,40.058761,70.55747,48.020937,7.808354,-76.00083,-103.645614,-104.214519,-68.514921,64.115002,142.686116,127.949509,64.886111,38.816641,-17.96885,-45.733862,-57.968232,13.933772,50.489378,46.920302,9.652576,-84.933232,-121.720785,-224.601692,-307.047956,-406.433937,-333.513746,-288.676333,-272.366785,-282.89784,-313.431581,-341.281907,-362.468073,-232.893818,-131.883018,20.423917,39.162256,-25.855329,-85.294215,-199.13118,-212.599441,-110.64556,16.038283,41.710143,35.8755,30.330503,10.713611,-31.11991,-131.778172,-69.060293,31.883354,244.506523,278.387593,160.282651,83.292943,2.508221,-1.623148,67.758741,128.446755,119.051999,44.921698,-0.334499,-53.262619,-64.556751,-88.871402,-67.129404,-37.834705,23.58246,35.5066,3.487222,-26.70708,-131.203423,-205.152873,-292.192039,-179.055302,-82.235306,-1.115471,-37.879955,-119.198421,-118.622456,-84.528628,-99.126144,-112.576964,-78.210943,-46.775731,-104.651465,-200.836979,-369.988606,-385.368609,-294.656036,-196.460537,-139.675661,-4.399472,40.92143,51.521876,3.746068,-133.760464,-116.408808,-26.031793,192.419128,231.541271,106.081131,15.161005,-83.271045,-91.728575,-45.786677,45.182297,82.910517,59.264275,-11.687621,-183.714577,-234.819779,-201.930646,-102.675981,-69.286911,-57.623463,-84.833524,-114.552007,-87.654321,-34.778941,-40.290948,-66.985416,-0.70469,71.055498,187.197533,190.541871,102.412913,45.535977,-22.437135,-28.891494,-33.686058,-1.983991,32.444875,30.326384,5.550222,-21.435042,-28.907264,-20.020623,59.928716,135.766516,240.14024,199.365218,-5.160693,-69.220178,11.914735,142.423421,131.643396,69.669715,79.384951,147.404234,174.168634,156.228301,111.639242,69.279237,128.844404,164.099694,215.818006,212.083836,150.589308,117.375031,74.990526,149.95127,227.978919,303.14859,259.754419,74.530454,-22.575842,-186.79618,-249.798358,-267.162609,-124.61054,-51.526538,-1.715098,-22.389466,-129.193819,-195.699542,-206.961379,-61.886088,-18.829651,9.017082,33.031834,103.991498,139.262568,135.59035,69.278367,-103.743662,-142.430956,-111.475988,-50.127413,-37.025466,-39.840385,-80.055733,-211.971666,-196.719315,-136.472223,-48.170062,-48.720542,-112.254955,-150.398216,-231.028368,-255.695831,-206.881168,-183.483202,-237.798079,-399.074212,-447.577616,-422.855759,-386.490249,-336.901665,-259.54734,-179.182413,23.976208,80.250967,57.652139,17.96164,-94.739052,-160.510016,-229.173703,-191.265348,-156.758154,-116.146962,-126.654582,-173.735593,-177.125693,-122.652212,-26.023598,18.813328,58.102935,47.392185,32.399356,53.266138,79.108518,61.263441,72.258415,175.041006,203.530496,179.514459,160.62884,125.519219,86.281552,13.994578,43.262431,74.765861,144.25274,168.8666,141.015099,112.220924,77.135331,55.954978,22.414835,-5.348372,-29.441821,-6.932054,46.681575,103.718168,86.456521,95.227365,162.856469,180.323977,230.252635,252.474323,227.569791,192.894821,81.501972,13.246468:43.611256,189.8285,276.008758,343.343098,294.708288,80.151961,-21.364,-53.465073,62.294473,81.364196,-13.010406,-83.934793,-199.984664,-262.90379,-404.285361,-439.247991,-353.921445,-178.504597,-140.939037,-183.889171,-211.587359,-212.657647,-207.433485,-181.459461,-66.687172,-7.592578,57.890156,88.408242,138.589612,104.994687,-91.591923,-171.947254,-148.379392,55.486171,143.989066,106.33584,-7.264665,-188.184747,-199.683969,-112.486217,-52.231478,-63.028572,-79.591882,-80.398798,-158.531637,-232.103525,-321.093383,-306.341478,-218.405792,-120.958627,-60.345334,3.296068,-19.774033,-111.426572,-148.190926,-145.900203,21.606693,156.671256,356.07196,341.272007,137.760765,48.960188,1.002125,14.080707,31.320662,5.727822,-6.137514,-63.639912,-133.455533,-273.05387,-275.118284,-124.547059,-56.028046,-79.823697,-54.947484,-25.458879,-96.148657,-172.172937,-232.98884,-208.652552,-145.35611,-107.899577,-84.969287,-16.297143,23.605982,47.07247,14.069701,-12.582457,135.444721,240.608738,384.601364,389.56532,293.18549,225.838396,128.338561,112.190257,100.273896,59.425671,36.123921,13.843255,14.427907,-24.78343,-88.782642,-218.268969,-130.896306,-5.565746,194.104368,193.991505,42.108322,-40.025874,-137.562112,-149.225218,-88.20853,86.982726,171.77075,215.98202,187.082044,72.950282,-3.199123,-90.527871,-33.989196,24.66576,133.647554,147.196823,94.887448,53.368519,-58.106887,-100.851596,-68.585729,79.019803,156.400791,197.022714,141.492363,-30.284629,-106.216325,-157.440412,-54.682225,-7.400762,-15.289508,-42.163491,-78.412783,-100.220467,-134.419181,-108.940161,33.551245,107.070774,94.880659,79.641946,74.485751,0.68502,-48.366374,-41.515607,77.938629,105.639894,32.675865,-40.80689,-141.016589,-164.620934,-282.228109,-363.035181,-390.795974,-277.221033,-244.409306,-275.007753,-307.707022,-345.579416,-346.014131,-303.888355,-206.701236,-140.054009,-9.276619,36.658255,63.500342,15.380621,-181.701705,-240.912033,-135.335177,77.572268,124.739128,97.611964,63.934119,-35.006889,-113.356527,-210.75189,-69.724616,53.170974,217.622481,209.199163,67.672887,-15.999078,-110.364323,-83.377836,59.44768,130.804741,139.063261,108.425335,55.798223,-76.666333,-124.947523,-150.093302,-37.522639,48.7911,106.435295,56.475249,-46.741132,-59.633837,-71.726277,-91.175238,-143.61819,-63.152481,33.906507,79.483575,-12.973279,-241.406763,-306.401252,-276.488398,-143.792839,-79.514688,46.981751,48.153913,-167.693828,-300.384868,-459.669803,-496.515551,-424.020511,-154.02027,-35.611203,12.708959,-29.519511,-116.080442,-153.04744,-203.774787,-135.528121,-53.861728,89.295536,91.916869,-37.452073,-111.730761,-191.260691,-186.657154,-102.80156,29.834762,91.279195,107.353139,39.842206,-165.653515,-247.59506,-260.492469,-98.9649,-20.359496,14.993772,-22.605879,-93.491546,-117.034955,-199.905569,-226.649222,-127.88937,78.42517,169.996694,240.09436,195.760336,55.515434,5.817643,-38.426738,-23.978622,17.926472,169.909712,209.422276,138.112829,86.124652,10.648464,-15.757643,3.077183,157.239376,250.75738,285.589442,205.234612,21.085715,-13.518652,42.798554,129.155949,157.655335,195.590174,195.257743,178.29453,169.438297,107.016981,69.996538,101.968039,256.029075,317.89888,306.584733,241.226733,119.408543,93.693202,97.18024,157.70901,211.29841,320.249325,332.028262,194.459242,71.667382,-149.258459,-206.609404,-155.701565,50.179002,123.037773,107.43213,47.169664,-102.713282,-164.252182,-173.4648,-45.482567,18.799525,83.181683,88.949817,84.133274,81.649761,41.000792,3.137662,-53.314612,-69.792489,-69.344242,-46.118179,-27.066482,-24.31694,-64.672803,-171.234563,-175.191994,-125.951775,-19.174233,-20.916023,-117.618468,-173.850617,-286.152545,-323.463729,-314.498218,-279.723249,-280.765561,-345.537216,-393.080303,-447.898906,-447.694706,-334.764245,-135.923324,-62.078515,39.621684,74.716294,118.285226,107.115102,-49.440439,-155.274143,-225.760281,-109.854406,-57.519969,-64.178797,-123.747261,-266.188881,-281.112308,-149.308652,5.02756,45.52157,94.862312,115.056507,123.202501,95.976617,-9.736214,-47.455703,6.060202,210.464672,306.546314,341.925347,288.317366,123.711506,24.422474,-122.361751,-82.816131,-13.98487,108.213314,113.768138,8.867131,-38.901148,-38.777223,-21.204151,-23.665652,-21.499423,15.188509,84.623525,77.322456,8.034397,-20.157098,10.365231,140.10937,209.901615,251.652612,207.352116,106.532117,69.225463,-39.549901,-87.313794:-59.750762,25.683441,111.11682,192.636304,165.276855,93.221672,75.851253,65.897784,114.238519,159.656475,214.01909,179.722924,-18.232735,-103.757812,-132.851425,-113.511826,-91.482744,-157.633607,-221.563137,-304.696332,-293.279766,-182.455642,-125.965207,-72.877171,-39.183369,-25.473771,-4.095926,2.664046,-24.903234,-76.074123,-243.61088,-303.106531,-259.269774,-83.534355,3.372568,54.879441,-3.129165,-141.896544,-163.459263,-165.798264,-181.158802,-156.067784,-39.734953,3.588998,-12.437323,-46.553886,-113.53478,-133.662934,-114.928867,-98.960221,-103.879454,-95.800185,-84.556855,-98.563183,-125.290337,-90.636683,152.833338,280.709582,407.434494,382.282898,183.376812,80.139201,-23.777412,-36.178657,-42.075711,-97.083849,-137.111914,-211.266517,-248.484526,-276.419509,-259.151295,-206.986972,-157.942489,-135.469622,-90.604824,-102.81606,-232.385228,-274.84661,-227.262848,-195.4692,-186.721771,-167.364069,-115.869964,5.277694,25.593457,41.748279,54.745788,51.795126,95.401745,149.819278,260.305604,290.435141,254.764826,198.646429,73.979796,41.479256,114.4521,193.503026,141.783396,6.453421,14.323321,81.192813,58.846918,-31.441776,46.233659,115.499872,133.72395,85.755127,-8.039891,-32.276365,-69.171531,-77.753289,-4.640372,110.721167,143.543369,143.203915,111.453056,54.470365,49.067737,35.523274,39.780067,95.555512,220.96708,197.482676,13.300873,-52.641469,-88.086719,-90.004574,-56.507728,52.288835,117.030174,177.608599,160.592988,133.59081,142.000093,150.877648,170.404026,196.877929,240.288444,218.159131,101.371202,64.425885,77.262939,102.257921,162.188763,246.588654,288.587667,281.391604,212.799163,77.860203,43.919174,-15.568296,-16.406699,-0.486987,-41.554318,-87.915064,-115.489233,-95.740125,-160.879309,-261.808033,-361.055733,-286.533041,-262.548118,-227.408156,-202.682965,-175.744729,-192.147597,-258.279761,-233.747823,-187.522278,-80.846083,-25.42284,57.831471,70.872173,25.684855,-20.394052,-64.046802,-18.985632,14.324662,122.812702,177.890224,169.525668,100.176355,-24.443382,55.984302,144.305351,287.189223,312.313728,255.891434,220.101718,196.301091,182.940896,167.477996,164.452268,148.81962,105.506204,56.619256,-132.605822,-219.712069,-225.037831,-94.228309,-48.796974,6.774776,30.859115,67.250957,68.422417,-35.685476,-126.197943,-178.885701,-44.969261,-10.004618,-36.598293,-47.719695,-47.677497,-69.041653,-122.397016,-65.935639,-18.015538,13.517142,-6.415882,-64.917309,-117.074929,-301.583138,-371.538007,-339.254338,-153.277346,-43.827249,82.771006,75.36401,38.216302,46.391407,45.924813,-42.49173,-53.525898,85.389843,157.240011,110.652899,38.818253,-26.579461,-15.284679,99.282553,215.504026,216.460454,130.303523,51.660722,-150.639274,-225.08234,-216.161487,-118.115663,-114.543605,-179.326421,-189.286842,-146.887561,-149.960222,-240.662802,-272.869273,-215.676077,-118.035212,-92.628724,-56.944026,-27.549929,42.313029,34.72206,-97.68694,-189.500514,-178.154521,-67.436209,-24.866058,-76.855117,-132.490935,-213.944911,-231.752803,-123.158472,106.299513,152.66795,78.869903,14.624282,-76.703077,-97.785765,-87.972567,-8.644496,17.61758,28.922128,46.633683,89.065526,86.427075,44.704936,40.199059,143.06522,278.586464,303.603788,329.40771,347.059461,343.81043,312.805999,233.050936,236.366993,268.83158,290.097649,244.912568,110.634055,69.73592,-15.696992,-76.358235,-108.763809,-0.644321,53.292883,55.312428,5.951828,-101.087266,-144.678011,-147.349915,15.926583,79.923451,89.215572,83.729047,118.248681,144.756983,132.589022,73.699226,-38.681028,-41.470732,-28.660934,-11.366162,-25.407341,-128.844336,-180.121937,-168.199732,-15.952733,44.139263,60.679506,48.902323,23.59733,-3.847173,-100.016822,-131.667206,-56.15367,73.715633,55.58642,-158.957069,-275.488785,-390.092515,-402.835588,-389.090911,-244.264646,-113.600007,110.260699,134.027334,32.366663,-21.559298,-131.498422,-222.025674,-371.866165,-365.273007,-330.240188,-268.434305,-249.825227,-192.925071,-153.491806,-84.629869,3.802153,22.488766,-34.466365,-60.197182,-14.343248,39.362634,55.822214,7.802488,-29.077168,46.988155,84.599879,119.675226,113.133425,72.317528,46.260823,-11.796457,12.258507,65.962887,127.652414,102.401156,-5.046961,-45.489782,-91.108364,-112.797835,-115.079163,-89.689486,-90.156207,-64.517137,-39.95525,-41.892265,-62.83424,-50.696969,-3.065487,10.835459,44.508278,69.146244,112.308077,106.41075,7.801311,-52.02566:-62.876192,82.119493,179.804889,241.526711,194.682629,71.777076,18.614537,-3.877062,115.984831,184.407058,261.724093,243.697309,55.640995,-81.271613,-280.265595,-283.110556,-119.376524,-41.498884,-81.404986,-157.545097,-146.507782,-65.014674,-53.994784,-98.425742,-23.798137,40.199971,63.081035,35.07939,-13.787431,-60.501183,-213.930346,-245.336109,-110.94622,98.204395,143.50438,54.730081,-33.725755,-142.993777,-168.656086,-222.735704,-181.364696,-117.620217,-4.655039,4.708387,-82.106373,-143.765683,-243.099138,-254.522972,-182.140573,-103.026889,-66.169638,-17.750691,-40.359963,-152.704765,-196.340182,-169.026976,67.5491,237.563608,459.310248,432.269043,194.875915,88.573306,-20.877656,-34.249057,-2.582046,3.277016,-15.245072,-101.722037,-177.535369,-340.369741,-372.908676,-260.101073,-82.342079,-44.181801,-30.295142,-44.56785,-119.930632,-149.015555,-162.663489,-162.7828,-131.936106,-69.832872,-15.594203,116.429794,127.447912,36.007465,-0.706011,14.104614,85.242541,134.108942,294.030787,366.556796,344.253693,256.076274,59.846358,8.107032,54.090214,114.587037,107.682208,85.237035,67.113462,-35.441102,-108.910784,-186.040449,-17.896377,106.67039,174.742601,112.291146,4.786107,-4.414767,-49.655359,-101.711478,-97.684059,81.791726,138.511752,126.777265,95.010405,17.39654,-35.075627,-106.224294,26.4321,150.66337,307.48119,270.621432,19.620329,-86.558404,-123.44735,-86.358048,8.091268,107.503131,158.975855,175.7595,104.419878,-93.25493,-146.134913,-124.146823,-1.681945,68.095307,144.977514,132.621094,60.717294,34.131163,1.793842,2.499036,121.217148,288.331659,308.233954,239.057357,182.214277,71.557169,30.757488,-6.331161,14.904861,35.826433,51.623053,29.208751,-67.377754,-117.563277,-213.949483,-276.77376,-359.343083,-280.369633,-210.127049,-140.516339,-174.237201,-318.841718,-364.737295,-321.601803,-138.195008,-43.099299,60.702176,77.824053,57.63137,7.781614,-148.845955,-204.254442,-122.120015,130.94111,218.743304,224.93784,181.211459,96.623177,38.88431,-78.570479,27.796975,163.740601,387.41262,403.036379,246.066083,145.479107,39.102456,28.005486,80.087995,217.7253,262.49766,203.340615,113.475712,-79.685877,-143.645887,-145.675568,-15.461978,51.653147,123.157415,127.717208,81.850167,16.056269,-163.153844,-211.332253,-145.45839,36.216837,96.562487,54.223842,-23.332758,-178.005443,-230.149374,-219.07252,-96.08422,-43.384333,14.847834,-0.437109,-159.348554,-271.999551,-449.402533,-472.417889,-335.432397,-114.732968,-20.833426,106.785922,112.894443,11.533717,-56.753299,-131.961777,-61.695372,15.692699,151.418891,162.004721,38.63312,-54.644056,-173.26413,-164.13748,-25.534568,116.954834,148.352251,103.288859,15.65363,-237.486515,-348.133138,-414.534675,-271.555452,-182.108428,-97.735506,-100.026074,-101.677338,-109.914454,-185.976747,-200.028417,-94.177518,65.805439,129.851398,196.212111,171.106234,-8.615323,-114.462642,-181.785636,-29.146285,51.26199,97.271571,73.806016,14.107646,-12.912221,-89.404206,-122.31734,-79.99723,112.923894,225.120068,296.019565,205.577308,-56.015979,-119.08165,-61.07495,26.499954,39.812862,132.628944,207.743677,240.093387,183.63792,38.87375,13.811512,139.164338,309.108193,337.242978,322.470504,307.697356,244.656373,196.416837,163.726194,289.239334,370.298272,440.822441,399.559403,197.949109,74.333916,-152.833767,-203.31984,-108.728241,52.017892,101.274396,86.217191,17.287754,-148.10155,-210.057209,-201.819595,-13.389712,51.974521,79.98105,87.089971,87.749735,61.18609,-33.534344,-64.611436,-48.407873,-5.161185,16.906666,12.520516,-25.767019,-111.541514,-160.082332,-231.00159,-108.219379,-10.160109,55.43614,8.510178,-92.238179,-115.086844,-175.400585,-207.081585,-200.092559,-145.39972,-140.684882,-246.204583,-335.551515,-423.606978,-405.654414,-317.182515,-167.00853,-56.664172,157.529637,191.389026,69.440743,-21.722948,-146.03676,-191.372347,-243.934857,-182.271683,-134.930744,-124.115062,-174.786025,-314.117682,-358.374137,-316.615507,-181.515479,-127.185743,14.982214,90.071992,88.555184,19.00353,-99.914129,-100.372689,40.16334,199.342123,233.884718,245.429972,230.63025,116.262107,15.525231,-141.61668,-81.197228,0.380675,129.026408,129.853389,8.323052,-52.496589,-87.799739,-76.957746,-50.581739,-37.627865,-16.075009,73.271242,100.822631,60.792672,28.545965,43.57372,157.228083,213.730126,245.405964,217.891873,143.809761,104.730607,-8.6857,-65.005215:-99.208568,-24.296601,-4.3097,-13.890851,-19.020738,36.458701,67.460151,24.280096,0.63275,50.858503,175.623156,195.242428,90.851648,1.172574,-70.657789,-35.218843,9.975251,-104.202713,-173.470484,-232.39277,-220.553846,-163.289755,-151.849925,-177.075508,-116.62697,-56.432753,-17.792934,-57.133428,-173.48599,-207.795501,-209.363925,-199.913871,-182.764406,-130.556617,-79.540182,3.608659,-12.530402,-116.621538,-141.840188,-102.244619,-46.311746,-25.42256,17.039637,17.401921,-24.600598,-33.960772,-61.492109,-99.735651,-152.340608,-153.04676,-152.375599,-143.929719,-134.406581,-128.894002,-144.297215,-160.921622,-16.551981,98.053313,237.716073,235.698892,139.677785,71.672192,-19.26018,-8.925961,78.587142,67.362371,27.02131,3.657698,7.130204,-46.152401,-92.743916,-140.532198,-111.401119,-84.410203,-23.038837,-15.788659,-60.86813,-56.095981,34.046476,43.673121,-56.547664,-140.711415,-151.952104,-125.435349,-92.915451,-17.975533,-6.470673,-57.189557,-61.548641,-20.040957,100.289735,158.401845,209.148919,184.664525,50.746343,-20.025722,-59.745095,9.705998,28.193836,-14.72056,-30.924231,3.144768,13.691527,6.749759,50.612802,85.385841,99.153738,65.13353,13.612774,31.951932,64.227817,55.046128,51.465292,12.742421,-4.116302,72.764484,129.081298,133.650114,91.977364,47.245381,112.16594,155.81041,199.993335,182.089311,68.978021,18.535436,-5.391179,-5.550096,-33.560901,-51.893003,-30.350068,33.815498,37.173184,35.280976,75.306832,168.881678,190.042703,197.952595,219.82474,213.394123,132.267396,95.057493,136.974843,195.261992,299.259314,355.155783,374.348704,390.094315,370.868615,295.096642,255.148231,212.337543,190.567086,152.120478,63.252863,36.117258,-0.08784,-18.29154,-88.337926,-130.286811,-142.821199,-82.887033,-50.731874,-20.485021,-46.741331,-148.359606,-184.056392,-173.767908,-66.078533,-17.691081,39.830478,59.717364,60.106006,43.255841,15.743654,5.778786,-14.77997,-19.398449,-8.670006,9.56599,12.932223,53.311831,62.885989,-3.890383,78.08583,209.454415,411.414668,405.058804,291.164778,285.945221,347.260379,337.105349,255.888228,160.806465,109.49976,24.491345,-43.018,-225.588831,-266.704491,-186.134169,-39.053619,23.903885,117.597661,153.635545,224.896974,246.422137,182.373704,104.295526,26.947416,103.562245,138.57613,140.680983,123.033179,82.884998,62.175883,36.841989,34.040219,23.572086,38.901741,84.402968,115.175771,38.72292,-202.891972,-264.738372,-162.861165,29.613843,82.134506,121.594485,144.426088,193.600676,184.312713,111.70671,96.274867,110.592958,156.830592,179.263397,136.109852,78.639838,45.487684,96.927359,210.721298,153.366686,91.117379,-8.722301,-65.386833,-175.200567,-196.075214,-183.026921,-154.359688,-142.748338,-141.415981,-161.914799,-226.838871,-252.167567,-236.988179,-190.591474,-92.550793,-87.062511,-102.779879,-79.558337,-38.355876,27.162455,28.52794,-41.172756,-131.631239,-126.129014,-15.484401,17.469909,-43.239262,-89.364239,-156.891088,-180.409736,-120.230555,48.464707,99.140458,57.348063,-16.68874,-128.759921,-136.844046,-119.140803,-130.473238,-152.845947,-173.006742,-129.197322,29.744418,76.473355,73.223573,77.98193,182.085253,316.976154,356.457094,394.162948,409.512875,432.778185,412.798786,280.1185,214.631856,245.800057,272.892091,211.892027,39.837123,-1.291883,-27.725672,-45.70731,-24.007343,75.090407,108.481007,130.620436,126.422914,97.107362,67.326966,9.037804,99.76763,155.012697,130.317999,98.020264,92.187879,87.801522,28.332086,-10.831915,-66.795127,-71.375887,-57.200253,-66.819857,-94.05364,-105.182427,-89.559329,-64.443795,4.35585,48.648333,98.80443,96.974014,51.194166,31.474166,16.439651,11.486061,21.058875,31.774312,8.757333,-118.254095,-193.37874,-263.176272,-249.555447,-186.351194,-124.031164,-96.916869,-63.583036,-34.244717,80.956568,127.312031,60.984718,-51.459623,-283.887062,-353.883445,-321.862048,-248.340092,-234.08261,-182.380397,-125.047992,-20.432911,-22.375211,-51.375762,-84.422731,-82.493932,-67.796918,-54.797895,-55.242084,-79.91459,-102.531194,-67.900765,-54.399537,-34.909954,-22.40232,-25.243994,-63.16367,-107.000487,0.090172,42.822669,36.7908,-2.440277,-123.855058,-168.188804,-182.405648,-170.541101,-137.679299,-154.94286,-166.183088,-115.009281,-83.478733,-78.716149,-88.706256,-121.583419,-130.708562,-100.988748,-57.72298,-77.810488,-160.292012,-182.324083,-135.329423,-78.626635:-173.159711,-29.662704,59.050578,107.865808,63.241062,1.911995,-9.271524,-68.456199,-21.194741,69.431537,200.414719,195.629796,102.901603,58.68474,40.071844,60.869469,69.059513,-84.061062,-185.620433,-271.060604,-231.089629,-71.413646,-8.734163,4.487959,-24.385544,-10.266541,27.679577,23.979498,-38.57574,-79.793253,-153.38707,-187.506424,-223.92211,-158.33026,-88.388102,30.209422,48.031651,47.653233,51.824386,45.837417,-6.143172,-30.739313,-16.688491,6.755116,18.767792,12.695308,-20.02503,-35.419699,-8.348023,67.628432,110.361624,155.823166,124.031949,-24.866936,-93.549457,-120.016524,54.377186,174.912122,277.503047,231.620201,83.918004,32.611249,-50.869867,-95.576488,-167.080191,-206.41609,-221.569942,-277.926923,-307.325356,-289.19335,-241.564215,-151.793766,-141.940147,-157.654092,-151.720295,-131.649302,-125.084768,-131.146471,-179.533474,-239.645185,-310.238495,-195.235039,-119.210985,-67.231259,-79.477516,-73.361286,-63.219409,-63.1452,-17.388681,16.85912,124.001385,206.137558,291.447163,249.993435,75.098772,14.172355,38.950881,110.166991,103.012317,91.066077,106.906599,67.201593,-5.518037,-96.403825,-2.183401,45.641557,-8.736086,-85.375794,-142.746425,-118.204944,-128.913553,-145.557755,-81.720351,-50.674489,-39.06341,97.089956,169.46136,176.847817,128.548545,17.057805,18.139257,74.196201,162.042888,141.136481,1.542264,-58.215979,-124.550337,-137.653789,-61.641842,126.350353,194.906182,215.033521,188.677393,169.598202,186.496143,214.451227,226.781074,224.852361,198.803897,158.503162,23.508971,-25.506368,-44.522581,-24.211797,82.171044,233.87984,311.250548,421.102351,418.831771,272.539214,157.14345,36.9693,186.538463,262.486344,248.111507,183.287645,35.706898,-27.794187,-144.961793,-193.42679,-222.233628,-205.909505,-189.961967,-153.252265,-136.743688,-89.271433,-88.208164,-176.554759,-235.621742,-222.263084,-135.810167,-81.410562,-11.781761,10.432059,52.689298,44.575929,-9.593999,-36.376806,-35.844866,-9.662012,-3.284482,-43.869235,-97.597848,-181.510646,-14.026495,137.219102,361.535182,382.466242,262.447105,194.007731,98.51715,45.707655,-12.210742,21.972136,32.759353,-37.189378,-127.276228,-295.052877,-307.366779,-185.043504,-26.229636,25.035116,65.923709,62.422541,67.787692,78.883322,11.291588,-64.338376,-110.744889,-5.621788,15.933024,-47.814265,-87.043935,-125.670303,-144.313642,-150.448947,-65.419117,-44.413281,-42.380427,-10.721038,52.919262,15.553395,-169.18197,-219.51457,-149.491399,-68.305886,-42.856518,35.875004,66.165289,107.149006,129.988364,112.055551,17.051018,20.008277,194.402443,278.521482,247.593055,179.345236,128.792247,143.741342,154.041761,84.148856,41.162278,9.987252,13.630576,-8.935629,-42.644664,-87.240873,-59.916449,-54.419698,-93.544589,-107.431179,-75.577371,-53.446546,-72.278911,-108.623268,-171.412233,-185.610569,-167.921171,-64.928627,5.106901,54.078696,5.765267,-134.044613,-179.513341,-165.759863,-99.917281,-76.375642,-138.053133,-210.690323,-316.694573,-314.232147,-183.739769,-48.084661,-47.798295,-109.764766,-121.243188,-81.832133,-59.06985,-82.893951,-141.658924,-161.545758,-125.379888,-52.615693,113.25914,164.097991,161.288733,136.501575,140.524199,213.87695,263.651521,359.18056,379.157514,330.351985,269.231348,125.526077,105.842777,164.322841,280.216801,266.027365,81.504011,-10.076202,-67.17145,-60.572856,-27.873564,41.666825,77.02087,87.316342,41.987902,-82.402002,-120.018289,-126.320571,-31.020876,30.393727,66.238611,37.980242,-16.733436,-4.217671,88.778282,101.334614,-13.067334,-85.111432,-58.778805,7.824202,15.009788,7.947306,3.467556,-27.651716,11.72666,68.35378,143.395492,148.84771,122.017778,99.31834,38.958613,17.954218,89.449076,194.450937,158.275493,-88.551944,-217.525764,-296.669563,-256.025586,-212.048981,-207.894608,-149.367588,-2.727079,11.182518,-42.345511,-33.627774,5.011143,-42.200651,-205.732268,-254.703211,-247.814323,-234.531566,-214.658131,-87.259822,7.882788,134.669032,69.254957,2.344238,-76.446691,-88.554204,-85.970224,-70.947751,-47.19842,-37.488278,-32.985805,-97.420093,-106.05378,-39.101116,-9.72449,-1.584158,-7.207515,-8.129309,22.191767,44.783964,113.015645,125.710488,1.179354,-92.744644,-165.873086,-144.064082,-98.916947,-174.142192,-244.041777,-327.674795,-315.973288,-198.648659,-150.727863,-180.171984,-199.447903,-161.152954,-58.992587,-39.421134,-77.791627,-96.656771,-108.883706,-101.011852:-18.119493,15.264685,31.386398,106.594802,127.023665,40.007679,-19.800549,10.059862,186.770614,241.7358,210.949663,158.793991,79.870638,62.598179,29.075946,5.330756,-27.269288,-50.93116,-72.374833,-111.971122,-117.26604,-108.693932,-116.539046,-163.730864,-140.855273,-101.145662,-43.909865,-49.235715,-132.274069,-181.571906,-246.458685,-264.063157,-227.170139,-39.783584,48.234028,16.232643,-74.665818,-134.442133,-85.538833,-33.794467,-60.582452,-56.240399,-47.399202,-70.022129,-119.642956,-112.610296,-75.554507,-73.609162,-121.278053,-179.085007,-150.802437,-39.284031,-22.220194,-89.291407,-147.347677,-173.931126,92.273626,262.975398,398.865682,357.380278,225.380586,170.244572,63.629649,35.245511,81.906065,84.534944,43.084251,-3.554568,-2.603652,-33.980319,-66.590465,-67.339857,-1.823261,0.747875,-50.197404,-63.181969,-47.545475,-39.98035,-57.714323,-77.023105,-84.037194,-38.422763,-7.995344,34.941995,37.23791,-7.330951,-41.627051,-45.114932,19.308216,32.800773,89.962366,162.270515,247.393273,194.435517,-38.383161,-107.797816,-19.842725,82.474944,70.809969,13.740779,-13.191555,-45.99935,-40.914834,-7.743162,31.073657,57.83819,113.85007,118.005967,59.541191,21.272469,-43.306862,-61.51122,14.339551,113.105923,95.629945,51.736773,66.861545,69.613689,21.031684,-59.345741,66.188219,156.279021,209.9495,159.49492,3.055824,-46.293641,-59.151395,-30.457983,68.421574,114.902297,132.512591,205.759332,215.295671,124.54934,62.002704,12.219797,83.964536,121.237339,148.176764,146.242252,143.231462,163.286284,201.991785,195.727604,225.385033,309.106999,322.319327,295.664153,274.655072,218.085729,163.6678,49.77462,78.389287,102.045261,16.487969,-73.444761,-198.334689,-192.75625,-118.247808,-122.888452,-209.120773,-216.026824,-179.482823,-88.693869,-75.954392,-170.579454,-238.88278,-235.683315,-53.275736,15.508809,98.33591,132.459401,86.633484,12.364993,-75.976404,-80.032335,-74.580134,-3.849031,67.937949,149.910264,114.425872,-0.912882,-17.745891,18.964797,102.628693,161.153056,288.82784,334.817402,285.517517,191.75687,58.761454,88.250294,252.450177,280.083268,244.872208,167.849026,95.897123,-112.374151,-172.564451,-145.578948,-61.111616,-1.821742,128.924542,152.041335,124.884465,111.79735,61.741958,21.911525,40.452971,169.301692,198.499274,150.76323,95.834957,-43.16554,-105.164459,-103.115394,64.075243,135.52408,168.009345,135.475059,-4.028392,-106.605142,-326.064601,-385.247435,-281.08895,-28.837011,57.131154,77.396969,58.862949,89.271107,97.846284,22.189171,-3.078358,18.824357,56.518475,69.230735,61.839136,38.727538,-18.102074,-37.200767,-1.261448,54.081369,40.020219,-77.409026,-160.595657,-266.763643,-264.246203,-227.923064,-191.025323,-165.984065,-126.071227,-108.646702,-105.496802,-128.218659,-177.71965,-183.324825,-138.736746,-87.752699,-71.541498,-41.252176,-34.932821,-61.755304,-92.76318,-144.488717,-149.08368,-146.939443,-116.448224,-93.343259,-64.404751,-42.847122,-12.052243,-40.746591,-65.079256,117.718015,199.428279,174.198456,103.220193,-9.702225,-47.781895,-88.636951,-33.798712,4.582607,59.586447,64.683419,11.406129,-23.981823,-14.857524,54.727159,265.518201,362.000453,356.872125,354.257662,353.129555,319.41699,300.882003,296.5449,362.333842,373.012529,286.583026,230.288309,163.503486,140.129872,63.726607,29.808711,40.221116,55.104407,52.205661,56.523641,34.536332,-57.972484,-83.633939,-56.476596,4.143128,21.324561,40.098519,28.879553,-69.727775,-115.977139,-106.836346,-69.568979,-32.272926,-74.444531,-88.351155,-91.511704,-102.064522,-112.626255,-110.800072,-137.930408,-90.621581,-4.782175,130.369977,117.191546,-25.058716,-95.852477,-173.176528,-177.12197,-101.69433,-32.960669,-63.270909,-194.703507,-243.984757,-246.024818,-215.24434,-171.768908,-114.071906,-60.578704,37.575245,56.423829,55.652644,45.831685,-64.011175,-165.285371,-301.965411,-246.595938,-193.409576,-152.263228,-168.832472,-189.530694,-168.871856,-129.635889,-99.694978,-65.632145,11.221396,44.086717,104.136904,109.696661,-38.221231,-153.234744,-157.818708,92.372701,178.148651,226.928835,209.861008,107.390571,29.883766,-87.354635,-41.893461,8.005811,73.136925,80.73094,52.017753,18.642985,-73.443274,-97.516053,-57.090961,28.485931,78.749464,131.282461,110.387978,54.408282,37.094784,31.591652,132.138516,179.399066,176.737222,151.519481,98.410625,63.885521,4.506085,-2.493074:left
-276.125119,-273.85974,-268.382949,-176.854831,-121.299179,-85.232111,-96.93764,-137.178029,-138.384041,-85.322727,73.074596,114.550025,95.732956,67.893228,1.088784,-30.598924,-44.232017,-38.804346,-49.524539,-41.538257,-28.102943,-74.848247,-114.812594,-127.655264,-97.227782,-86.58734,-97.487548,-120.577959,-156.111223,-170.958944,-158.373089,-91.221448,93.212258,168.741701,136.35279,-40.561268,-118.64993,-103.963433,-19.961493,140.828609,174.338182,163.276802,114.577627,87.490649,75.780561,77.048057,85.9103,119.086133,184.103373,149.164668,116.230154,84.204548,105.303132,157.797803,144.367497,56.532113,37.656371,81.746842,134.74506,106.132109,-8.862226,-97.384808,-270.722193,-293.292411,-229.159761,-104.016281,-52.114836,-53.088558,-90.448659,-176.518953,-196.416497,-175.769191,-224.4733,-269.65724,-290.204964,-270.151608,-241.280435,-262.275287,-376.538645,-413.13525,-369.669079,-298.727153,-287.478686,-291.269823,-293.764256,-255.012748,-190.524363,-29.303557,14.393147,-4.11529,-8.868829,21.416207,66.242121,40.170205,-63.309006,-72.773333,42.748994,133.391528,108.997942,-3.092671,-41.330507,-61.727847,-44.545162,9.600327,27.673126,37.234485,9.144588,-22.152796,-31.672839,-30.284238,-25.404262,24.978786,209.772496,293.48211,287.714869,273.774424,245.605085,81.704319,2.772326,-41.157565,-76.536104,-86.538184,3.273544,75.616153,115.200101,70.968031,6.567788,9.238692,-25.732278,-71.771065,-47.943304,25.636222,47.13647,65.053543,56.255952,-23.938934,-77.031431,-3.87089,291.591972,386.228182,316.870144,217.996722,83.751122,64.226848,85.139132,160.823858,164.253887,28.986682,-59.226508,-157.885113,-165.293273,-153.931707,-124.757972,-97.442568,-72.988848,-71.863334,-47.697407,-62.911597,-167.707768,-188.363455,-77.102376,120.904492,180.884382,201.505383,193.814846,128.862959,89.226875,162.460059,365.641344,385.852959,252.926158,215.690746,251.623142,235.393806,149.585184,155.587065,234.293599,252.078184,239.210662,218.715218,206.91243,165.916431,164.333157,210.025706,134.607467,49.355409,-32.292345,-11.108123,2.574837,-50.718127,-191.454031,-218.060949,-143.291527,-10.135921,23.829506,5.548798,-18.204996,-56.420802,-88.289393,-193.025088,-217.501209,-162.89416,-15.054742,44.090671,91.294071,51.435848,-66.632479,-66.107965,59.872517,218.378799,263.515369,262.766912,240.334146,164.589544,124.938557,95.078517,120.515334,139.390935,88.732417,-2.292628,-210.213341,-272.481851,-265.565582,-223.593519,-132.417212,-45.820127,-28.876576,-101.613918,-171.846934,-256.780745,-236.626869,-124.224933,-74.457322,-73.577397,-73.028444,-88.940252,-194.834416,-268.803707,-320.890949,-262.383343,-46.446294,110.584653,61.855492,-250.87622,-362.147165,-331.853574,-273.301035,-220.407101,-125.597145,-33.657557,87.854322,83.164552,-15.077829,-85.898804,-130.16499,-67.858364,113.155047,240.397359,278.867663,299.582873,279.109224,164.56189,102.925293,102.213257,174.745534,194.814031,215.802322,202.366691,109.433738,59.799616,61.895507,130.245101,313.502601,415.718917,406.861678,263.296997,162.305933,12.495254,-5.914826,24.772188,43.6747,75.093035,150.006887,150.235001,104.374956,79.928921,54.567037,71.030678,184.701288,325.613644,340.195074,278.494355,243.188229,143.678822,107.221533,177.598467,215.648792,152.186883,31.3237,45.397425,172.866193,213.813524,205.15001,200.3009,219.354689,242.628796,275.139111,401.7433,456.935671,404.721774,339.746046,310.364816,281.470487,231.884518,134.045123,101.804276,49.675553,12.852925,-44.513262,-52.798431,-61.323869,10.114242,68.417061,102.286176,58.558613,-99.687392,-153.002876,-150.331077,-133.876383,-129.319566,-138.772962,-169.991594,-220.181165,-210.285884,-120.914799,-57.148279,66.993493,151.77921,146.621049,37.973424,-20.29489,-81.875337,-83.604364,-52.569138,-21.840951,-12.209877,4.543883,22.410994,34.207174,-19.30515,-209.668958,-256.885447,-175.874661,11.547734,92.739793,158.391693,170.563997,181.510074,157.695112,77.372138,-54.555798,-121.82746,-138.255599,-90.593825,-32.842017,-77.237253,-252.884774,-317.399099,-317.469527,-159.707625,-76.503311,-17.387596,-45.368508,-157.543068,-198.399728,-163.579912,-50.662231,-16.710353,6.798437,16.113341,27.377793,8.628616,-80.935091,-121.142106,-144.954411,-71.312799,-2.611313,54.883987,19.747224,-68.952773,-70.283175,7.562898,82.275571,116.966185,139.315111,131.164291,191.978918,246.710402,257.054426,200.699723:-177.602582,-181.569096,-194.986114,-158.057594,-122.416873,-131.301793,-168.859859,-186.630385,-76.728497,-5.659227,93.169857,116.07782,125.039821,99.496225,-9.885423,-55.95406,-52.919199,-45.468545,-91.706093,-207.751199,-222.850274,-147.042156,-94.197807,-17.143514,71.672912,130.610786,159.883606,82.927339,-150.851558,-211.532703,-135.172508,-49.823035,97.093086,169.235492,169.323048,165.598196,184.251688,241.750584,270.717559,285.896707,269.392971,278.91054,255.734847,216.032325,217.355128,267.881783,352.677792,363.89917,342.496402,327.648854,321.288492,251.253656,203.233589,149.927512,127.013126,66.440142,149.653218,232.783895,236.722163,180.946594,146.249243,130.048447,-5.485294,-85.078592,-128.7243,33.79676,108.020506,86.731659,28.388085,-62.457987,-78.046098,-67.591677,-80.49435,-94.863129,-161.919246,-228.500067,-337.803459,-365.993684,-394.95651,-381.314329,-297.766011,-229.18135,-246.72659,-361.194017,-414.570954,-406.275217,-320.220715,-99.059669,28.876228,50.26884,-4.507709,-37.392909,-10.818366,19.462387,53.601717,73.270118,129.38635,150.208905,131.701297,34.090959,-31.682272,-83.65816,-33.491845,101.988018,118.034451,117.314317,104.134541,67.460585,-18.041153,-51.07104,-37.846087,35.778092,218.794268,237.985918,192.709018,90.170386,16.989426,-153.368133,-164.320599,-18.869536,70.831092,84.361271,115.985877,125.830209,41.972586,-56.326549,-136.616993,-80.412207,44.290055,110.254493,119.331813,67.650461,42.38139,22.098358,6.395317,-3.837976,39.286983,78.914496,190.453997,232.728217,218.084708,164.404414,50.492134,31.997389,50.524657,29.796054,9.056199,-49.845645,-101.306134,-216.532469,-243.71379,-197.525851,-138.055349,-135.701475,-128.033186,-104.317879,-78.226048,-107.938794,-163.510028,-137.92704,-12.563182,71.787819,79.91969,71.47343,42.166446,-36.599151,-36.071262,62.845265,219.424555,251.9508,133.216209,57.746211,2.071123,-18.76085,-32.364249,12.70238,122.492166,97.239473,52.53174,31.507117,52.664978,40.00605,27.694406,75.533662,53.602969,-2.360052,-80.641086,-73.127577,-41.408571,-67.359275,-173.836669,-195.71087,-94.347732,56.814683,70.06804,3.619015,-35.784476,-128.590201,-165.579277,-157.195103,-140.242469,-150.246839,-125.28997,-76.499639,-40.657606,-98.588889,-182.910284,-131.693623,33.524802,151.829926,195.081744,175.755184,111.566504,-24.57641,-62.956546,-106.768187,-129.704379,-131.961457,-194.073305,-249.462271,-356.583124,-402.174743,-440.415285,-420.494725,-300.651037,-158.559871,-121.528801,-115.689079,-136.228631,-219.881335,-255.588324,-248.378688,-198.513013,-182.446307,-176.099401,-188.424065,-257.098994,-307.947673,-330.00069,-255.380903,-15.072391,128.139743,80.650588,-237.115465,-367.939911,-348.396344,-276.085941,-209.889885,-93.820013,4.901504,66.68247,20.667074,-47.908874,-61.313922,-81.431164,-68.637269,21.966325,129.556033,162.665572,219.083927,239.382104,211.650613,196.6523,227.402403,217.892527,182.355599,103.496736,88.805459,122.411101,131.622256,123.416167,152.327951,271.545222,336.811813,338.759325,256.50432,162.487139,-19.580352,-38.923728,67.058973,192.127254,226.409846,223.436128,189.944174,102.451211,72.59028,112.047365,186.13341,340.5714,374.761806,342.813909,238.907344,176.050259,73.256857,69.28429,127.412266,175.037528,183.58755,168.053396,179.172242,290.333834,335.945514,286.257743,229.77392,181.315933,223.893056,258.448519,318.188578,328.506714,266.459553,218.249263,196.178116,216.930835,203.47293,123.664663,71.427463,-27.53023,-73.93592,-99.794415,-52.520919,75.852696,62.215396,-4.225151,-90.878643,-69.7747,-13.982314,-17.874403,-38.509553,-29.358241,-21.24102,7.239485,26.01211,8.392658,-48.693354,-141.141721,-113.7561,62.621244,219.730201,213.104718,44.060041,-30.563064,-52.467524,-33.41316,-2.538263,77.31601,132.815628,191.741448,179.605398,89.837815,18.948005,-144.574288,-199.37174,-152.327548,43.596414,114.863428,161.368145,173.324809,195.600216,199.024822,195.956785,100.657426,24.035236,-73.468963,-78.915066,-91.395642,-125.571942,-216.738937,-256.197678,-263.716783,-148.330043,-92.251844,-77.089496,-110.547239,-162.587886,-164.317006,-153.663352,-108.399905,-65.570801,25.857162,74.844891,149.907049,121.139242,-17.179636,-23.289111,104.731961,181.046226,157.338538,41.221566,6.67642,36.841082,76.21778,137.335439,138.386685,156.833877,216.18449,196.172522,57.501977,4.290777,23.801434,73.084026:-175.522543,-226.714479,-285.902073,-285.558875,-198.655131,-69.939349,-85.610679,-140.708296,-81.842905,-39.495325,23.291635,56.495156,107.921303,101.307702,47.95558,18.013926,-78.411715,-173.062961,-172.815832,-99.712256,-68.714026,-42.808516,-36.143524,-29.955377,82.591808,171.174635,179.160896,79.606831,-149.854475,-204.429355,-123.586521,-24.186681,190.522319,297.659075,258.492951,163.96584,193.477073,297.24658,321.767081,369.033494,348.862741,271.6603,90.069226,56.453572,108.209065,161.763532,291.458456,332.364092,286.878713,204.981812,180.843432,144.188873,136.379711,130.317628,108.038263,0.260434,11.090476,102.313991,213.179604,184.997293,85.238029,55.813651,26.970163,-17.521555,-116.625254,8.719247,93.980285,107.926979,47.907186,-71.300791,-95.796979,-92.086454,-110.337642,-145.724931,-185.955113,-178.195958,-239.274991,-322.129929,-448.438508,-455.50019,-352.283014,-156.32538,-105.183344,-188.968536,-272.391577,-334.372189,-268.531301,-26.144913,159.263255,202.710525,147.656717,77.952353,-22.092688,-51.456357,-72.529521,-46.211917,38.158971,19.793372,-31.49315,-138.967481,-185.31317,-205.713522,-162.432261,-73.41089,-44.540174,-39.185203,-92.122836,-136.520528,-117.49588,-62.239505,29.361029,59.090871,84.006533,105.355193,113.140153,34.003454,-55.760363,-192.2291,-180.811306,-40.103524,64.547831,67.2886,16.032339,7.618051,30.26681,18.261518,5.57445,50.02146,193.927725,312.045135,332.565636,287.52032,236.170037,110.216969,58.911952,3.122099,11.467946,45.829114,174.747869,240.0645,256.521467,220.648615,171.996276,166.422906,165.852679,142.691211,106.457648,-5.226874,-62.258126,-155.859,-181.487767,-157.082395,-92.403459,-68.516404,-67.633762,-80.731575,-102.428104,-123.280145,-141.701277,-117.015045,-23.645748,37.967035,20.792531,-67.820014,-116.756294,-214.328933,-232.498065,-144.954345,31.947018,65.226637,-54.80779,-132.641677,-198.980637,-211.140873,-192.029095,-138.009294,38.998576,125.690041,64.416227,-100.534069,-102.53017,-1.108767,21.650337,-8.921338,13.83178,44.10244,33.160356,-3.365957,-60.215173,-76.972511,-107.909319,-102.523196,-17.692095,19.57223,-2.424122,9.650702,39.747465,-4.489205,-66.290823,-91.385254,13.48952,29.464393,-50.470857,-80.404516,-70.64443,-80.229416,-121.647465,-108.689245,-21.564444,109.121374,165.360192,150.233772,73.134775,-134.282154,-203.817461,-206.938738,-216.631978,-258.982985,-358.981794,-406.316719,-476.270619,-484.378623,-464.06806,-451.071867,-389.79982,-311.197949,-305.076428,-310.334722,-293.172091,-266.58018,-269.088322,-259.112194,-229.655471,-220.485277,-247.079612,-269.028866,-276.37521,-302.279027,-396.475602,-378.094615,-152.335883,11.086572,-48.733729,-361.743439,-486.71397,-524.427753,-465.778896,-264.375459,-39.215409,32.827019,57.383915,46.124786,35.535539,18.426598,-14.453832,6.779497,108.20385,133.669214,101.372394,66.71119,75.022539,66.077878,79.599514,229.350439,315.955769,275.617826,134.106105,96.893878,91.748578,73.683643,52.816142,97.250866,236.065594,332.618198,352.892654,329.752219,279.826712,164.627959,169.651012,261.075529,254.912881,263.982494,327.857641,304.520524,199.815835,218.014177,367.402473,394.760818,328.42164,349.608864,380.498345,359.305011,304.671207,185.117701,156.234649,144.235918,219.924538,290.802604,317.693749,254.754499,164.424518,163.159065,158.031638,157.979163,162.649742,174.520696,208.179027,287.364501,291.73144,191.230014,122.526235,68.124661,103.745031,133.545513,138.605172,92.283137,-34.014148,-93.470881,-125.046716,-67.546871,83.881977,62.306876,-10.774317,-125.476906,-137.337312,-90.325227,-52.046425,-41.624465,-108.696348,-120.142215,-53.323496,0.005549,14.000319,-34.403867,-126.349863,-126.83392,2.781108,170.485482,179.153655,80.532234,34.539256,-20.884822,-32.995306,-10.645502,70.020812,116.622193,152.088828,132.896081,99.630721,88.590764,-7.719205,-77.738719,-61.320351,179.038228,246.138783,194.524709,161.057672,164.773523,170.256308,179.754033,140.897237,79.609749,-20.233326,-31.134296,-67.149351,-99.175524,-85.49379,-64.085447,-91.873942,-69.342987,-12.649666,55.166976,19.364997,-84.521134,-78.429296,18.608292,63.351047,59.901316,47.543142,64.648022,129.372248,131.623821,93.686823,109.412986,215.409888,265.391223,228.103367,100.492304,58.268435,8.723833,17.963092,157.305508,268.996992,295.082623,334.650634,302.131679,108.404839,39.312032,118.706471,213.3847:-251.345216,-154.238033,-134.691203,-180.092595,-196.664986,-185.320021,-187.14561,-216.337482,-211.673061,-159.199263,21.379049,94.411914,152.071874,152.714418,138.245343,128.412873,101.538865,81.181462,88.1662,100.817911,75.361092,8.739062,3.848686,19.260999,86.806739,144.073148,136.541696,45.204192,-159.383185,-208.024575,-118.048726,-6.350922,162.994028,194.195227,176.16462,126.232687,118.88339,101.094873,86.213162,107.249668,133.446005,130.931958,122.337864,100.316786,47.51441,57.237295,139.23374,177.408007,220.479121,265.38789,286.532645,246.448558,192.769243,104.9995,80.076309,81.68414,162.025312,187.561114,98.3548,23.360522,-92.380403,-168.25792,-318.344158,-327.599001,-206.3283,-11.266626,60.65119,36.648564,-47.860999,-221.370964,-258.469566,-229.503536,-222.176575,-250.374453,-311.94919,-325.115018,-317.459751,-319.278781,-355.626439,-368.83047,-334.517186,-260.019422,-261.333474,-335.783469,-367.549963,-357.728588,-283.139841,-30.150336,131.463132,147.641813,74.232603,24.911026,7.317642,12.152584,-18.766968,-21.47893,38.92656,122.644432,127.390442,-24.151956,-143.105454,-261.767847,-224.263414,-79.946123,-33.87083,-39.536,-68.35966,-76.722038,-47.271733,-36.644253,-19.054319,23.838413,144.898585,248.017757,283.623133,265.432965,203.231319,48.085818,19.196234,73.581663,81.536203,66.160939,66.983056,86.913206,95.117475,50.070252,-1.211183,59.338421,231.611941,271.960334,265.669879,264.99959,257.796729,158.4094,73.263541,-21.412115,52.967717,121.094966,233.680107,263.979619,276.558484,245.371516,110.729722,49.270707,31.629623,116.172807,131.866849,43.579513,-23.390137,-113.886541,-139.899686,-183.554756,-201.033325,-175.390693,-92.418949,-66.763857,-47.670887,-55.397547,-109.602779,-128.435187,-88.337248,-1.914604,21.782159,35.027172,22.333076,-81.09628,-133.926722,-117.343355,-8.150266,26.270484,5.652032,-22.421163,-76.134137,-117.331795,-157.95785,-130.944937,-19.796546,68.27762,61.235442,12.533158,22.110275,69.519764,76.324703,60.135789,8.837382,-6.872068,-0.619966,-4.726844,-70.187645,-119.182907,-162.860609,-129.340006,0.037324,56.000041,30.825982,-40.657264,-47.734832,-65.75689,-114.777841,-196.303284,-127.30177,-83.140663,-48.807228,-21.132973,93.133396,120.989738,68.798078,45.190654,56.59562,150.144778,216.446298,248.356732,186.657745,18.77079,-19.659791,-34.932025,-123.535017,-158.491942,-203.137957,-260.033325,-367.986432,-357.78654,-253.896563,-212.008118,-149.051929,-89.476622,-91.414632,-131.938347,-130.36504,-102.42098,-98.328716,-75.373665,-21.537858,3.472983,12.543298,-21.366797,-145.213019,-214.297469,-280.251431,-231.650457,-23.592475,76.231722,31.543666,-140.317882,-203.092109,-278.066845,-295.502836,-234.811643,-81.868843,4.40203,127.80453,141.86615,47.574362,-57.49126,-190.260496,-134.278479,106.836643,186.205869,147.372648,67.409235,52.961021,25.782377,28.04203,136.136908,247.753515,273.334003,279.196098,252.63971,196.105751,192.894888,241.215559,268.930006,278.006094,323.388103,357.929888,320.733384,255.342165,119.580169,75.697141,68.016896,118.379952,136.285401,143.949678,139.253056,118.506378,113.832483,150.424605,182.063228,234.416474,299.674064,330.854917,338.68836,286.970969,110.284987,67.768111,123.265452,177.248326,178.814044,143.036758,114.018882,102.064286,127.594836,177.422401,181.055534,166.424582,193.566595,216.794874,252.797698,255.89284,188.944108,137.913256,71.633516,12.49149,-8.201653,-14.289967,-24.19357,-97.33195,-158.302505,-249.732601,-246.461761,-184.111178,-98.740618,-64.811921,-71.272868,-97.368659,-145.87939,-172.036967,-212.411896,-200.57177,-203.37089,-227.9108,-217.717344,-184.796617,-198.753828,-244.338224,-230.390112,-109.902896,45.516235,61.013817,-74.922836,-151.377997,-201.130817,-189.089687,-149.906844,-101.883097,-58.243827,32.741974,40.009135,3.970859,-12.898421,-95.012403,-151.204064,-95.822897,219.397703,335.218012,342.267535,309.384161,285.290469,265.934232,185.880915,120.262044,120.82447,165.012752,170.552224,103.643419,48.340276,-34.27036,-45.291153,-8.534668,59.848583,89.011389,132.815141,121.941232,-6.411565,-71.929627,-71.152842,34.625543,74.85597,96.270113,96.751715,85.091457,40.312245,-75.995462,-79.037766,27.045558,116.810285,129.568519,81.163871,16.578523,-101.925131,-98.319313,-8.425645,68.82092,126.445085,219.848326,206.802712,103.363792,59.005019,69.291679,124.158383:-230.075359,-158.229401,-169.651155,-244.489883,-282.873408,-317.548421,-287.033349,-155.433111,-38.671812,1.129477,1.675588,-19.272371,24.003887,79.742516,126.796336,102.797626,40.258388,-6.568646,-44.291931,-91.246212,-67.091798,25.254666,53.735286,89.781225,177.14696,204.142634,82.282187,-42.291344,-229.762649,-265.155541,-234.4949,-173.206552,18.116882,165.437684,160.133242,72.857215,54.880395,73.878326,87.674881,113.146061,147.981387,164.394264,125.039639,66.858993,-14.454993,-2.334481,82.163532,118.332368,175.912577,240.070987,229.443242,71.916307,-20.155486,-67.519121,-15.470385,112.380851,177.388161,182.728721,72.20333,-20.810559,-175.702301,-236.150754,-300.31708,-298.025521,-217.576562,-12.118034,49.511976,-64.304494,-179.471521,-289.97273,-260.341414,-175.998927,-213.541413,-256.854304,-275.960115,-245.263553,-261.652044,-323.0999,-374.325422,-341.41154,-222.11424,-82.120324,-64.24798,-191.099379,-269.177606,-282.74326,-203.980496,33.484182,227.218423,251.746159,103.609032,1.162423,-101.149855,-114.262941,-95.927422,-44.942208,99.330541,80.014565,2.120421,-151.289792,-216.358833,-306.320028,-292.311005,-181.390253,-119.670097,-112.338017,-136.657369,-161.855172,-173.981057,-166.88799,-155.739056,-126.451971,12.771514,143.624941,144.725325,40.57539,-1.682843,44.639662,123.287164,234.20684,160.636949,114.477107,112.142589,127.904807,99.696305,72.287856,112.292732,186.926243,392.436776,520.422806,494.135438,359.917211,295.988893,150.790206,79.678881,26.911786,115.078076,165.766152,170.088175,134.203428,64.81422,56.013908,112.899783,149.112158,171.201288,176.95077,178.013134,114.435311,42.630098,-87.085463,-94.358337,-32.944254,-18.857677,-16.12145,-8.768478,-30.225209,-121.875878,-151.132304,-110.476775,-71.810858,-35.964808,-49.375172,-71.918558,-129.829894,-171.264526,-273.874682,-300.563346,-268.255841,-143.823638,-86.415512,-98.689457,-141.489899,-209.328629,-247.684859,-286.087113,-252.164167,-102.791771,-4.16804,-24.158612,-84.665845,-87.132554,-99.962841,-92.739933,27.252938,160.308452,178.653656,93.455857,12.446338,-159.533428,-216.130096,-168.130867,-69.085937,123.485831,130.904723,82.710516,9.068248,-20.317137,-117.131717,-150.825904,-79.467787,115.197477,174.921128,133.237575,86.509318,41.915441,15.584643,-47.090188,-51.67762,11.188127,149.8034,206.076949,153.491799,48.619076,-158.534487,-197.600034,-132.953568,-82.986548,-100.740921,-232.086999,-350.403226,-541.290489,-538.971455,-373.423625,-285.775079,-154.352473,-103.341369,-142.219395,-200.196087,-179.079017,-142.578961,-122.083541,-21.905354,77.847967,114.917013,79.355419,-13.946415,-222.566575,-284.593953,-272.900555,-200.651323,-7.557397,66.502379,23.552784,-163.498116,-270.058629,-405.516644,-414.351431,-328.379275,-107.007992,12.734058,128.870831,132.706495,81.862434,19.995461,-66.450702,-26.102025,184.583755,246.34936,157.150182,-55.893804,-106.97021,-106.18948,-61.099903,107.961492,252.682193,281.84805,237.359137,182.071118,107.282443,98.804158,114.473027,132.11428,200.889376,309.496197,334.276386,268.664969,196.338665,97.070907,110.693383,204.336838,296.582475,335.832634,339.979397,308.322736,261.7732,276.34781,358.149613,382.12114,398.692175,468.837216,487.518019,410.048881,317.229848,127.641275,92.549316,170.262169,296.640082,310.739327,200.4974,121.255248,46.806773,62.004995,153.656983,196.871809,207.246848,175.152874,173.866037,197.816888,187.007928,75.9912,21.279768,-38.451873,-62.616717,-51.625763,-81.5576,-145.198013,-282.701851,-314.302065,-233.318682,-155.231763,-71.93211,-60.232287,-74.308929,-178.468033,-242.448459,-290.516708,-266.638403,-183.451621,-148.207544,-159.651422,-157.841637,-131.759188,-147.374279,-201.114903,-246.215618,-197.288605,-14.692244,98.666833,72.126049,-74.353299,-136.305682,-200.218378,-210.697121,-185.725192,-46.607719,38.174353,113.529486,98.042887,25.598882,-13.109025,-79.541017,-91.145514,19.052052,260.841496,327.577987,292.475454,232.386398,154.900977,162.043179,223.187913,304.749866,318.458648,232.179575,168.367322,58.502568,16.067113,21.145535,60.900011,115.328293,142.629113,156.702903,131.958659,75.684545,-21.358518,-12.028574,74.602693,145.897564,179.561943,222.480805,215.492757,132.910558,59.686731,-29.054907,18.702881,231.832008,333.006825,308.404212,193.702733,126.308965,0.128154,-7.129306,124.608232,258.380131,308.603246,383.458262,360.92627,158.627813,67.653056,112.929313,202.322718:-284.899154,-249.642288,-231.541753,-208.494316,-210.830443,-161.513851,-125.748394,-118.805106,-152.232791,-142.744937,-73.949538,-42.458437,15.673657,42.32872,39.541996,25.285125,43.129456,76.90908,71.929194,24.176842,-1.94772,-50.156436,-64.125974,-57.605476,-36.150768,-18.043577,-23.197,-65.676746,-159.279897,-185.004208,-171.90531,-111.112594,50.116214,5.769353,-79.098619,-174.233219,-185.985614,-227.492239,-236.925098,-200.912044,-167.512212,-127.447047,-41.794648,-69.860786,-239.722885,-294.147587,-217.087225,-117.210669,43.346405,88.245011,76.651011,33.546214,39.637097,119.125782,155.758057,164.385841,97.462812,36.228708,-113.680124,-172.56241,-289.751472,-375.827269,-511.222868,-508.700081,-368.058864,-128.094813,-43.275071,-75.843167,-152.108546,-321.014951,-395.358077,-448.299143,-452.757863,-477.623157,-487.098259,-425.797474,-244.988524,-218.879913,-327.309276,-369.446625,-295.583597,-181.348632,-187.538297,-257.855346,-261.601856,-190.724085,-129.24145,18.678468,119.926184,150.835459,154.193499,114.81712,30.440889,0.687526,-64.825529,-71.26117,48.291106,173.786333,142.245834,-66.64567,-158.523012,-225.101467,-209.177202,-137.279092,-111.850243,-108.154598,-125.168426,-152.30584,-139.47286,-89.109417,-13.437573,8.753011,132.298229,310.508048,352.130701,363.617924,348.915065,233.593504,163.559018,112.043908,61.148106,36.202973,112.797001,175.204944,190.723942,148.007933,94.872899,106.565659,177.066024,289.333617,321.944573,288.264084,254.615462,208.255232,180.778334,111.274403,113.136517,169.914523,316.0518,340.668075,251.975022,192.490512,177.808547,216.562068,284.336052,306.331344,307.037594,215.580306,110.995194,-94.694385,-138.449115,-153.076634,-185.996538,-178.771359,-137.664316,-144.13009,-192.411335,-214.927946,-222.689657,-201.136103,-166.539566,-132.839124,-83.230501,45.804302,80.824807,21.01954,-32.069403,-7.730211,132.979527,155.630256,86.826881,46.804522,10.53767,-8.828255,-72.083338,-80.489213,-5.695236,122.716138,171.077376,185.269687,167.570546,181.673535,224.364445,255.092316,108.204047,32.928396,15.537268,42.295449,10.629148,-60.814905,-177.839588,-154.946155,32.836088,108.64545,56.375145,-49.292418,-59.463498,-59.896757,-85.329372,-152.683696,-78.082807,3.215569,86.761243,81.727926,62.886534,59.090547,99.500827,136.79867,179.25973,240.657226,277.438276,324.902664,331.228439,221.154918,129.618712,76.447784,111.691006,113.070553,116.915404,94.274777,-44.610469,-107.662174,-110.283457,-68.327147,38.69828,87.224714,60.197016,-27.666152,-46.041125,1.915286,50.556455,118.74583,115.870214,107.282098,89.385557,77.866046,17.191537,-63.727445,-243.944009,-233.490195,-11.514224,105.2621,55.936263,-157.911638,-267.390813,-412.496783,-427.610486,-348.148193,-193.297563,-107.361566,20.173029,43.465562,-47.245273,-149.837091,-233.281567,-164.963887,28.563379,137.289792,155.304088,103.722062,56.425075,17.951984,37.467657,92.774919,156.376735,220.518377,322.752908,305.111341,158.512042,96.845452,158.589599,261.973372,391.632884,333.227429,278.768888,174.153874,123.082976,39.207476,16.174352,7.515244,89.730765,160.262835,192.557231,132.91899,90.525755,158.572148,274.713439,269.501851,242.089404,278.259111,299.995287,292.31192,249.543479,139.645779,117.222752,166.573168,180.280494,119.191602,-21.026824,-28.949768,60.230223,93.248087,64.10649,43.96664,92.881259,163.356383,185.680604,244.425682,267.539005,223.051223,168.311769,134.557695,174.105276,147.028244,-8.665599,-64.634617,-50.058021,-54.137669,-184.878257,-245.953884,-236.635279,-122.761766,-83.398444,-56.317247,-51.948472,-102.013257,-162.741796,-275.337636,-262.910207,-214.421763,-140.756738,-133.013098,-148.148811,-167.096042,-158.893068,-106.343063,36.901141,104.632433,71.179163,-73.768255,-113.464048,-101.476128,-106.678619,-152.338156,-161.623746,-156.865034,-133.221089,-114.774729,-94.869906,-109.520737,-167.57579,-167.441877,-34.408141,164.10948,216.058188,205.117643,179.177403,141.765589,131.233406,101.858792,28.880016,11.502618,91.864145,165.760089,215.713805,143.293405,-86.06383,-143.241384,-52.535053,104.632588,121.985777,63.081709,29.576432,-15.918521,-26.596282,-11.324234,16.777826,34.852574,45.752665,11.572032,-96.646799,-150.00529,-265.649248,-307.86425,-296.6715,-163.07685,-87.779611,-11.3672,-17.439438,-87.285768,-111.445176,-82.888377,-1.636438,45.794585,89.736229,89.061282,147.393529,201.405045,274.231344,277.305063:-204.386075,-147.292946,-174.350121,-232.577679,-244.737331,-213.500963,-167.495269,-78.13054,-38.417668,-20.721335,-3.594011,-7.063558,1.018873,11.317563,23.093281,43.720702,152.441349,221.243502,197.03094,77.813544,25.071333,1.727299,21.969787,69.756688,119.010338,129.088493,39.574547,-48.701072,-192.41304,-218.934015,-132.464772,-18.50688,212.043303,219.602954,137.959667,-8.874503,-38.833152,-99.615816,-131.345605,-91.890039,45.106264,86.591341,16.352972,-71.357803,-203.906622,-204.736467,-75.646933,2.930135,113.975179,178.584592,173.763669,93.943612,63.333863,99.806833,151.567676,199.247282,163.292666,152.982237,87.733361,1.356965,-257.133704,-385.267093,-491.563129,-458.152703,-296.99993,-104.758814,-64.083783,-146.807291,-226.018923,-360.557894,-385.366911,-330.965072,-269.268773,-256.192599,-261.684231,-281.255485,-326.730155,-355.697646,-381.65884,-345.312223,-196.800975,-57.719504,-45.365896,-177.214836,-254.6846,-238.749135,-138.569724,102.319718,246.175825,272.105555,193.623669,106.279056,-31.388559,-56.287709,-31.784861,11.9652,141.79755,185.231612,125.591468,-85.311564,-184.450201,-327.826569,-358.740753,-274.794955,-85.932061,-33.604752,-127.444618,-218.105127,-257.612617,-222.797533,-179.203022,-144.533453,46.509683,238.353391,259.780535,233.74214,234.174434,244.812442,251.238139,281.52446,285.586169,291.087158,297.29459,272.916152,165.805966,98.05851,48.440025,104.934815,333.668246,490.922965,463.805886,286.191447,215.097606,134.081692,98.134918,74.21568,184.393329,248.861222,275.460119,241.424333,147.823433,107.911475,66.362937,77.024599,171.20332,243.229959,210.748891,42.250483,-34.768311,-113.544478,-127.271244,-124.554224,-72.422269,-46.452972,-118.49678,-203.884298,-306.014884,-286.718476,-151.805451,-95.513534,-68.62248,-12.733803,32.347964,38.853911,-11.710023,-171.469267,-236.641863,-220.879067,-46.282672,16.94563,-29.299579,-99.764482,-211.701434,-254.919601,-287.468922,-239.303504,-11.788742,185.619387,189.327328,56.293415,-7.052469,-38.230697,0.757013,127.565803,143.311307,109.330374,39.860501,5.932122,-86.715378,-142.053978,-182.499678,-125.933387,88.331455,210.416357,183.841734,-6.27026,-113.94004,-213.12407,-199.741379,-124.130349,26.014751,99.44712,86.229773,22.449967,-26.375457,-10.216625,20.501084,47.262791,117.055603,166.926479,178.668578,132.987759,78.950147,-43.379963,-72.959042,17.38249,128.644946,114.150948,-51.133712,-162.609372,-300.457283,-298.414532,-165.156737,-63.770363,89.358449,115.276515,90.010624,47.102855,47.74199,58.973969,80.185935,164.476779,208.940073,208.789207,171.242399,125.997798,-28.950129,-126.067392,-213.200528,-158.387848,50.31641,151.840333,104.030252,-101.240837,-184.942909,-272.617695,-277.349484,-176.206775,5.179623,72.398534,67.571242,5.258967,-140.141963,-192.914732,-140.408961,-31.591302,158.17959,182.773883,143.909816,22.351002,-32.521317,-107.288598,-118.144806,-10.365233,232.375292,317.471006,264.270883,169.101356,68.72691,78.680305,141.51896,177.890529,239.736249,253.777454,229.524335,150.417866,105.495477,-14.968269,-59.419805,-15.201845,124.136438,161.6186,148.429137,133.973138,148.478052,168.344406,180.527017,168.075941,186.213651,298.650888,325.583477,258.394236,179.33031,17.484971,-13.318137,51.853288,136.611002,137.918664,69.05481,35.615587,-4.191463,-28.594759,-39.104232,4.02207,140.714812,192.478571,160.86593,81.581341,59.805105,9.723467,-17.186088,-20.021698,0.102723,-14.900563,-136.256342,-224.553138,-323.306726,-325.664168,-266.482058,-201.587494,-76.050103,-11.805754,-4.107115,-43.899029,-73.921425,-138.540997,-171.352625,-169.371153,-58.941143,-17.214601,-18.96756,-45.202793,-126.664223,-164.478885,-145.754629,-90.425355,56.269039,145.666892,88.801884,-140.223151,-205.027052,-227.782678,-233.381947,-216.734336,-95.380346,-45.681595,-106.354796,-166.192693,-173.608268,-159.428593,-172.278362,-143.420734,72.584559,314.624218,340.769485,222.139401,157.619098,124.602376,139.55683,164.466967,212.462757,260.744107,332.888396,317.347522,143.842911,32.79603,11.21509,122.380351,318.294089,286.035935,233.002394,121.836618,63.174305,-4.87252,11.33116,99.276136,137.344006,137.846459,103.166883,58.832107,-67.995792,-128.14136,-160.552162,-128.696714,-37.300167,80.675406,125.971343,70.146194,-18.612433,-147.818677,-130.895208,40.442263,194.18471,222.737256,179.30662,127.028261,46.821382,47.786439,135.49172,180.088872:-530.242892,-411.66687,-347.100288,-199.982088,-163.518989,-217.326236,-246.119687,-195.364856,-140.835178,-147.113578,-192.508368,-209.655067,-204.076554,-192.614448,-165.935899,-148.261067,-143.396417,-187.415445,-179.339462,-111.520558,-107.348218,-205.931127,-257.146076,-226.078317,-103.447736,-65.801819,-85.136196,-128.332873,-208.465753,-241.789114,-243.974821,-179.600315,-53.210472,-112.428706,-178.722938,-273.440802,-286.472346,-296.077233,-316.116302,-370.801817,-331.499997,-260.969881,-200.99403,-261.966183,-460.630865,-526.278173,-485.023421,-397.511163,-222.881835,-111.958373,-94.564131,-107.693787,-79.358974,58.759861,97.427041,23.349554,-122.551597,-154.221773,-166.963656,-184.661325,-241.65693,-273.534556,-320.203726,-314.002806,-247.36396,-174.274484,-152.590252,-177.263829,-214.345521,-299.641904,-341.121056,-395.107619,-432.283105,-437.514725,-409.839477,-396.742389,-379.672552,-374.061177,-348.194906,-309.611793,-251.190609,-257.985457,-239.434377,-146.85102,-99.298586,-50.419444,-46.892816,-18.90296,78.363272,132.12482,144.977223,94.596772,7.874698,3.538249,27.295848,48.451858,101.375179,80.137197,22.65852,-124.712031,-160.437299,-140.404745,-126.878756,-124.430862,-83.59307,-65.192427,-136.191113,-184.644855,-166.014675,-140.435293,-142.889098,-129.48956,-18.005841,110.312443,176.114389,306.208233,335.388316,261.357542,184.04053,55.745341,-5.845493,12.991103,137.830803,175.783105,148.486389,133.207483,162.514988,182.846618,175.369377,141.462323,142.80794,175.861959,191.144537,209.098629,219.01768,229.700746,241.986825,285.545739,385.429655,381.150347,291.618726,256.459115,214.318593,205.754402,253.972949,361.121335,379.149226,278.212187,216.135824,218.461211,241.209358,156.130316,2.149508,-43.886307,-81.863537,-73.415292,-56.034161,-84.509535,-147.868255,-131.770215,-63.188647,-16.482615,28.968245,158.679497,198.348112,160.746179,119.519344,82.182339,103.993834,132.108908,153.270537,135.00535,102.388365,93.879456,83.095692,98.552483,170.094189,215.169699,223.156866,252.032647,272.688647,299.931954,314.497122,325.623462,216.13271,127.089057,-6.696332,-26.119225,-40.653485,-76.290929,-139.678518,-117.901957,-13.256881,24.416778,4.777333,-41.981099,-28.268174,38.466155,40.443489,-9.299282,-0.663915,29.049808,78.415633,96.786663,124.57173,124.936189,135.476121,178.749738,328.282879,402.733825,387.788162,335.17823,322.484592,266.981689,223.498493,203.169375,251.561376,286.384525,323.283149,292.235448,179.465993,134.265216,78.31612,79.049013,196.212446,334.73078,323.619858,145.816381,59.526069,52.772789,112.239222,207.128123,180.456685,130.105341,28.583769,12.153819,11.788154,-23.83986,-142.302913,-155.976344,-43.936414,83.669814,64.400684,-157.303778,-280.976605,-362.329273,-302.843801,-148.640946,-166.599903,-176.466585,-65.402045,-18.524999,-109.783684,-196.242473,-198.109855,-113.341312,-6.102301,12.602303,33.333927,43.844418,26.990413,-12.665001,-11.128338,47.27794,129.980456,179.361503,235.700961,236.284003,187.403145,116.448322,-13.756353,-2.07588,110.745889,143.075782,129.135205,101.010129,94.406515,52.997811,2.846645,-86.172698,-63.823153,-14.930392,44.698043,33.259691,34.165794,73.045011,128.148771,112.726941,69.249133,93.731699,123.525789,194.045074,208.122873,150.965251,118.294024,129.080494,122.285797,49.924694,-186.752501,-249.526392,-150.031254,-97.722763,-209.324549,-287.614167,-260.313984,-146.712495,-134.226377,-115.507046,-59.379247,29.573267,26.034775,21.438794,31.320125,14.546398,-70.012105,-113.524008,-131.208472,-142.183036,-276.991888,-342.967838,-302.908953,-139.465603,-65.864064,9.363416,-4.965353,-94.57441,-125.106445,-124.22996,-120.815917,-104.972744,24.594289,104.188348,95.463501,-0.4689,-107.817846,-42.014533,179.252459,239.456016,188.604769,88.593246,100.2442,138.668982,89.764577,-79.408787,-140.025988,-138.488995,-126.89791,-107.996299,-50.437795,-14.898066,130.339217,223.125269,273.659404,197.062196,185.332034,175.774683,155.784224,102.658447,73.484537,-1.209991,-43.729496,-9.522958,110.771349,147.988727,166.432345,147.393519,89.147727,95.326911,183.959189,245.092351,242.945668,208.780789,176.03434,74.966332,49.528921,109.505337,175.968981,172.800692,100.159397,53.288093,-21.13813,-89.858878,-278.948143,-313.583874,-232.675579,-130.041227,-85.72997,20.820121,58.944794,17.400195,-23.927232,-0.732293,83.066448,105.129095,126.028707,129.651158,108.283814,105.994307,160.312827,168.758881:-458.827039,-352.234058,-324.477535,-271.620067,-233.001774,-156.27008,-124.996424,-98.844526,-143.987462,-159.161447,-158.191334,-173.593432,-224.742604,-237.738405,-222.301086,-199.714911,-186.215094,-209.81881,-191.761931,-118.652655,-124.616449,-257.428568,-304.70126,-206.461408,-65.623884,-73.334475,-181.996274,-217.317604,-212.070013,-211.226295,-214.166562,-194.50586,-166.784585,-225.910303,-261.278204,-303.719176,-319.63137,-358.842113,-374.687337,-347.198226,-232.764632,-163.323877,-82.921697,-96.295136,-228.748528,-315.550689,-341.343567,-263.65397,-124.687678,-74.851968,-59.667239,-46.137088,-19.792688,53.403575,42.779011,-47.8285,-36.588688,-2.432249,20.869196,0.283275,-109.031525,-199.429863,-379.567413,-402.459148,-293.548529,-161.5915,-110.997355,-80.899513,-110.098909,-175.223274,-193.254345,-229.071028,-263.945564,-267.584389,-244.017354,-212.12739,-155.107633,-166.727283,-214.575175,-207.866302,-174.232344,-188.849489,-201.310316,-207.594049,-172.509168,-5.950633,67.482938,98.663001,76.956385,87.293674,109.99429,101.186254,55.788209,17.303901,-53.871802,-38.815818,72.097866,65.361477,12.014561,-52.708361,-47.229694,-67.278679,-114.910621,-199.281178,-144.298833,-85.219205,-49.672323,-75.193367,-96.017391,-72.874732,27.438131,98.334519,191.579088,159.425995,159.791728,229.843225,230.271266,59.250542,-37.423921,-69.280749,-10.822112,34.331866,166.299372,198.29599,152.862911,135.029947,190.949121,225.491906,210.139601,130.261628,103.675089,104.70029,139.156583,226.20483,240.351105,169.464855,128.297408,212.206951,439.420471,468.143989,340.411663,265.081756,224.507462,248.2634,332.062812,423.161648,425.375733,264.772821,138.318935,-7.614007,-1.432207,32.478977,-22.645298,-55.429225,-58.907922,-36.453105,-22.056886,-71.634638,-230.842204,-256.323968,-116.643264,155.324876,257.325804,330.756529,334.243736,265.656595,217.871612,263.369718,391.923305,388.862666,241.546881,184.66491,232.019642,278.780337,298.324062,292.573586,269.994127,232.494658,234.964984,263.23187,270.673161,299.2438,333.5486,376.330702,260.320216,168.733591,33.633869,1.38795,-19.399882,-40.654357,-94.759583,-88.15623,-26.643854,-3.346362,-26.354667,-91.128167,-98.001008,-118.446514,-160.17731,-220.052725,-205.440114,-182.646414,-129.49657,-111.378157,-75.316974,-56.507405,-16.825693,8.242485,43.98145,98.471635,152.974218,248.136442,250.00788,159.251437,118.164152,140.289056,185.186632,204.68079,221.894687,169.33138,2.392736,-37.852541,-34.792014,-27.730215,13.156675,80.754004,78.59124,-2.397609,-43.776682,-105.671495,-114.747,-12.906383,103.425786,83.606956,-20.698615,-32.339104,-18.057713,-50.03182,-100.19216,-51.89882,97.979352,144.809155,102.420517,-97.661089,-179.042856,-201.86256,-192.009512,-183.633646,-88.881966,-12.119934,74.351211,57.327362,-49.414765,-84.401045,-8.028899,60.299952,109.593802,158.680952,210.634449,231.835178,178.827687,61.709781,38.481792,38.611026,42.118229,54.64577,87.689244,82.512598,33.919758,-0.883968,-54.871314,-38.764547,101.529025,225.063972,208.782388,73.613196,14.121952,-70.769837,-110.266614,-151.588307,-84.527704,-8.521684,115.602303,131.00301,103.352623,64.74359,-3.441595,17.5992,169.531347,270.876002,256.558649,228.735502,251.277967,264.67321,254.570334,292.966421,262.826481,188.819214,67.980169,70.973927,152.120261,160.03018,86.281338,58.612698,92.754528,174.671153,194.783611,214.758182,239.035678,256.170727,243.512927,242.577688,206.257765,164.37568,74.830763,42.757688,-2.478513,-40.808255,-123.541584,-134.620441,-76.771274,-5.441789,4.888218,31.56031,54.0826,17.826276,-44.68084,-122.788288,-59.377663,-12.628165,-47.574883,-131.283011,-201.790145,-154.900605,-42.584813,3.166181,88.184448,125.032026,124.11538,124.973071,120.397389,22.323341,-49.331839,-119.273227,-80.540849,-35.741086,10.399159,-1.219923,-17.455849,-14.766977,-28.342667,-40.608062,-37.206038,42.024675,97.500196,157.060797,148.70125,85.690426,64.342788,28.593009,-117.035768,-171.985303,-102.420524,-27.918437,5.554384,-49.284769,-186.166281,-211.439219,-99.720494,104.305182,133.698525,46.77174,8.040477,-12.013071,-0.023324,73.800719,113.233069,92.087881,26.075425,26.266707,60.878916,16.697318,-169.346097,-215.623926,-203.979025,-161.247066,-114.630093,-19.948058,-8.043196,-51.593306,-62.82902,-1.517331,79.440925,112.916055,161.825112,183.805483,275.31015,310.934828,262.783369,198.925342:-493.28299,-410.027335,-308.003079,-121.411999,-91.017932,-118.841478,-131.159268,-123.860292,-134.742155,-134.210699,-46.393474,23.348775,66.139776,31.66534,-21.768362,-24.535109,-18.951347,52.684,100.39755,124.885112,87.385961,-42.005874,-82.878861,-82.235389,-16.622407,34.458396,66.249709,25.160334,-74.737393,-100.124315,-77.549762,-27.167793,82.530285,91.545376,55.072389,-92.058521,-175.400199,-244.110762,-225.062737,-174.171624,-150.967078,-135.024224,-138.714019,-184.599055,-314.779447,-349.700091,-262.151456,-154.963931,35.679355,72.973971,28.800747,-42.863925,-4.978115,137.608164,153.365459,69.847025,34.777147,41.668793,-6.725158,-75.00279,-221.884793,-270.87964,-335.602822,-367.737571,-360.374556,-227.353125,-193.472311,-246.879547,-285.584636,-328.238715,-341.347275,-371.557042,-424.669534,-434.05509,-375.424123,-322.855613,-248.369077,-259.59212,-294.608367,-261.842292,-129.282929,-41.337205,-36.975252,-97.558247,-130.272937,-112.906564,-60.738083,69.598816,199.0573,256.877097,282.96484,219.679901,14.195164,-47.581736,-16.867956,35.015278,138.543503,202.104623,181.532011,31.478739,-45.639536,-113.759008,-112.570788,-33.307032,87.760169,86.475527,-56.922764,-113.011582,-70.977554,-56.388584,-157.598391,-179.308729,-31.117429,142.25413,199.657217,298.861574,326.345159,338.78625,350.801339,336.738505,175.932101,131.894132,217.548162,257.630089,218.653494,179.179022,167.494444,197.125772,254.338753,317.477418,337.408296,287.038292,251.58292,201.353022,154.937712,62.191493,100.988356,143.094855,167.655905,144.644967,78.308627,61.010059,77.092625,98.649885,166.619628,229.962233,209.400466,82.696435,42.553589,23.431423,16.518165,11.391176,-7.294253,-31.101622,-113.59835,-151.511251,-146.68612,-124.337355,-119.40481,-132.040476,-128.078326,-37.250739,19.323419,63.817553,49.771154,-36.601678,-105.044758,-156.987651,-42.384817,-2.890505,-1.168854,2.508191,11.742444,-36.974435,-180.314726,-189.919086,-69.968683,115.330974,201.548514,311.837624,324.052002,259.596662,229.75279,248.718172,198.247496,131.414734,32.277342,28.070675,17.51815,-49.320604,-187.805001,-159.798659,41.711284,114.251382,72.665898,-14.688149,-26.47444,1.739831,29.950763,56.224745,55.879906,73.850892,86.541237,44.231589,-61.104043,-52.875486,62.359867,97.311215,132.501687,267.079214,312.383343,261.084071,200.476498,79.032764,47.089459,122.595115,247.549572,255.092753,168.396001,91.51637,-77.012344,-127.644096,-82.037679,-4.283846,134.044804,185.47099,176.276107,121.609347,111.414668,144.56492,183.11837,294.857308,267.196256,183.282217,81.663318,91.140091,60.225763,-23.984689,-159.025186,-130.473204,40.673136,71.050084,17.281711,-74.702982,-109.398988,-251.515904,-326.590506,-339.033153,-212.6986,-132.72265,-11.693774,3.774364,-78.081644,-140.746279,-130.784862,-64.527058,30.265034,70.698887,62.452836,-26.525834,-66.785799,-105.658103,-111.044086,-59.997286,126.926272,215.406981,193.945442,110.906189,-23.105559,-40.0318,63.635012,137.677571,163.746073,73.860133,26.061476,29.387281,80.10475,92.966598,30.307513,-68.946773,-13.165658,17.832804,-27.099867,-64.213384,-3.125619,81.139504,194.377603,206.178985,190.091413,168.028979,168.575741,168.95634,140.07031,62.565153,63.018805,116.506903,51.134527,-31.060392,-153.912498,-160.869053,-124.376834,-125.982303,-168.360341,-157.903825,-52.459922,-35.551126,-60.393607,-32.712573,15.710685,30.894599,-16.210646,-88.481866,-56.551241,-29.297933,-61.173859,-126.568405,-202.922855,-203.067276,-240.473815,-266.631222,-231.543576,-80.205723,-6.227127,64.94215,44.260251,-87.348315,-140.939592,-123.864035,-30.903682,7.623198,81.795066,110.227187,88.389369,53.661972,58.771321,98.634051,146.454164,142.149594,122.737592,66.393598,49.837646,10.862696,-32.220923,-125.134965,-142.341327,-129.120806,-139.382573,-161.617085,-179.750659,-174.043844,-76.996454,31.619819,219.705827,238.5251,222.633161,208.695009,219.974626,236.534312,205.156545,106.80435,117.525034,158.893479,208.000585,218.31801,244.222881,227.897279,143.402051,135.117793,187.569442,163.090586,117.035621,79.416597,101.957838,165.170603,192.129425,198.856822,98.945043,41.027216,-4.577125,-10.152396,-116.1138,-216.244029,-349.890124,-335.788209,-234.360913,-181.256771,-141.648508,25.300988,92.210325,7.551997,-86.583991,-132.405403,-39.01473,10.241123,59.493134,49.568119,22.570077,22.985139,57.743163,99.57468:left
-38.792021,-124.426187,-158.930272,-92.430403,-17.417667,52.717316,47.8774,40.977498,8.865538,-53.295811,-232.605892,-282.156832,-234.068089,-167.915228,-37.568343,-12.720448,-63.324708,-142.11661,-163.821663,-174.170473,-169.033485,-86.990001,-0.363635,127.574169,129.079547,100.035896,-32.693165,-93.926787,-100.527803,-72.748956,-45.429871,-56.982088,-115.131012,-156.295345,-168.777208,-190.822067,-196.562764,-197.418437,-179.530166,-110.231607,-76.412794,-98.010256,-192.607333,-199.728007,-73.620884,-10.461796,-3.059602,-29.773375,-81.365907,-198.633886,-264.240786,-228.280089,-128.239017,43.457192,78.42126,87.488252,55.262634,18.028642,-91.93088,-136.79036,-142.355337,-103.934071,-7.464175,14.732125,-21.170663,-131.594862,-178.16542,-156.215064,-106.217348,-16.088076,31.620258,125.064658,122.68673,93.330163,13.282144,-25.648625,-56.942277,-53.896941,-61.567621,-94.023553,-167.548193,-145.054835,-136.481608,-133.604339,-101.846874,24.899159,85.851686,78.779516,-99.758823,-179.942631,-228.318235,-204.900245,-102.661267,-33.960343,80.312412,89.038465,14.433429,-90.03274,-134.986109,-96.314547,-18.085542,56.572549,24.876644,-58.802147,-74.470771,-93.274214,-175.154561,-185.923201,-109.49853,-64.385566,2.394839,28.543412,23.599205,-88.106051,-146.319156,-134.515832,-67.663835,60.508498,92.044707,86.201017,53.600751,51.100629,32.169808,18.77841,38.695225,75.36052,161.257579,181.619612,127.082784,-3.963533,-55.16504,-65.133722,-56.12369,-126.051325,-186.997031,-276.832343,-347.772983,-383.578355,-355.557074,-270.432148,-134.143472,-144.685243,-164.953801,-103.754505,49.826529,25.804731,-42.808562,-88.467483,-30.982874,123.210756,186.057978,266.400635,283.280895,267.947429,189.516259,155.687797,148.962227,174.718301,255.048392,273.679057,238.033425,183.123248,181.191015,270.483758,321.731723,335.998291,313.856492,247.308898,185.887964,154.245362,80.671524,77.62632,172.594981,228.564044,301.308944,302.515638,167.063596,-10.835547,-26.962381,92.486586,171.489923,237.740956,220.12105,150.057435,57.737622,-19.591782,-175.18521,-186.342494,-66.854306,11.058212,99.220801,96.237151,54.80995,21.41671,-13.134009,-91.425775,-99.548857,-29.76221,20.442229,34.74465,-58.863082,-106.876366,-166.095745,-151.914168,-56.375907,-34.499785,-97.838236,-153.664437,-211.121941,-158.602007,-117.670011,-77.933125,-85.233985,-64.947487,-26.146435,-45.349386,-238.302689,-315.184646,-342.770682,-323.19755,-288.353654,-264.871059,-177.655243,-136.388223,-114.76067,-172.713037,-215.475157,-244.411959,-221.217135,-170.443885,-147.720143,-94.379223,-86.900074,-117.542642,-206.559825,-206.354372,-105.408316,-69.350121,-53.590175,-50.183615,-36.18043,-19.258043,-0.729165,73.918022,97.872573,93.014889,99.655898,141.971116,128.324934,75.708053,-84.469505,-145.96033,-163.279251,-125.319973,27.524737,124.13031,235.616337,152.088232,80.042127,27.410989,53.644437,112.72045,128.10446,145.822811,177.476284,193.403697,199.067263,207.502439,242.933423,251.081647,235.986626,218.907377,203.122797,181.525012,136.785205,13.796946,-32.477554,-14.639684,52.610284,145.8386,82.663807,47.721081,36.661263,58.828398,122.569528,154.294774,241.459743,280.051009,259.190471,100.546505,12.399369,-56.591845,-25.079496,102.063401,152.76425,122.616577,60.384893,66.558158,41.727933,21.215535,116.901205,208.763739,284.280107,248.6754,127.267958,1.770633,-59.85485,-104.890341,-71.549212,24.057189,42.178341,-12.446125,-93.751329,-125.019403,-196.13998,-202.543699,-59.740561,44.206172,110.279517,59.188098,-70.022072,-165.455728,-200.377646,-125.975261,-20.278627,137.359988,163.506877,179.796585,137.64393,74.275571,-90.553516,-129.857498,-44.795326,23.317426,73.610618,53.86674,-12.933944,-30.049891,-30.058646,-78.209699,-115.84792,-123.041442,-105.800998,-132.435832,-209.695992,-243.901501,-277.388951,-276.719427,-273.2078,-249.714667,-114.897913,-60.324317,-119.105119,-311.734196,-366.881817,-271.388529,-150.851538,29.585585,30.21925,-112.161908,-185.965187,-172.702075,-169.54267,-168.079321,-100.323308,-47.942003,5.858634,-20.479641,-118.745424,-196.238746,-248.890785,-367.108356,-375.804314,-231.369162,-140.847861,-95.713485,-154.265963,-158.797476,-137.12429,-139.035607,-95.058231,-22.772813,101.32964,110.637922,44.490052,-120.880501,-207.420975,-204.304044,-127.234634,-7.895305,9.10485,-17.771535,-46.450176,-33.551968,10.099406,14.553148,5.564394,17.169848,60.15486,50.010343:-95.724313,-130.948861,-104.509394,-9.456227,11.099624,31.966677,63.949282,113.490897,39.316912,-35.298556,-223.421396,-287.34685,-213.914504,-111.945654,-3.100982,-35.844725,-159.396088,-185.041117,-177.505472,-151.59118,-108.79989,0.616974,40.19245,80.358928,37.297233,-5.902088,-44.882851,-32.296661,5.196033,19.312339,13.208413,-17.996804,-86.628354,-177.952615,-237.044602,-264.087891,-240.640011,-202.55318,-166.413661,-69.533657,-120.946625,-213.800082,-344.173397,-317.446275,-173.566857,-140.523999,-171.548356,-175.769208,-140.214613,-203.372798,-251.635095,-259.82939,-235.275462,-187.649421,-167.169126,-157.841699,-228.091508,-281.053056,-333.655751,-319.516634,-263.942407,-252.07976,-288.558765,-286.134251,-176.28838,-184.04439,-250.979968,-287.625736,-225.74798,-64.690032,-8.361618,40.422284,24.237902,15.568398,31.219281,43.688611,36.08483,23.830034,12.945744,-7.958487,-110.431703,-154.132763,-135.257423,-99.18531,-77.90795,75.554762,169.120242,164.482457,-4.832094,-74.742312,-159.761978,-155.646885,-32.137558,34.751099,47.716523,24.350439,22.955405,-54.527984,-119.097305,-85.664539,9.627646,132.316683,114.822824,21.011035,6.020809,3.862875,-80.880353,-130.932907,-109.316935,-52.535412,17.108005,11.575929,-61.205771,-175.244556,-212.601004,-157.116759,-73.210956,44.108066,43.115001,28.838409,43.868617,3.990267,-149.32892,-181.800717,-69.829003,21.559388,87.398699,51.16435,-22.545127,-56.996669,-89.812079,-121.259403,-101.121479,-68.860608,-78.809234,-167.138363,-353.096312,-432.040332,-395.072729,-292.992352,-116.22319,-72.525901,-42.175834,-45.023798,-64.63851,-91.834401,-84.513916,-7.672562,26.337462,44.669169,50.045269,66.362907,70.760506,57.698165,54.380633,92.132986,168.780212,187.080003,261.04599,304.036415,277.347744,136.484405,92.250484,142.143292,202.781994,274.613812,258.383395,123.561977,12.535348,-19.351029,-79.815507,-78.965505,22.263525,85.542217,100.605752,36.931653,-91.074639,-79.896798,-34.399433,97.025741,151.419327,167.065177,145.807094,87.71765,-24.32204,-105.091127,-244.165525,-255.81813,-172.981342,-130.716068,-108.728811,-115.059351,-121.212422,-133.64177,-147.719069,-168.942522,-154.74697,-56.019052,11.535301,81.722766,-16.654013,-100.071639,-217.189736,-221.696322,-163.111258,-143.300683,-192.885413,-256.637313,-361.068891,-375.142096,-344.715601,-208.534187,-139.254986,-71.552685,-74.952834,-170.45047,-353.176781,-424.123279,-429.546681,-391.179305,-342.794702,-311.730493,-212.902645,-199.877278,-302.686849,-399.238147,-390.491401,-333.259348,-329.937181,-311.229022,-249.784139,-134.560611,-206.949132,-276.820007,-306.310458,-251.708746,-151.654078,-151.733314,-194.096689,-190.707822,-115.670809,-64.548143,-49.034076,46.054186,95.162279,94.084473,67.326132,36.882179,-15.500459,-81.106186,-205.155254,-206.154557,-117.022242,-64.981627,54.606844,116.600874,169.63941,63.95121,-5.014972,-41.176397,-9.743479,61.364111,78.175398,98.345618,133.39951,133.999729,83.694845,62.609146,80.823856,115.324536,218.229059,264.32674,284.070467,179.650014,94.271142,2.189344,42.482852,211.265685,251.678605,161.150208,13.305838,-31.144863,-46.101402,-13.843103,54.589934,72.994229,132.091946,172.635346,205.970145,88.63945,-8.72168,-131.989604,-117.990206,14.944949,68.129431,55.303872,19.515236,17.755109,5.673599,22.700576,141.628759,199.020151,204.005095,168.376625,102.189781,25.749475,-16.528996,-79.843672,-90.302763,-11.809216,60.10496,130.864163,57.827584,-8.262907,-86.446327,-54.80128,93.69748,151.046616,181.916605,166.293851,52.867604,-152.56146,-196.478839,-4.209718,161.256531,334.989186,341.917084,361.730064,318.381456,234.538989,113.326427,136.30407,256.710664,288.2886,286.822426,282.44239,249.527139,137.085003,74.12905,-0.313542,-2.607343,48.457199,68.164985,54.111683,15.621048,-15.246168,-93.426501,-124.184686,-114.89629,-59.30414,43.844656,16.948138,-150.856601,-279.642552,-312.450183,-270.91129,-203.43556,-72.856366,-38.781573,-44.548385,-81.324022,-107.783545,-151.544767,-129.946544,-20.491322,14.790967,-2.280922,-29.243115,-76.755098,-170.915254,-231.859378,-303.938082,-298.570793,-204.863099,-138.971705,-96.136934,-180.443663,-198.211261,-92.215846,-3.028317,128.581944,174.262456,256.594078,271.706354,229.100773,114.607373,36.674364,-54.704924,-18.012272,168.884043,225.680594,184.19759,140.825751,125.961549,70.482292,60.306209,91.653014,113.07733,143.856929,146.850805:-114.553349,-91.022006,-34.875592,119.504497,159.360912,102.338297,44.361725,-8.468798,-62.360204,-132.644533,-250.017152,-260.448555,-205.181723,-149.159008,-27.73695,-0.211549,-80.294616,-223.573768,-232.265113,-110.587885,-19.346013,145.66087,188.000812,151.500641,51.720313,15.332013,-24.613068,-22.369424,25.434497,51.324802,57.485459,39.443014,-8.432518,-103.08323,-158.576872,-208.094073,-194.134656,-116.115742,-82.399743,-74.443134,-140.376316,-183.169936,-216.841733,-212.278697,-206.011328,-198.071637,-185.306674,-190.51419,-172.504735,-174.091092,-195.655446,-176.790343,-141.43026,-108.183919,-112.583213,-147.293965,-250.815365,-306.260623,-275.97731,-203.283316,-159.497435,-195.52561,-194.045261,-130.013893,-18.052062,-86.76099,-140.795676,-118.132505,-76.284138,-62.355954,-56.571188,17.845724,49.680185,38.736609,45.854908,70.718121,138.302177,173.664048,159.270631,91.033088,-66.91081,-141.421535,-152.654556,-88.815153,-17.121528,111.811832,143.632934,120.208408,15.187338,-61.594712,-171.804722,-145.457287,50.296879,144.26383,157.0326,76.493394,-100.298251,-161.927608,-141.543182,-16.734528,57.476009,162.857435,183.69235,151.987711,50.720538,-1.834169,-87.509694,-116.475842,-109.287548,-71.829255,-29.097352,-49.666119,-127.935442,-214.429766,-236.504896,-145.104758,-55.50594,58.918914,73.334936,53.975182,-52.908449,-122.230863,-204.012865,-206.646893,-149.554768,-105.036725,-48.000894,-40.421295,-48.505222,-116.264529,-141.603151,-47.758624,42.24006,109.297314,49.524106,-189.360321,-399.973525,-439.757763,-365.697672,-295.825725,-194.782592,-159.407791,-116.70157,-120.587989,-145.75622,-146.483439,-118.619561,7.007714,55.950107,51.304151,18.60626,-21.259626,45.134356,71.004386,44.012403,32.935548,100.566289,161.743972,216.771591,203.94852,189.397286,147.800383,108.284594,82.547307,104.634823,157.280995,154.394004,65.939007,-75.323322,-136.813773,-178.47942,-146.416405,-52.505115,-28.123448,1.051905,19.961133,-3.335584,-114.313394,-118.924254,34.467121,128.014193,226.297599,217.114578,105.210202,-32.740979,-108.684776,-239.11768,-251.345302,-186.001818,-142.400827,-114.898292,-145.209675,-213.234416,-205.741319,-190.714308,-174.477461,-155.922055,-95.460165,-84.438425,-110.727996,-132.094084,-149.688364,-184.932371,-182.83668,-189.426552,-204.633538,-245.237796,-282.45304,-363.969953,-342.558265,-270.078862,-122.997177,-108.588501,-136.497159,-137.491,-166.011768,-296.181203,-378.179232,-467.050264,-439.320118,-255.213459,-157.608633,-104.474906,-136.67827,-190.163844,-261.631882,-316.666944,-377.384647,-362.996718,-245.198495,-168.862455,-102.383943,-181.404547,-241.165797,-292.053021,-256.898186,-120.170228,-59.364257,-40.182655,-82.697274,-146.609344,-99.461728,-51.742101,30.309512,40.602251,21.250292,24.089217,28.074152,-51.539303,-82.993326,-74.988031,-56.10935,-36.273676,-30.915986,57.667653,131.911803,178.356514,68.200733,34.267752,64.279623,76.778378,61.391057,70.052327,105.166,44.420082,-6.690956,-20.092302,20.528051,91.51889,107.815643,147.794515,173.48707,178.494876,106.559548,65.02811,19.656087,37.044276,119.735146,134.380603,92.834567,45.748288,13.555352,-27.744869,4.023781,101.258809,108.83679,87.330139,94.3889,104.403386,16.050103,-46.206282,-79.190304,-38.94902,57.181589,58.161199,-16.007746,-18.984105,-16.006121,-43.728823,-33.376734,75.412492,142.041406,186.265404,155.328257,67.293465,-34.889844,-90.331492,-175.152128,-186.045893,-107.989191,-51.425529,-30.83478,-77.363373,-83.11992,-54.662174,-25.166653,63.171962,122.050934,197.208205,163.484681,-19.524942,-168.945368,-188.782803,-53.67033,83.154019,319.125622,374.728392,398.60851,337.760573,265.299051,104.861894,75.150906,136.82196,174.418342,171.086887,150.186637,130.03767,46.54613,8.273617,53.595882,78.875699,30.326525,-7.808854,-47.965699,-75.081801,-109.665745,-180.431887,-172.593516,-84.488178,-40.899059,11.243231,4.445847,-102.387074,-247.191367,-265.63713,-152.429836,-78.26873,-13.125429,-25.849489,-114.852157,-160.13442,-141.340401,-78.180545,-40.925541,30.095317,52.887672,19.529324,-53.311038,-231.380589,-300.217144,-274.361236,-208.481342,-217.235989,-255.214897,-226.824119,-112.827729,-87.3828,-123.776292,-159.45454,-102.412186,84.597747,145.925446,199.715963,235.740084,306.136449,257.086258,211.302759,176.869621,198.222628,311.102822,369.381821,372.378588,301.636209,273.619093,222.807176,217.824968,292.888499,350.695983,365.021339,305.351596:-56.805371,-89.238083,-90.528218,-32.507087,-1.463019,10.816176,6.825911,14.396518,-31.82089,-101.377857,-266.51594,-306.970709,-269.50243,-217.007295,-106.649569,-74.190269,-75.828168,-144.089121,-189.829029,-209.055067,-169.186163,-45.133783,24.857426,107.446791,78.473636,50.248875,-21.043037,-51.011126,-42.072046,-14.095735,6.307447,-15.647302,-77.232647,-166.655622,-241.972034,-318.531624,-264.143977,-108.344014,-85.405724,-90.968001,-70.409439,-93.275361,-176.277336,-188.673852,-158.643237,-128.970296,-43.602155,-15.417112,-46.545755,-110.396797,-112.475143,-46.33358,-16.046804,-10.483807,-5.404222,21.875796,-27.389722,-78.454907,-128.168406,-115.110821,-92.769761,-82.457259,-12.447266,20.392204,10.907449,-59.806715,-97.669759,-124.295724,-106.181914,-28.366149,25.408182,91.854853,61.790846,33.957189,-35.960427,-64.088375,-64.264599,-33.996922,42.345429,37.344449,-101.368251,-262.389061,-310.372592,-267.949424,-164.466539,89.757562,176.204656,192.984768,68.094198,-9.871233,-140.583361,-156.849356,-33.234042,72.860737,191.488527,166.248784,44.006551,-48.943783,-81.666298,-65.913056,-16.311539,65.488829,67.833924,-11.946611,-89.331881,-103.686922,-142.17069,-144.444726,-62.804158,-15.285484,-3.26413,-43.638202,-147.931883,-206.518186,-205.297094,-103.45994,-28.522056,86.108996,121.748537,117.323544,10.678937,-47.524546,-106.549931,-85.818275,-2.851676,7.50387,-10.944665,-7.482507,-8.933751,-43.240912,-44.912289,-7.978886,0.975579,-40.163455,-79.111832,-175.440843,-322.553257,-402.270524,-394.508718,-271.195271,-24.116624,-3.378675,-96.644633,-114.882428,-63.233408,-79.759083,-105.840861,-53.12834,38.092123,226.129493,267.983808,260.958985,237.196958,198.145764,101.816996,110.515759,224.141329,267.549035,282.453658,273.039694,255.927918,189.0558,156.209205,244.507182,336.744397,394.87241,334.400589,158.451128,75.213138,42.396711,-73.141224,-108.481859,-43.009854,35.367189,165.559705,172.245833,87.443796,49.763777,70.80938,122.656283,136.169761,145.354101,138.262721,102.672644,47.120299,-25.367217,-206.364557,-226.76802,-111.264945,-44.976991,-1.878328,-23.916361,-90.22093,-169.644858,-211.880774,-227.569018,-197.582375,-119.44621,-84.515271,-58.02186,-86.559242,-112.167331,-166.553811,-181.661632,-184.266526,-174.000682,-179.739203,-219.678158,-275.173064,-185.221511,-120.313281,-21.936283,0.476151,-7.958845,-25.885591,-81.0475,-204.397588,-276.645506,-328.948177,-306.025484,-243.793885,-209.68346,-140.639718,-127.518494,-133.634095,-137.051625,-152.086763,-219.026803,-248.102511,-225.772409,-169.582776,-48.655532,-50.267394,-116.669688,-222.102523,-188.076551,-69.621453,-60.407505,-81.074462,-77.778067,-51.938922,-16.126114,-6.168917,0.10722,-1.882977,9.716474,37.471523,91.151495,70.288766,21.256826,-110.878507,-148.105941,-89.857001,-10.949448,165.961947,226.635966,228.764849,132.895966,84.641736,59.080517,91.674449,174.775323,193.583331,203.890125,228.123052,216.753259,146.439981,135.351724,175.617411,184.755858,184.586718,211.371439,263.039601,154.528345,75.115398,21.289377,47.288038,128.282887,160.451417,130.138457,-11.713516,-59.680464,-66.920616,-32.148778,105.847655,180.369411,258.104104,252.647365,187.804805,67.179309,-4.355038,-48.55483,3.912889,135.330503,152.984595,72.809098,-35.934822,-67.838504,-74.461219,-36.491356,56.040716,78.537076,124.150275,145.080251,117.026223,2.945961,-52.853197,-83.268132,-66.114664,-23.740005,-6.220393,-11.378871,-136.01388,-238.095779,-358.492026,-311.79141,-99.21223,-13.363003,51.37221,14.510558,-188.637089,-369.119698,-369.687568,-175.592689,-40.44712,152.669252,201.147327,216.411309,64.305662,-48.148921,-180.77613,-163.144747,-34.728031,8.618619,5.836641,-1.886965,-12.699899,-120.282278,-181.635092,-214.966387,-208.751948,-194.969151,-181.85477,-196.744947,-278.406335,-309.316951,-322.265967,-309.753873,-223.469124,-139.130021,27.157938,29.788069,-154.31067,-320.165612,-313.287448,-135.58148,-47.260467,10.274394,-2.505328,-97.4814,-190.264156,-203.842767,-245.940716,-264.364154,-179.962405,-101.875121,-44.075348,-76.814385,-177.573049,-268.661623,-303.524325,-331.481147,-332.920571,-272.67503,-188.945482,-47.713048,-57.006737,-88.033991,-122.251332,-93.104598,34.926796,90.315475,136.739776,142.317148,150.019969,57.32428,-19.071099,-20.187204,59.486311,186.27707,210.274355,225.359332,200.283804,163.429119,72.649378,52.431458,75.839811,90.405802,121.279622,138.361449:-57.487397,-205.790418,-214.531261,-70.535354,4.969195,54.650475,39.698359,-55.388383,-204.694216,-255.253804,-276.720403,-277.136721,-279.74402,-249.566985,-139.078843,-110.839796,-145.812806,-255.794509,-302.199728,-226.439005,-113.53508,104.628354,155.416174,84.919022,-23.953283,-35.23412,-32.139065,-29.947119,15.245334,59.551209,130.071046,123.958832,11.927212,-133.402072,-178.513946,-184.290005,-142.260688,13.16499,79.691765,77.836772,-65.058652,-147.588467,-267.868556,-276.533455,-144.292729,-35.752498,92.656515,81.940367,-10.274458,-95.073741,-89.299323,65.912668,143.020081,154.041372,118.913668,15.472081,-163.120175,-227.093208,-196.144793,-150.056473,-136.760973,-146.875581,-106.403969,-66.45265,-37.300616,-125.307131,-159.62667,-102.771103,-51.933839,4.021474,22.865383,23.159699,-47.658443,-79.029611,-53.146087,2.381698,89.111387,100.952361,80.882346,36.68323,-81.268334,-124.390341,-119.214831,-78.483916,-26.323895,140.335527,193.237024,155.01608,88.922061,42.098978,-98.95603,-123.693842,9.191414,136.295296,276.421548,218.90002,29.090001,6.947862,38.887125,70.217753,62.26908,103.814337,157.901678,158.928057,5.082929,-63.542591,-134.995075,-120.956393,4.285124,72.074176,78.696161,3.420615,-144.859424,-148.283824,-124.382455,-23.527954,59.842876,219.244199,249.221022,144.639978,-64.02691,-137.896342,-166.495679,-131.176965,-26.910559,21.767821,57.296194,30.964344,-50.58184,-64.894808,-37.621838,25.602795,42.45612,49.352653,13.940527,-188.492272,-431.807141,-514.446757,-501.176114,-414.223298,-257.512888,-217.535836,-182.412622,-177.363215,-195.768954,-235.843764,-220.658444,-115.23314,-48.374531,93.864759,152.030362,193.122047,130.132503,73.732429,31.304374,74.416671,206.822779,255.60623,299.268859,310.403873,309.180437,222.548076,173.352641,150.457711,182.994753,296.065057,326.597728,236.005077,86.349104,28.334577,-43.914724,-30.080434,103.15379,188.302541,287.093973,269.946338,121.113618,40.961719,85.415476,187.380327,182.123301,178.666574,206.771207,182.799514,0.37637,-111.777832,-251.635451,-254.822129,-178.827858,-118.443434,-21.281116,-36.358193,-213.809044,-375.222613,-360.435202,-205.349929,-151.143639,-101.428506,-64.3617,-1.084178,-75.165245,-165.567456,-262.057636,-211.852757,-75.583289,-48.112514,-48.173511,-77.014648,-184.717756,-255.601164,-237.435472,-103.445832,-32.630577,29.707719,12.487239,-79.817703,-199.268524,-258.989939,-273.592942,-220.42124,-120.637132,-85.849512,-26.1859,-33.24198,-123.0845,-164.373807,-139.058094,-100.14995,-122.054128,-143.605322,-105.55773,-7.58056,-29.387378,-94.185125,-141.932797,-81.284856,39.534265,52.5373,42.777542,26.717253,-48.526492,-107.61316,-107.457556,-61.654793,-18.419644,96.389284,137.761914,119.290793,17.34819,-28.636133,-60.341165,-39.634819,19.097644,46.048554,115.760609,135.071473,76.364756,-13.844486,-10.010251,87.371707,143.729724,242.468149,274.744289,241.097117,125.41724,98.609372,139.519725,167.606965,184.266379,196.238796,240.020308,248.699779,216.647608,106.440554,60.60645,65.205326,74.689145,65.107896,78.751112,110.48771,26.520028,-51.012521,-115.802566,-42.483109,215.359424,303.960846,295.113487,229.694722,97.492369,-32.491164,-66.512848,23.855686,105.408697,199.493089,206.088129,144.647059,45.068818,28.784908,57.890973,72.795502,102.667008,141.051637,215.394259,209.82285,128.875447,-18.827998,-103.675559,-144.115127,-83.305054,72.293246,121.475363,121.987835,-39.529496,-156.392628,-230.652634,-152.529142,53.062759,125.676268,186.267721,160.221031,-5.66961,-210.491299,-249.320799,-141.567615,-31.617763,189.907266,265.917401,294.673967,174.432399,88.316494,-34.090852,-34.243205,85.869365,158.216629,188.841331,147.915886,45.11466,-49.403882,-72.30312,-64.726054,-56.100519,-5.106564,32.539564,-2.028296,-199.749045,-274.275063,-252.232338,-178.306171,-11.590791,62.341952,161.114864,156.053923,29.896719,-113.415394,-129.823244,-34.392338,38.410771,168.564042,195.49917,90.291614,-110.729391,-185.13762,-181.508036,-85.130913,109.693303,134.339673,78.366472,22.337894,-127.86369,-247.179501,-274.490293,-327.283714,-352.28741,-279.504179,-174.554065,2.040493,-27.45347,-95.32009,-161.789975,-117.483567,62.223013,146.161874,220.819985,210.439714,132.547886,-12.083692,-79.769294,-57.724434,42.302695,282.236864,343.611611,291.292054,189.779471,145.415884,41.466525,23.504555,134.143208,216.4895,265.406844,221.280152:-123.612821,-196.471856,-232.71982,-185.45846,-137.054321,-125.402766,-144.16064,-196.500282,-208.551066,-182.400632,-167.488913,-188.872951,-191.41059,-148.556618,-46.652148,-32.994389,-65.507183,-150.606001,-215.866324,-279.351889,-252.874512,-110.506975,-7.659224,175.112975,197.256297,128.607952,-82.449961,-140.345969,-122.333735,-117.256377,-135.054317,-112.211818,-36.667096,-91.288437,-156.119726,-172.224415,-112.693089,-45.359056,-67.660691,-101.649177,-29.240857,8.634183,-2.817883,-44.392504,-114.040758,-122.597856,-84.157186,-33.919915,75.531821,53.336479,-8.697003,-70.607109,-33.690784,70.382804,115.771176,212.497039,162.287712,74.544874,-31.207403,-15.134048,53.343434,89.850572,214.277136,267.413888,228.215527,29.337336,-66.302107,-94.887183,-32.280543,80.368444,98.398481,92.063714,118.329392,144.955434,97.664498,20.760741,-104.171932,-116.771492,-79.129337,-85.931009,-187.154097,-251.810529,-262.109275,-218.615282,-129.470635,99.835981,168.877977,163.081084,31.370061,-35.520718,-78.220137,-49.326586,57.621128,108.525805,162.678641,168.155899,135.994561,-1.561859,-94.12331,-181.780281,-148.960336,-45.067421,-38.008939,-126.22048,-222.05848,-251.578163,-286.74859,-267.78367,-129.74306,-55.349938,-0.297202,-20.695014,-102.165639,-132.917398,-128.796782,-100.284627,-55.006685,94.374286,147.836293,76.220558,-70.355601,-67.194983,67.759248,140.533379,193.242226,174.701546,140.556848,139.450123,127.555755,54.846559,8.927265,-25.804288,-32.861853,-66.449034,-77.780412,-161.368552,-369.834962,-440.695019,-363.635665,-234.128342,-27.822413,-13.619683,-51.429542,-53.773741,-46.932289,-100.746065,-146.940761,-139.49825,-51.289256,177.138553,240.104708,212.743341,134.880838,102.7309,20.102801,-9.986753,34.863389,98.852624,189.27413,182.540256,117.245578,122.998689,151.56909,181.063835,171.410038,140.502072,136.153651,148.01536,167.322485,160.36803,120.658926,124.529758,228.133224,318.667727,469.994636,456.628666,271.604717,170.640745,177.576698,190.849046,177.440194,208.266179,274.426882,339.654996,200.750621,121.183151,66.993025,79.216248,93.835541,109.501046,171.765804,171.315625,101.906759,48.847965,37.109192,39.066458,46.411794,63.673299,72.598845,52.953182,-25.333704,-63.47901,-83.986788,-62.190122,-37.655602,-47.595811,-50.557803,-51.104625,-65.515147,-26.138738,1.108474,71.83982,131.762598,228.806058,216.066,38.919499,-182.38101,-228.749091,-188.751142,-154.231273,-133.983428,-135.262755,-118.519195,-102.047071,-68.955777,-92.981186,-123.143865,-150.254376,-157.160188,-190.123613,-176.638071,-22.107248,46.681787,-21.981204,-182.848149,-182.062145,-31.498529,23.038306,-3.020539,-28.876598,16.773842,96.68918,113.538381,162.538759,188.284741,194.998337,204.708161,219.347698,126.892154,70.59702,8.249747,7.380886,51.087123,84.515499,174.64934,218.702578,252.993922,204.028372,166.156835,140.588705,149.753885,173.290278,201.067253,263.537907,297.166535,316.889099,343.391694,335.837331,246.741547,177.916123,112.943515,134.694229,187.579319,135.48784,70.169529,-41.053858,-53.239768,-20.383037,-1.049894,24.692953,11.990218,5.535485,39.966188,71.353173,141.088088,174.864731,226.470951,258.455517,299.491086,191.640044,122.822449,80.686098,100.444127,187.230764,242.147443,252.548984,105.498541,19.028821,-132.885495,-145.912368,20.616938,132.841945,256.863926,264.837899,236.861539,191.938816,149.817099,55.66722,35.473596,72.700746,105.218124,83.089708,-101.705288,-202.608405,-288.221501,-252.310683,-66.562707,31.627115,79.772279,8.482728,-178.997346,-243.564961,-234.017335,-158.191783,-87.215645,75.173873,130.647403,137.554747,5.268656,-81.173954,-173.248186,-156.718832,-62.152721,-31.466462,-17.561581,-10.252479,-17.604771,-113.835892,-160.934071,-171.968735,-161.978474,-171.996253,-183.265863,-230.602561,-261.470367,-233.474785,-165.437373,-154.420098,-86.319711,6.794417,208.641879,230.046443,34.510921,-176.553807,-167.881035,-14.02633,46.627837,88.794203,94.142639,74.91418,-1.429361,-68.777254,-176.125534,-147.825983,14.841911,63.037682,54.52967,35.581036,3.297017,-111.312762,-210.348653,-353.685894,-353.370418,-225.222514,-125.833766,21.36808,1.495221,-34.10394,-25.402247,28.24124,137.66906,169.584295,197.067991,171.215268,-6.246273,-202.588425,-228.233086,-85.039179,16.346675,72.834768,33.196172,-53.974588,-41.695919,-17.862962,-50.803758,-78.787928,-76.319404,-61.729464,-34.106483,-37.619108:-128.297222,-288.908977,-308.885088,-174.045149,-98.507339,-54.336773,-43.196358,-9.498195,-122.228527,-231.674783,-369.02972,-351.855319,-213.527913,-134.195177,16.54132,59.647877,2.307967,-205.781158,-294.334934,-302.754807,-242.282525,-81.900853,-0.621707,78.384777,62.480561,41.417871,-44.842975,-72.915975,8.145322,86.091464,147.421449,111.285224,-30.435207,-179.002427,-226.188914,-198.578725,-118.055598,56.722328,89.181467,58.217982,26.578534,-1.03417,-93.328185,-101.314185,10.861308,81.56007,165.558853,175.861869,118.381756,-32.25487,-92.996199,-64.300109,10.454375,127.879659,134.228044,66.941978,-9.245988,-34.44662,-55.656515,-50.978763,-26.729829,7.450278,136.236702,185.014462,138.148127,-61.310679,-131.495618,-88.815118,-1.329556,187.81541,233.611622,160.061811,32.659337,-0.311772,-43.654217,-57.332885,-19.797016,22.465999,52.609244,19.211511,-105.125313,-200.610122,-200.730745,-107.570229,-30.822001,151.329509,219.700558,211.132394,62.895303,-4.80643,-60.190671,-40.167118,87.245909,166.691628,266.857229,260.076421,132.235685,-31.671345,-81.054011,-75.739554,-42.730633,17.600527,34.002543,-10.991658,-109.874548,-144.141796,-166.078022,-131.853495,-9.153982,37.473215,60.508386,31.299978,-77.600782,-153.383903,-148.82254,-39.463781,49.065081,219.081454,245.283848,99.767875,-67.37873,-86.057028,-64.719124,-29.154581,97.337913,147.203471,145.834271,110.778831,42.46703,-55.758272,-113.89395,-113.31916,-44.621332,70.356808,60.590566,-85.751278,-324.637913,-436.01093,-466.261939,-353.716664,-69.832583,6.322261,10.529059,-26.675857,-109.352268,-175.741613,-187.186117,-88.980541,25.544342,271.042191,323.817805,224.988218,64.274417,11.196185,-14.246378,19.284745,128.390979,199.997405,332.316023,349.387051,285.920826,199.109115,176.931907,230.092641,298.844304,401.824142,397.296873,294.023906,197.187889,150.420913,48.760182,46.262535,194.336548,298.752504,385.224393,331.97216,160.899527,114.397038,152.22898,259.252518,280.570104,254.456999,230.60847,129.918466,-64.666264,-141.360035,-168.497504,-134.827504,-40.25326,18.022478,103.242013,89.928308,1.153378,-48.985204,-60.864381,-80.009997,-75.785932,9.557581,70.113676,94.28796,-34.111503,-101.214503,-147.296179,-120.703753,5.687001,78.624015,108.767918,48.196959,-49.28345,-2.862967,32.818993,128.331871,192.507549,271.787021,254.486613,104.154367,-126.179554,-236.993451,-332.77927,-286.782071,-72.988771,23.82018,20.745171,-71.150714,-229.017857,-241.482176,-213.455608,-128.572931,-92.479288,-54.884473,-38.677951,35.65535,72.641909,28.628053,-47.777877,-25.657256,52.861287,70.906315,91.610193,83.675076,-31.028604,-136.646765,-109.051353,69.447369,154.820173,247.662008,267.63808,242.045493,83.819326,-24.790698,-126.85568,-71.647483,135.99099,199.367235,199.123828,170.5539,114.189584,99.771166,118.947595,203.136268,239.351007,260.167513,254.289008,230.966783,219.586746,217.833068,204.118305,196.114587,200.279146,221.971971,277.022487,269.899311,145.38717,5.547792,-13.327802,44.060342,85.323508,152.30164,169.499311,128.395594,-15.479839,-100.361791,-171.207852,-115.386339,127.937347,245.750134,328.11751,294.622397,151.237878,-46.426322,-113.358402,-72.355963,2.613649,142.847629,183.050266,146.580716,71.427312,57.325353,-5.633203,-35.852845,37.778964,120.826006,210.575223,201.30147,140.383773,23.715392,-31.74683,-19.342474,45.943703,213.198437,273.798849,237.653523,14.165888,-94.098375,-181.71421,-150.860087,-6.101883,64.806099,132.840843,105.817732,-57.320307,-223.772059,-244.312117,-103.359034,10.796469,179.656778,230.190514,269.959914,126.089773,-2.436041,-166.116633,-143.080227,41.049401,120.022415,147.163418,121.90509,37.874607,-133.096423,-204.36278,-185.739152,-118.085883,14.332585,39.070041,-53.807333,-230.654502,-289.044074,-264.496294,-182.717658,38.144946,145.785504,263.328271,239.345043,59.508133,-152.375915,-189.186679,-63.214966,31.35183,155.427464,172.343816,64.4739,-111.752861,-165.894197,-189.31194,-144.174369,-4.597309,42.508138,83.16611,66.946568,-81.183959,-272.724806,-332.135432,-360.699067,-339.679505,-213.629971,-115.29463,24.197444,6.154611,-41.255696,-93.832004,-59.00533,47.015066,71.901786,89.788698,84.560853,-17.22896,-202.209249,-247.340839,-140.620685,-35.718381,121.618877,152.7719,114.449069,-13.272149,-86.470099,-199.0916,-203.948306,-78.619031,12.089338,96.290834,54.272052:-194.334163,-248.783593,-270.659954,-260.822828,-253.529339,-284.430604,-283.065536,-184.397576,-110.884372,-115.277929,-157.489501,-165.566976,-111.368377,-60.84436,17.407584,33.480978,45.934836,-42.761848,-132.480509,-275.159902,-292.519319,-170.266131,-36.979296,208.721006,221.191924,145.932058,-23.276198,-65.693245,-78.35594,-76.36159,-69.722347,-76.047109,-95.627329,-70.512677,-59.214865,-38.357136,-20.742787,-13.304821,-26.882716,10.466009,141.93963,159.4924,63.848123,15.33937,2.900381,27.691307,110.83277,138.705414,103.095796,20.733785,-5.529467,17.346972,71.541393,196.645024,235.583228,245.194383,181.425146,129.295743,53.401742,72.129095,169.296274,197.636498,213.290417,199.240716,89.273528,-56.54056,-113.992035,-173.494235,-158.200675,-41.445357,23.209966,76.030717,61.318615,46.626853,-9.104853,-29.426715,-35.138746,-50.000975,-135.230143,-178.732965,-190.091726,-186.144218,-211.823759,-184.268148,-94.306456,142.494115,232.164245,281.268091,160.295743,73.577,-42.678614,-45.882953,61.575255,148.764873,288.57414,303.319794,205.871725,30.36877,-55.733232,-192.246696,-219.65732,-160.531992,-96.5729,-43.836414,-152.686149,-208.71374,-204.362399,-159.639221,-130.254746,-143.241266,-81.731016,-34.630728,-74.24723,-194.374637,-204.161596,-109.578591,-44.892681,47.287716,72.270263,46.051142,-48.343387,-53.130662,48.203705,94.836312,117.902154,123.03706,122.608081,96.832873,40.717767,59.759428,80.047071,89.286439,72.69073,28.735481,20.384508,-13.71409,-130.468884,-167.675483,-90.717317,-15.701969,77.632224,91.103852,95.353237,97.277501,71.772884,-41.004653,-92.501736,-43.04153,58.161851,250.245722,273.551577,180.515819,72.147288,20.621641,-110.219833,-147.520299,-67.437957,18.031776,123.787593,110.125678,34.826588,46.676013,72.676418,84.68473,59.09218,-27.160554,-45.54876,6.354872,26.979337,7.428548,6.842431,45.293087,151.439235,193.444938,240.915795,253.054879,261.546732,212.713374,171.069214,138.414887,153.051724,196.954664,224.099448,243.287153,130.187504,54.700095,-8.754855,26.39579,172.245722,242.64589,286.1182,252.569445,203.31151,226.541719,207.170055,90.830877,38.332224,1.779574,-3.008611,-45.878384,-95.706118,-94.34239,-44.818199,-4.276896,60.034798,45.307993,-39.652855,-54.460862,-1.373761,70.581006,77.657272,76.090155,101.116084,150.385147,143.056808,31.057711,-160.017596,-198.211373,-123.411124,-77.534441,-35.854436,-24.202093,-3.107328,6.321025,16.122531,-3.094006,-4.766257,54.063488,87.280658,91.766301,92.357683,153.542749,213.33189,209.636999,165.092751,150.168214,134.612486,115.93606,74.637221,88.53027,208.453872,243.983123,208.416992,232.204472,301.635193,391.864261,402.698111,403.104061,392.24939,390.376251,368.166346,346.914389,303.514341,297.428712,309.949099,291.824816,223.402201,222.347162,219.064918,154.941306,114.647241,94.429062,131.571365,233.380664,336.850856,400.66072,429.85609,358.520863,196.434831,181.955288,247.047516,252.307298,168.50188,91.168175,65.160925,22.091163,9.898563,23.195054,46.900858,73.5096,53.841044,40.189363,24.850155,23.838587,23.523494,48.286427,187.365089,257.349136,278.225092,156.906359,93.234945,52.104368,59.213006,74.184745,95.148731,133.22299,99.689526,45.626834,-123.591221,-176.511483,-106.651804,-32.15687,25.826189,21.170243,78.846,167.958674,169.432008,123.744961,110.321808,112.346658,118.57399,96.287101,-69.296935,-182.575573,-291.546815,-267.255284,-148.912299,-87.636123,13.910417,36.796726,24.196254,-13.368247,-51.248554,-88.257889,-32.950458,155.987514,209.56773,156.44017,-5.114548,-76.623119,-125.048461,-85.453972,-8.293476,-34.283781,-96.557361,-62.388514,53.756813,24.628098,-27.392694,-87.961069,-113.157888,-190.065558,-221.566065,-274.349149,-254.339241,-182.991117,-25.840895,17.730977,65.405569,88.92877,148.678345,174.088222,146.210992,26.67195,-8.804553,3.849632,-0.818117,-66.360695,-76.809149,-64.54549,-72.771518,-92.341489,-179.056639,-187.489012,-73.881075,-11.082838,44.439061,35.835039,-9.572046,-10.860569,-33.755665,-187.281104,-254.039169,-155.793962,-12.644625,167.560862,108.257798,70.339025,84.509042,150.643588,341.119153,381.192386,305.259672,251.548669,145.858374,3.499509,-40.095095,37.854736,124.511943,196.988625,190.369704,151.151665,35.180869,-13.522726,4.00555,50.121725,56.640981,6.219804,-51.735065,-46.888696:-179.026299,-234.679335,-245.298296,-154.071042,-95.896315,-97.248348,-123.683768,-80.511946,-4.761429,-5.373884,-52.078854,-62.498397,-41.076192,-26.405321,15.628275,33.279841,-24.94608,-154.616087,-200.620677,-243.568312,-231.794167,-83.041984,23.931646,166.088149,236.227143,228.586344,66.318215,-23.870545,-80.225433,-60.478013,18.754035,47.096235,52.982721,48.718753,43.265522,62.843062,74.610473,56.690757,55.484203,90.495268,132.979164,154.613701,134.725634,96.956793,61.0613,70.451886,136.149262,181.792511,166.964227,-55.690706,-164.849522,-146.976568,-26.297932,205.512105,259.374886,238.683486,137.203048,92.165126,23.955767,16.082416,63.169964,97.080322,136.196029,119.116168,39.933532,-36.96735,-83.019056,-94.436665,-38.98092,65.902545,89.014972,138.129652,155.468658,114.100473,-27.068828,-79.360408,-100.008355,-76.669434,-21.59078,-25.996406,-81.636589,-90.372612,-94.699803,-112.433744,-78.270843,78.674522,136.262778,109.083333,-9.13285,-59.342381,-111.478207,-83.944044,41.951282,81.036019,150.139365,204.000768,216.746532,90.900081,52.526904,66.769442,87.766754,100.262083,88.447315,15.895991,-74.574944,-104.267547,-112.609871,-71.136272,46.9025,85.986789,108.483273,80.821763,-26.323415,-102.623822,-109.162964,-64.606677,-33.147123,26.014171,48.210482,44.012949,30.07072,51.382863,124.461103,161.754691,188.21597,170.040158,130.207691,111.134416,56.735709,30.111178,33.488516,33.44585,1.97592,-103.6329,-129.510701,-125.720176,-170.51968,-198.687594,-179.272855,-141.315415,-89.61351,-65.617344,41.38689,83.731619,64.553951,17.81123,5.588897,37.178107,91.732092,199.307008,217.840108,215.557284,236.819685,223.131219,98.74405,41.151956,28.065805,52.207447,125.340807,171.746912,255.510255,260.602081,224.649947,155.598062,141.89322,158.551675,183.170613,208.212495,228.888935,241.397457,192.305114,147.561884,149.604326,219.335219,390.920323,413.802537,253.577559,60.326883,63.738487,230.620812,288.49531,236.091285,195.801006,175.278293,99.333334,48.860105,38.624379,79.642086,159.752898,182.756365,213.488982,216.975863,225.183326,230.058183,185.117757,39.812142,-11.82813,-20.411141,14.513157,67.306356,37.614192,10.859769,-10.438243,10.730646,37.205245,8.615179,-82.57942,-116.507953,-113.243713,-14.121909,29.070462,18.717878,-3.308494,96.985666,196.701807,179.93597,-83.448207,-136.241965,-74.406077,-53.218784,-68.530283,-63.879634,-24.405441,-15.949377,-11.011764,4.209414,21.954382,120.391472,170.836499,158.91176,131.961595,184.723439,290.640588,298.700366,225.028307,198.7527,200.764373,181.848202,132.809875,155.37363,258.829033,271.749502,249.413222,274.361236,331.316738,390.653095,361.942209,300.954907,336.757003,347.534498,275.546647,209.876914,86.038293,70.188083,198.386175,283.712923,308.862873,218.541224,183.995945,112.999823,71.831371,37.231793,68.006068,214.931102,408.723712,472.166095,440.389723,374.363747,274.800128,261.53877,293.242484,295.364125,207.544066,129.822579,112.834589,72.158402,45.453603,39.134567,83.482492,212.011276,254.170359,232.705015,185.256051,188.609069,218.154972,228.48791,307.559799,393.770843,509.259052,376.354433,270.261315,154.905998,153.327836,209.630041,242.685615,293.051251,287.485163,225.487224,34.373786,-6.799704,96.363936,179.624583,262.5004,255.663103,245.457401,266.585508,260.766767,224.045125,179.611351,47.272835,10.883993,-8.178507,-95.683182,-163.899566,-283.154262,-293.829167,-174.228334,-98.065882,-38.923829,-39.066106,-34.837283,-108.291394,-182.47339,-213.170208,-126.472374,74.448676,100.234851,-3.076434,-122.409376,-155.306599,-194.539581,-191.840355,-153.684691,-141.032465,-113.058461,-92.710524,-54.794383,-17.116269,-8.180979,-37.870205,-57.327227,-75.512048,-103.526381,-207.360716,-194.21788,-145.600422,-141.604754,-178.883959,-180.452428,-133.917274,-50.812097,-44.0747,-95.8025,-221.457578,-266.392952,-195.307459,-99.528368,53.796901,75.892804,-6.387785,-132.187679,-181.162547,-289.270991,-297.882888,-157.970444,-72.896912,8.158533,17.315497,19.307555,-78.129678,-165.919005,-312.99571,-351.090903,-306.587191,-221.103015,-76.84437,-75.565904,-84.468679,-64.301996,-46.388867,4.504717,48.541532,111.564414,91.070812,-28.079075,-155.319671,-191.207829,-131.966255,-59.29412,22.771598,22.754234,-3.557325,-86.706564,-144.757947,-189.855686,-164.293115,-136.641098,-158.953059,-197.106024,-199.169727:-192.123544,-168.290572,-212.885815,-253.236831,-200.081626,-58.194903,-22.46745,-16.427842,-67.62666,-94.76505,-96.745945,-72.378976,-44.837506,-49.189699,15.935468,85.231087,124.5499,-84.245327,-197.134704,-207.183045,-127.323407,16.152314,43.89849,17.447616,5.793577,30.944176,2.624947,-64.436064,-111.531605,-54.533794,53.042086,32.407795,-94.035163,-170.032464,-185.730722,-127.683028,-59.335789,15.880256,-0.214259,-27.665669,55.720846,84.146121,28.730154,-21.428067,-50.615373,-23.491155,57.636246,88.407192,75.449106,27.994354,31.975263,74.678607,79.105399,4.420092,-40.606413,9.466658,179.184405,202.21707,106.258002,54.497304,50.057891,89.684163,154.929396,154.364076,122.680008,37.911578,-38.329081,-130.895973,-108.120432,-24.546937,-9.906007,-2.92614,31.623133,30.369408,-36.277796,-67.203969,-63.260622,-47.768131,-39.150593,-43.753418,-71.035271,-161.727789,-210.837167,-202.568835,-142.319973,30.192498,123.930173,226.406608,150.134479,80.556069,-28.164097,-42.012981,42.344292,124.135836,229.431176,221.832396,167.605522,84.195111,-3.521895,-161.255019,-158.676023,-35.07877,-6.921164,-125.958702,-255.389656,-232.836026,-97.707628,-57.556566,-81.976231,-104.379382,-74.596959,-66.649072,-140.96047,-170.817672,-137.708096,9.785915,105.183336,236.506649,247.444949,135.721279,-29.19952,-46.126538,40.067113,73.983297,33.109563,-6.170428,-10.420116,12.358119,41.945511,7.417958,-24.05692,16.21184,82.74502,134.636136,79.08314,-127.830587,-292.241384,-323.661904,-283.332434,-225.135345,-109.016181,-73.723472,-33.930409,-21.293477,-28.13386,-111.700964,-137.721769,-40.615382,61.711296,249.520564,291.228481,209.714674,84.115041,54.847596,-33.374499,-84.338042,-55.320707,27.734438,160.772177,161.159835,110.141047,95.386175,94.256571,104.847573,108.445503,117.287299,134.787514,123.643412,66.533222,62.495663,97.679547,137.427705,248.148488,292.37911,309.800425,294.280183,272.790711,213.553906,169.6695,166.194657,194.94149,209.46036,200.279972,197.485965,143.099075,85.268202,45.595925,91.829748,181.776054,183.523636,176.528361,179.482421,150.41757,74.466642,38.792759,15.295744,24.850191,101.653702,150.770739,136.795376,41.004343,17.420312,15.557908,41.220918,79.032284,55.568269,2.580777,25.818818,112.260746,129.572085,151.287944,256.018505,298.649504,284.87005,232.186482,73.441868,-118.176066,-196.098063,-221.331656,-161.506969,-28.085022,-6.372743,-6.234145,0.774267,-7.809769,-57.555614,-76.15641,-71.037644,-54.696536,0.726684,38.812287,52.851936,16.359084,26.28918,67.854219,85.072898,112.273525,109.815941,51.677874,17.496098,3.421066,62.803079,102.699047,167.639231,195.454524,271.308147,325.769724,387.765636,325.599832,286.650451,220.198089,179.4814,133.072651,175.189714,364.947002,409.53032,246.987027,59.961578,61.967875,118.123304,116.09293,122.915126,154.670338,223.083609,283.840663,307.443909,293.330333,270.866329,262.1735,255.004686,200.456486,194.814122,257.427188,183.811128,83.775623,-0.911095,39.209126,146.228517,181.662917,154.742249,-19.398867,-88.55442,-115.262027,-85.774899,21.75928,70.686633,147.036104,169.843306,121.290834,-24.363828,-71.815703,-48.884247,-19.805264,9.704583,27.780856,27.078795,-54.381946,-100.631814,-149.18259,-129.382746,-24.239113,23.514281,43.281419,22.151391,-8.152885,28.396537,49.663549,67.396091,73.451224,119.667574,165.106926,189.132077,60.894733,-30.859776,-193.177178,-191.71802,-20.135281,51.739385,59.952648,25.900441,-67.153334,-141.185671,-153.721446,-81.010515,7.60978,155.678926,172.777952,122.575414,16.478298,-36.773629,-123.668465,-149.064643,-110.600452,-51.590375,20.836117,-5.563769,-116.661118,-138.057608,-129.594003,-178.274102,-218.113535,-222.788998,-193.894679,-163.633158,-161.932564,-154.331457,-140.513445,-133.439586,-81.861384,-23.348392,125.335927,157.43356,43.279634,-109.062725,-116.682872,-57.46079,-54.865504,-105.947464,-108.512526,-72.972389,-101.586661,-144.121454,-245.440884,-278.775996,-212.378651,-108.663989,57.334088,37.72671,-135.631944,-253.155326,-273.188189,-291.596915,-304.45772,-260.643456,-176.378852,-4.936421,27.010854,-8.477226,-105.44901,-106.442159,13.876113,81.240577,131.84164,103.475592,-8.59377,-81.633169,-87.345219,-46.796104,-26.254742,27.023723,77.949767,103.514416,-21.550866,-63.972436,-67.5028,-61.800389,-97.646211,-110.600875,-5.593101,51.610001:left
-16.675016,-12.682999,-53.54449,-153.144047,-172.613783,-176.036693,-171.662259,-163.235998,-126.418895,-82.39547,-21.80921,-40.139888,-159.318608,-225.154393,-300.883782,-328.734836,-414.529547,-435.450405,-421.801301,-416.081021,-423.583089,-458.596294,-471.998878,-434.861867,-343.635849,-291.885185,-187.602801,-154.324728,-145.715513,-142.928669,-63.116537,-19.402762,-46.009334,-169.602517,-225.839505,-239.171557,-183.076178,-39.386433,-3.642202,-63.317634,-180.664586,-217.021361,-287.442903,-318.310153,-288.28531,-253.192158,-305.520903,-383.560286,-387.981921,-159.951727,-89.822843,-100.52654,-132.797219,-175.54687,-163.398501,-89.511731,-84.978759,-122.375268,-193.848164,-178.062081,10.014846,120.275441,179.653527,144.995535,119.184105,101.046509,42.055446,-40.388664,-16.113938,92.747367,147.73167,195.046802,117.616875,60.034066,-59.243036,-97.51176,-85.664323,-79.427539,-101.858044,-101.922984,-105.839286,-142.232368,-163.680092,-206.309071,-217.954541,-197.939152,-171.991051,-157.711526,-210.576128,-205.685928,-143.118109,-150.425793,-233.799289,-233.068525,-85.984392,-24.00832,-131.123056,-314.042271,-315.016792,-200.644929,-164.846471,-210.178574,-243.07039,-272.05967,-328.108113,-359.129922,-409.404548,-429.697939,-442.984405,-416.732715,-243.20443,-141.278626,-109.934471,-257.797172,-311.350408,-315.331,-295.999709,-222.096783,-130.099924,71.25759,34.935198,-41.800889,-129.743952,-117.64747,-14.22227,28.755159,1.853578,-61.977621,-186.783052,-183.881899,-140.575963,-32.914327,3.122008,7.93455,-20.338809,-141.878793,-264.811089,-282.460676,-273.131718,-271.995106,-257.251442,-240.33581,-237.429898,-259.563103,-230.131056,-61.470208,-20.56494,-78.033048,-111.398495,-113.054977,-82.290968,-33.972003,-114.402064,-139.381925,-44.066231,30.964158,111.597854,114.306707,69.93068,24.530277,-68.170282,-82.371979,-69.297122,15.837923,83.256366,151.927424,145.626395,94.912878,-5.7116,-58.74023,-133.995942,-125.785291,-24.066485,11.72632,-1.933902,-24.639955,-32.819194,-12.504561,-42.884014,-143.363204,-159.641293,-154.236167,-155.447833,-140.332883,-151.97262,-196.886293,-329.272606,-366.014776,-299.252871,-210.604292,-48.995978,-31.7301,-95.448376,-116.222058,-102.338478,-28.244062,37.072972,136.527517,138.861017,52.218504,-90.125201,-123.162246,-88.903758,-62.995899,-53.602346,-64.425631,-67.777856,-62.959098,-83.984033,-141.248308,-169.120293,-147.761095,-85.90324,85.792661,174.707052,250.852759,152.478626,110.025118,65.061799,37.930415,-43.340576,-86.422661,-99.892517,-71.623817,-44.345564,-116.997996,-167.292285,-211.251995,-194.995457,-86.862606,-16.11168,13.911949,-162.255935,-255.396991,-305.956582,-257.503287,-118.26131,-79.804259,-88.318465,-114.302089,-156.697943,-147.666374,-135.126286,-150.860058,-167.426799,-131.509699,-87.274759,-65.14816,-102.180052,-92.640061,-70.262291,-81.166122,-62.286204,-10.754341,88.534534,89.501733,27.659503,-21.83341,-50.628055,-2.798373,97.078791,210.712063,178.10905,81.18886,38.559743,34.920625,67.042015,108.865318,200.686995,226.001532,280.113778,313.535007,326.435827,302.740535,310.627239,367.90699,391.420178,374.752651,359.623087,359.126363,342.844613,337.056853,341.175099,351.626651,334.008634,276.888954,131.368685,74.574267,14.488033,40.65497,62.767514,116.191328,172.743853,308.573359,351.972788,359.224441,277.709407,241.282113,241.673514,258.23629,203.048878,146.737895,129.980285,152.480691,120.747782,33.256418,10.261748,1.320523,7.32691,65.1416,113.954094,142.570494,67.972262,56.591251,102.229607,131.230145,191.440593,237.417205,324.428151,304.252193,116.705105,-29.668993,-53.68876,-60.974648,-57.151008,-42.391129,-5.336085,141.319694,179.701701,115.814811,-87.769553,-161.70935,-192.154676,-182.830431,-193.461597,-232.76053,-353.226634,-361.768298,-342.42633,-332.591023,-302.866405,-170.231871,-110.898163,-85.248468,-105.470531,-105.040186,-139.791595,-165.280939,-155.15126,-119.4441,-43.543508,-37.190423,-67.221184,-10.162,12.642432,-20.695833,-30.388128,20.678942,49.602843,59.018941,88.694694,117.951707,105.831726,68.579318,51.246358,79.956418,162.153092,176.493131,91.666538,31.732418,54.353202,133.671396,169.16047,228.509988,249.795974,245.370106,184.470834,154.563801,108.860424,128.617317,300.936323,374.776983,315.379116,212.094621,55.330008,40.990711,48.752212,56.78683,60.847575,62.213457,57.691517,40.261372,51.39217,62.519599,64.213903,74.057235,110.781848,97.849876,-10.359124,-65.688992:-110.117649,-190.075776,-253.585377,-345.926622,-339.155499,-257.927197,-232.443672,-261.45961,-310.748081,-319.088208,-283.832888,-246.228584,-234.486249,-273.173282,-316.87305,-308.191883,-330.298212,-390.130495,-392.042432,-362.898965,-368.990937,-412.367518,-427.356969,-439.327173,-424.526281,-390.16436,-265.248005,-197.208223,-90.845877,-51.067393,-1.992113,-15.249366,-117.616429,-255.530286,-315.68319,-283.599766,-176.713252,7.479379,-2.873088,-156.674934,-247.535672,-259.274142,-265.320737,-263.464769,-267.184146,-281.810614,-354.181078,-413.401142,-489.017607,-394.167382,-316.379008,-226.490185,-220.433087,-198.315688,-171.431864,-139.934754,-187.669975,-245.332023,-299.455654,-243.267355,-51.030914,30.133242,132.564312,139.437987,86.233284,29.797949,-16.649052,-107.507727,-96.373844,38.849515,114.149073,177.531799,81.131949,-12.636487,-193.263661,-223.522492,-122.111008,-41.515873,40.031901,21.876684,-46.373387,-50.249638,-58.449035,-127.381651,-160.131825,-162.965731,-140.398316,-115.879277,-168.831717,-206.616715,-224.341222,-187.908633,-83.993721,-55.207141,-66.502353,-96.626544,-167.064185,-218.159351,-241.69316,-266.634028,-250.570127,-130.765122,-47.026956,-54.758541,-320.595514,-427.449717,-509.123273,-493.511291,-368.512999,-281.332736,-116.807477,-95.436046,-218.63482,-279.704972,-245.952181,-183.997328,-175.884082,-129.675111,-66.479061,76.231532,57.015173,-12.300044,-106.751037,-93.613617,-16.031494,5.791093,2.009733,-28.767196,-141.622558,-168.006173,-129.562203,-37.400842,-14.244503,-33.310078,-71.097892,-217.314552,-368.941856,-379.217304,-320.682552,-308.108961,-289.624665,-250.807866,-165.828307,-156.276374,-133.156678,-45.907082,-59.396812,-164.979433,-148.851163,7.96088,49.650415,-45.827797,-216.159385,-260.0541,-235.037916,-155.378514,56.941534,114.99155,86.858952,33.523704,-85.934104,-161.222484,-160.049219,-35.756812,62.005197,151.985975,133.110816,100.411814,69.137681,26.944872,-27.868312,1.987713,136.810985,185.35531,186.10272,155.071806,102.665365,85.672059,64.211398,16.354808,12.012215,15.607007,11.035693,8.19066,20.337404,1.026479,-143.322748,-220.007212,-264.195458,-253.163466,-205.120201,-166.218605,-120.958292,-121.695071,-90.890137,52.439668,109.120739,111.29083,98.305315,81.178622,-5.158822,-62.347271,-161.080605,-167.789901,-50.729643,15.468746,9.051993,-60.448964,-205.621768,-247.326177,-225.3964,-121.956346,-65.826548,12.864954,27.743551,-15.795332,-51.57487,-48.350565,-87.207739,-108.5535,-96.710779,-101.133242,-150.342883,-170.579022,-170.14991,-146.947419,-149.748189,-170.093505,-157.012717,-50.621344,-8.426338,-53.222281,-189.972682,-258.855446,-324.770945,-289.909785,-127.4183,-48.340402,5.766081,-39.063635,-185.886718,-275.49384,-281.744232,-230.856753,-198.876225,-131.755964,-106.733534,-148.596937,-160.497419,-125.182585,-117.011952,-137.763027,-96.593624,-42.83115,15.154764,10.151321,-16.316115,-55.973309,-71.681204,16.178503,132.238662,330.686613,334.77581,148.280355,4.25725,36.270877,126.677125,127.061019,162.248644,243.930644,434.66579,464.854881,385.923506,287.499425,280.711582,362.514803,405.341089,444.76515,464.536371,456.363677,334.940364,294.493801,315.30859,344.841408,333.410339,288.146339,198.259419,170.736323,157.303374,137.756493,115.919826,164.736337,245.30616,383.187592,396.744757,285.044528,134.579073,119.510714,194.194072,216.724323,173.805566,168.445769,248.94853,252.442386,76.084351,-66.632443,-53.817164,15.397559,14.723983,1.624308,37.344978,139.780114,180.69079,165.374935,79.875165,69.164627,172.149971,240.342147,314.518879,316.713611,279.472784,166.111625,92.445274,23.424274,35.031962,97.38263,141.919877,200.491999,188.140044,154.440533,-18.545352,-113.304362,-165.586232,-128.093694,-82.775298,-121.215369,-192.574754,-207.22449,-242.209461,-259.741904,-212.907689,-123.138637,-118.716922,-175.000649,-263.382311,-308.899266,-343.472784,-313.415012,-232.797225,-199.191707,-99.844498,-52.245078,-61.163573,-178.35887,-227.088561,-241.733624,-216.368582,-164.854308,-156.011041,-132.324005,-47.261304,-19.902576,-62.111953,-92.959679,-39.673297,50.755882,253.612711,291.97615,185.345258,24.725373,-8.396505,77.815329,167.722725,286.776355,294.172604,280.464129,273.736348,252.744678,212.280176,223.132673,312.0005,356.175144,314.943114,218.528198,27.317521,-26.859982,-29.696995,-5.498544,28.607737,84.534203,84.681584,83.402747,150.747068,165.161857,69.635293,11.260048,24.688948,73.058004,112.044116,85.018369:-181.173778,-350.014058,-397.250943,-343.168549,-276.224573,-182.994987,-200.499409,-331.421987,-392.092299,-397.871467,-374.563482,-344.375786,-318.508375,-307.960785,-261.757604,-267.950331,-355.687044,-414.928285,-409.548632,-322.713248,-259.119515,-183.301798,-176.350907,-203.503368,-280.446911,-289.489497,-175.26597,-101.353865,-35.873526,-42.842266,-85.504352,-108.844238,-136.571019,-202.618233,-267.311494,-287.366339,-207.249164,-23.222148,5.341591,-104.083635,-283.807243,-348.596609,-393.933028,-357.769933,-206.789943,-152.580012,-204.979436,-292.646784,-385.5055,-281.513916,-227.74231,-195.511377,-197.134533,-194.071812,-187.043931,-189.672767,-265.395783,-331.519479,-393.986761,-333.032354,-114.672799,-36.734221,-16.303075,-42.644574,-48.66555,-40.64497,-69.328582,-146.621887,-147.793127,-2.328734,91.451197,99.522105,-92.059377,-194.107886,-337.529631,-328.705321,-141.334921,-35.466095,22.597203,-26.930733,-108.387797,-114.903808,-136.505894,-173.093622,-164.641043,-124.430657,-98.418765,-48.460924,-52.597934,-81.582897,-113.631692,-80.528228,27.890163,65.195243,86.579394,55.418457,-30.671312,-57.95137,-92.917366,-154.212597,-131.140338,-38.106607,-16.489218,-86.604797,-200.987669,-239.539063,-325.897741,-339.626414,-228.0873,-149.17814,-97.551007,-118.631114,-137.677381,-165.443444,-201.366594,-160.092292,-71.377603,39.43472,40.672024,47.646639,33.369981,5.093789,-5.326362,18.763065,35.022598,24.83711,33.195594,45.267806,59.283302,77.755708,76.144625,61.806243,61.519419,40.886329,9.761231,-60.031127,-141.462972,-202.163106,-309.284891,-314.115468,-214.223367,-137.382944,-49.572186,-61.09833,-101.69813,-123.442063,-150.453154,-163.244578,-127.759676,-49.354489,-22.281559,-5.937814,-62.727202,-95.231172,-72.63637,-3.451473,154.274216,198.694631,199.707597,157.7343,1.370066,-121.683759,-123.807518,1.082515,102.710982,242.768067,242.365149,173.795304,165.065103,164.000902,134.733621,148.935375,214.163389,219.700284,240.148755,287.811473,358.819312,243.377985,141.447961,67.358273,109.586985,208.126008,234.648291,210.306064,100.316555,43.645415,-42.616379,-61.354948,-51.021101,-43.060613,-48.154236,-46.855582,-17.942642,-13.651394,-16.93715,70.745392,126.488452,97.270433,48.500211,31.899521,71.85913,75.200219,42.296005,29.89248,67.330681,97.876631,77.941086,7.838226,-159.227973,-240.378721,-241.53036,-148.425974,-82.68536,-13.004224,-13.082205,-46.123988,-47.363486,-50.774674,-139.790406,-177.608767,-147.917723,-127.813596,-140.776599,-138.221657,-71.99621,-54.471246,-91.6711,-145.452429,-123.933342,-36.590719,-19.824164,-82.611878,-202.493372,-247.628087,-232.190836,-171.560265,-52.441467,-22.154204,20.739487,33.298188,13.948963,-72.56212,-138.003245,-193.95998,-152.318145,-30.366058,3.326776,14.706095,5.795062,-10.286236,-65.657941,-80.311531,-36.689537,3.954999,6.105612,-46.731344,-121.449557,-81.530824,-65.917112,-39.307821,5.382993,179.714873,263.362192,221.813407,-1.238443,-55.238634,-35.14549,3.143862,145.351277,248.48227,379.772755,355.936451,220.785127,155.102533,172.556851,274.552902,324.240456,388.538412,403.678817,348.391884,219.630717,177.238812,179.57928,217.060809,241.69326,201.567066,126.685221,128.52891,164.123564,147.240176,117.381946,78.939176,115.908552,329.781715,410.203218,246.210835,-40.307183,-50.985308,81.314008,105.278746,49.506559,52.282023,128.044025,115.928277,-70.120659,-277.124401,-328.643323,-292.429701,-242.11209,-188.374194,-171.418584,-74.655033,-20.093,-71.343471,-153.148337,-103.767882,50.268986,80.759127,133.884071,202.681281,254.978422,54.99556,-41.190253,-55.507139,7.784972,128.983941,142.754369,81.928973,14.073488,-10.534641,-41.433181,-16.851298,73.989594,84.061034,13.163336,-35.587466,-92.65654,-138.490228,-166.487957,-144.620989,-106.712674,-109.054287,-140.101364,-154.158019,-184.991276,-242.630373,-321.176835,-301.885145,-201.779087,-146.202147,-68.661016,-71.12583,-130.253961,-183.585008,-204.45928,-157.581127,-88.446937,-28.863506,-74.892534,-164.171337,-125.268356,-123.217391,-154.841029,-133.200951,7.970312,102.501366,205.777798,165.538854,19.60825,-26.136064,-27.381121,59.060681,150.983286,253.500473,226.459219,114.828244,94.085547,116.625848,154.051481,175.04796,236.727802,248.15539,162.490191,74.677737,-95.326855,-178.819902,-193.032068,-171.120747,-136.484627,-60.120373,-30.983577,2.395374,25.123639,22.319577,-42.427537,-74.890183,-85.471167,-64.390927,38.738329,88.715335:-169.709338,-198.177238,-237.390527,-258.098329,-197.921111,-61.975993,-54.24282,-146.19671,-181.020591,-137.006564,-21.728528,-1.977737,-68.920812,-125.403708,-204.934759,-231.545829,-261.564553,-255.819083,-261.41141,-268.969815,-259.720213,-235.888827,-227.038079,-227.703896,-221.936484,-197.992372,-150.716981,-136.098303,-74.498941,-46.746542,-63.966078,-88.552924,-117.848303,-166.208451,-203.409473,-193.043658,-137.814068,-73.750276,-82.899719,-111.936977,-177.369803,-234.717317,-313.608544,-298.85219,-212.531035,-203.740743,-311.75472,-382.780143,-380.797325,-211.057704,-173.526505,-226.114277,-244.00162,-204.459518,-187.12284,-217.625881,-287.057955,-309.281959,-278.025611,-219.312729,-89.142913,-45.797846,6.341345,6.618471,-56.488934,-111.697884,-130.171826,-149.506491,-136.465904,-54.23826,3.757477,75.029233,31.119324,-21.704841,-139.404526,-162.562953,-88.773544,-45.897702,-67.758716,-104.4412,-122.816527,-86.126348,-83.731461,-163.073873,-229.173763,-273.318014,-231.552477,-159.910066,-191.868479,-202.313569,-154.25418,-111.483067,-43.451696,-32.381492,-32.387214,-35.502558,-66.522354,-79.902366,-62.457655,-5.274209,1.779392,-50.051141,-73.679999,-107.303247,-205.009554,-280.324639,-430.516793,-450.102693,-326.105339,-253.83132,-214.394145,-226.196846,-221.366965,-210.497167,-237.532828,-261.52433,-226.608813,-85.228275,13.937199,161.114339,110.519972,60.426265,47.997193,83.464425,151.664936,152.880865,123.794901,121.048229,101.028186,81.014133,96.063513,124.705809,119.216992,79.995131,54.157542,-42.366219,-182.79906,-231.721159,-279.31784,-285.135011,-248.132423,-201.683288,-113.486968,-109.856788,-143.624589,-163.472505,-192.033128,-215.531059,-176.638238,-83.65395,-58.624523,-34.637573,-45.014434,-54.969398,-1.206433,87.675798,278.659566,308.790146,215.850054,130.077207,-26.83863,-81.041817,-71.632652,21.863788,89.193765,175.688481,201.970749,230.985027,141.869746,69.179635,-19.58113,-6.733194,83.503854,109.7358,101.630302,94.26057,93.936865,50.386044,-4.125299,-75.992158,-48.398954,79.473104,121.264341,59.749247,-103.896296,-146.044937,-121.226099,-74.529679,29.807197,62.314333,70.057642,60.812795,41.083863,50.149486,82.583444,181.171382,207.551842,166.637319,144.171873,132.162739,42.675904,-7.092795,-35.344787,-21.835263,25.013706,39.548682,4.175177,-32.250539,-102.936487,-178.268677,-189.540127,-109.487279,-42.052963,62.457959,99.94773,143.466366,107.50975,83.582943,39.084473,19.592081,26.822628,42.2855,20.039512,-21.847386,-84.133035,-77.071821,-61.249154,-0.127336,25.395905,19.553098,3.099862,-30.735442,-129.323345,-193.556382,-241.000576,-205.016347,-86.444764,-49.357957,-56.121166,-85.37638,-127.959663,-119.594188,-118.994651,-140.135623,-140.679528,-63.589302,-1.45151,47.569362,-13.080593,-37.367044,-50.40509,-49.201554,-52.937799,-62.389475,-43.985455,-9.646674,10.245522,-35.900794,-49.109309,-22.489466,33.965728,167.705028,193.842513,115.894673,9.856532,18.201656,65.820197,66.010947,79.16977,112.616069,251.29073,330.904428,342.050605,192.876117,159.924985,239.041019,307.195677,403.098455,410.131165,334.452293,254.320514,246.159069,268.930244,288.363174,282.480861,222.160197,44.672997,0.375759,29.945341,62.796996,72.092923,136.786509,182.880627,232.174927,222.26721,151.523359,109.212495,116.561148,96.865479,47.288254,-40.629585,-39.163116,23.147086,27.820348,-103.560859,-264.438237,-283.066353,-238.114147,-216.75839,-184.472177,-161.933521,-148.452362,-170.606204,-168.582787,-151.393715,-129.869258,-39.47308,3.932877,28.14561,8.360739,-63.501404,-163.1046,-219.251973,-239.495357,-181.250126,-52.554615,-20.803019,-5.397334,-20.465679,-37.463735,-97.755719,-117.217968,-90.631388,-69.622035,-107.104553,-157.604177,-201.117052,-168.527776,-171.276628,-181.9705,-161.84911,-85.168161,-26.392344,75.150546,-32.430504,-133.643898,-232.462633,-216.857373,-155.104198,-130.644884,-47.513831,1.552808,41.693397,-2.528564,-55.574212,-107.528955,-64.403449,66.70111,99.924433,116.745048,160.317547,164.609684,57.460469,-7.856862,-6.972396,50.720947,177.310147,202.495256,111.094787,-32.269563,-52.03076,51.917148,140.519496,270.676889,278.081464,152.347549,-21.137429,-54.274269,40.512927,147.479764,348.541678,373.857438,244.533919,153.779915,53.19383,41.259019,28.254199,-7.353593,-17.988859,-48.567657,-57.68521,-28.683624,16.412193,31.936379,42.961321,36.148191,5.040944,-5.53888,14.732526,33.002515:-285.049584,-419.538465,-427.148086,-329.032239,-248.518194,-112.153414,-90.875858,-150.22882,-220.935476,-243.08403,-256.32722,-230.503063,-164.764077,-149.630532,-166.230778,-197.061817,-252.851365,-250.170651,-225.04533,-116.096768,-49.748238,9.151024,2.686346,-10.894358,-41.993248,-67.316846,-81.919286,-71.751708,-44.452878,-20.75816,32.91291,21.546176,-91.359054,-180.411222,-192.551567,-108.008989,-15.027789,123.600295,116.723194,-31.154122,-212.590223,-282.483744,-340.899239,-313.459601,-207.39233,-176.598327,-196.287746,-247.153294,-380.461069,-380.210055,-328.413624,-217.922361,-182.994403,-168.513443,-173.473742,-211.996376,-330.76362,-398.710504,-399.689403,-306.212216,-118.924738,-89.086389,-82.496254,-81.827214,-113.571744,-180.053883,-203.602005,-180.870797,-135.992844,-8.043348,36.311166,-21.682653,-131.534945,-153.527268,-184.568001,-179.445428,-95.755835,-51.644708,-22.43332,-31.953988,-61.147923,-140.500262,-198.410499,-249.858508,-242.989719,-210.579349,-177.691599,-89.019062,-44.543552,-54.877264,-62.699535,-20.071405,103.528227,141.218711,188.575874,202.62166,142.839693,36.181576,26.021158,75.461573,81.172084,13.836662,-17.832027,-49.721665,-127.864389,-198.941956,-339.075384,-341.271417,-185.440532,-104.165306,-84.05924,-129.717903,-204.358818,-242.753037,-257.50888,-206.120869,-149.557525,-48.465943,9.090435,103.154161,126.381612,137.376262,146.438715,153.623299,228.177893,276.715856,310.517392,288.819616,207.487533,140.268212,133.451807,135.661394,127.369907,152.85287,174.692102,101.180883,-38.871271,-80.552495,-130.884127,-152.98423,-191.005761,-167.113558,-17.677147,25.364235,-37.11473,-120.215921,-147.439197,-161.111205,-134.728312,-47.459684,-0.280334,47.944539,2.500307,-20.416468,32.687816,112.384533,249.925061,270.976889,269.453543,249.50595,131.836912,-21.579002,-61.51214,41.472056,162.33186,332.730763,339.494548,270.807697,232.538551,207.510161,97.355824,69.713833,144.445502,202.981396,255.085431,238.78,157.441934,76.752132,42.832481,25.477139,62.299164,189.751858,247.99038,259.54026,124.669354,69.76791,50.174009,65.338155,124.310536,161.289105,195.873202,195.970266,198.632988,130.818957,75.38383,112.161619,193.004157,243.277618,211.553078,178.842477,179.385317,149.683351,84.133193,96.855242,174.884932,195.451606,146.850921,78.641414,-67.34547,-129.94191,-124.712497,-71.124738,-40.937485,46.392429,101.675909,97.928112,-21.100362,-37.929848,-31.958368,-39.777482,-29.84458,1.270302,65.135142,51.492068,-60.22162,-109.87289,-98.200484,-36.235684,7.968011,84.33433,86.159864,8.727891,-69.159722,-92.90763,-127.40689,-119.880664,-44.008529,6.246639,99.612189,106.067577,5.46662,-95.381181,-117.095482,-120.83033,-103.819049,-26.669218,1.170099,-44.161224,-101.965081,-107.705751,-107.970517,-102.243481,-107.550671,-113.960857,-101.04485,-103.056461,-164.695669,-238.17127,-230.742377,-87.648947,17.998968,192.105431,216.526614,90.177136,-85.718156,-124.224158,-133.971398,-107.551998,51.331648,167.068668,341.127262,349.189424,214.38135,69.286968,53.794794,139.823051,210.475776,325.838455,352.727429,315.212001,147.691395,59.480275,18.313373,67.905147,180.261322,200.079397,157.489069,116.441899,70.592672,86.269038,100.562717,141.620762,171.423709,231.579502,228.672072,97.591576,-29.927873,-47.852558,-82.194983,-121.633238,-173.486119,-135.418772,12.279469,22.072004,-147.525987,-343.866906,-391.661814,-366.957079,-322.242855,-210.88362,-149.82057,-112.497258,-179.545013,-201.676602,-201.987507,-166.850129,-24.505914,31.324037,58.621113,53.369539,4.224308,-128.212185,-180.355551,-150.902485,-83.563995,75.381634,131.118564,132.023362,58.477185,14.15058,-77.188678,-81.871265,31.307532,86.229169,67.739201,21.561178,-57.313992,-147.969199,-180.042126,-139.178874,-87.069762,28.751589,85.721562,119.310969,11.452569,-65.869141,-183.37859,-197.889849,-147.471494,-92.308579,69.107753,131.162005,102.086542,-55.800718,-120.103136,-123.804714,-79.166335,11.846802,45.438512,100.857784,77.792579,13.56694,-102.181239,-99.29051,19.962266,98.345554,194.715381,183.834286,47.166988,-148.14611,-214.14457,-128.489217,8.11681,242.076525,266.027823,98.642519,-104.746849,-114.872735,25.983172,117.339374,239.205356,245.440361,100.47754,-16.528151,-162.997293,-197.513321,-220.630817,-227.261593,-195.123873,-149.171606,-156.139604,-155.397722,-95.092359,-79.72158,-94.117898,-95.842495,-83.376819,-80.719981,-66.537324,-65.751178:-21.708688,-79.082979,-128.811275,-180.264175,-133.67563,2.358871,25.253166,-27.405081,-21.249719,20.833042,64.148509,56.87559,6.709574,-61.218263,-243.69376,-294.370117,-301.180833,-304.986473,-316.515102,-336.871172,-334.417093,-288.362804,-252.732252,-204.379815,-167.330951,-124.042724,-27.712818,-6.836053,-25.134276,-35.027839,28.671939,72.734745,20.366283,-121.553524,-140.052543,-33.777665,54.168257,125.67238,87.397298,-33.485519,-83.016994,-99.156074,-187.994693,-212.118255,-139.975071,-106.314892,-178.027621,-249.090861,-284.35076,-173.893203,-135.466311,-123.307848,-122.278186,-122.557573,-125.11947,-130.873915,-170.408621,-185.136507,-152.667005,-113.268927,-28.970538,4.684823,36.324905,39.250777,73.027673,104.454191,89.168658,27.292485,1.515368,7.036838,43.084675,69.494441,-3.639774,-15.906205,-21.473584,-42.058855,-55.463824,-47.05935,-66.466866,-98.709828,-145.862125,-149.577,-172.04706,-208.272682,-184.471857,-116.610606,-110.099703,-136.027508,-111.819962,-71.379891,-36.335827,-68.242274,-160.751823,-167.706083,-56.36696,5.742947,-30.293197,-137.824468,-108.851209,39.631709,69.235989,18.508571,-28.22956,-188.821094,-360.713903,-382.388669,-350.975134,-360.793511,-432.398227,-441.39554,-325.358644,-231.503243,-150.322521,-281.918727,-343.707448,-303.803639,-243.310984,-136.408748,-59.880094,114.832595,157.618801,138.841739,101.853113,97.514647,136.679064,170.397945,198.616179,175.261996,102.91227,105.803307,126.622409,135.934723,136.067518,167.316679,161.3856,17.873923,-136.524251,-158.897707,-157.248405,-152.153975,-142.652539,-140.737605,-112.02864,-98.949905,-98.407467,-45.768319,-18.465834,-7.002658,-3.944725,18.290459,40.326153,63.706551,71.377951,115.455818,250.536361,301.919646,318.402786,283.313003,178.789335,119.321687,-14.185931,-67.404399,-44.272911,68.384664,132.719995,215.276129,233.004327,226.528191,147.467258,82.237089,-39.378521,-59.142973,-56.026498,-79.402554,-139.028681,-131.418248,-57.465676,-63.749173,-114.88073,-151.833589,-101.902841,-2.827479,-3.207964,-72.722022,-117.575869,-114.086888,-122.87337,-135.81108,-85.52484,-6.878677,159.676253,190.896064,146.071313,86.066608,75.537605,157.50121,240.619685,308.189108,272.201471,176.253015,112.588543,92.668423,59.383282,56.145298,59.90071,41.191054,16.305797,12.419998,-87.367909,-202.739873,-201.28818,-82.089067,27.355035,268.382016,346.661202,325.417624,156.189938,92.355154,40.596698,46.224013,94.504283,105.214867,67.410356,23.056963,-72.948792,-86.698224,-70.23261,-13.135874,23.702754,71.265771,73.188646,28.447304,-89.884534,-157.819996,-203.737257,-167.069199,-82.880415,-81.523061,-126.138347,-136.903157,-126.098824,-95.803944,-92.201261,-95.851979,-77.494485,-8.020681,13.34562,-32.230594,-78.766661,-51.020117,-23.477002,-48.47549,-26.851037,23.51749,41.128787,-2.942348,-84.914639,-78.315648,-61.449257,-15.017075,34.181858,128.770237,131.120935,53.054779,13.734847,42.621361,141.565306,179.847543,195.474505,183.257398,225.979492,273.182649,255.492407,180.422594,197.558059,273.377584,293.295866,274.185912,244.423932,223.784416,248.54397,242.49252,205.625896,202.396593,198.38518,147.031416,-24.516524,-83.787113,-96.168591,-8.671037,42.034737,89.836882,93.813161,133.459534,173.153203,194.036417,99.112081,52.709561,1.157901,-3.001667,-6.678672,-14.087657,-2.160047,-2.121087,-99.012945,-231.663955,-251.285828,-213.336683,-197.148632,-194.836682,-184.88191,-162.61887,-152.034458,-137.427437,-114.860146,-105.128581,-55.065826,-19.694478,33.532593,14.957447,-180.142521,-342.170995,-312.793651,-152.484605,-112.115069,-152.569918,-173.590036,-100.16371,-8.850019,-19.290981,-69.679627,-59.951778,-33.692024,-68.15696,-194.283624,-231.242956,-194.420537,-116.769882,-106.034613,-90.135031,-53.197823,34.256772,62.994705,101.899933,64.316639,26.100261,-40.101542,-74.042891,-84.527616,-34.797242,107.520321,147.71693,127.760814,103.363247,110.637978,130.319148,151.307355,197.991286,197.225368,167.288525,173.804812,183.043207,138.594703,75.903369,-41.330506,-66.687477,-37.504409,-3.16676,2.354027,-39.248084,-28.007465,57.88007,100.286443,111.715623,69.897707,-73.368799,-197.22571,-211.785083,-89.522841,30.315019,221.633259,241.636722,197.377181,157.546513,5.797032,-137.612121,-142.182337,-57.71093,-22.110693,-11.834106,-10.069301,14.693502,-9.662158,-25.445601,6.6145,56.508942,158.632746,159.456438,17.411335,-70.141796:-94.891821,-226.345463,-291.506159,-288.939252,-209.21152,7.73979,89.081954,65.005234,-96.974468,-113.750698,-17.570717,23.803282,11.942498,-20.895216,-76.856479,-107.143075,-194.03902,-225.830331,-208.602405,-140.849715,-90.383098,16.545073,40.054228,-14.519469,-44.983062,-23.458338,-8.870006,-13.168131,47.33574,101.811701,168.894295,156.030145,28.220852,-118.509869,-146.161436,-58.968862,21.165682,106.57645,104.063258,29.616564,-123.093551,-188.469582,-233.766488,-203.762535,-91.300873,-79.049479,-216.275296,-307.181291,-330.231788,-201.515019,-183.90228,-212.20723,-202.026594,-141.034616,-119.749791,-156.90414,-295.510662,-351.25459,-317.432644,-228.828986,-53.62756,-25.840548,-32.641822,-28.248965,-51.624205,-98.045511,-95.760717,-69.462638,-63.072641,-52.936359,-45.358525,-57.878725,-89.348845,-108.11502,-179.0664,-186.181932,-69.758793,-9.888733,-19.859385,-78.539977,-203.606938,-214.187413,-191.213696,-160.425585,-144.542146,-101.590911,-93.416257,-122.161875,-163.983574,-163.207624,-96.080135,-69.883278,-99.707887,-107.017476,-28.828218,0.748035,-46.271035,-78.827102,-62.798878,3.820871,51.05554,103.486076,70.468016,-111.895132,-251.17359,-266.744595,-293.466148,-306.240925,-253.812798,-198.322651,-127.41288,-145.397832,-247.911053,-326.412163,-334.416203,-235.773279,-148.610566,9.748694,75.377424,167.389686,164.238204,127.992845,102.325243,158.296226,304.784106,325.637284,277.340469,253.349242,212.159676,148.255951,128.35934,160.918465,203.33783,266.026199,256.909954,123.563871,-36.143256,-87.895459,-146.483039,-136.272581,-62.936108,-38.107976,-30.573861,-57.90896,-179.614109,-212.312955,-176.255753,-120.170396,-124.710153,-138.503176,-103.107557,25.963831,54.561759,33.643362,95.231169,202.137225,367.435392,363.635364,272.555239,215.549994,60.824585,-27.301365,-2.933874,133.96041,200.997848,262.585572,271.778906,241.553758,118.44207,60.879456,4.507627,15.989044,100.632343,139.059999,139.433693,86.002852,-66.735945,-115.881815,-92.258644,21.850544,87.636644,147.262123,135.638013,74.796531,40.589689,41.789098,32.953888,24.520571,61.996828,112.905562,205.543025,215.954507,179.778129,125.012267,104.010485,156.313666,212.031751,259.892049,264.148002,263.381132,184.194897,119.091391,43.632528,65.364326,119.166904,95.58113,-3.692289,-40.543227,-102.292561,-150.326874,-139.656683,-27.79595,44.985995,160.769786,193.648704,155.368827,17.776421,-21.462717,-25.724532,-13.990067,38.034118,62.938827,34.299811,-17.294109,-119.314912,-162.574101,-140.255183,11.127788,86.389846,126.52868,116.697865,64.423872,-111.806201,-204.40302,-251.824629,-205.347054,-82.489794,-46.74519,-34.526828,-51.629949,-118.103763,-157.898568,-148.783998,-107.719279,-84.761053,-23.816618,8.775629,-2.925972,-115.471469,-153.500384,-128.006927,-78.059532,-5.457404,-16.013402,-95.215254,-127.001475,-159.925399,-170.402637,-161.0077,-75.299018,7.641541,163.529671,191.194162,134.588668,29.083393,-3.472697,-35.216466,-31.487317,75.159033,163.266186,300.6825,315.446981,192.800195,74.105885,100.862854,218.073948,254.49413,302.284067,319.229867,264.309631,124.509016,86.753813,108.031577,142.180656,175.066863,153.871011,78.673984,41.905601,-26.610095,-31.997258,3.798776,123.771499,193.740005,284.554412,278.777784,159.877203,2.61556,-54.827189,-122.302055,-134.101714,-98.569073,-51.827856,23.860819,8.231509,-128.1985,-266.261156,-296.098001,-262.864827,-212.441515,-118.922348,-104.169529,-149.228772,-176.044398,-150.605607,-62.633727,-6.842201,135.970412,186.239268,147.3092,76.435493,-103.671365,-217.548576,-190.45432,-37.090023,8.858018,-27.545807,-60.13559,-51.900133,-23.337934,-21.120238,-8.765196,9.713988,76.824936,102.00226,74.707223,49.289248,14.548461,-50.387277,-61.424308,18.349756,82.156752,202.734205,236.26544,173.664509,-11.158529,-92.401183,-159.395167,-138.473091,-22.37788,49.577972,164.43447,172.069465,99.352905,67.745178,60.338088,43.135695,69.172323,148.871505,153.147123,120.915007,131.156368,118.952514,12.487425,-46.94808,-69.303779,-21.340017,88.67685,93.69028,-29.346722,-176.369073,-180.708948,-41.627363,47.625805,125.755459,100.308476,-41.305669,-250.55276,-321.403761,-238.463732,-91.040987,230.674881,305.507979,168.763093,22.069603,-164.535044,-148.280866,-141.567785,-212.741992,-251.457618,-208.810286,-133.344777,-51.610461,-151.035022,-200.804136,-165.530669,-99.932804,-38.954449,-66.40993,-142.759072,-155.129381:120.09816,57.149317,18.808592,-31.381294,-36.568218,-15.933083,-9.066144,-28.352294,-26.83147,12.238622,126.377102,151.627144,64.063143,-21.682526,-141.103577,-162.922369,-190.811418,-193.489569,-185.325083,-204.992189,-219.080209,-197.891065,-155.687304,-54.312283,-29.007367,-19.077803,45.065961,69.650902,95.83477,130.926652,244.540518,267.38751,205.049236,176.102841,188.592603,242.328073,290.126803,343.312776,319.957001,246.450154,226.643871,191.037319,3.927545,-70.071841,-75.813219,-88.285106,-220.662523,-263.630977,-173.884403,-32.724771,-28.178474,-91.269038,-93.1557,-83.557312,-114.739027,-204.804023,-238.778879,-212.272447,-97.415291,-43.248942,10.836771,18.273497,32.48564,52.343034,116.524734,166.000971,152.923019,10.929467,-67.196323,-77.618233,-29.597042,42.152157,30.359509,15.766488,53.660063,85.569188,48.083276,-13.840836,-101.581781,-114.963812,-122.441034,-122.463594,-125.528918,-113.308607,-83.55533,-19.796172,-12.229042,-44.180447,-43.208405,-21.832946,-29.016004,-72.646394,-169.576198,-194.595489,-183.242098,-157.102691,-131.664552,-165.603168,-160.758953,-14.096628,72.992498,81.914249,31.834055,-59.636615,-189.215179,-253.857695,-341.711184,-377.311063,-435.419222,-451.201253,-400.985882,-336.203577,-285.104426,-371.760672,-405.674114,-352.651062,-262.718815,-62.310794,32.536785,198.258602,176.758364,121.658132,118.814336,165.16964,202.451832,183.154006,184.287487,207.461491,178.96327,86.505862,80.33289,147.458218,174.985528,177.102958,179.954463,180.899222,141.600255,134.186275,124.10422,110.96158,105.967151,123.320036,162.788281,153.391212,87.710557,146.786665,215.148918,290.005245,282.374083,237.179054,239.112992,293.196125,296.571052,295.686303,362.223805,392.227489,351.870032,305.911372,213.36863,148.414115,23.003182,10.738253,37.149834,111.640788,159.941373,263.202566,307.195742,335.13714,180.445879,78.252257,-0.875224,2.721377,-76.293981,-164.903778,-279.787346,-283.475094,-265.053208,-257.877056,-261.333115,-244.253725,-194.644709,-65.52987,-46.711826,-92.174088,-84.61344,-64.502353,-60.866031,-69.277257,-29.595985,27.231257,160.882688,206.787092,229.766972,211.402993,204.517591,229.973775,258.4361,311.478806,354.574685,435.34194,343.377665,269.156112,197.596975,193.050688,117.559353,23.060706,-125.50813,-136.642283,-133.790293,-180.013863,-193.914085,-130.18857,-31.736589,260.765599,381.686952,421.360453,278.155421,211.796263,130.205461,103.281216,106.836966,136.109332,155.080888,116.572921,16.453642,13.731599,17.533213,0.976101,18.223285,104.659096,130.167752,77.421134,-29.227066,-60.230547,-60.907667,-45.206095,-52.838757,-98.190483,-207.101878,-218.284048,-187.920918,-209.28204,-227.860381,-205.49548,-163.752043,-102.2167,-94.81821,-110.429338,-149.044891,-149.103538,-98.352328,-61.829507,-10.586594,-17.471753,-79.154496,-91.352093,-22.869986,-1.764183,-46.912381,-82.510694,-32.577605,91.468695,114.554451,94.139554,126.14966,174.670017,232.463214,227.052513,194.807909,188.540184,197.645312,189.089446,109.307382,114.542255,173.573669,227.49231,185.550921,69.308431,64.946969,163.778827,205.420866,176.803925,100.966588,98.819013,124.43063,83.780313,-59.351034,-89.272294,-66.156059,-43.275147,-31.362506,26.652557,62.197689,94.944321,89.014661,70.779121,51.611901,39.204193,26.607757,16.327518,-54.09121,-88.144533,-50.694687,-0.803452,41.399862,-14.701026,-75.669567,-195.610381,-205.372549,-119.584351,-81.566678,-115.054279,-167.163944,-153.275747,-114.233602,-99.830614,-44.167192,-22.970669,-61.824274,-119.187811,-251.706635,-274.873035,-238.605743,-171.53558,-149.045134,-123.392282,-120.306819,-47.750406,82.021502,101.73528,67.665915,70.49567,102.912182,74.875439,-54.592027,-99.880246,-102.248903,-68.221742,-77.826444,-129.282192,-120.253262,-2.271177,73.503838,165.932103,85.578268,11.483949,-50.528276,-24.544351,85.883733,137.526433,189.378056,196.33259,209.441529,226.956654,208.350479,161.772628,177.285597,240.75824,244.326788,209.787212,171.443484,146.834158,77.386968,35.45892,-28.405875,-44.879979,-65.329319,-83.031435,-124.392661,-94.378516,-60.411238,10.167953,38.481753,48.614454,25.134386,-94.269441,-220.020174,-243.021492,-227.899285,-176.263057,18.643461,87.554794,44.157179,-7.942064,-10.446474,36.136324,37.77764,50.530334,65.571553,57.491333,43.771792,19.615189,-23.872066,-29.624644,-27.09569,-36.192567,-47.604637,-56.667081,-140.543785,-195.599335:116.789394,77.571783,38.427753,-56.291769,-76.501345,-48.946233,-33.452324,-42.174947,-5.079663,58.61642,128.201111,83.640512,-49.098291,-74.844326,-120.032393,-208.028434,-427.701725,-405.246118,-338.508323,-305.47836,-327.06016,-334.359148,-308.571889,-244.790142,-182.727617,-145.168541,-101.861709,-96.166777,-38.489098,34.936813,201.605848,245.29009,236.64508,130.188871,66.696675,62.869833,123.701899,214.527151,211.581148,151.985273,124.238628,104.605118,-11.0842,-65.189522,-110.842355,-153.280112,-306.209111,-349.837006,-244.347795,-23.173643,26.756489,31.276333,25.559271,-21.623874,-41.189717,-24.158962,-29.999426,-33.898612,24.791036,73.484676,153.52244,175.101822,191.779435,190.212288,176.054332,177.92146,166.498004,74.018212,22.513178,33.129143,88.440203,171.997585,157.743858,124.707256,42.880202,17.872463,12.014192,15.117518,37.385015,42.118061,-26.146945,-91.783808,-95.781351,-90.536291,-77.814232,-39.842829,-31.951827,-67.409929,-137.867509,-139.330238,-77.369795,-63.654371,-126.822117,-173.115905,-188.125678,-161.09664,-173.625139,-262.984058,-268.535228,-170.905465,-119.097293,-113.19687,-140.757705,-210.696879,-225.331441,-208.632697,-324.026243,-463.652247,-649.271292,-626.598585,-403.929751,-280.217718,-165.484108,-261.865577,-368.044999,-484.127515,-434.085831,-228.421037,-125.120773,61.038024,136.171565,113.723597,36.941041,19.902007,90.939028,159.06639,170.622053,82.273122,-99.200646,-86.449016,-39.112648,37.817605,73.683888,153.80313,177.316283,142.897521,45.229422,6.107655,-39.623257,-47.063862,-53.451658,-53.78694,-14.595481,4.779651,13.687913,81.486078,100.982034,51.251084,42.781861,131.081269,179.194533,116.744751,-79.436394,-103.767013,47.102675,134.247248,170.645011,132.557856,21.442836,-30.091537,-84.539137,-60.141712,-40.200603,-19.852405,-4.214503,70.076805,116.119567,133.541107,-9.179642,-75.622359,-76.043909,-51.54723,-69.300573,-100.074819,-150.789132,-180.315386,-242.916914,-216.565291,-187.144173,-183.601383,-194.144481,-187.250645,-180.737892,-167.391237,-119.885439,-118.428853,-225.825754,-275.705494,-220.840905,-127.92221,77.171994,132.022213,123.611351,69.706438,46.630142,55.551735,96.480246,182.911716,199.519999,156.519904,100.101586,101.999081,112.816353,116.671189,110.362931,75.662878,22.960309,36.805913,27.33518,-97.385782,-160.923913,-151.469475,-38.562939,279.247506,385.862386,403.953044,275.791864,210.423153,93.593743,44.731327,12.084658,33.473128,105.488117,115.729659,29.335858,-125.500269,-179.469877,-152.264478,-84.679064,63.224746,121.411665,159.447196,73.404764,-0.385469,-121.692173,-126.291169,-45.710053,-22.578385,-87.978034,-135.681431,-152.52249,-132.642153,-145.673601,-198.873572,-215.421601,-138.994613,-60.839512,-38.954963,-168.421207,-177.22553,-122.395713,-120.123433,-109.669114,-71.771628,14.878235,44.210058,66.382851,-3.877061,-70.004369,-116.061106,-35.642933,175.786278,188.995173,54.740363,43.880239,114.482388,250.217929,283.135112,294.575709,277.95386,230.959064,224.387591,242.782304,242.438925,230.157947,203.228356,189.213688,173.254048,181.133584,200.738866,202.790174,206.346974,227.290687,248.227131,236.949007,168.599506,27.113297,5.639495,-17.766253,-74.811297,-79.010417,-17.200913,22.216779,109.535432,167.812166,236.154337,215.476116,210.375348,176.710751,130.668179,38.997883,23.092064,50.193379,71.105698,64.299497,-10.650949,-32.922002,-19.419957,-1.496304,19.639323,28.555607,63.978884,84.516064,75.004832,-0.613028,-25.615329,73.569582,160.786491,231.337886,167.887767,-109.243368,-283.604822,-268.787339,-129.612223,-57.095265,16.27683,30.289759,119.227757,196.149186,163.680499,0.992003,-70.196981,-129.568942,-136.623206,-151.864525,-174.324811,-245.484458,-262.659318,-258.012989,-264.700962,-253.697758,-151.68424,-76.151437,19.2761,5.290943,-12.375057,-28.897959,-14.099877,77.723881,120.034649,118.937085,91.179533,78.58691,143.364332,159.251373,143.331604,140.798051,161.676681,170.574261,194.003435,239.355017,225.131904,114.469775,74.185328,68.823056,84.568517,135.662236,145.992092,76.073238,23.938704,46.228411,108.852703,117.880266,117.21736,126.750725,126.99604,22.073974,-49.741342,-130.27906,-114.599425,17.35628,87.830969,126.412454,99.597737,60.877111,79.313,91.386153,125.329162,129.815211,65.366735,19.585685,-56.840985,-96.880216,-87.884224,-51.220814,-27.535634,41.121889,53.052146,-50.218582,-143.889531:-1.9711,-165.085633,-208.545555,-172.90779,-114.614261,-16.987244,-4.191974,-18.647955,-27.001667,-26.260809,-24.753111,-20.044498,-18.244591,-34.029451,-35.888567,-18.951804,-94.739774,-241.067195,-247.306507,-134.368606,-69.919336,-0.4072,11.916177,9.500766,-9.45956,15.837859,88.512371,67.978479,-13.266861,4.131397,99.796556,108.650921,59.807478,12.651821,-21.788299,-35.15289,-2.363071,55.765801,85.988165,133.714924,18.087951,-78.045343,-157.832823,-120.164977,-47.169138,-66.651643,-173.271118,-227.096551,-274.876424,-173.324458,-115.177768,-83.583957,-90.21835,-98.9267,-100.325562,-147.286111,-249.822131,-251.064856,-137.3881,-86.206468,-28.664151,-9.780005,-21.131037,-45.60366,-81.292013,-66.934711,-35.736764,63.344323,99.975372,57.825181,-11.960918,-132.660897,-133.806353,-94.307441,-30.968736,-21.196038,7.417099,22.441627,9.209161,-13.051702,-64.744947,-110.400158,-119.13604,-121.723957,-151.451578,-225.324231,-210.639999,-135.944579,-114.852035,-99.508606,-98.962816,-131.826854,-181.405797,-173.360545,-104.482713,-71.699267,-97.226034,-96.869937,-31.102437,98.609324,97.674867,12.242324,-0.440186,27.353095,-42.532535,-102.654816,-206.448913,-238.710923,-271.648707,-280.694389,-254.015685,-221.915654,-189.176356,-242.321765,-272.341454,-195.149499,-90.500437,55.672603,61.52602,47.980576,81.481198,88.474159,84.831838,107.01528,208.525106,241.213674,224.381694,194.784622,106.329502,79.66256,121.914076,206.521013,202.47453,127.931257,99.036264,97.125648,104.119443,88.774622,17.069934,-11.992746,13.704326,54.507783,108.113171,91.023773,-0.204493,-0.199191,37.755066,122.353526,154.993069,157.307304,142.714334,126.006696,116.346647,136.132568,199.929666,221.104567,262.650642,283.5264,236.276432,141.591611,-51.984283,-24.436083,34.290661,169.042997,256.573743,346.351961,312.962283,223.711655,199.656412,165.678523,23.919779,-37.446689,-97.383505,-122.267122,-171.380715,-174.047618,-121.416075,-121.373437,-156.972639,-146.276817,-89.422186,-21.551483,-29.793773,-47.681413,18.846466,64.672869,60.360069,23.549876,26.409409,72.789005,200.751086,258.094909,254.041523,130.68021,98.138967,180.194597,270.599702,374.562026,376.812767,389.422526,354.481821,293.949287,167.898549,137.68026,103.098915,45.985633,-111.088775,-161.325297,-203.248585,-214.02172,-218.00142,-132.118121,-12.941139,212.895275,255.1654,202.75766,99.456374,90.157689,125.045838,132.547467,159.634853,197.458878,240.731955,182.118923,-63.276503,-123.796351,-68.034443,36.068238,74.054231,123.56912,117.920156,98.617284,73.64449,28.86821,-40.763628,-28.639003,13.671763,-16.874585,-162.573588,-213.738859,-239.533839,-188.78928,-137.966166,-86.227899,-111.215837,-133.259688,-90.933785,-47.024258,-123.429173,-119.875962,17.723837,82.366904,60.618191,1.738273,-93.83265,-134.95674,-147.464689,-1.888946,53.61612,70.717997,78.922664,117.235828,128.003784,133.161519,137.010412,131.904052,126.166068,146.634691,183.933678,173.2118,171.316681,195.276452,155.930153,43.407266,58.684749,207.496842,263.918403,294.312121,297.57805,242.704964,99.722114,59.086372,118.777079,193.321787,275.981886,228.9907,36.899117,-22.546315,-16.416169,51.0993,78.32342,108.473192,110.178614,87.607632,83.988197,76.292527,-47.6964,-109.855306,-109.435575,-85.358834,-95.788604,-109.54445,-90.340832,-75.663833,-83.600698,-97.029158,-97.478407,-94.246753,-98.419572,-152.174424,-187.609727,-227.090384,-220.40771,-206.934802,-157.206818,-108.276787,14.84505,42.399388,-35.411327,-96.8515,-179.807729,-243.0044,-247.226968,-148.609854,-88.549361,-83.165503,-116.860277,-91.22609,-16.807504,-10.643269,21.954846,57.107239,89.943127,77.42454,50.646713,47.799846,-5.101522,-131.569943,-164.742206,-64.940656,41.110053,165.143621,149.837573,77.356223,27.013459,10.865992,-11.179836,-27.305274,11.240346,97.56637,259.3932,254.70582,133.272314,83.62778,81.558305,98.859659,137.30134,205.726157,186.859812,105.681647,120.666376,119.816271,41.687785,13.597759,15.779953,25.388352,69.893319,76.690889,-17.340737,-59.308144,-26.469655,-2.804657,-31.396955,-86.253694,-80.935128,-68.685997,-143.531524,-150.959977,-34.880297,63.782016,236.788544,257.567768,187.40397,141.619453,40.775789,-13.443059,-27.522449,-83.716457,-87.731801,-16.697258,11.376164,-51.240364,-147.951046,-116.613594,28.752368,55.308189,-21.207082,-77.881952,-150.453075,-168.734129:left
73.052182,113.903266,171.324477,300.994622,354.160201,350.146359,280.755451,105.245897,-15.172851,-36.448469,17.768371,72.117381,177.770104,209.941796,166.476653,104.321935,27.209654,73.138417,106.619822,118.637019,105.89118,75.276267,60.873069,40.721974,7.547073,-0.06433,11.695056,14.337254,45.312225,79.415067,94.732987,50.123899,-93.587165,-117.700944,-67.760746,49.654281,114.805969,221.131543,207.470548,42.357609,-130.03451,-153.461307,-71.020968,-25.692677,9.225474,19.285967,23.827417,-2.160609,-144.882574,-302.870653,-325.686157,-259.005096,-205.00556,-164.782919,-198.315303,-284.054575,-267.09069,-211.423412,-55.698438,7.757935,34.658858,2.159347,-56.864692,-67.931322,-158.092071,-291.009957,-309.052227,-288.48228,-249.270286,-70.549692,9.947811,-53.037588,-246.572216,-256.813552,-162.292514,-123.431195,-43.723633,3.950416,50.975848,48.131815,-6.633477,-80.415375,-76.761655,1.360433,49.25287,120.685661,119.209785,-9.774685,-190.200966,-229.8463,-214.462171,-188.811331,-140.639605,-119.645974,-74.845052,-60.375273,-78.376306,-101.37406,-97.921017,-111.155767,-136.210677,-171.524001,-176.51848,-220.675467,-329.569375,-351.147075,-233.786374,-117.542158,154.974566,276.020222,379.955329,360.336064,248.14009,166.339489,185.572609,282.275358,304.329482,277.307509,249.178214,152.452565,1.916175,-53.404185,-55.063625,-3.057735,127.713845,162.801123,173.499513,177.667391,167.865451,145.770158,161.062085,239.877876,279.443304,245.459592,167.665411,13.800398,-75.957394,-119.121232,-192.893211,-179.773535,-52.04407,-14.816369,-80.519951,-131.058723,-208.822195,-241.823879,-206.913468,-119.887979,-124.001454,-200.590152,-222.855287,-218.255624,-248.614786,-247.456543,-118.22044,-26.068996,65.512156,32.561837,-138.350786,-215.717014,-271.726747,-205.429353,-171.695131,-182.001413,-186.371693,-123.374957,-95.128255,-117.300799,-180.806666,-210.421167,-265.924897,-287.852546,-309.074503,-309.266711,-265.994425,-220.932789,-204.643917,-342.481231,-391.214338,-334.732379,-252.69628,-134.461904,-137.163758,-212.664136,-284.323,-270.314741,-112.886266,-24.315393,74.724371,79.005891,10.164084,-36.579402,-118.503383,-207.35143,-233.456059,-188.073825,-110.469318,53.321829,68.790443,-29.725835,-149.426459,-172.057305,-84.295811,-10.176156,96.148703,118.071518,84.453697,43.674425,-3.246248,15.46373,11.053869,-38.191723,-40.218085,6.329624,13.45708,-65.889518,-160.496115,-136.357629,22.842894,87.953985,154.494041,181.952451,181.300934,119.414221,-82.314092,-155.491921,-114.786945,19.993654,92.608455,172.541231,151.181061,41.64828,-116.681349,-186.049203,-165.346738,-91.382035,20.730213,27.645923,9.835929,16.079539,24.008397,24.792486,52.062009,128.76471,149.037194,143.77707,144.842699,162.601066,79.192151,30.408665,49.781851,105.107063,222.192514,245.582733,166.693936,99.634144,0.355542,-22.667547,-11.055132,16.461513,37.304843,61.376144,36.211927,-14.813097,49.570963,113.605453,263.192434,309.79442,285.742314,252.676788,204.363406,164.660819,51.38269,-17.020501,-27.82951,-0.111624,46.776379,165.565514,185.695215,74.546026,-38.856667,-2.408644,144.287796,165.853494,115.354291,92.976311,89.767191,91.246586,54.012559,45.630213,70.126613,114.152915,135.429864,146.184876,105.752191,-59.722976,-242.663103,-279.993425,-213.946158,-165.359005,-123.615499,-110.929102,-61.904577,-41.740526,-69.132157,-105.448777,-68.722122,73.025636,121.822734,116.777315,78.418962,-32.62972,-162.227982,-205.384931,-236.374379,-225.229221,-128.60241,-86.463747,-121.663338,-168.559463,-250.659609,-287.14959,-290.420311,-329.520259,-335.092638,-226.047999,-160.86613,-156.507935,-236.658891,-248.042162,-203.023145,-166.885907,-77.462351,-45.975567,-69.85562,-90.432136,-64.201755,-37.864924,-65.59637,-180.593965,-222.391483,-196.455501,-152.365748,-120.954991,-143.419393,-94.336577,129.554098,213.058536,207.416815,171.067778,137.527218,86.192478,-161.768687,-254.921073,-184.613243,-43.880341,-22.963363,-18.84249,-25.023716,-99.153675,-236.497813,-276.957239,-243.29885,-208.150612,-158.669105,-98.806125,52.446002,45.971461,-146.702501,-257.480673,-233.391018,-140.113112,-104.52926,-58.70332,-54.729003,-133.930115,-259.62903,-288.632344,-284.793735,-277.858191,-221.23678,-153.388502,-46.389935,-52.589905,-159.112559,-225.56516,-202.573892,-99.851903,-33.860431,75.739823,92.192858,66.169518,6.919372,-11.22382,3.031847,19.297132,82.720052,135.663406,210.409725,214.037668:74.719089,84.434436,137.484035,254.321938,267.317852,195.210009,138.617484,3.868493,-86.786009,-54.074455,146.447332,236.679901,288.388856,260.497711,133.063401,54.276047,-54.558624,-23.614676,22.144803,99.037577,105.587089,20.639254,-21.781766,-47.403299,-119.370518,-134.043172,-37.322627,24.652378,112.01243,141.793454,103.941185,9.798272,-215.992204,-230.894902,-169.754408,-50.358717,13.690578,141.551617,144.748892,-18.022581,-175.059274,-169.907926,-47.008641,-2.058978,6.73891,1.175126,-29.589171,-65.525022,-133.584721,-144.207984,-168.376544,-275.928624,-288.775901,-192.948405,-160.254049,-209.750495,-202.32977,-123.022024,36.463757,54.910735,8.493048,-25.847148,-79.745838,-103.706551,-208.712053,-259.607289,-222.979991,-161.347011,-157.237177,-109.187126,-61.677577,-16.696327,-81.859349,-106.959667,-57.238844,4.255967,95.24312,79.838006,-32.996696,-68.889747,-95.941158,-107.21055,-80.745447,-3.76263,13.662149,-10.325592,-33.650746,-80.403093,-176.734688,-202.450355,-117.304306,-51.312907,4.650259,-12.351215,-73.700866,-97.069896,-130.607922,-131.385092,-121.070976,-118.991294,-128.717001,-168.256807,-203.060005,-267.676407,-284.900982,-255.171324,-87.231305,31.902943,259.525583,322.363129,333.691642,319.864467,276.128207,212.634009,202.734354,228.466225,232.652938,199.395577,179.91204,102.444029,-33.502119,-56.143242,15.103254,58.36093,73.558611,40.048222,-27.890123,-18.532608,50.476218,79.751329,114.884299,285.795884,357.889605,296.62638,181.824398,-46.584424,-164.379994,-183.642452,-167.541991,-129.986546,-37.808845,-24.792176,-102.595959,-172.190288,-297.487296,-280.633909,-227.354815,-144.35056,-135.037205,-201.760116,-270.091503,-402.136999,-394.786802,-301.810239,-40.920888,29.949197,-50.80317,-143.068809,-257.376653,-278.126255,-311.699608,-276.287644,-215.552907,-97.293547,-79.377632,-128.721103,-144.224213,-106.397959,-143.11603,-212.30895,-284.121288,-240.22952,-145.149978,-165.375482,-265.364515,-292.226393,-330.439368,-383.549716,-380.75575,-253.711006,-157.690291,-77.552675,-100.986246,-139.495557,-159.147176,-158.45238,-68.88816,5.80929,136.158431,165.979131,109.78484,38.058419,-94.466914,-162.401055,-169.712984,-122.855576,-71.860201,11.485949,18.301798,-16.678698,-109.556878,-132.640368,-43.607368,25.416903,105.157335,101.693775,-7.244226,-84.859157,-167.127958,-181.937915,-200.609703,-204.515348,-164.602056,-66.237384,-55.110588,-122.283126,-141.902827,-93.877253,0.803292,7.145501,-2.564781,5.94546,19.355037,-10.239767,-159.0356,-233.316915,-184.660401,-1.835324,53.825877,-11.192227,-85.075294,-171.351062,-182.698219,-163.017203,-97.091029,-71.025337,-11.968832,17.979623,35.732386,10.92409,-110.108312,-177.958178,-160.72084,-116.069814,-100.310766,-38.573176,-6.319181,-44.440615,-163.528479,-178.168754,-126.906945,-86.629051,16.909795,59.164981,88.767895,78.997821,10.525892,-0.178626,49.558573,148.285336,165.167294,195.60085,226.357778,245.701325,185.278173,180.583219,255.913162,304.246653,365.373191,356.066929,269.854251,228.083682,141.641173,75.756064,93.230666,152.671895,162.409605,154.451508,109.001839,-97.408653,-189.099264,-130.924335,41.13762,92.086409,75.812956,23.072656,-55.786318,-57.300967,-51.666666,0.647253,59.744419,128.720403,125.464329,117.459854,115.921639,39.662161,-131.984877,-182.268767,-134.342442,-69.444613,45.175632,74.959864,55.683009,16.806309,-42.352169,-19.981756,27.810156,181.983204,251.547253,250.579754,175.076621,-9.494361,-78.798553,-51.855824,53.54772,99.363005,139.185626,125.312779,42.951428,-7.7501,-83.911412,-66.063128,-36.959258,-15.223774,-7.186242,58.454818,103.80116,109.643355,-74.886839,-161.306361,-116.775695,-7.88343,169.272873,176.40936,18.249472,-94.809059,-225.812509,-159.834014,-113.11397,-101.796559,-107.996933,-85.841174,-79.287037,-96.765104,-90.57932,-60.374569,81.464595,162.51129,215.04672,175.8828,5.327476,-98.257433,-244.462337,-229.725378,-171.022695,-63.569731,-54.947681,-104.312482,-135.704815,-218.249384,-268.886322,-226.2075,-107.408772,-101.048366,-121.264216,-94.245214,-27.566668,-41.745408,-161.964198,-217.837033,-179.913305,-63.718358,-30.859864,-87.475928,-174.751167,-337.117911,-369.542015,-339.424467,-239.726323,-197.281079,-108.820033,-55.99697,-20.595463,-60.600495,-178.14496,-164.792447,-110.825026,-33.855797,-8.139843,65.093055,98.067015,95.027297,14.343812,-7.544991,2.830671,23.887663,157.696077,250.39955,282.348295,206.020959:-3.024605,40.710492,77.744208,97.933879,96.953866,107.338994,101.74046,3.330806,-120.994989,-105.20922,79.676413,167.497021,197.659796,159.348165,70.495766,22.061125,-55.098736,16.003001,81.005937,165.589993,177.796593,116.290401,48.132242,-100.628489,-157.19391,-117.345284,30.58364,95.995941,199.182572,216.29342,82.234779,-30.170197,-142.428652,-129.18485,-126.237365,-74.462132,-11.77792,60.330965,26.864017,-106.564845,-152.976706,-113.653602,3.04644,32.899948,29.204699,23.568882,23.683562,15.48916,-8.24815,-43.528589,-73.381492,-97.606017,-88.069981,-102.469519,-129.697963,-184.305482,-182.523045,-116.272562,79.568095,135.077466,127.877608,92.362247,8.742342,-41.746292,-178.814736,-246.308384,-230.302505,-141.000488,-92.760433,-48.338682,-47.816663,-66.896833,-87.900805,-72.496803,23.654106,72.705111,77.648462,47.58153,14.807657,-3.991518,-88.831734,-88.93594,-25.102826,100.135101,104.246232,11.438316,-32.645248,-78.130011,-139.289969,-132.76599,19.843568,100.342586,119.208676,73.224568,-9.730791,-35.218073,-74.61737,-73.957043,-63.717519,-49.764097,-50.500018,-102.881928,-154.850362,-235.009198,-272.922701,-267.676501,-117.678989,19.304287,260.472488,305.687553,276.406178,235.898342,119.044025,92.162921,140.071076,207.156613,176.846114,69.827933,45.654998,11.136948,-38.572713,-31.171211,12.841879,23.549893,32.636935,38.328252,24.442977,-10.306689,-94.463922,-64.804491,13.065096,193.185111,239.133988,196.104355,128.347005,-53.290773,-215.781491,-231.645999,-163.508245,-136.704885,-136.226869,-140.617044,-150.608232,-183.701783,-279.606475,-241.189707,-179.14243,-114.301097,-137.871527,-233.810698,-258.686593,-232.771109,-190.100883,-162.736491,-38.01268,30.147963,15.927997,-76.686494,-239.193944,-249.508106,-212.833475,-179.102718,-152.30809,-78.4031,-46.114749,-46.645533,-62.584542,-59.915004,-37.22382,-40.619105,-56.040797,-42.104352,-9.895079,-38.576466,-166.678509,-203.690885,-189.002325,-181.10199,-194.294385,-170.130992,-112.200154,-27.743014,-25.803869,-25.750304,-38.028687,-46.188741,-2.851144,49.641813,138.14498,136.446773,32.673004,-35.639483,-95.061045,-24.961203,5.851059,7.619377,5.497175,-8.187064,-44.569304,-129.99323,-164.126738,-140.083284,-14.368355,37.489211,72.125854,68.174701,-6.473198,-106.197921,-343.909902,-374.269908,-305.956693,-130.355221,-74.251869,-76.864307,-112.131796,-177.889247,-146.368149,-91.619889,-31.971262,-49.518361,-111.558646,-138.524782,-200.440736,-252.256394,-367.359369,-323.607532,-233.671901,-62.823303,-32.737759,-86.093704,-136.297365,-227.525864,-260.194935,-239.033694,-143.869488,-87.432682,-24.651982,-39.175595,-122.71354,-172.871294,-234.037335,-180.328353,-142.81881,-122.492111,-135.72222,-148.113617,-136.511388,-170.113729,-307.086225,-339.733631,-255.689907,-180.988597,-81.481154,-65.004416,-44.118183,-13.132289,69.129758,124.427627,158.022718,211.279096,212.67229,231.061485,268.567965,295.126327,206.075143,181.33622,212.745193,248.325921,327.326528,343.158883,275.764652,206.162512,35.725325,-62.379263,-35.074731,81.372867,104.899955,38.718924,-32.929677,-173.22788,-198.936543,-172.298496,-88.8572,-29.136215,62.797634,63.978962,48.958434,35.906177,-64.323388,-94.842605,-42.808692,66.808305,90.613764,58.89598,14.419644,-69.762272,-112.946082,-106.634589,-74.288395,-61.930989,-27.229745,-0.709661,37.244864,12.421896,-127.264432,-151.235554,-71.091586,133.765256,195.382349,172.10601,98.829124,-67.970642,-140.265295,-120.849829,6.14172,87.809366,199.67495,200.620602,96.061242,29.319288,-23.29766,37.343861,66.906797,86.965088,71.695955,4.183372,6.878586,76.668344,7.241939,-50.369829,-61.17896,-18.610317,64.896457,62.303872,-44.343814,-102.78614,-148.176028,-155.904725,-168.640455,-191.799097,-197.618637,-214.564662,-213.967901,-159.063295,-80.569801,-42.701968,20.316003,37.316179,44.073116,19.584859,-121.795212,-225.869849,-433.518853,-471.205982,-395.388849,-195.019622,-133.240773,-135.263453,-171.706423,-243.590092,-304.648668,-296.793327,-202.526918,-174.313797,-196.351423,-197.402866,-137.368127,-121.950292,-183.237218,-153.117959,-72.669954,36.253042,49.831597,33.03433,-31.815055,-251.543212,-328.261566,-266.814069,-75.387572,-9.14275,35.721611,39.926129,65.746314,81.090027,72.980558,81.18111,112.579242,184.488286,214.908184,251.724481,239.780631,112.163789,-39.158093,-51.605129,32.971994,96.017103,205.165198,225.611928,194.151897,165.690594:60.818611,-13.59452,-13.338224,15.461983,39.738745,81.975873,82.253416,1.351196,-88.91373,-78.701682,31.102209,92.191406,141.956582,121.024081,54.148881,35.769236,14.577534,32.146654,66.547541,171.893914,226.534948,237.83805,190.964289,90.122525,20.889141,27.130157,124.225038,156.563676,167.278045,181.592876,196.685755,148.059917,-74.494717,-181.56302,-143.398693,-26.372537,27.150511,90.436852,80.222867,-15.697463,-152.144247,-168.525854,-24.004032,63.615349,108.485313,91.521154,57.277056,29.406574,-67.158668,-150.379856,-156.156518,-109.078432,-74.30836,-27.787743,-26.600363,-62.626063,-107.195414,-86.002436,21.50052,55.430965,96.007777,120.75655,129.105165,80.292798,-122.902447,-223.943924,-186.567234,-46.783129,15.868837,86.917289,91.9973,20.120098,-103.85138,-117.102204,-41.171581,9.178249,63.070855,45.7469,-25.957885,-35.517741,-30.214851,-37.547686,-19.354432,55.02384,78.783523,28.693031,-17.856993,-83.940517,-180.269813,-198.872449,-107.721906,-57.447036,-56.031281,-75.2961,-46.773314,-8.581911,2.278435,-68.297141,-77.686039,10.002903,55.111668,-6.021036,-81.290372,-159.96413,-191.930351,-193.84122,-73.573203,35.677739,235.982979,294.450065,337.309315,324.323537,230.135162,210.390625,243.15787,271.76108,268.917159,258.296435,231.861785,105.503199,-45.756879,-80.463112,-60.022356,-30.007111,19.14867,25.951962,29.606419,35.859862,5.54803,-46.056064,-31.755463,90.584411,163.477899,179.407279,113.929085,-45.224848,-177.995734,-220.285625,-246.487297,-232.965951,-130.522732,-69.33924,-70.508353,-146.96414,-306.050309,-252.128377,-166.020029,-54.671751,-44.416815,-62.726195,-81.707712,-128.069856,-163.585562,-145.373741,-25.190884,47.089081,135.833197,119.420874,-14.483831,-65.801928,-76.973742,-71.137812,-82.619809,-87.265268,-56.799178,9.325576,15.370025,11.647157,-9.519098,-27.205612,-39.748056,-56.724516,-144.52771,-191.836537,-210.458902,-169.737647,-109.895154,-155.311986,-173.520932,-158.508152,-130.888898,-71.505251,-72.971603,-158.304312,-240.9348,-234.09102,-92.335369,3.044684,111.71019,115.114354,60.365838,4.001858,-135.248866,-164.560972,-141.852828,-101.51287,-72.304483,18.444457,47.05781,8.20819,-84.293123,-95.501289,-25.76917,20.248139,86.839459,99.400755,48.815285,-3.843622,-102.58932,-164.003913,-160.486222,-61.135556,6.16352,59.543732,18.969754,-144.613476,-212.540769,-157.976996,8.287393,45.351606,6.864889,-26.809019,-74.600456,-116.887023,-263.319741,-284.427016,-217.842652,-77.546337,-37.333716,-46.089749,-89.954579,-147.73011,-155.661068,-185.101095,-225.431847,-173.87352,21.740197,66.4032,-18.570882,-85.930138,-166.106932,-157.784355,-132.47963,-92.041105,-77.101366,-30.093516,-12.368278,-79.418143,-200.376304,-202.01077,-115.231043,-61.023855,51.058737,85.51757,65.527575,26.291835,-77.29813,-99.767833,-46.851334,108.886435,171.065633,181.860052,136.941049,77.752144,104.862891,117.608742,139.782412,170.929777,273.567691,306.088342,269.764629,207.35125,47.255658,-11.060897,10.876183,43.374196,42.564239,16.587694,-8.41508,-27.264868,1.825401,16.047703,43.196858,62.035614,94.817916,91.636785,63.446346,65.271569,58.237095,35.698399,55.941386,88.661581,84.875328,49.499089,10.991398,-60.998362,-133.733242,-170.180461,-170.675877,-144.673323,-77.399771,-43.617283,-13.523564,-36.485141,-162.139717,-202.76858,-146.603321,-16.176183,20.279016,42.180303,10.326552,-177.618233,-357.307299,-359.796526,-270.6405,-236.021229,-154.770359,-98.219507,-54.687836,-95.00958,-234.736342,-281.678727,-255.257088,-198.821668,-181.441037,-148.313664,-146.805966,-203.054586,-308.745142,-346.446735,-310.491466,-245.752361,-146.204635,-146.018944,-216.870933,-253.771863,-264.131656,-205.438359,-190.172991,-225.627741,-249.37009,-246.781013,-243.256174,-270.804486,-250.910625,-190.929542,4.158224,88.554784,128.956856,84.484388,-83.967513,-189.792644,-369.160886,-319.46749,-220.469786,-125.203736,-152.100588,-198.633703,-188.108856,-170.880872,-235.365933,-257.983129,-235.071915,-216.615759,-158.061725,-111.719179,-71.083915,-104.177607,-238.538028,-288.222007,-246.930995,-111.543924,-64.779983,-92.722776,-164.020489,-304.475114,-320.883268,-275.417866,-123.030712,-56.3008,53.264133,102.372899,98.19324,46.926953,-62.127155,-103.552234,-85.816002,8.792244,85.892188,215.123101,207.301323,72.932579,-20.040766,-29.207868,-1.183721,49.036358,228.172168,303.199757,291.961257,215.779258:-14.565535,-76.544407,-44.244151,57.823935,72.425214,-32.47978,-101.20465,-176.465072,-183.90532,-133.566162,44.967584,113.743314,121.093714,76.200821,-0.960974,-20.988498,-45.655857,1.151013,49.539675,162.514971,225.952792,301.197929,273.625012,89.291313,-45.424901,-9.658845,176.424762,235.32416,234.499213,216.670414,140.886031,42.983969,-203.764879,-270.533725,-220.527727,-70.202756,-25.545842,-36.457058,-59.7614,-118.951766,-159.056901,-117.119278,32.860776,79.506549,100.390185,97.547173,43.978987,-19.786579,-135.585162,-128.45344,-92.249571,-24.120323,-13.340148,-44.793702,-66.40807,-90.256334,-83.047316,-40.310099,90.165144,130.455053,133.239212,104.208164,-3.631095,-80.020046,-226.36989,-226.92713,-182.952638,-79.435072,-26.592143,15.22854,-10.10603,-101.645991,-155.101806,-124.061321,1.871766,47.574162,87.589465,72.695707,-29.266041,-79.139815,-106.845965,-53.93543,-22.959443,65.359198,114.207509,74.04577,-9.120606,-153.933975,-267.92821,-278.236735,-126.818925,-33.19896,17.97533,-10.572221,-54.029969,-57.143919,-84.173425,-108.796467,-90.190685,-20.396924,-5.555661,-63.72103,-100.993289,-124.965199,-163.954952,-154.540847,10.838422,109.596868,180.795148,169.726186,177.228228,175.006296,62.768381,20.59587,77.56007,205.622767,232.08275,194.836659,146.443711,14.292238,-100.252424,-103.990226,-22.279358,18.082514,17.82399,-1.633093,5.001142,6.322044,-67.460715,-146.557383,-138.947844,-2.428553,80.052576,110.803424,61.204249,-79.59831,-211.053121,-238.022082,-216.975465,-184.57472,-82.910901,-53.630451,-143.865124,-225.81788,-279.749265,-135.410212,-58.390619,19.639954,28.591299,-33.12395,-77.992378,-83.752865,-41.382169,-11.303065,103.791493,143.902643,90.780667,22.93266,-88.966377,-118.955293,-147.227331,-107.465287,-58.051849,47.790842,77.468624,59.767718,43.586719,11.641374,-53.153261,-50.967951,36.868219,81.359503,70.043612,10.266491,-84.365244,-71.901514,-18.782331,-77.027153,-101.589575,-32.712053,41.56396,113.319255,75.576503,-80.449874,-194.690479,-182.949048,-13.931304,96.065671,212.073907,193.121721,80.290861,17.930719,-69.318064,-17.449128,30.122227,67.707126,60.794546,29.734396,17.25784,-44.613032,-161.892564,-165.474254,-22.846603,63.600562,133.622698,107.429879,11.224631,-48.925455,-185.066751,-190.233497,-129.819299,-1.761769,28.964296,45.426856,39.411698,-99.384378,-267.565486,-220.507369,52.991485,152.87479,167.503301,99.661928,-117.775103,-239.041063,-412.013178,-349.80129,-249.341425,-47.516948,20.97323,20.537469,-53.54043,-239.831637,-285.673198,-230.069448,-93.195122,-48.432714,15.116166,19.353795,-66.424407,-131.861794,-202.977221,-161.692097,-131.44395,-83.902178,-69.716485,-87.235556,-113.884049,-182.732639,-209.040178,-189.159617,-133.102952,-97.915443,-10.692856,3.778385,-49.796391,-78.422827,-95.246337,-39.427787,22.562348,161.083682,209.713395,238.672997,233.512775,195.26968,158.239642,182.694098,291.878424,335.187662,387.955923,408.696694,365.093111,273.255105,55.969997,34.929348,87.102613,140.880674,142.319524,123.582181,81.354413,-36.144063,-39.997724,8.537228,93.7153,128.585256,220.017923,242.704788,209.907419,180.077465,116.809991,88.42978,105.481639,157.548266,164.934722,132.802579,100.574109,-7.217026,-87.277042,-59.940428,66.019394,117.116945,175.851193,171.72517,107.962848,57.993682,-60.6043,-40.495553,34.454231,165.118264,178.899562,133.76555,102.793046,18.448322,-77.713595,-88.307183,-13.031589,63.20074,217.590453,243.591584,191.447923,139.84782,25.46223,29.855619,84.074491,163.737082,150.633921,39.686786,-6.481631,-37.132365,-125.140253,-177.105541,-159.753263,-101.21558,-11.59784,-0.950947,-23.403129,-47.560962,-88.101826,-50.927752,-12.156031,16.723324,-9.769557,-73.070971,-89.041869,-175.493514,-306.610063,-280.191067,-36.956173,72.31277,106.85473,38.098169,-183.550597,-288.138792,-397.051862,-314.144587,-229.077943,-143.870261,-157.643215,-205.215687,-225.144558,-275.866794,-329.527123,-331.413864,-274.454531,-231.383253,-156.903495,-149.656739,-216.170034,-264.683391,-341.176517,-346.234935,-298.062067,-148.908862,-95.431825,-118.804902,-197.005106,-385.948117,-395.904225,-308.630526,-107.817911,-51.222777,-2.166218,16.599659,44.959013,25.917485,-108.04282,-185.964228,-158.941091,-3.275767,91.957134,156.361769,98.539843,-100.798717,-236.544018,-243.307961,-176.969733,-121.348387,13.605812,58.995349,65.361241,40.799808:52.544995,0.748969,-7.123402,46.864398,124.083081,242.665251,215.15912,56.556314,-44.486622,-46.281195,53.691149,125.238743,200.982016,205.572016,190.402759,167.842868,91.606884,30.189456,29.870124,100.449638,143.992951,137.577944,93.823054,32.769978,12.458338,18.232605,54.185458,71.260006,124.66922,158.499162,176.687669,133.912379,-49.040214,-165.271177,-150.865696,-55.118203,-2.317225,36.089613,5.226519,-68.597604,-107.769709,-112.518399,-51.96061,-6.163189,53.183082,54.546472,4.797833,-26.926754,-97.545272,-132.491715,-111.234391,-27.903895,11.337252,66.328868,60.062643,-43.032608,-117.85984,-74.10194,99.448218,127.954492,96.42548,130.174036,245.841231,232.436096,24.174875,-138.293871,-136.486948,-36.482704,33.394575,145.051912,137.025082,-7.150554,-138.63291,-152.91409,-115.253959,-94.873711,-31.425911,9.237005,46.234189,31.03307,-66.863406,-38.222526,68.691713,216.176994,196.950953,60.699871,-25.475674,-196.72557,-270.893957,-249.359913,-107.176382,-24.506925,27.328452,-8.702233,-63.477637,-41.881375,15.122268,-16.025179,-49.238819,-107.750403,-101.493218,-20.963772,5.59301,-23.270419,-152.419613,-213.407644,-189.778068,-87.881838,194.649301,298.172051,339.308123,299.216266,139.745713,12.97716,60.620884,309.068312,382.489724,306.579562,216.857463,54.527919,-67.734953,-100.114871,-110.540519,-100.938796,-31.993639,22.83754,98.578258,109.049696,92.236774,99.628279,126.867664,143.690848,129.733804,89.428871,51.619612,-60.015066,-152.642498,-173.985741,-182.97209,-175.739035,-88.905113,-27.325438,22.115657,-5.113129,-137.49908,-212.514846,-186.702456,-82.554368,-32.474408,16.240678,1.843453,-45.465587,-21.396231,28.702292,180.605656,249.436489,277.632357,236.043552,120.672387,66.664099,-32.246465,-92.033362,-96.185337,-44.290348,2.359342,49.632966,18.38787,-85.148061,-90.724524,-80.007768,-129.724966,-174.022542,-220.70875,-227.145645,-224.89775,-214.144975,-224.586611,-228.024803,-188.683968,-113.433281,-109.632687,-120.036911,-117.646222,-138.670729,-209.765972,-210.916489,-119.663579,-75.101535,-9.616118,15.233865,-3.072342,-46.910907,-142.96781,-167.746876,-151.209898,-83.151847,-28.930011,82.714334,105.035061,31.673267,-127.152301,-173.078325,-112.364771,-26.934505,109.106636,115.528179,28.373114,-21.089139,-50.090505,41.635711,88.242424,95.715822,79.192771,64.16639,56.622675,-22.677846,-137.557747,-125.922294,70.458574,176.79195,267.006704,266.923982,206.845542,135.714776,-67.719889,-163.48546,-124.728958,26.916761,93.816038,131.677195,87.783341,-21.2886,-92.02644,-124.292723,-74.23661,19.888289,171.939563,162.02408,45.600477,9.423257,-11.078522,-6.401629,31.336308,167.339874,213.89533,186.809332,150.032138,58.177469,-79.550305,-92.073733,39.537471,126.392891,238.990327,253.075553,175.923808,89.414912,-104.060687,-131.852315,-47.861154,157.965155,206.851755,124.263487,21.079011,-111.352039,4.935646,120.515359,313.920432,344.137335,293.454015,256.182545,164.1244,95.139836,-55.4883,-144.289565,-134.463718,14.582444,98.819075,133.739554,97.496456,49.487287,85.573214,117.902366,174.870805,203.627253,258.570047,245.771215,127.895262,90.204093,127.506358,218.26109,248.475184,220.336178,189.146299,149.765907,118.624949,4.459488,-103.102834,-124.768494,-101.639894,-79.575684,-40.172444,-16.862163,-0.324824,-19.90771,-83.896713,-76.998423,-34.916094,64.865214,106.109967,113.061279,75.378612,-12.863904,-103.662268,-161.347902,-243.2939,-227.429402,-61.147131,21.345577,36.68232,-8.306403,-126.838354,-149.404228,-108.377574,-82.739597,-99.018968,-46.394027,-0.209038,-29.208722,-124.97036,-126.672639,-76.449074,-54.099893,-3.2601,2.666817,-56.574157,-59.795105,62.124428,140.353731,126.057529,89.786778,75.887047,26.780863,7.070588,-5.671762,-1.557899,41.676017,223.254737,301.458076,312.261314,259.26253,116.462496,37.052613,-102.303494,-113.679491,-67.939398,11.846611,19.03319,3.031004,-2.670207,-31.576461,-75.673554,-87.893942,-103.379881,-115.535028,-113.438799,-74.625628,-11.072674,-52.260132,-239.406327,-295.043829,-254.496859,-157.123265,-111.566849,-57.864719,-73.042258,-178.666233,-268.892426,-257.198939,-164.84678,-141.792319,-141.824311,-125.851896,-81.747642,-95.651088,-226.266818,-301.94529,-272.412328,-195.491129,-166.417601,-72.538982,-44.753432,-147.533248,-286.727578,-290.476659,-200.535658,-121.77471,57.077045,104.853115,59.274935,-0.188616:-44.182122,-119.62622,-104.449484,9.709766,80.518919,119.041875,73.720371,-84.793402,-181.540968,-146.67925,60.355403,166.360444,241.883886,210.900848,103.264186,48.781346,-35.491309,-6.930512,54.119698,174.974048,219.664581,277.880078,261.22278,94.650388,-60.449425,-34.623709,163.416495,236.149038,254.298823,234.379756,165.988883,96.549865,-73.674249,-111.013959,-86.702363,-12.305885,38.499945,95.354938,69.292843,-84.075756,-215.973379,-189.252865,27.534708,133.471941,208.165075,173.336309,34.61445,-19.24109,-56.383853,-21.660359,18.718652,128.874944,176.824737,167.468365,98.931392,-91.148197,-158.286054,-100.016403,72.690407,117.716388,145.311886,153.71768,112.229528,47.942139,-96.118505,-126.341562,-86.536446,44.970831,98.830052,92.565537,30.438103,-126.212177,-200.284776,-177.395481,-66.673748,-14.337956,50.849584,47.769083,-38.208766,-93.400626,-186.40646,-137.800842,-20.167406,210.575061,223.410256,48.817503,-64.286373,-247.165515,-313.98622,-271.922787,-103.117643,-27.091317,50.371516,52.783244,11.942696,-24.717869,-102.526566,-64.096397,-4.199975,77.767506,82.732666,33.517538,-3.651403,-79.867247,-164.603505,-155.1528,32.399991,151.275755,304.041264,325.454748,268.614392,201.356588,58.829474,68.511863,139.249625,284.211653,325.880886,291.142589,198.203202,-39.24439,-139.299864,-123.97919,-51.899067,-15.316982,51.975219,63.695406,11.640581,-41.570913,-152.303034,-149.610579,-79.053421,104.900881,150.827901,82.748323,-0.646571,-193.437955,-308.544447,-290.607721,-175.692954,-114.671394,-10.948865,-1.937138,-98.857504,-175.312118,-282.327736,-184.523438,-92.131899,42.152878,71.93616,32.35887,-18.986446,-77.732508,-109.338686,-104.068493,61.361961,179.239896,291.148726,267.428647,94.562412,-22.23887,-158.764586,-79.132267,-13.023684,76.938057,115.936165,154.785802,122.336403,-12.588949,-109.534232,-101.985924,-8.075352,29.33243,18.6754,-27.18786,-126.118359,-158.037797,-204.84207,-190.186529,-150.338982,-29.009017,32.580963,57.110876,6.870982,-140.880872,-267.81617,-272.791816,-109.235427,8.090542,152.105056,140.190464,-26.973973,-118.811492,-198.737943,-146.585593,-92.995623,46.899754,121.823186,188.334791,143.664827,-77.365181,-255.036603,-252.828209,-112.809917,-15.955526,165.528123,196.660655,66.189524,-50.454645,-198.568553,-104.960393,-9.523794,120.101078,136.737198,90.506918,41.756781,-91.003355,-191.393744,-148.452118,119.070599,232.128632,259.575234,204.618353,29.247478,-75.185726,-258.4505,-238.013022,-121.409629,110.843218,149.263154,66.285392,-26.440051,-195.5428,-227.184635,-181.734501,3.288572,104.786079,180.087468,126.023869,-64.894183,-139.310117,-219.662081,-215.670258,-157.843185,21.301743,97.372339,130.962425,80.775273,-106.919358,-252.847488,-239.383849,-104.825607,-30.669917,127.270513,175.227081,91.394157,-7.272693,-172.295422,-158.805842,-52.546589,213.689583,284.321264,228.287901,143.645435,18.542612,33.038119,86.598501,234.97227,305.309887,398.085011,396.563869,265.021124,151.37769,-64.030058,-87.149552,-33.534603,88.810101,145.769177,200.408117,170.979464,49.91293,-15.19182,8.661157,136.791992,205.218774,323.52288,341.768093,229.05021,139.845485,-8.09158,-26.888012,39.082386,212.531725,256.468288,200.399626,126.182063,-31.180212,-147.596627,-144.381964,4.163302,96.901303,207.93357,215.240907,155.995025,94.929798,-76.262481,-140.614412,-78.466892,130.303076,197.470816,148.906152,62.489685,-86.462052,-160.74231,-167.272755,-83.43242,-1.595567,147.061122,167.978824,98.583371,28.775264,-122.197042,-103.980286,-15.387631,153.925487,181.766054,122.263332,57.906711,-73.178058,-131.924221,-107.487264,34.507507,101.197384,101.903871,36.498761,-91.017676,-110.662916,-95.001368,-24.599055,29.799209,98.124566,89.581754,4.043179,-53.073404,-149.613476,-168.93617,-110.707612,112.451887,186.550772,181.039493,140.856193,-9.000351,-124.237041,-295.284895,-202.734707,-100.246016,36.986571,55.753985,0.904931,-58.969292,-165.76934,-265.862217,-307.061981,-274.820751,-219.314878,-139.520276,-125.08808,-185.109881,-264.719745,-405.356155,-386.41541,-323.638296,-163.538831,-102.197282,-108.887206,-181.529764,-367.828414,-451.575198,-410.340119,-213.803999,-116.018713,12.350125,32.994532,-29.413842,-105.377528,-291.135452,-355.767603,-301.291485,-95.67971,-6.782813,15.786942,-50.766556,-240.854852,-361.121041,-344.015945,-147.320135,-15.672715,129.867168,108.003715,-40.822147,-121.72448:-76.095378,-102.80662,-56.233477,26.986092,60.702445,108.503752,99.30663,65.355576,80.178983,89.49969,79.010328,50.209654,11.426657,38.951744,90.893542,61.332008,-32.849011,-62.427859,-71.318883,-102.788007,-104.106878,-69.649773,-59.930339,-70.225437,-84.105802,-67.688235,34.429361,78.520571,79.974544,53.036465,3.844503,-12.202103,-92.548689,-231.20211,-263.457843,-234.530005,-200.889437,-134.340552,-110.770143,-94.004017,-102.409278,-102.232553,-59.449346,-20.924451,6.492037,-27.174118,-102.06303,-117.307093,-161.203123,-188.906847,-161.107894,-58.95954,10.494688,127.079247,125.673671,81.424866,124.70909,140.064972,143.865899,175.244953,297.114154,326.596392,242.458566,169.345954,33.048359,-42.735568,-32.223192,14.973965,34.569568,103.729599,137.570004,103.344567,-71.56761,-133.36736,-66.561958,9.197904,68.408129,52.019793,13.448476,8.247535,25.377009,117.671966,179.741177,217.739298,190.922107,100.695875,30.049857,-117.839684,-169.885039,-157.845237,-62.688284,-1.625968,64.982712,81.820835,151.303803,178.421879,106.104872,-27.754029,-52.328,-17.134912,15.535989,33.003849,16.074593,-40.543504,-163.57194,-222.166116,-191.676732,-93.878163,119.628002,176.021776,183.490774,166.824213,97.854377,-25.914147,-73.282098,-88.424957,-63.809125,-32.437323,-48.025369,-110.997175,-149.332867,-133.539985,-59.528686,-31.552993,26.436978,67.880587,146.986973,170.031475,152.14742,93.679951,95.738024,142.357771,159.423629,173.016816,151.246616,61.765322,10.012884,-7.146526,-70.254749,-98.242679,-47.5848,23.116051,117.667809,119.98644,54.54445,-4.789309,38.178657,212.433791,265.908264,239.693149,205.436308,204.040542,227.757299,229.437788,256.89549,288.293453,338.389636,326.69225,200.214856,116.675531,7.411519,-20.919291,-42.193157,-92.494734,-65.055685,82.459665,119.153968,7.093102,-198.13175,-246.784763,-260.657738,-300.569836,-436.605893,-457.167797,-382.858601,-333.561546,-290.558435,-284.564334,-268.833945,-240.190753,-235.87473,-227.635323,-214.800126,-181.020629,-191.074709,-209.501636,-208.296841,-184.34042,-121.933829,-95.640512,-79.261345,-95.701295,-173.13436,-203.222697,-182.687231,-155.639468,-146.125482,-64.759309,-8.851546,51.516165,6.553278,-44.970835,-96.747307,-65.871382,33.638695,50.608179,42.390161,44.398616,34.429899,107.438906,185.062556,201.391677,121.596062,-0.741456,-6.060145,-6.123366,-47.240247,-30.840878,138.925773,247.650815,355.121321,341.155214,261.072205,192.579262,-47.210245,-194.586237,-157.532308,28.125753,109.730483,134.937562,65.660584,-105.206354,-127.441953,-65.215831,84.07694,101.385153,20.939268,-31.004368,-72.906447,-44.009365,14.806231,14.155415,62.722948,243.848553,297.890235,302.860195,304.270595,297.412524,152.293879,68.256456,67.026875,153.714187,352.361568,387.665029,283.021864,210.586216,128.799715,122.833787,156.624734,253.956992,287.565097,263.538928,201.410742,87.468796,100.50125,146.241088,292.842936,351.01597,288.060444,190.989557,52.454455,26.672461,-25.537782,-104.891189,-125.646703,-89.512413,-51.918975,-23.985147,-32.477079,-12.223728,32.290208,31.646086,26.851209,46.993978,106.19408,115.333655,108.104159,123.913097,164.40921,164.642226,166.521017,150.665855,124.650963,71.106433,39.273732,-41.5659,-78.861723,-86.935444,-116.892659,-138.984065,-145.962324,-108.582933,-23.62597,-28.408957,-141.823958,-178.316785,-119.189613,31.576152,81.293695,111.803409,81.218555,-100.293451,-273.831053,-257.700732,-102.282837,-51.96259,-29.112692,-31.293454,-54.414155,-73.196817,-118.857977,-150.582061,-163.663519,-176.837829,-147.991723,-25.372691,6.267075,-83.059374,-139.706848,-84.283185,60.226162,68.106421,-46.032076,-89.001835,-54.127357,5.715983,144.434773,225.804621,238.004503,205.36973,155.279044,58.547693,38.310947,13.171528,35.874504,92.296945,202.488004,207.092366,154.815865,133.595984,99.566069,76.470182,7.537619,-19.830912,28.742456,172.160414,204.358328,189.044157,190.520087,268.539451,276.767293,221.948814,84.811254,35.50186,27.266453,59.294948,94.695126,70.663615,-16.984153,-50.267869,-43.666275,-15.457637,33.771182,189.202259,218.156607,150.812979,81.481294,51.779977,-7.90808,-26.518101,21.040537,85.011936,150.657892,120.237295,4.492158,-32.128689,-2.764816,85.107255,140.491121,226.299633,203.005402,36.267463,-82.048187,-80.836967,21.104628,90.626089,156.534697,139.513566,67.502437,33.269544:54.590027,78.472107,134.242701,204.088291,210.934461,211.410847,212.379258,188.668163,118.502469,99.161994,110.290111,118.465061,129.72437,143.873532,172.737212,171.694256,140.384091,87.754096,51.274803,-26.595734,-50.972261,-88.216973,-115.371933,-137.969563,-82.242593,-37.889383,27.873773,37.904069,62.482644,62.787959,-24.065864,-69.860057,-105.744935,-157.489699,-169.379333,-62.925447,30.028536,128.287558,120.487273,71.850759,-33.759521,-84.62276,-68.015772,-25.374003,5.589338,-17.106539,-105.019229,-160.776357,-272.420623,-352.256989,-349.252573,-225.285065,-153.134369,-100.870241,-100.929683,-78.93873,-52.103984,-30.708147,39.693165,68.639009,85.656695,78.140027,74.617038,80.631291,3.668492,-145.996046,-184.201287,-191.812182,-163.584994,-62.245416,-11.499782,22.373993,-118.088592,-194.88892,-190.097396,-117.419841,33.84483,57.043623,0.195043,-25.735587,-5.420542,74.134173,121.975955,162.673676,142.19241,77.475436,47.214553,-6.051993,-29.687134,-39.569537,-30.640688,6.013622,75.373725,87.343218,119.393399,132.215799,62.088599,-54.06845,-76.018494,-56.374264,-41.301263,-92.82956,-153.284019,-228.380991,-227.100011,-208.200466,-165.006888,-144.470766,-15.894119,86.70215,193.597536,173.892235,64.401428,-23.64547,-8.855902,134.924138,222.48772,284.28965,223.515728,40.861437,-62.445305,-82.098727,-74.122381,-62.693469,-17.465985,37.614803,210.043243,298.983115,349.895516,232.808496,186.979136,167.054146,169.65223,119.025884,63.073387,-20.924795,-37.677485,-35.79207,-35.340386,-43.359194,-58.334676,-47.216,11.95774,20.048089,-64.644267,-74.846998,-17.543005,40.227184,19.131421,4.07162,42.558329,120.565541,65.242504,21.602375,21.032338,72.110167,210.123887,235.815281,124.700612,41.629325,-64.789582,-117.237207,-123.995878,-71.564668,-8.416554,114.496618,110.735635,-45.66521,-136.115062,-128.790608,-177.631738,-251.870417,-389.43569,-403.80381,-307.936701,-251.55898,-262.302077,-335.191669,-324.172372,-251.623557,-227.890477,-205.259162,-196.432427,-215.859289,-310.760987,-350.426544,-323.790414,-261.756745,-105.506569,-37.504093,-0.169215,-33.141154,-121.076487,-208.239828,-251.248595,-263.105744,-203.527767,-22.417778,38.409865,52.748191,-71.384002,-148.931306,-151.545064,-50.948077,188.689748,236.981068,170.142282,116.737109,116.815026,266.392341,282.818413,83.381519,-39.242002,-138.232202,-130.115645,-123.884641,-148.982427,-129.818114,-2.563258,71.598968,203.564328,252.686936,225.364404,146.636132,-40.138582,-100.590661,-55.306919,63.508476,99.146732,86.759393,35.944866,-63.304729,-123.772726,-133.803591,-51.484067,5.548305,4.215061,-54.428256,-127.064916,-76.774644,80.80939,90.440234,99.257944,187.387306,212.895235,221.442587,238.578633,248.551689,100.267423,27.20216,61.64175,136.748849,240.241559,242.973019,204.946728,184.36856,43.603757,-95.930426,-58.187938,98.070408,145.98298,173.037704,146.707099,30.215402,-24.044935,9.581905,166.088399,236.6775,207.524126,125.822886,24.637256,17.749561,-27.063746,-118.940174,-155.078905,-135.054059,-59.408123,105.474554,129.327597,70.77883,19.049338,24.088278,52.202441,46.262557,3.958499,-10.094389,18.18772,63.922626,122.968647,79.677976,75.131113,109.04409,103.571246,45.918557,19.828238,-36.125092,-164.190987,-238.947065,-314.880886,-306.543127,-214.566004,-144.539588,-50.965762,-53.402991,-129.01282,-186.803578,-167.127864,-45.169339,14.789633,35.675963,9.323418,-53.349387,-186.415301,-257.191558,-262.058368,-202.918593,-135.393183,-166.298903,-239.936687,-237.295868,-247.788505,-323.810023,-369.521914,-415.198205,-373.170493,-201.37571,-141.932013,-148.218262,-211.316913,-211.271885,-141.162121,-116.290238,-113.858227,-108.22347,-77.944199,-49.516168,34.70187,106.895914,132.959101,125.226878,94.248011,37.396024,14.230427,-21.057437,-32.191211,-11.357347,109.431255,157.43071,134.314428,102.11063,95.778804,88.004683,-50.865709,-138.017223,-83.220053,50.952767,68.870617,42.392408,38.30828,102.809051,73.163323,-5.078859,-114.935236,-136.737546,-146.46934,-103.531611,46.6777,91.367346,73.886167,6.362954,-19.733295,-40.866693,-21.419727,49.092199,69.575608,123.854348,148.110484,92.514974,-36.094271,-50.763481,24.18941,86.049255,150.449879,125.991684,0.794281,-40.305423,7.567433,120.056444,156.508484,200.341476,200.610988,188.917771,207.046203,207.524238,144.293185,105.629519,110.346357,144.107068,209.900716,225.053914:14.152328,-99.473637,-89.288815,37.375181,85.763592,41.788161,-8.647246,-4.12523,63.680457,93.774969,173.737004,181.400722,80.75563,35.533562,48.105981,63.506177,-10.433006,-102.281553,-86.60195,-22.312389,-3.207814,55.431282,77.677601,4.236918,-73.175063,-29.233449,113.534492,146.727226,187.204993,197.000776,109.858103,41.040263,-57.062613,-83.809015,-57.519979,13.236684,3.504161,-62.586657,-51.90476,17.037565,-1.686449,-9.999844,54.810733,96.174826,101.816963,63.120383,-23.729122,-44.532546,-83.181819,-95.308302,-58.198107,40.866371,70.911642,75.528557,71.666791,107.211583,60.467457,-1.491142,-11.060553,58.371328,213.882089,244.174684,145.120436,53.881704,-32.39469,-14.19553,-25.534237,-43.664817,-3.778537,136.593137,176.368676,121.560723,-63.668058,-125.753287,-84.639146,-2.080191,190.74774,226.230091,97.683181,14.577609,-41.678762,-0.732541,48.41631,168.138383,192.766812,78.149275,-32.893284,-177.524598,-195.352273,-192.10584,-156.84741,-133.482059,-85.836194,-51.916243,15.166253,24.130264,-24.219511,-37.564993,-14.052228,5.144969,-3.065179,-45.610738,-66.345479,-35.362495,-36.587299,-79.249512,-39.141761,68.287804,226.567754,231.836745,204.710174,189.64474,83.188864,-16.51446,10.86938,123.196432,143.97813,141.174963,128.799541,8.418893,-175.493444,-192.972303,-36.551049,40.50901,64.940618,51.945621,13.651638,-24.751876,-88.173732,-6.746212,67.886323,119.019967,83.279438,0.703129,-25.530279,-86.513008,-120.246957,-96.701185,-43.407196,-49.529925,-84.488603,-75.683695,-10.664716,-2.905531,-98.535032,-185.083323,-155.810178,27.678054,105.759368,77.354512,15.871498,6.73356,65.789727,65.560559,83.921859,111.229182,161.388665,174.698144,120.772139,51.032009,-83.513749,-65.214186,-11.283327,36.386862,46.33599,109.157289,122.144625,43.649341,-106.505133,-130.780341,-45.157648,-29.820385,-151.914034,-212.603609,-169.629475,-96.775469,-39.492282,-75.610197,-67.420221,-19.16983,-7.717472,-46.790749,-89.849023,-169.719111,-213.150004,-203.27381,-105.132461,-25.351807,108.068181,92.994965,-82.313227,-140.452993,-117.843861,-96.551838,-88.737083,-1.038829,64.579035,130.545694,108.330308,-9.498942,-109.067379,-117.362687,-65.323978,-21.627276,60.647865,79.734445,34.995774,-9.035111,-29.986705,58.162324,103.993531,112.773975,88.588447,102.576239,120.15309,38.169214,-91.449819,-87.665843,103.604889,230.896903,365.743753,353.899136,210.903395,106.859093,-70.14758,-92.283826,-48.882785,44.73886,83.292626,124.853714,91.488363,-18.897724,-49.398267,-52.560133,-46.4057,0.502927,136.721089,130.024721,-39.409277,-90.353497,-52.513779,0.534343,39.854768,168.246486,230.723546,301.324001,309.737998,245.906772,12.060219,-73.569868,-7.641621,73.379315,169.856807,201.504894,252.130054,236.084946,80.216163,-1.14835,38.517906,113.129168,116.23131,91.018814,76.264478,53.462508,13.392921,16.413913,127.844876,197.222751,259.706078,248.9235,183.469137,130.30275,-51.163234,-171.202269,-156.567178,-50.360809,6.099793,39.159165,20.099027,-3.285861,1.052784,-0.641437,-5.87393,17.116578,131.608334,165.160297,127.580476,111.845451,148.25565,186.009487,170.903443,109.339268,110.065604,143.517341,114.708486,-13.88692,-96.117311,-117.271854,-82.761409,-14.175701,129.397681,135.573562,-8.438302,-98.055468,-166.787863,-61.220417,-5.060709,38.585917,47.437138,15.334774,-29.269535,-105.747229,-161.295393,-169.942715,-126.459272,-97.043945,-46.412419,-31.193532,-36.339018,-40.356018,-38.130786,-23.569615,-16.368384,-4.653254,10.502718,-5.09162,-53.176156,-149.324437,-153.893219,-93.500316,52.49456,68.040178,-22.272487,-85.658955,-147.884229,-123.799483,-35.299886,2.554496,11.136632,-1.570806,-26.264608,-53.603272,-53.695263,-32.942285,52.493017,95.268485,96.085304,59.281753,38.254403,67.932711,56.596913,-6.401738,-113.248567,-92.260636,-33.678812,97.766403,134.162162,127.214938,100.443792,42.515254,-61.107658,-125.643554,-174.938082,-151.01195,-77.584578,-52.680583,-74.091325,-125.177463,-238.594337,-209.822364,-150.734059,-59.426469,-21.399627,28.588244,3.73748,-147.688393,-246.717776,-227.645692,-110.426039,-56.697007,11.775837,38.361094,18.797669,-40.910336,-164.738217,-175.781828,-148.032843,-83.598923,-38.207879,34.617205,6.482652,-186.948006,-318.581626,-293.064146,-148.669264,-79.732414,61.958165,109.857192,11.498982,-98.444126:left
-91.800213,-150.565343,-106.706003,22.897384,67.779439,99.963419,86.486878,48.972935,33.14545,15.483905,0.307025,6.892452,4.438943,4.800462,-2.744876,-33.463179,-124.770554,-159.65876,-131.245755,-41.849533,-11.169468,50.21736,81.486677,86.39167,-53.481166,-137.061307,-100.782416,-2.872732,98.058742,98.463846,110.634208,126.853755,160.36661,83.69712,-1.566179,-127.4065,-128.453322,-70.509598,-84.341666,-210.800437,-270.872443,-272.32617,-250.084839,-224.80987,-204.741731,-232.064568,-345.737772,-397.060099,-424.200643,-372.993441,-317.689502,-192.021718,-135.389106,-24.310738,-9.826325,-137.246869,-306.811003,-319.25043,-193.833405,-137.540594,-151.509233,-199.297784,-315.394035,-344.784775,-326.000988,-342.316583,-324.274184,-162.124229,-73.211189,28.471789,40.387242,23.744164,83.111748,152.294228,292.658109,330.257548,313.445046,302.366709,327.915202,317.353213,174.461417,-1.013732,-48.955013,-86.751135,-76.923883,21.046445,61.574851,0.169303,-181.338027,-236.766966,-204.502842,-157.7504,-97.987176,-74.361032,-47.711091,-76.543915,-208.559102,-255.051297,-216.732484,-128.672185,-103.812017,-58.643858,-33.882067,-19.825028,-114.071654,-179.104084,-215.949133,-186.919767,-108.464209,-71.342592,-51.428333,-74.281727,-127.410917,-130.934823,-114.533905,-129.637269,-159.223166,-148.300823,-100.998175,23.264008,107.012646,105.504098,90.063426,94.596217,105.453693,114.505424,137.176402,145.453158,144.00131,102.970296,88.158819,113.996602,144.063317,154.152558,140.14321,169.430485,212.971388,226.603649,269.371562,284.130429,263.013978,228.438803,162.207917,158.340297,163.622164,94.394294,75.76709,92.688041,105.700038,152.001515,166.366889,153.862413,190.282973,230.737279,252.900125,227.18101,198.2563,204.73475,170.344808,134.506615,133.710834,174.115376,162.618067,81.579895,51.971847,85.613982,113.934894,96.904958,-5.98083,-48.632489,-60.397094,-46.941341,-39.357905,-66.871899,-200.928794,-275.152095,-359.572462,-397.432114,-412.178037,-420.482483,-393.354338,-275.581097,-224.555558,-156.226678,-83.885898,-40.519699,44.633418,67.422686,92.375533,113.955337,136.885835,125.985617,83.232673,14.279439,4.058017,87.816365,135.806526,120.893289,75.552159,21.912225,-8.806404,-36.209199,-79.048616,-94.269135,-104.923313,-87.518035,-11.419975,25.968126,25.539761,-58.7778,-83.889583,-96.694078,-104.782362,-102.877227,-90.121385,-40.532704,17.671849,31.916499,64.027496,76.847353,55.545739,29.115396,-61.406292,-109.349737,-133.641713,-114.937655,-105.861687,-81.43091,-65.710555,-38.464439,-42.175645,-113.135087,-266.198972,-348.816095,-409.110925,-355.421647,-119.859768,4.441808,91.717065,33.212596,-144.006091,-219.530875,-208.86362,-128.127,-88.294374,-72.042941,-100.012861,-183.565975,-236.49173,-264.196413,-334.186611,-360.566635,-344.38373,-285.292866,-131.757332,-80.060295,-76.845783,-183.472744,-193.619056,-31.709723,67.256401,132.133436,111.484963,60.917791,25.069611,6.016597,-8.741269,19.821778,137.376723,165.658755,68.116362,-6.262423,-101.789967,-130.175741,-92.183824,43.805519,89.706801,130.668026,135.707966,90.254845,-26.711051,-100.364336,-139.908747,-72.480711,114.274293,182.110529,258.495653,278.846292,226.178873,66.877263,31.549143,70.580118,120.086635,237.804236,250.309627,155.014316,57.529044,28.23007,21.564386,31.932658,44.064686,57.031191,106.378908,137.303854,155.331477,90.578029,73.013982,76.39412,98.711175,203.575931,244.499608,237.246322,193.151219,176.842256,170.696982,178.361717,177.085441,168.322304,121.404794,69.744609,-79.097763,-179.039781,-174.138278,-128.106881,-126.835294,-135.888078,-125.998619,-93.929286,-89.075206,-96.707014,-57.383426,-7.183273,98.692684,137.663828,157.315245,143.691866,57.187691,-108.752995,-171.698982,-194.216527,-165.197505,-108.475133,-108.138534,-141.159914,-217.844923,-273.827581,-287.245268,-224.426092,-54.379716,-3.913566,-55.639933,-119.588853,-207.796556,-220.933463,-191.917293,-111.896792,-67.016645,17.161784,-8.528685,-181.052318,-223.075821,-194.773698,-162.161917,-145.847724,-49.751244,2.690945,22.758578,9.099016,-16.379899,-110.192609,-151.086053,-93.453414,-20.846503,43.663614,21.980268,-54.041215,-154.705611,-197.542501,-139.539045,-43.291802,85.450447,85.091494,61.519167,68.882527,62.479917,-23.230602,-51.464969,-46.6798,-29.576807,20.419547,34.216644,-10.737535,-110.98614,-136.722109,-91.598119,-43.890465,67.777972,126.149923,157.344429,96.417602:-175.332998,-140.739459,-117.038015,-104.030664,-100.094637,-97.657352,-121.139021,-118.238543,-6.269079,16.933497,-4.42107,-8.391361,-6.992263,-22.867268,-103.580283,-147.007205,-154.184502,-76.188018,-45.441757,-19.526409,-10.05761,-5.37922,-21.744921,-82.704332,-176.66909,-214.097584,-137.360078,-22.238345,169.851722,186.143502,122.058905,102.332201,91.02743,27.229565,1.293556,2.832317,5.497571,-11.445311,-15.988198,7.81318,-1.091988,-60.250699,-217.186565,-244.560046,-170.595959,-132.675321,-182.146178,-257.418399,-395.519301,-367.904507,-283.198633,-111.026303,-67.112541,-59.65484,-70.006638,-79.902779,-119.732808,-130.674836,-72.686267,-25.960543,29.510346,29.371125,-31.386389,-86.74324,-189.072052,-148.834455,-59.823157,94.596919,103.210503,40.910102,8.371784,-21.973622,23.594287,79.109701,226.897385,262.421901,170.609,109.922652,102.111467,123.250285,107.212084,-1.295864,-59.083896,-87.828601,-60.424563,6.55298,13.44858,-50.497917,-135.408091,-157.853812,-105.563277,-29.716872,97.136156,106.733168,29.343156,-32.958662,-139.471565,-199.004616,-200.506884,-78.253903,32.779738,194.185708,202.218119,134.239556,112.100897,143.944344,188.448978,155.012546,43.825024,2.489121,-65.333557,-88.414032,-109.932778,-103.104893,-82.377475,-39.742032,-20.511481,12.060316,12.640312,35.432503,165.613177,252.15738,341.783616,306.365572,195.731688,177.089126,130.817922,87.884866,54.734798,70.284274,59.422626,35.272377,56.122941,140.590329,177.773395,244.334314,242.503993,219.285739,248.047726,284.805669,271.959358,222.92039,126.575139,87.806353,17.615107,12.9319,44.442406,83.60546,82.45232,125.826324,159.964369,167.31366,147.935616,157.699004,193.866973,204.784661,219.654518,215.770866,132.850797,62.80939,-20.353235,54.713725,101.068834,79.447791,33.615055,-19.125529,-24.907499,-36.054881,-60.561459,-73.354113,-90.153315,-95.004119,-88.218914,-91.337333,-206.155558,-294.204279,-372.489465,-332.7355,-303.562954,-235.31843,-189.529022,-95.843088,-71.459702,-71.007671,-26.178565,30.802871,159.751034,209.835642,241.40239,217.153737,130.59623,95.513736,59.297525,9.748325,-18.239718,-22.45423,8.935655,47.495494,7.929295,-133.948474,-226.217834,-232.992453,-132.536779,-64.303303,-38.578346,-61.491307,-55.807713,-24.895901,18.952455,-23.560354,-60.591982,-85.224691,-62.337426,-38.962229,-70.099531,-143.575867,-147.364195,-118.134007,-20.690256,9.395523,4.247584,-6.943619,-76.52123,-154.21683,-302.70621,-294.013642,-231.013468,-81.927142,-41.678178,-55.300555,-74.031461,-88.001652,-145.460672,-216.321091,-381.882591,-393.394921,-205.754973,-98.170972,-42.751903,-72.675241,-181.950325,-279.225164,-272.449016,-182.411855,-132.00242,-92.312773,-124.240976,-223.258863,-293.236218,-307.367928,-279.621761,-270.413302,-258.940777,-214.89433,-113.537255,-115.775171,-172.866391,-184.872888,-177.825142,-141.535588,-91.144697,45.109942,70.845101,9.774658,-71.889973,-74.589412,23.173615,90.391187,183.885498,193.921711,123.877938,67.529368,-8.986504,5.542122,27.234414,74.983416,115.419348,193.177872,203.387758,155.426002,48.415557,-2.43658,-38.817815,-9.054189,119.617322,169.374959,202.493854,213.21684,182.7741,104.852179,119.135662,217.438168,255.200332,284.35801,256.406182,100.320919,-23.630575,-21.765711,-1.662299,-30.864715,-65.448414,-39.500409,-38.834366,-93.620913,-192.601014,-150.785941,-83.240276,43.481031,87.119611,166.888205,192.929769,153.083251,-1.516152,-50.897205,5.438578,64.503092,147.546276,180.597933,215.398192,194.569334,72.669633,9.297616,23.93624,5.949128,-35.069327,-83.822079,-70.386274,32.540004,75.893022,58.529664,100.807849,157.146996,210.896531,207.921204,167.835738,112.293943,-30.734988,-90.63973,-98.896289,-84.005583,-44.797894,6.478465,-22.027237,-128.204909,-195.484225,-200.393793,-151.900699,-121.838826,-54.669714,1.464097,78.348984,44.690537,-141.592196,-251.993976,-232.674906,-138.563716,-97.089004,-73.526967,-114.549259,-223.823273,-197.868047,-151.385962,-91.847436,-77.957816,-27.02933,2.415519,4.08124,-28.139676,-145.383205,-241.156478,-229.666835,-127.124063,-70.248743,15.201375,29.717895,-17.488695,-164.112853,-224.910573,-167.46197,-70.00781,85.414463,118.900486,85.414937,27.298255,-64.01608,-74.915935,-74.929663,-100.278782,-101.736489,-23.526843,42.655745,151.587683,147.913481,117.869582,80.160255,61.733557,26.689892,40.90189,77.044279,33.64939:-163.425998,-219.904352,-236.933579,-238.790932,-213.026702,-151.207232,-142.959809,-112.781963,-47.124963,-23.946853,4.813545,2.074302,-28.883747,-41.212193,-40.419856,-34.802568,-64.267074,-87.349963,-53.686686,0.584006,-19.149155,-73.489498,-83.731537,-125.022082,-197.143856,-213.570589,-160.839794,-94.266841,84.032521,162.1596,187.488908,145.730963,47.180032,-6.278757,-0.7762,42.624685,68.298641,107.547376,108.96055,57.846452,-58.127147,-98.883502,-93.789979,-95.452753,-152.562122,-152.950424,-80.441171,-75.021567,-174.064268,-223.162224,-172.889237,-15.364699,23.063086,-16.277226,-49.201777,-73.505424,-68.612882,-55.729522,11.578472,67.441744,182.609021,198.205576,87.678834,8.305427,-83.623917,-78.801877,-30.768446,109.505378,161.340116,146.764008,87.549366,41.225473,163.894928,229.88684,310.539333,324.936138,318.698188,301.969722,201.723006,117.699639,-32.53598,-87.571071,-87.537146,-45.993582,-11.12873,3.275763,-32.636122,-73.170069,-17.419059,4.829514,41.510601,63.202736,69.554243,55.16037,9.545119,-15.84549,-51.842099,-69.987597,-65.846308,-11.66058,42.287742,140.343908,158.564901,191.765535,247.873276,262.790882,246.525226,211.596564,116.974591,67.87621,-13.692029,-31.044329,-25.710208,-8.229799,-5.551335,-9.11898,10.607774,90.355604,108.294312,57.411131,-4.488445,25.236097,166.219505,213.808399,250.157343,238.61333,126.084517,53.248055,-38.435999,-8.338861,32.861121,24.247761,-22.263578,-22.547804,31.531079,104.643768,81.738918,73.942585,112.496442,133.385623,139.696395,132.920457,59.919469,-17.71845,-155.414416,-124.339222,-63.386611,40.717669,71.507299,92.941842,80.229279,37.412184,73.273453,128.906119,183.022529,147.497579,53.65109,35.516908,4.756106,-28.691036,-82.408167,-66.868604,-47.613523,-58.799983,-82.565008,-81.435164,-62.646361,-87.087455,-216.582439,-273.79958,-284.827243,-249.227884,-197.547534,-215.34161,-323.479802,-367.190855,-353.968166,-295.844006,-271.19014,-194.115562,-154.059611,-126.540476,-120.703386,-69.898461,-21.908821,11.569393,110.874294,133.117147,100.961935,81.443956,83.582413,79.445902,-50.285507,-205.282987,-199.891472,-119.819395,-118.366991,-186.488719,-209.06729,-197.679948,-165.537661,-144.444911,-129.687901,-140.843423,-139.512887,-135.757503,-164.508406,-178.356404,-171.040306,-125.074571,-91.13435,-15.422164,-0.959656,-90.266528,-158.485406,-184.957216,-135.083925,-128.104925,-101.51106,-83.742205,-76.217791,-83.564808,-145.237006,-197.858826,-292.260937,-327.488363,-301.814534,-162.220309,-87.469733,-58.634641,-101.536417,-173.239053,-159.765915,-143.147645,-165.787085,-199.312329,-207.366361,-173.201396,-111.952747,-106.47258,-146.207134,-202.624282,-204.708751,-131.887183,-80.980224,-72.189211,-124.018505,-210.550632,-243.669485,-243.422518,-185.314436,-161.963763,-171.491934,-182.001651,-187.561465,-193.696589,-224.553749,-195.47156,-146.917454,-61.42255,-34.059099,9.373688,23.638591,25.88845,4.440824,17.293504,129.416119,188.146938,197.972722,155.515275,62.895647,19.718825,-87.560914,-119.466994,-60.855567,124.504232,185.435789,172.646551,125.254278,40.607783,-9.477292,7.690163,107.092606,139.685775,152.578755,147.005875,114.360257,93.383688,52.723027,87.821333,152.562187,248.239767,264.939867,322.736372,327.37174,179.100054,6.300472,2.930529,81.419192,69.667282,-38.461114,-63.153925,-84.40983,-124.962816,-165.358,-42.440134,15.138157,35.369341,43.449962,116.53393,131.754545,79.899928,67.373786,78.702724,103.125062,121.178177,170.789204,181.610673,145.482891,120.7601,57.308834,-2.9207,14.545769,59.341691,28.394295,-72.872704,-66.048046,74.53023,93.334645,34.679153,-6.704106,25.634544,91.506196,116.336588,144.138332,128.593753,50.630348,-3.570773,-22.500805,-61.984284,-58.91057,-27.027296,-34.798669,-85.568506,-109.695229,-95.143062,30.649106,120.819948,217.544252,196.871256,105.742358,65.444394,-42.17328,-112.382754,-94.36694,3.746923,39.430058,25.243213,-7.125975,-56.92516,-69.904494,-55.658853,-8.522174,-4.347016,-7.371384,7.228557,16.89419,-8.696074,-83.595894,-121.23167,-111.384317,-43.914474,-15.221688,-11.124143,6.826894,92.56498,60.841206,21.860523,42.832023,93.588258,193.859944,209.134895,125.914188,64.238392,-4.780923,-19.610712,-25.721725,-29.003902,-13.897122,31.289746,49.403008,100.427106,151.815156,166.145704,157.915459,130.591434,94.780538,97.681401,74.682346,23.237199:-94.374594,-153.080817,-152.04939,-112.719076,-83.55627,-65.181416,-76.031602,-34.840485,32.036766,35.318473,45.429289,57.718142,40.031145,5.557455,-68.876563,-78.035021,-36.438788,-39.455849,-58.123477,-85.006829,-80.738385,-4.346104,26.443358,-33.193128,-137.085124,-157.354933,-95.691402,-25.704875,127.310288,197.425943,240.431106,203.903596,124.150789,73.441842,61.377455,78.983597,108.145957,196.794107,206.94919,68.690147,-112.788797,-160.000731,-170.54439,-162.02737,-161.534345,-156.013446,-158.152171,-196.567469,-326.624817,-343.237896,-267.459751,-83.820153,-26.508805,47.132277,55.438544,-55.016399,-227.382771,-237.285311,-51.032975,44.507703,31.161294,-35.374565,-123.080189,-145.253693,-192.19455,-169.362121,-118.304527,-15.524293,29.492918,119.567659,128.100974,59.615166,108.702055,203.429448,377.178363,403.739991,356.984662,324.23753,255.927211,201.216959,65.581278,-85.073179,-144.7452,-144.210133,-90.074215,28.460109,52.153724,-5.31261,-113.247813,-147.003636,-148.564823,-119.497893,-47.871372,-33.788502,-64.993108,-96.695187,-187.332631,-264.250832,-267.090832,-214.841184,-174.49127,-69.129062,1.332231,119.402422,64.539338,0.241778,-70.438955,-76.878235,-29.001319,10.00396,-19.482682,-78.217541,-157.717805,-182.80445,-173.135491,-117.827607,-92.908161,-71.621653,-71.304331,-68.105942,-33.139764,0.289437,100.03756,141.805432,180.721348,187.164005,146.474422,106.78142,43.593416,-24.214807,-49.083635,-44.110681,-22.711293,10.345555,17.93493,70.72339,136.979251,150.64706,182.969846,199.789965,215.207527,212.14033,134.466786,61.492616,-56.389735,-80.55573,-63.143966,22.158669,84.530299,182.172116,180.072876,133.540229,146.623943,157.410836,182.476586,193.602275,163.710547,129.681693,72.956927,59.046708,72.735972,100.393466,91.309532,-0.355288,-50.653142,-45.355897,0.770439,41.465426,-57.527155,-116.99914,-189.479135,-221.987477,-292.561724,-307.00662,-333.133256,-373.586447,-453.727395,-472.025389,-444.830391,-320.274039,-258.754994,-186.703551,-171.567059,-152.849253,-138.021187,-136.631877,-108.527464,-67.499922,52.831604,95.935924,83.114634,40.256903,-87.2037,-169.303463,-135.433254,-18.32207,0.213717,-32.052137,-49.688544,-86.922711,-176.382431,-198.200889,-139.390259,-114.584443,-140.457125,-141.574001,-56.909496,-19.69419,-106.270476,-271.318392,-266.62726,-105.802763,-41.687296,-64.244614,-115.147748,-172.141046,-159.200301,-138.870657,-77.669043,-63.169446,-50.932047,-23.07154,11.728881,-13.667485,-154.230219,-309.544771,-302.53926,-138.590274,-63.989538,-10.698911,-23.035281,-97.97443,-198.232205,-262.263627,-380.177202,-375.736135,-186.037987,-86.226677,-51.977287,-78.092153,-155.585916,-275.878409,-282.175596,-157.115017,-84.29116,-33.719289,-68.066036,-174.66864,-262.952648,-309.760669,-366.122343,-357.013512,-273.210749,-220.481445,-185.353978,-204.824004,-242.74941,-257.461869,-250.481342,-174.031772,-104.082173,45.658065,100.967123,152.636922,91.548548,33.589432,-13.698142,7.313207,85.566913,124.436017,123.4302,72.23374,-62.6434,-131.101628,-103.84333,29.689198,83.678825,120.747884,120.95039,101.806138,33.385699,16.044715,77.810878,136.916698,263.374121,317.525855,360.820788,338.475443,246.924691,192.050583,190.049996,224.721704,270.657164,365.706395,344.866375,154.94471,-29.528626,-79.874028,-81.766136,-42.604264,53.159527,75.772836,20.358457,-26.339268,-22.50442,105.28644,165.162235,182.631038,156.848929,163.062083,199.439493,231.638241,153.338033,104.799137,51.419199,48.136405,107.303022,155.610125,145.118877,65.028449,-148.227722,-242.12401,-200.433533,-75.65291,-62.236285,-108.371788,-122.16123,-111.902366,-149.538867,-162.803893,-73.412129,-2.058251,109.70413,142.163754,90.919972,31.926808,3.221077,18.241627,-12.324047,-62.823573,-32.012395,43.617449,28.829876,-62.16292,-137.28264,-145.995873,-57.235584,16.031887,100.802832,107.071563,103.904303,76.836621,-66.041681,-114.49126,-71.141776,-3.975797,-4.805842,-54.884398,-105.733151,-171.704178,-143.771437,-131.982058,-98.460425,-68.321959,-18.036893,-6.091929,-32.764776,-66.642372,-110.052908,-92.352458,-64.104135,-28.982215,-23.113432,26.503572,54.920644,38.320131,-101.621132,-174.326608,-182.181563,-124.76981,-15.11098,23.241119,79.790884,93.510859,83.72591,26.136092,1.775289,-24.445458,-34.112068,-28.213319,-6.136261,45.041803,47.653059,36.345989,24.232996,20.395673,51.419714,94.615465,122.12084,62.783007:-76.589929,-133.910604,-134.03983,-157.247522,-141.347539,-31.047825,19.729051,57.185192,0.046114,-18.288966,52.52233,104.444301,136.814182,117.877319,73.209103,65.70697,46.578817,7.964244,-2.468085,20.796843,69.005059,166.44106,159.526052,43.524688,-123.663979,-193.058886,-155.919245,-38.041876,232.977493,300.063648,242.621457,184.126264,126.522962,90.239707,92.762619,173.120455,233.467305,329.142603,337.538091,246.747815,58.554747,-9.754702,-51.995095,-56.034344,11.355039,71.909598,64.77111,-3.435488,-117.056704,-81.238504,-18.668262,104.735222,147.928601,140.879211,103.09894,43.429261,-34.999706,-68.601607,-34.933585,22.46081,128.06998,147.12566,102.969002,54.712096,-88.06815,-157.031756,-100.432423,72.059753,130.093121,173.300331,161.61416,114.406702,94.617649,96.961985,154.433917,219.750284,364.58493,387.120781,251.661465,128.691476,-96.998209,-203.342476,-185.288937,-58.684785,6.601621,67.666927,53.207675,-33.26558,-100.880271,-97.60745,-21.664411,17.663583,49.339346,57.449244,59.136257,30.153592,-84.415191,-136.943965,-124.304496,-79.015368,-27.664344,112.569714,142.535161,112.567038,56.317892,37.7271,50.50576,56.030536,42.930118,59.236745,121.001477,120.980186,22.302347,-88.061898,-102.573283,-66.771866,-24.56978,52.245992,54.197698,-7.542699,-71.923679,-64.577803,27.697907,91.26537,223.556041,248.113147,146.914447,64.073677,-67.040299,-106.440402,-83.283246,-26.311658,-14.94017,-40.290332,-77.973903,-134.995292,-112.640021,-96.959503,-75.260296,-48.100871,81.096455,133.641911,39.911053,-79.532153,-272.020617,-285.311168,-226.289751,-63.502775,6.807438,81.042824,74.89945,26.753634,19.083614,33.477038,79.687848,98.060132,99.960645,83.9744,20.340146,-32.219236,-155.150953,-182.846552,-147.461154,-63.981043,-33.273272,-11.053124,-28.074235,-112.832158,-201.069158,-203.353978,-146.912502,-131.938748,-135.465308,-147.235141,-224.850641,-274.738943,-346.384367,-339.076548,-288.91642,-182.650536,-159.615164,-112.802163,-60.840187,5.894501,-114.12058,-160.869712,-85.486143,-30.535285,2.34941,6.879894,36.939882,33.115377,-106.253238,-256.612978,-253.52506,-153.601537,-89.305105,-22.277974,-63.75072,-204.933687,-197.422116,-144.590366,-78.854656,-92.367924,-138.733756,-141.729559,-102.644092,-71.124663,-93.246612,-184.301634,-160.65388,-5.808002,52.68132,25.318932,-50.496359,-183.506326,-196.246379,-161.940479,-42.412042,5.919024,55.900011,74.321786,56.443316,0.134503,-179.401293,-265.125509,-229.741862,-88.066661,-0.860788,144.85438,152.833378,26.100015,-116.038651,-140.562218,-139.546584,-130.898501,-39.507612,19.46606,-9.725562,-90.491869,-235.731379,-252.129723,-191.863384,-15.6583,47.238489,35.185553,-37.393159,-189.10621,-284.071712,-318.22425,-331.492891,-298.656198,-152.288103,-81.202905,-77.145085,-142.403652,-318.902344,-356.071356,-274.388998,-41.271111,55.573691,126.470075,93.664534,24.585573,36.837052,49.042171,66.192958,68.755897,87.309898,108.680276,105.309942,44.658156,-174.71979,-252.90987,-180.971942,53.560863,148.076693,170.99956,107.32359,-16.72946,-34.537936,-12.019173,57.605454,102.662147,223.809723,263.576613,206.815238,140.795944,58.289383,134.946684,210.614797,273.964152,272.35225,287.556842,272.25948,116.724182,-89.675543,-130.492397,-65.484493,-9.554361,70.425877,74.778705,-12.162236,-77.921542,-147.01413,-44.14622,36.841911,140.54162,166.276751,163.096621,117.306313,-4.927297,-77.206238,-75.835707,-6.05091,29.838897,71.827955,88.922889,85.096347,37.421246,-117.715248,-150.8861,-94.869606,-26.629457,-45.98234,-84.80942,-89.008278,-82.592388,-120.689359,-153.800396,-102.037247,-11.382659,149.256473,176.113801,129.164512,88.932511,27.390329,-38.955574,-71.308016,-58.601429,5.663451,106.262962,79.093172,-63.263508,-188.273884,-185.197557,3.136627,111.753847,197.863346,182.801302,105.257378,57.945662,-45.629957,-106.306647,-91.24496,-10.754763,14.129322,-36.467582,-95.111795,-159.651147,-157.684455,-153.197511,-102.803791,-62.265251,12.230658,39.485792,23.779114,-23.569578,-119.364289,-146.158922,-127.102984,-29.890005,41.685615,160.359797,162.916787,55.334635,-86.286129,-129.483084,-106.361011,-45.540358,108.178394,149.722223,88.274816,21.79061,-61.184579,-52.217854,-37.05587,-40.052029,-52.562093,-10.079183,36.631997,39.036089,-69.558406,-89.497346,-20.296756,33.532442,112.561446,109.944112,-15.088223,-109.672595:-5.102212,-87.478872,-69.492268,26.66525,64.796301,97.559829,114.228718,174.871016,183.884645,143.914933,82.098681,79.963043,49.148017,37.650261,98.304104,132.099411,73.976933,-98.504606,-144.741438,-101.413962,-52.078658,6.036267,8.71964,26.396514,51.016572,35.443446,42.555849,103.725659,253.766156,282.415257,220.226593,181.389507,180.783264,190.150823,181.858557,129.647522,100.013821,110.548918,94.701556,-86.17735,-177.673623,-153.880112,-55.351288,3.324273,18.415617,-48.555841,-209.612112,-257.523945,-287.330189,-248.273171,-192.399024,-39.312935,35.415813,103.899945,69.081448,-69.815106,-142.444664,-132.118197,-28.421879,0.627011,-94.261516,-160.353196,-237.317672,-265.991379,-316.758601,-300.299337,-244.432026,-89.768376,-16.530215,114.172443,155.813381,181.087839,235.960415,278.850157,360.343942,398.389761,408.588272,373.531875,333.441629,339.292805,289.374822,107.705521,32.375608,28.501801,78.26786,161.784257,165.268714,85.940172,-49.303334,-97.363504,-94.283084,-70.641717,-64.896755,-66.27491,-42.809993,-45.789468,-104.336191,-175.112033,-205.405839,-181.836692,-127.301493,-70.781791,-92.336707,-172.341957,-190.852898,-172.011839,-143.544784,-137.272291,-63.326393,-5.326716,21.987566,-10.612888,-110.122562,-205.086086,-209.115087,-186.992684,-195.766643,-196.3845,-167.220965,-91.721699,-0.783121,64.478791,153.210747,137.011731,92.998286,119.100463,188.769352,194.680284,188.603993,165.11872,136.20122,102.469894,115.539226,155.771396,161.28086,199.486027,260.903342,258.644248,238.642798,246.008356,253.719125,233.79633,114.568839,31.399689,-42.825203,-4.585488,7.635543,55.814445,111.525269,198.829927,181.065207,109.515798,151.237849,168.655241,154.221609,163.710187,207.74152,192.400395,72.271195,25.572344,77.677301,142.2337,92.491644,-4.569245,25.680531,130.753265,139.38207,98.141012,34.232711,-10.810466,-97.574065,-127.286335,-132.871949,-99.757823,-42.331791,-69.701998,-239.458026,-382.371162,-401.518125,-376.853729,-333.122174,-194.50471,-154.423076,-134.27831,-27.92427,25.858347,4.717674,-49.377972,-75.538181,-18.03409,102.927323,112.74656,35.400112,-47.409427,-27.890709,96.255976,145.794814,184.679163,182.338676,157.654844,151.372958,147.679418,100.065748,72.58464,75.04759,107.444398,194.746597,206.071526,69.669082,-148.895638,-200.529884,-171.702081,-124.607847,-30.988627,-9.811022,-18.378997,-6.437196,24.983592,114.887264,137.247949,111.475296,102.470201,107.729686,86.96755,-21.402385,-116.242931,-98.871433,43.719866,84.576442,-15.22319,-93.732515,-114.960883,-103.743896,-153.632765,-219.053215,-183.03142,12.73519,135.814118,258.240164,212.55289,10.932796,-90.095172,-71.383011,12.077541,28.055018,-20.654747,-59.935787,-95.618361,-119.747678,-173.583082,-307.943319,-329.512065,-230.535486,-152.538916,-98.221533,-112.40808,-101.52961,-67.838344,-53.888202,0.475621,40.735762,119.331235,143.735743,138.856864,42.501997,-13.6861,-21.858487,35.045305,176.651462,212.485262,163.726911,98.369903,-92.190073,-269.173141,-265.905945,-113.382104,-52.97291,-24.051454,-26.327162,-35.79425,-40.519564,-47.886358,-51.656419,-21.585691,106.023638,182.810781,284.680963,273.113663,132.999543,56.572342,85.7369,159.150211,177.956107,207.400753,186.386329,18.403472,-99.068807,-95.037656,-16.877767,31.955002,60.197604,43.440205,59.975938,102.587136,160.482093,175.553452,208.453321,239.575241,218.76485,208.725874,216.724189,206.036925,144.117138,88.533289,20.926375,44.553998,129.764044,122.238835,-29.983148,-125.628466,-299.954944,-434.310145,-442.474958,-358.542506,-326.435175,-346.842501,-366.982464,-336.55227,-341.098326,-362.121375,-255.53964,-156.231217,-28.358027,15.714316,60.403933,26.978912,-115.815383,-237.621203,-267.618595,-245.171036,-181.249327,-28.467812,-5.896426,-77.158118,-219.936847,-288.040878,-271.042721,-190.28188,-39.576161,0.107193,-14.98644,-53.30991,-139.328747,-200.981448,-178.365425,-68.641334,-34.983463,-46.849271,-87.795866,-186.01469,-213.414883,-188.778801,-117.775185,-105.312759,-68.818368,-21.999906,26.972351,26.246893,40.202258,11.74745,-17.156446,-37.559732,-19.584876,16.796949,-2.93029,-101.397475,-162.401269,-185.537139,-250.103665,-260.421698,-183.638472,-127.983581,-27.633763,29.656385,89.706923,32.821407,-8.651191,-100.57581,-129.979523,-108.46119,-90.05512,-127.574951,-227.756176,-247.630319,-187.818123,-130.483449,13.632431,72.710631,40.516645,-34.330015:24.72669,-60.009574,-35.048488,42.675604,79.310102,166.376891,198.566471,225.312984,182.730812,134.63013,93.930554,112.583476,139.309487,144.331479,151.581763,124.725321,-11.184781,-80.153625,-59.477487,-13.910414,10.810332,77.047126,75.869828,-5.060637,-76.926508,-101.916335,-40.427977,59.232842,279.350403,355.257562,352.780709,275.973386,108.316655,77.250536,115.001389,247.028939,319.208343,376.747496,323.163591,106.573387,-55.046836,-65.833365,38.119283,101.471899,146.322537,128.872494,42.593549,-16.662942,-120.656534,-116.034742,-56.270361,145.095325,252.13474,326.482598,254.197059,10.234595,-127.727456,-130.847955,-21.296104,51.539961,110.863969,94.187459,-9.647521,-85.769631,-217.47487,-225.234025,-177.323638,-42.570206,25.194511,134.784634,152.934013,98.213275,57.51517,91.910664,227.975363,289.631164,351.294356,342.695302,263.334828,199.293808,29.067574,-50.466297,-31.639638,51.362666,100.203807,147.770409,114.589349,-10.188851,-60.862091,-55.246031,-1.358592,50.484894,123.618465,103.286871,11.377484,-8.846504,-51.056496,-157.581523,-179.972628,-90.711717,6.187826,132.432438,109.955905,-10.378735,-87.938601,-100.507182,-60.988933,-13.755891,84.989459,117.724638,129.845715,102.315691,-17.393622,-131.386474,-133.451056,-25.412519,47.732396,134.462362,110.779557,-44.490943,-104.624893,-54.363139,93.466351,134.207601,158.801648,168.052391,157.244197,123.755718,-8.431775,-98.381192,-78.292854,-6.719284,6.773554,-0.934044,-7.891559,-26.83114,-94.731076,-107.878242,-0.299859,88.989814,195.086246,183.529096,57.637325,-38.190132,-235.817072,-288.451737,-229.761867,-65.18622,-15.938599,9.464903,11.647245,35.956076,66.870368,87.209162,140.682341,158.221546,172.891849,162.484445,41.008227,-46.727622,-135.341149,-91.125261,-60.777841,-17.36285,9.66337,77.019239,92.832644,42.867558,-78.630174,-133.857679,-166.250462,-134.128013,-28.790333,2.358686,-53.316765,-134.438265,-328.925956,-414.838197,-369.889303,-199.50514,-136.411711,-96.692027,-110.177911,-166.777447,-227.81672,-230.607336,-125.773618,-57.992016,7.96382,24.66175,43.55231,16.647511,-132.142506,-178.540254,-110.743837,30.223021,77.55872,144.962054,133.015389,54.58602,40.689291,42.435246,25.358146,14.82804,8.082515,17.416921,83.612945,130.435517,86.531247,-149.637774,-201.049721,-53.206909,57.413776,107.435373,42.472793,-80.880782,-102.075263,-89.374964,24.53044,108.271349,208.989177,215.655093,179.225007,141.084619,19.160606,-96.386284,-106.308226,-19.555995,45.395485,121.077225,109.049128,24.922902,-47.349211,-92.713859,-165.226813,-117.035589,144.771164,230.770364,136.181213,25.806511,-124.648014,-165.223974,-147.530726,-38.999841,34.237014,121.37286,83.297877,-132.423354,-309.99101,-352.105221,-331.675114,-272.745325,-146.403829,-120.754414,-184.802655,-245.253499,-332.39908,-294.663407,-215.454945,-16.968491,65.695244,154.114744,156.015071,88.069855,-49.703548,-106.711467,-74.356496,0.734717,117.143997,130.142416,50.954816,-33.534579,-220.771228,-313.160467,-278.900244,-103.996452,-31.944295,-7.738861,-43.470932,-109.305125,-99.768174,-70.823087,40.50511,126.276589,303.377063,337.991263,251.229399,170.42466,30.810788,35.633803,100.009506,186.70446,194.229917,227.02717,220.30128,51.31425,-180.898814,-244.000293,-233.96791,-182.240532,-19.329821,49.335355,-3.552534,-99.391646,-182.506535,-3.489508,101.339484,145.464172,114.358673,93.893478,111.114337,94.949009,-57.444651,-107.057465,-12.08123,59.507622,64.872111,22.509735,-82.397823,-156.824101,-310.594422,-295.156349,-233.42117,-173.009149,-191.319002,-258.777959,-295.689745,-361.972411,-382.797424,-351.268152,-181.826794,-77.522975,116.41497,196.014581,197.511066,100.696621,-153.628765,-235.828243,-175.691515,5.299102,76.074318,129.441201,90.854287,-55.262136,-146.881254,-163.982016,-116.893601,-39.934967,175.839443,249.785236,226.201237,169.336601,51.60844,-47.788563,-41.316605,56.840026,89.536794,55.61497,-5.714665,-152.130612,-255.022906,-275.215617,-219.161656,-152.830192,-3.724926,52.27768,42.882229,-6.217911,-78.262681,-100.673289,-94.156616,-35.871242,14.078603,76.928433,48.461673,-104.724155,-302.632051,-359.542589,-273.877733,-179.005933,-73.489545,-69.951544,-87.523256,-94.824035,-121.553263,-156.339341,-154.340562,-119.743897,-102.702214,-91.544091,-102.140774,-165.168037,-284.396772,-316.249058,-222.2861,-137.758908,-25.418506,-6.281821,-54.703441,-115.617398:35.276958,-69.185945,-54.083261,115.916511,219.603776,350.439117,366.482523,317.048405,209.828234,156.754033,102.677326,106.208373,154.823044,192.652575,244.054435,236.141401,139.900494,-8.525889,-58.714991,-55.936969,-22.894801,14.836276,20.224968,62.285353,31.688584,-31.410863,-61.276319,10.847118,205.270178,265.466429,272.264878,248.588363,221.397127,195.897704,167.255347,110.311104,119.124176,139.22787,79.641198,-93.827125,-43.900711,48.451086,206.646221,253.961826,269.645634,230.232662,70.548984,-4.630796,-10.213707,114.891706,170.787989,227.912805,243.432904,285.598654,284.181257,165.158908,-22.966334,-105.285363,-166.453676,-136.196737,-73.983178,-85.644827,-183.871219,-228.701818,-216.78265,-159.055779,-148.276405,-109.143802,-72.724644,-6.542898,19.588506,89.18766,148.133031,151.484013,159.153218,161.418445,111.058804,103.87218,202.631164,243.78427,161.029259,19.021629,7.797813,26.41838,24.790661,32.752041,29.70821,-8.761707,-55.419507,-101.164234,-190.792955,-187.248874,-82.017756,-20.44295,63.852852,95.476012,151.03804,107.849072,52.009763,5.749884,26.105971,37.360081,0.651353,-96.780518,-131.292971,-127.133225,-139.772415,-152.668363,-82.202859,5.198045,119.359299,113.322583,36.540228,-33.733628,-41.014497,-41.214447,-53.684437,-61.61793,-41.99377,-17.261559,-81.111867,-111.62805,-83.672603,-43.787649,16.731903,33.561838,30.705103,31.899166,91.018048,115.321851,124.345416,201.238599,218.718032,133.05209,80.95134,90.849876,159.31529,144.757686,48.340525,14.468661,-1.748214,-5.839703,-50.774188,-70.102575,-46.038375,34.232469,84.838827,88.955865,15.839188,-111.407964,-118.250507,-80.195377,-29.386453,3.186771,110.743267,167.357444,179.612984,117.644888,-67.950544,-115.58111,-6.648009,139.45064,133.229536,41.517117,30.639033,128.186621,181.687272,191.681377,169.615935,191.138132,250.549969,244.650442,149.931123,100.442642,28.208468,-20.431795,-161.203876,-233.736291,-216.483946,-192.301147,-203.135036,-199.653269,-195.287948,-155.501613,6.068794,64.536626,31.047776,-16.020715,-21.729516,32.606956,144.282858,167.514644,162.405296,136.385081,135.429036,117.314705,101.768575,138.850076,185.937624,251.739335,244.100409,218.641513,171.008873,169.184336,178.485229,167.690657,130.174512,123.271484,82.082599,-88.486614,-173.004945,-204.350289,-163.806594,-69.132827,-35.794988,6.948034,41.7014,51.183192,74.622874,85.934366,82.593775,96.212846,163.543669,173.414338,104.572072,-20.255311,-59.651298,-22.121572,32.388835,106.307049,108.039231,86.444775,70.005544,37.202953,-41.601395,-42.005351,100.677908,223.210704,364.126122,328.228063,148.112835,32.191548,28.117067,88.333983,110.126853,89.443432,78.995544,86.894885,33.844674,-26.266388,-135.201313,-151.051853,-95.849021,-52.742967,-15.325024,1.555294,71.889258,81.680011,69.411712,117.96069,184.745487,271.817554,244.271316,134.317741,71.761747,41.73944,11.753542,23.916411,53.893335,56.291318,23.603686,-15.732292,-126.756172,-210.019719,-191.873216,-77.998489,-42.262059,-27.717716,-34.277315,-76.088101,-127.621757,-140.362469,-121.1971,-112.594691,-94.695331,-51.848239,65.473479,104.02052,101.459491,50.756944,52.356812,106.694485,142.361982,202.052922,177.206665,-17.892224,-129.839879,-97.614691,28.692458,74.664532,149.211056,193.779857,238.225605,239.879251,257.303614,239.248597,215.610711,178.357297,174.480257,198.788227,184.958963,89.975222,20.000971,-29.988967,-119.092327,-110.522667,-12.357112,28.331995,-8.240783,-97.245556,-336.095557,-450.694423,-444.865453,-422.103494,-415.268005,-372.043197,-348.994045,-347.587287,-367.058421,-357.130027,-260.891312,-187.524634,-30.0395,45.721648,63.954469,-3.805633,-87.373853,-104.459829,-148.994417,-186.745255,-126.10063,35.209431,55.058511,-5.768562,-71.741822,-117.838038,-202.319285,-208.29771,-128.041186,-60.710275,24.945431,21.970108,-26.032307,-43.587822,-12.433988,106.034662,161.322479,212.835615,197.540482,107.256291,25.055369,19.428091,97.811569,147.918935,208.16932,221.647405,221.6679,223.043511,221.116308,148.209451,122.289888,171.209535,218.648798,242.665766,200.202942,75.760516,-13.139418,-27.308439,10.331705,29.917012,3.743891,-33.718937,-70.67959,-59.923509,-54.469992,-43.854729,-7.304996,15.412769,-36.878674,-176.381048,-226.173211,-259.101807,-210.660582,-190.55651,-131.354873,-63.126774,82.588179,110.977021,60.690604,6.329085:-6.516167,-11.571636,38.831301,121.064601,161.150447,230.707165,213.374934,121.760578,142.046986,152.735753,88.976142,60.467217,75.258424,100.359076,102.202703,67.813875,-43.673569,-169.975618,-185.043113,-92.892984,-35.974959,42.879151,78.096082,145.758539,125.576451,84.430964,86.561973,124.984694,177.464359,208.253656,282.30453,296.811511,310.33399,259.264844,181.646125,42.956114,33.992662,31.840844,-35.806746,-211.386097,-185.99299,-126.884422,-3.000257,62.542465,93.934498,25.350895,-162.536488,-209.159235,-200.370793,-176.488939,-150.553467,-53.993195,-8.275482,49.145785,49.283077,-41.603722,-176.546887,-235.19987,-308.884469,-323.416525,-337.520481,-344.534939,-370.514059,-378.988989,-346.007099,-288.562735,-265.41134,-206.524755,-162.836822,-60.436048,-7.804925,90.869766,151.375323,171.650361,208.911844,216.538001,200.208242,206.566887,297.825813,343.775599,309.075266,140.124858,69.623234,5.597242,17.083673,124.690808,162.040099,51.29273,-225.813897,-321.541736,-267.484117,-168.060755,-66.61229,-74.816501,-97.766343,-98.414604,-69.113252,23.807926,58.169561,30.498912,4.452402,-9.110533,-33.275167,-127.796408,-163.698425,-161.995936,-179.432547,-211.476664,-237.803884,-191.31013,-90.745305,-99.457576,-181.107973,-174.171595,-138.493487,-85.07508,-87.385871,-143.620464,-157.07838,-100.530461,-31.779125,-17.671947,-33.629877,-49.558385,-45.039376,-33.687788,-43.061337,-45.075516,21.32441,106.82159,128.73945,108.226701,69.074335,0.174266,-14.034767,13.809798,99.546052,124.079963,96.144317,67.795096,19.146433,-10.344908,-47.599359,-29.674583,15.898229,-1.666281,4.742311,17.586471,-15.227031,-104.394602,-137.539488,-180.857113,-129.585963,-67.424815,34.940731,47.261559,15.936012,-5.887496,-60.952874,-85.876741,-52.375453,50.562473,57.88666,-42.360966,-80.006317,16.25547,107.066657,166.84572,55.327126,15.400029,26.337454,20.257724,-83.021936,-133.432075,-186.862617,-233.373746,-413.739092,-571.201291,-590.563855,-541.101349,-507.876401,-474.092921,-459.770392,-354.074096,-183.287846,-134.254975,-128.971234,-147.809131,-144.559598,-97.563291,9.939493,25.883877,8.56501,3.374703,37.734471,170.642824,208.309211,172.382536,141.091244,84.325562,1.724764,-33.394812,-101.555829,-142.129339,-152.07218,-122.231131,-111.167252,-128.682186,-156.812214,-211.489495,-244.706961,-278.75009,-267.68434,-202.342383,-161.940347,-72.527066,-59.93476,-97.752053,-114.023095,-72.398571,15.098566,41.784053,19.329848,-18.57958,-68.364984,-120.915792,-144.68953,-144.566991,-123.432195,-99.877641,-128.978737,-223.181951,-258.239316,-262.72294,-246.868678,-206.238837,-52.708199,20.242426,84.147498,88.045428,59.493519,-57.981379,-115.665721,-94.86558,-47.607001,-37.224524,-72.420319,-129.929861,-189.27344,-240.488263,-322.930618,-332.865424,-286.273443,-228.413152,-94.413085,-36.751357,14.811262,-83.044492,-106.47395,25.180095,113.570663,190.812682,169.448586,81.773976,52.654635,35.582887,-38.898334,-76.815778,-77.049173,-24.108983,90.859213,101.483641,-21.104221,-173.881048,-170.332313,-67.507695,-31.259548,5.090021,4.692895,-39.566637,-78.084697,-112.158726,-203.675293,-221.813864,-139.50335,-52.614965,84.665463,101.848437,40.124955,-71.624666,-87.434491,-38.533326,4.969147,87.335867,70.069891,-72.219095,-99.102581,-61.808595,-5.227041,9.925155,102.453143,186.18492,304.642907,315.188444,296.090292,234.470568,213.488255,226.643586,243.777731,308.446053,335.099985,307.143248,248.688274,219.976832,168.552861,173.414793,265.596769,317.982923,299.205686,205.381847,-59.58807,-186.214556,-162.892705,-95.523515,-97.158436,-111.912837,-96.858379,-25.321569,27.417887,22.861614,31.044511,70.902436,222.954608,319.930038,383.656044,314.32404,131.11803,-18.965346,-77.940695,-87.926556,-41.444807,78.243052,114.714036,84.580802,-23.518437,-55.609086,-68.864169,-92.15394,-152.904866,-143.385362,-102.76295,-114.455917,-145.002737,-94.480844,-44.027139,67.305667,115.277492,173.680769,151.286254,3.468521,-66.926749,-40.213106,60.459553,100.133707,138.33942,143.86486,135.166978,133.201971,122.815909,98.291157,110.277943,184.617167,217.606028,212.263142,168.688964,43.791717,-58.910618,-83.477363,-50.13776,-4.582357,58.841682,62.23647,57.879202,60.721384,54.440228,58.902225,69.254789,13.116095,-57.020768,-130.053452,-100.359954,-44.099598,-118.860943,-142.264277,-59.014177,-5.948801,26.351842,28.373359,34.304367,26.893414:155.031469,83.377735,51.78371,98.869658,159.617145,225.659845,222.672133,214.501775,179.083966,130.961849,46.482559,37.140031,67.81801,103.01412,220.014143,256.439783,125.405909,-133.519562,-186.810825,-99.217474,-17.49582,54.010363,31.295199,-28.197014,-48.785505,-63.868666,-37.411667,43.749915,227.995589,254.519509,158.676862,106.575257,135.084216,226.835264,228.998928,132.352226,101.195758,182.512182,202.640791,49.131867,-100.739345,-113.863721,-22.509292,53.324562,93.362342,41.409318,-81.410255,-117.832939,-117.728836,-25.543557,50.740273,167.212942,158.456554,72.957631,42.92633,7.703139,-59.036375,-117.017689,-152.796492,-97.306554,27.097314,38.961617,-74.018419,-167.146236,-264.176283,-204.002707,-167.455572,-115.224584,-72.081,42.845051,69.576217,45.022385,46.26407,72.13409,106.711275,104.080522,107.925262,137.012016,219.853748,230.808005,105.348738,-80.811452,-93.364375,-10.899575,5.558776,-12.355323,-8.77904,-11.908876,-106.199744,-161.331998,-168.561482,-100.812496,63.45574,91.155433,6.162549,-54.621473,-97.099536,-36.961783,7.107585,47.059688,36.800991,-2.302878,-27.489291,-86.123723,-157.048374,-193.5281,-188.925197,-135.002026,9.37538,71.636169,139.859023,137.914818,59.366924,-52.389944,-73.689218,-17.336503,22.025676,33.162379,14.549282,-14.42764,-27.321167,-14.447755,55.64693,58.84927,-51.804676,-105.428896,-72.016075,-3.113038,65.448959,20.258479,23.002688,40.990824,10.673393,-45.544689,-29.305261,22.976187,18.390446,11.772525,-0.383516,-7.066972,1.245948,3.028924,-63.296664,-114.463812,-179.830135,-175.815823,-144.540275,-108.816479,-111.489892,-39.389152,3.902552,-56.967706,-92.617211,-45.166316,42.872416,65.93037,98.970331,109.412708,80.202648,36.627216,-15.006874,-4.492062,-32.368974,-108.953177,-89.527998,27.562533,50.010752,57.810856,128.470626,131.918136,69.93242,55.202563,76.513851,87.610749,42.5512,-25.366379,-211.922746,-338.946962,-338.593083,-255.791101,-203.461595,-103.572751,-76.541768,-56.539699,-48.280479,-65.594061,-88.651608,-81.243272,-61.036203,-45.927412,25.726257,65.259863,47.473071,-56.745105,-88.732161,-53.516793,25.206825,206.936437,242.03829,205.240483,167.072661,152.028462,108.195201,66.649985,4.434116,46.543405,215.59672,256.561152,171.581787,-37.24104,-101.702747,-61.213411,-16.203794,-2.638988,-17.877677,-20.578873,-12.043541,-6.792769,112.121114,202.872947,237.03239,192.318438,147.316659,138.173311,64.563845,-35.531282,-73.710406,-91.713281,-62.54291,31.174601,59.00377,60.247427,52.748753,43.997439,32.404473,51.843967,151.777655,205.552542,222.714781,176.967228,43.59821,-25.388214,1.188407,87.170108,86.865143,46.173986,34.705512,-22.298522,-145.481097,-203.181999,-204.133043,-145.975669,-19.957405,11.083767,0.299529,-3.146803,8.647725,-37.862287,-49.412899,19.392151,86.628641,199.652573,194.162028,81.843681,41.551825,56.084142,43.928149,13.14252,24.190041,59.397866,36.830968,-23.014325,-122.926543,-188.634403,-198.410315,-143.762391,-101.696947,-23.805192,-9.91755,-37.05221,-88.534927,-116.367699,-61.515628,25.498373,175.036581,194.068563,130.714151,92.092736,64.803286,67.024417,88.824668,147.982603,160.878716,147.042442,105.664468,-34.911179,-111.370612,-116.18633,-87.764805,-42.893458,82.117982,116.159998,105.275466,103.562393,111.938715,31.352192,-5.742055,65.586608,131.414414,164.622208,135.607595,34.747867,-102.852002,-153.497828,-166.532061,-155.091714,-111.897685,-70.066888,-81.775505,-163.314979,-340.835736,-421.109731,-421.065745,-394.968794,-385.909513,-351.088935,-341.003257,-361.36463,-367.898162,-352.909281,-248.053331,-164.772081,-11.457061,29.396107,13.531295,-17.425136,-90.157344,-179.651528,-181.014874,-58.535352,14.928805,63.472019,31.147677,-38.584713,-34.198656,-51.871587,-152.629147,-178.235202,-76.795218,16.53959,113.98155,100.466418,66.898495,70.64859,66.128563,45.165145,52.439453,111.102373,116.910922,28.776692,-42.433348,-35.775026,33.770903,80.126247,143.519675,151.580891,146.630351,137.712333,66.034325,0.225758,35.23772,192.613084,258.570264,253.950574,159.855539,-94.344528,-234.484437,-251.640187,-194.290613,-140.946044,-61.813559,-42.366093,1.774861,35.680848,57.425057,12.847807,23.871613,59.809509,29.535052,-70.684809,-106.028587,-182.373485,-272.572218,-288.35192,-236.662835,-171.966669,48.922523,160.446853,169.057056,58.117496:left
212.260054,256.921101,236.181012,229.775854,244.314184,213.65611,159.483956,77.554945,56.205512,45.656404,43.368601,52.678411,34.322025,-17.855662,-147.190946,-151.436325,-20.113398,82.369889,108.576986,145.9823,139.766118,81.796244,57.285731,100.610352,275.013764,343.204982,296.581031,182.624261,-36.969249,-70.9056,-24.770549,9.352102,62.119946,165.80092,225.808133,223.603035,151.609205,-33.813195,-99.89136,-122.038914,-70.321544,-49.780651,-80.584667,-133.342421,-212.357611,-203.313374,-117.58293,-69.518276,-7.602354,-2.395477,-23.912304,-158.715738,-255.660897,-405.302463,-450.005186,-451.717446,-334.813262,-275.29514,-209.348505,-209.336171,-234.872528,-237.769386,-231.264777,-217.834684,-137.34981,-12.920733,36.947356,41.87141,-4.70221,-115.531851,-157.094334,-194.159086,-140.202791,-80.016399,0.593359,-33.768273,-190.326313,-235.097596,-207.282445,-167.853399,-85.522778,31.36303,58.139555,-32.310179,-80.919428,-97.283696,-127.569989,-194.258942,-51.05559,41.980773,63.550597,8.826765,-106.51659,-169.9891,-303.285849,-324.82026,-232.075682,-53.508091,51.593415,221.558213,243.172075,138.416474,56.460997,-13.910548,21.043509,20.484234,-9.694024,-33.45709,-135.790327,-216.341707,-370.946565,-389.551557,-233.8279,-28.721339,-14.904335,-101.90308,-132.641381,-190.22463,-243.018347,-279.476469,-179.366877,-152.959687,-174.124495,-169.011629,-63.246961,-13.506248,-27.169754,-52.992581,-29.206591,115.419056,189.291778,208.037733,158.272829,69.752377,71.168298,180.300637,263.018789,249.779683,178.770905,130.643024,57.153545,60.708644,94.559679,104.439719,128.429392,116.582975,87.521076,24.402927,-8.7654,-128.196947,-206.11586,-276.076043,-149.464412,-49.57803,84.257156,80.876765,-25.104848,-77.115185,-134.929829,-122.982284,49.010026,211.67096,198.825922,34.772236,-51.482899,-98.65899,-53.733614,38.721751,-22.097785,-62.047349,-52.085865,-48.398902,-142.55526,-197.269256,-186.993663,-125.793433,30.515619,148.404198,157.415792,59.451626,-16.06858,-129.387997,-133.485336,-35.643055,74.210867,126.405734,219.184068,213.270769,117.827373,105.016837,191.363538,233.811091,226.996643,231.583936,272.022336,347.876976,372.156342,348.809028,290.987106,231.821456,351.415143,428.086467,476.989259,423.291729,238.693472,167.962858,166.388421,229.176178,339.056552,336.883875,323.350406,274.13342,237.388004,199.093445,188.07838,142.254487,134.945401,142.61079,147.771637,144.916721,101.963358,61.620251,9.877355,35.119655,137.910042,161.154079,144.411583,97.185666,78.32966,30.829186,-6.056813,-62.407352,-59.287385,-23.455261,72.171849,71.033842,-54.131207,-110.431576,-130.700451,-123.86079,-115.505733,-55.92834,-1.409246,44.15331,27.965893,4.885529,2.142019,29.627734,111.913833,149.861171,175.593107,156.770381,108.289646,107.792414,132.14306,141.074981,151.895599,201.643875,265.989316,395.912434,399.591365,269.329616,206.466101,260.413529,407.827642,426.013987,389.171152,363.518679,320.779041,292.194043,154.664197,79.870725,70.194889,153.819405,171.143682,181.356693,196.777641,201.10426,164.05808,79.607661,108.600414,165.05826,296.045379,325.824481,277.546342,225.014115,164.102997,197.061334,347.237401,407.515364,388.051807,337.97848,329.02211,303.05995,271.189507,277.462124,421.702247,483.575737,488.373128,429.475877,269.567879,198.12295,106.260753,99.961747,105.663541,65.089274,72.686953,146.324231,158.836404,89.994401,32.381793,-49.941548,10.37235,87.788216,202.055648,192.445177,56.625558,-20.492958,-87.980312,-68.620575,6.647266,2.151386,-38.273957,-181.142293,-270.719666,-413.093689,-448.20666,-415.883706,-259.680825,-167.220148,-54.19827,-70.83129,-201.897315,-269.032109,-345.408454,-340.508441,-264.153334,-127.813488,-63.549185,-63.617004,-117.215813,-188.129409,-178.606897,-92.875373,21.958735,67.261288,91.412664,57.935654,-42.789601,-72.633957,-87.175579,-65.034049,54.150696,107.955293,81.133892,7.568925,-22.644656,-111.044663,-176.990314,-249.361951,-172.907794,-122.61921,-95.008146,-115.435557,-124.684739,-89.87994,-2.423622,31.297259,62.123112,33.715656,24.62014,-7.845615,-46.971554,-113.502098,-121.892086,-72.584017,55.966935,123.091963,164.075965,129.947146,55.413613,39.894227,31.47922,31.170566,44.887591,134.394314,192.025455,150.46178,47.461012,-125.293939,-139.88178,-57.307702,-2.648656,1.516552,60.280846,129.9668,252.854787,231.434286,24.005483,-65.075873:100.219294,257.998748,277.177451,178.303729,111.919843,41.206707,32.459221,21.941155,18.145486,20.174315,-20.639966,-51.341648,-101.663114,-156.618387,-289.142509,-289.576252,-134.127609,16.59238,47.72574,23.043277,-30.063487,-151.176136,-170.25107,-50.660245,193.011806,277.656163,238.012073,129.148047,-78.198102,-111.335333,-60.767584,-23.686399,45.888064,178.812777,246.354606,256.415251,184.790145,-30.521508,-112.730661,-113.389075,52.068266,101.682262,-20.36617,-132.988003,-241.452037,-251.469767,-231.085295,-172.090986,-27.766706,-11.683386,-53.296673,-194.171473,-289.108782,-464.037484,-496.562454,-407.48188,-261.875795,-224.08975,-220.77546,-255.928161,-372.432542,-412.101344,-354.613831,-255.016073,-22.770442,87.509116,91.917014,61.293649,37.887853,-10.534754,-24.858222,-15.977478,-8.8801,-8.43151,52.115908,76.235118,-36.292423,-140.032281,-236.600938,-206.001767,-93.665655,-19.617667,9.172782,42.840535,16.816942,-153.008701,-244.853369,-245.994191,-62.283476,-13.960278,-72.328641,-117.935097,-166.801049,-200.426827,-294.339678,-305.570171,-219.826616,-113.952089,-57.510919,84.019501,137.532386,100.585308,20.985075,-58.754118,51.908138,100.950336,83.314434,28.968873,-158.891496,-271.828216,-354.160143,-285.210649,-64.454827,27.692364,-12.012736,-124.36028,-127.827942,-124.312085,-168.96581,-239.005935,-207.237717,-179.638286,-124.173799,-107.718558,-112.550995,-131.751974,-181.12964,-194.078145,-165.522513,-32.343267,59.308306,146.530601,104.931931,-0.62336,13.909974,124.901929,182.997729,187.476058,114.704522,56.942037,23.731663,35.81838,14.445792,-6.208509,-0.271654,70.517457,92.158489,6.50561,-74.532371,-208.699406,-261.35248,-314.039365,-233.96999,-165.330646,-75.58112,-84.480181,-194.128233,-246.417624,-254.609113,-200.503965,1.425996,162.524838,161.34771,34.41671,-35.93479,-107.28546,-103.735224,-71.113423,-65.617452,-54.07293,-17.758238,-34.787737,-131.243665,-150.691377,-65.337303,-6.577628,37.48182,89.862229,126.486159,74.898398,-23.184794,-182.919004,-169.740595,12.928257,180.552378,230.47156,249.704779,208.5847,125.766023,123.054404,170.762824,198.884473,232.397324,276.573778,286.520128,219.289939,164.52733,42.303837,-3.566943,37.436994,198.550776,267.25584,295.780995,241.408186,51.285537,-32.413073,-67.653744,-24.533731,92.087973,110.430275,48.491602,-125.761502,-181.688039,-213.648407,-199.812999,-146.27561,-140.145612,-129.101712,-11.198302,54.450041,27.676108,-50.511211,-133.198977,-95.956848,8.423558,0.08008,-30.053848,-87.283011,-90.185898,-90.201908,-119.656873,-162.204046,-107.864774,-56.50193,12.355552,-20.021847,-194.408977,-263.756777,-271.187426,-241.363305,-178.343206,-18.563706,77.78507,86.654589,-4.834672,-128.70366,-85.927334,140.632971,236.033393,187.82182,63.920751,37.706413,47.472307,67.956617,121.933042,149.69605,236.975159,452.726923,553.165054,563.191248,502.525543,372.933241,319.414994,323.099488,493.693555,573.684642,605.346961,588.490061,563.030056,511.813269,307.914575,232.233049,227.397658,270.823454,273.504005,278.829198,292.819911,281.826357,243.551665,206.016657,353.048785,433.673099,441.974557,397.308795,326.806845,295.958996,250.288226,281.353125,436.738742,511.208098,490.501718,375.463904,298.15114,194.51393,208.778671,364.506297,511.890351,521.984209,425.463191,345.052302,199.799292,146.784542,89.94521,99.419722,131.9018,176.111729,213.991085,193.73846,126.688059,39.941956,44.784173,65.734759,104.205046,152.887713,232.689004,205.375853,35.083327,-41.636174,-62.07667,-12.426148,85.940092,96.853303,59.706383,-88.414703,-171.225871,-297.284337,-320.826696,-273.202735,-123.253312,-26.93141,62.911313,18.799636,-174.144531,-269.202145,-346.698156,-319.041227,-210.589841,-105.217725,-78.135614,-86.326683,-85.795328,-81.413259,-74.040249,44.774986,166.284178,176.696466,161.936191,146.880921,80.431329,28.258951,-53.776331,-34.114976,131.110053,239.146074,231.458946,120.646496,40.91237,-23.611749,21.813416,132.008064,119.442707,104.925562,111.212764,114.953124,148.468771,172.441578,199.822532,208.089372,165.176685,122.207971,141.501976,159.520188,123.963509,6.507476,-25.749519,76.723701,284.179466,358.1729,400.471324,349.940144,151.727743,71.83337,77.351231,139.760519,239.72604,269.319891,277.985208,213.342116,128.837824,4.990586,7.33383,52.178013,28.14847,21.275855,114.466001,193.110029,235.892334,163.048198,-13.32744,-49.01143:80.039458,187.730839,216.896621,174.095506,115.990105,10.987924,-8.369662,-3.455413,-4.473431,-15.806454,-109.211959,-172.337929,-237.276811,-259.925623,-338.167641,-346.48378,-214.606624,-62.415085,-46.307341,-113.153109,-168.834532,-258.341552,-255.23058,-114.167731,67.787598,119.891609,128.590858,102.113677,24.578321,-14.99329,-8.940101,48.030799,166.445066,234.191599,245.65471,211.171104,179.362676,56.945531,-34.88126,-141.534793,-83.562142,-49.626445,-41.198417,-75.038593,-235.963317,-318.402147,-314.208971,-234.238335,-98.374576,-53.92286,-55.666364,-160.213646,-269.782706,-504.713919,-573.344574,-555.113861,-403.776027,-341.105941,-298.274394,-297.60226,-319.730952,-344.781369,-337.517969,-277.218349,-146.292406,-76.854762,-27.466233,54.41396,36.96069,-68.036076,-88.475826,-27.106919,4.083776,-21.594136,-72.445986,-74.125545,-79.86629,-130.845568,-278.079539,-281.87624,-122.278046,-19.941851,-37.580609,-85.92666,-97.560018,-172.856828,-218.760464,-217.72005,-139.204873,-111.280666,-89.508418,-96.574958,-153.984462,-193.943315,-276.891051,-314.100066,-316.810837,-203.445837,-148.009264,-92.052562,-70.272495,-38.560097,-37.51503,-16.035053,-1.04627,-13.459004,-32.256171,-46.738396,-130.578854,-186.145698,-271.264068,-271.109008,-116.697848,59.737891,64.743304,-31.650251,-78.055227,-146.246072,-173.243605,-177.781633,-140.098182,-104.472502,-40.602019,-53.531612,-158.79557,-221.391085,-264.424877,-226.009612,-108.574776,38.300557,111.909484,156.78342,112.234588,-25.130953,-47.039927,61.958564,185.371687,186.826337,51.231887,-47.540831,-164.391656,-171.785492,-123.50915,-78.682946,-16.29827,-12.609762,-41.108676,-172.803954,-234.731473,-292.238262,-298.274275,-269.142009,-180.755658,-143.263931,-130.920539,-133.352832,-148.169651,-181.402022,-219.59651,-177.57999,-24.818291,67.850524,66.862441,-14.634403,-59.361546,-75.389315,-62.313561,-90.819324,-123.737022,-87.177961,-10.266068,-29.104699,-174.325174,-254.277379,-292.978069,-246.918067,-109.333049,13.998347,22.754378,-85.143041,-151.793429,-192.461233,-145.486716,34.829601,181.083378,204.475349,145.230808,84.325552,-43.634792,-75.492247,22.499755,122.697092,233.318838,186.066167,147.350648,81.12681,36.007454,-84.036816,-98.757167,24.447528,88.753005,66.742075,80.607891,106.592684,21.499623,-81.187589,-193.509144,-171.039572,-93.206899,-95.961055,-148.35747,-289.187779,-326.815135,-314.877303,-273.871611,-188.646284,-202.329508,-204.41613,-131.723298,-100.108883,-128.26933,-166.778284,-187.751162,-150.016299,-45.132737,-3.660345,-17.603795,-72.057504,-80.968711,-56.479696,-37.082701,40.515775,124.291533,125.270244,23.48092,-64.667284,-224.776428,-256.527985,-196.251052,-139.565761,-70.356287,-10.798781,33.630905,71.900813,41.254433,-42.580995,-27.657494,142.630868,246.1477,243.044083,201.204356,151.989712,45.162261,30.730217,98.175521,169.053059,305.674913,416.989192,473.358358,494.70503,435.909821,296.840032,303.286727,487.573437,650.505037,686.332259,698.634972,684.793397,631.754706,571.390055,391.598618,333.593401,372.020671,449.679827,434.810427,341.319149,298.7385,220.021712,180.881511,206.351335,393.181194,468.064223,482.130503,445.201604,368.884461,348.827933,354.001932,381.795253,497.170525,615.717867,621.581071,507.197092,421.62943,274.203519,249.897553,352.172055,497.263919,516.06907,418.693733,321.895317,119.35139,47.371257,41.763499,97.839416,189.246759,241.685436,261.435398,227.749101,178.360744,103.885682,102.830207,166.745284,254.209384,273.360966,252.108721,228.658721,137.07662,74.315809,43.686125,86.991473,154.6407,150.583761,142.721755,50.836155,-51.58733,-244.932612,-271.372387,-162.945984,35.64696,121.707894,162.796328,100.697394,-90.243395,-163.203818,-197.960237,-173.352908,-120.809825,-40.081262,14.181204,38.758893,1.69962,-68.909855,-61.413565,32.9555,94.185044,95.684399,101.398345,101.663283,32.19812,-19.378883,-42.994914,0.137052,148.302991,282.685088,302.414842,221.540099,155.399995,54.314046,35.440861,64.338289,111.740175,127.937429,155.352917,152.998717,119.303557,111.476294,128.281655,139.686577,144.559682,154.118539,143.801822,57.841887,11.213932,-38.085275,-30.02104,92.469742,241.296168,285.666835,326.28482,322.73207,263.478569,212.484213,151.557524,165.457986,232.533743,305.519921,319.048391,229.609136,132.900959,-60.798083,-110.335688,-59.634651,115.509904,194.808327,271.951511,268.308431,163.680661,77.532213,-19.807327,-9.181643:202.599881,249.343074,284.376379,320.894564,274.666882,137.868477,95.077535,57.717925,34.661914,26.351673,-4.789244,-42.144648,-151.55111,-208.438191,-255.946129,-226.681121,-140.190351,-90.858177,-54.956903,-1.637978,-16.509829,-84.343004,-94.841403,-16.345226,148.148356,216.96196,221.347936,150.23582,-24.253261,-84.306648,-97.119502,-55.10534,67.858408,229.943665,289.013186,281.346569,229.474359,80.043726,1.505535,-97.659128,-81.6499,-58.298175,-89.180921,-146.882605,-268.550503,-300.832676,-249.246151,-169.946565,-37.606606,-52.493302,-105.50527,-273.918329,-365.984183,-486.269232,-516.687234,-543.876322,-447.279269,-360.822476,-246.217852,-258.295272,-357.52603,-374.487156,-278.54969,-204.230354,-106.583023,4.359936,87.509791,138.665708,86.928642,-6.809845,-33.054177,-100.939436,-122.95237,-99.507031,-59.913792,-76.955657,-189.973464,-270.85734,-376.587277,-356.154027,-233.461103,-137.613523,-106.524512,-81.883523,-77.701602,-62.542839,-58.047882,-25.655887,50.778464,72.490837,16.330526,-54.543394,-198.359667,-264.062595,-382.828426,-399.313175,-297.510436,-172.752273,-125.040909,-18.194643,12.354162,-38.621561,-83.107262,-80.299766,-15.551423,-6.096414,-53.171701,-111.04448,-300.933049,-407.758804,-494.529539,-430.595241,-147.729958,29.389206,-3.715067,-166.687926,-214.854048,-260.13159,-293.780126,-323.651981,-222.140628,-163.38255,-132.811345,-145.666741,-127.423932,-111.73581,-137.190266,-151.002092,-98.921174,75.00167,170.499051,238.150122,207.909994,119.85921,92.814198,122.251176,195.798311,204.947462,208.139729,208.376586,126.737391,56.536933,6.179763,36.126667,58.295646,22.571738,14.644886,-50.994884,-118.17799,-252.90607,-290.143252,-239.698129,-72.759428,11.911252,135.92973,136.798873,-20.846096,-119.565437,-164.303776,-85.525083,141.623708,214.528124,192.463522,107.470244,51.473601,-41.618168,-54.375438,-26.984305,4.126729,23.095408,45.800932,18.338642,-96.011974,-135.010886,-92.898663,-28.198967,66.376643,85.39203,88.069355,53.256653,5.215557,-78.214244,-80.976594,4.218677,144.261933,220.252596,327.243853,302.424516,118.616357,56.391674,104.350546,163.208094,244.55764,287.740095,280.194634,208.619047,182.703163,145.561573,131.467319,181.912183,288.032575,329.34785,349.864683,298.660359,68.807715,-47.54339,-97.834455,-32.259928,99.301046,153.075997,175.528186,192.491339,181.374497,129.189126,116.640874,178.864586,219.196807,195.035972,160.41947,176.719262,192.109379,159.960761,65.657384,46.74609,106.658684,178.223733,157.937519,48.409479,32.377659,90.966694,118.876059,154.438381,190.809521,210.874368,202.983971,134.095166,-55.755694,-102.533347,-88.94331,-56.185597,46.625095,161.315663,185.362655,118.79194,64.995364,25.181287,35.843083,87.922609,161.310722,184.914332,133.659427,71.067177,3.942952,13.013492,38.516076,50.755474,161.816156,372.217434,437.368684,419.879828,358.186273,213.370167,183.399306,311.245648,544.905664,601.214078,550.626499,480.044916,360.809708,323.575557,242.06275,211.499662,222.646206,259.337746,264.977214,267.304757,264.954801,210.940712,160.741875,121.943672,274.863192,390.895614,511.877641,479.229466,321.550088,249.342305,222.323087,298.628865,508.390518,549.307605,510.870395,434.98848,418.316287,379.067516,361.514576,415.098063,498.221514,505.266686,496.85367,470.936562,277.29416,136.825535,-9.823146,17.445584,89.07168,39.928319,21.655568,69.956963,109.634007,77.096863,-8.132305,-104.912522,24.692938,102.76024,166.38837,134.50482,-18.533524,-90.934361,-122.148463,-75.791802,13.264084,-43.588599,-99.17687,-220.580805,-300.126611,-435.393567,-449.361326,-361.215667,-204.962641,-129.21205,-48.901979,-70.432666,-182.21846,-229.544917,-291.854187,-318.656518,-359.332156,-265.645888,-171.192459,-90.748893,-132.183626,-217.119846,-199.098904,-108.531782,-73.357462,-54.213499,-12.448332,-18.12076,-78.078484,-120.128892,-221.401514,-233.377575,-94.190233,52.126528,61.243366,-6.318253,-57.805751,-208.016877,-287.006457,-297.814216,-149.031602,-95.668078,-72.173277,-90.197205,-159.816955,-181.80444,-102.113254,-16.596798,69.402643,24.505604,13.391366,45.020561,61.299704,12.08534,-41.174598,-45.760427,136.885012,228.312146,305.036053,288.407434,201.73362,167.725178,140.571821,148.039567,207.827221,280.254699,282.768458,117.98229,-26.740211,-231.56476,-231.528307,-71.914834,44.392857,49.802722,113.418774,200.719237,325.793801,276.800092,26.233005,-58.446876:169.160315,275.439341,287.991161,263.623473,213.450281,63.849393,8.57006,1.316531,64.58344,72.368534,3.862729,-45.583002,-183.819037,-293.067233,-433.573515,-403.676569,-247.526906,-107.595078,-82.975141,-181.86743,-272.61027,-378.50616,-340.503353,-106.572628,133.639853,202.795307,173.918769,94.128013,-57.826354,-94.330297,-48.866414,6.020089,82.609749,172.114898,205.031707,156.781568,99.062686,-20.726056,-59.549713,-63.147311,-45.563277,-42.79198,-96.737437,-163.971965,-279.839112,-306.421423,-305.576729,-274.485921,-158.308564,-20.200195,-10.140908,-193.62479,-338.009699,-548.248377,-568.855248,-474.588386,-331.211146,-284.205643,-264.987999,-277.986411,-344.167545,-389.345019,-386.352873,-310.859562,-114.505338,45.578951,115.543507,156.070213,95.838264,-90.191405,-154.582644,-149.349781,-52.080343,-30.525288,-53.588471,-81.742583,-201.106851,-299.464902,-415.031683,-370.563374,-177.393627,-100.041589,-122.688497,-141.79557,-108.714096,-42.519053,-30.129929,11.245549,74.567832,80.565786,20.368402,-30.199931,-155.476773,-225.208942,-307.684589,-301.73403,-244.029992,-154.360352,-109.172663,-86.34062,-105.780894,-144.694667,-150.944959,-163.810858,-157.32493,-109.083679,-52.621031,-113.524767,-318.766173,-398.787812,-466.591412,-431.598961,-210.77542,-4.436606,2.777917,-100.198166,-141.143049,-216.170506,-268.670271,-280.647001,-120.021295,-46.328369,-28.753496,-58.808562,-105.15812,-141.032108,-218.187739,-199.788277,-25.041942,180.947229,245.983256,249.892917,182.469347,15.42477,-1.225595,121.908094,181.689436,150.443295,96.130341,91.785075,30.316061,-39.200172,-106.830365,-50.78209,140.092923,195.694822,154.903347,-2.90279,-93.930907,-251.545422,-285.825132,-187.279638,17.523552,75.178601,53.807158,2.00414,-151.135508,-230.825216,-253.16106,-179.510197,-13.843569,56.743119,65.234045,21.020208,-25.476475,-116.398933,-132.934452,-77.78517,-12.243141,4.557772,-10.307525,-57.597469,-187.580728,-240.381379,-253.751983,-207.513599,-84.456908,-16.075065,-41.059344,-171.391093,-205.548456,-150.184704,-86.336925,54.542596,174.38092,229.366882,274.813995,224.184858,27.640176,-48.29093,-52.444042,10.553,157.522315,208.849488,202.599456,163.874734,110.138202,-52.443857,-77.56063,89.828228,272.649789,303.197878,286.281206,228.450186,11.943453,-97.002727,-152.61576,-84.390024,104.745383,197.48965,187.003722,116.137536,84.880814,60.90258,97.805603,214.357779,191.570365,158.572113,168.049183,190.436052,176.027017,132.766988,37.042822,19.179757,67.094355,142.895867,144.354298,110.161267,115.263377,112.094959,98.739306,188.031522,353.184398,385.781992,286.201788,163.984558,-73.566191,-138.695082,-105.048659,-6.234818,191.422659,235.737609,220.617887,167.436815,128.67739,8.327435,-35.636479,28.724495,229.847072,312.559757,316.826397,240.958962,71.822827,23.154345,22.444247,76.378813,265.986269,435.737534,456.884749,359.720345,280.498583,162.728767,163.164573,312.49668,534.694758,605.218695,594.950344,536.730474,417.622013,360.81537,255.886067,241.761988,302.127648,336.72195,313.776415,234.400281,185.978198,92.330941,83.723928,165.970061,272.379594,323.392881,409.451938,403.185417,266.656414,196.267731,233.463373,343.699576,571.128338,622.075708,573.344896,441.813603,386.471802,256.10861,222.263066,339.919206,507.64747,535.288805,445.896787,351.424987,177.275781,111.235138,50.332718,67.417372,109.761732,111.966825,118.340486,140.389233,156.179412,164.977458,132.676549,51.617435,117.52227,203.6588,268.152741,189.711546,-41.110243,-103.674163,-52.25406,31.376817,138.074265,98.882013,61.351373,-26.270959,-76.35677,-168.560041,-192.63314,-161.393548,1.869333,102.497949,160.795384,91.604446,-92.456343,-151.122043,-230.458202,-254.804749,-161.918537,59.26295,111.005584,4.849077,-100.201215,-210.876086,-184.236877,-71.046062,11.254286,60.40753,127.993677,107.761272,-17.977859,-88.812149,-140.464746,-107.645583,-20.164924,62.527571,85.831828,33.016076,-24.383748,-186.027086,-256.029941,-195.421002,9.10987,66.077577,71.26954,40.554099,-26.363215,-48.483219,-49.602729,-18.016141,61.521443,112.621782,117.939518,79.196563,53.383472,-10.898244,-37.625276,33.023012,218.77443,284.921653,307.030935,272.850349,196.155275,174.950318,162.272809,172.006357,226.784157,284.196342,284.456617,154.324598,41.474942,-156.002849,-195.429732,-114.298328,57.115158,144.737887,289.004275,315.104492,254.438051,184.845953,68.864526,54.764429:112.384928,216.465898,213.475049,164.089046,133.516529,56.541015,9.179767,-38.382027,-9.451428,8.824137,1.616518,-47.668027,-180.429679,-213.005044,-201.710034,-170.723114,-92.674651,-59.005184,-25.872786,102.683603,129.23926,45.558968,3.532037,54.497177,211.585564,254.721206,226.778706,179.765338,80.188326,38.949826,8.189632,40.926688,165.378081,245.001499,251.97608,221.41371,187.868687,112.664867,102.235581,137.337568,117.336205,65.29378,-76.422251,-143.002692,-225.304547,-228.685468,-192.611884,-183.744103,-172.871878,-136.430466,-148.093343,-261.632993,-323.310553,-402.84914,-439.833307,-502.290914,-445.579573,-360.984645,-182.430241,-165.380513,-306.832196,-383.227693,-380.487724,-318.197083,-175.08159,-28.906123,39.381083,94.721976,54.45929,-106.047544,-176.609488,-216.378409,-169.153398,-153.81792,-177.259846,-228.682591,-387.870844,-452.249884,-417.308557,-310.548839,-98.404728,-68.074375,-91.348442,-113.243011,-105.674643,-87.783071,-81.470858,-12.439931,91.880516,95.732177,-22.590799,-109.913545,-232.416083,-250.586418,-258.423898,-267.476428,-260.705411,-105.657088,13.310848,128.769201,79.238715,-137.597801,-211.360885,-177.384967,-122.69301,-140.732214,-203.440767,-257.920635,-406.895352,-466.362552,-518.287179,-480.471585,-238.529307,-11.825708,-0.827711,-195.671842,-322.379619,-434.590714,-413.010181,-272.61684,-125.113075,-106.308419,-175.051655,-209.537541,-189.917348,-177.146341,-236.334117,-260.430073,-192.006488,-8.161888,74.752093,102.61903,59.123628,-17.336408,-23.533444,12.586654,41.641187,31.341936,-11.647706,-19.513746,8.109232,28.565487,28.494248,9.179808,-0.418966,42.688634,42.367932,-67.248891,-149.687843,-285.209687,-314.699709,-212.577426,35.836606,126.506981,159.813231,110.948729,-32.564212,-64.44969,1.975297,53.91474,139.283295,230.76778,245.354779,144.239079,64.981446,-31.172011,-37.016837,15.254535,60.582742,70.174564,76.35993,40.823621,-116.420029,-174.521331,-113.37814,-21.047609,102.434028,89.844678,54.917744,-55.381284,-102.108745,-138.271714,-137.53769,-89.819882,62.449834,182.465925,390.335371,393.012217,186.193482,75.309583,46.36578,118.972798,243.582809,221.27788,216.228365,320.153601,378.529779,339.574901,264.132834,212.671132,337.70985,408.287577,463.106168,400.701493,121.61935,22.461183,103.588662,223.747682,373.159819,366.742412,366.460808,358.510216,318.5688,272.247772,305.016241,382.140177,361.702142,329.386494,237.940586,191.883183,164.109199,162.847689,88.273025,40.862844,64.296717,198.820645,238.102494,222.308216,207.967,173.014824,124.721181,67.391869,151.659137,207.882936,259.868264,221.505643,62.353813,-1.501606,-63.89962,-62.349999,24.317761,106.286539,93.269731,23.086958,22.587615,44.243273,24.721048,51.84598,221.386077,278.57387,250.286523,170.314988,14.012699,9.45402,97.59165,110.585842,40.957605,63.310174,145.748244,271.368625,242.458614,34.328348,-56.516015,-37.060973,135.44085,185.145043,158.632259,106.698254,-26.13919,-94.345149,-151.105864,-121.20785,-50.839105,-95.461734,-122.905082,-97.901326,-73.31453,-84.020196,-119.432921,-163.026171,-42.774129,67.762361,233.060429,221.350396,39.538658,-55.638702,-99.181609,-5.009648,292.750631,345.064088,276.19088,198.880181,225.846243,264.71275,236.14519,236.110324,428.452516,524.295715,570.625209,490.25884,182.174691,59.804221,17.295627,48.617098,58.966626,-25.636931,-48.442542,17.361269,58.292769,6.963268,-51.570701,-40.456912,54.893357,88.002497,174.620863,198.62711,127.624453,69.745242,47.134494,95.411997,169.541286,47.937163,-39.651071,-144.850328,-186.169035,-302.17802,-333.165007,-227.457446,-33.327556,25.208616,67.508487,49.879773,-61.763743,-133.240969,-247.426905,-259.6839,-175.355026,4.740534,79.207573,60.046503,-11.593953,-116.792247,-121.887247,-47.085397,69.259235,94.627469,62.887964,25.325915,-62.567667,-88.837902,-67.700203,-30.851731,69.035728,172.173233,189.169199,111.098303,33.512829,-159.395722,-248.991363,-310.629259,-244.595532,-212.508493,-175.985538,-172.508481,-151.590272,-108.714896,-17.748036,1.124285,16.395707,51.529085,69.98767,63.505974,40.197735,15.038248,25.242195,82.631773,175.168724,230.751653,310.008217,294.272292,181.221083,127.757368,70.251526,92.255357,224.1892,286.17617,271.499292,160.766978,62.988271,-85.665562,-67.570834,97.86439,114.077307,70.234788,114.009462,204.688997,356.599006,362.129567,225.752696,148.40643:189.208393,305.666058,331.172796,281.984758,191.150884,12.440578,-19.152445,-11.181234,42.129081,84.485614,91.539114,27.667088,-176.033293,-264.892136,-308.698459,-258.784939,-96.032713,25.633769,47.479543,0.279199,-58.679862,-162.953602,-169.691162,-42.809298,152.900955,215.163511,225.860864,167.310463,-21.629975,-100.485793,-131.375411,-76.737943,123.977806,292.038275,306.730842,226.103467,173.435801,74.97856,41.521361,56.914774,62.343078,22.580812,-95.476625,-171.755896,-348.838462,-404.432338,-352.959702,-268.592516,-113.638167,-20.306541,-26.61647,-220.978411,-347.922422,-484.003638,-500.271199,-456.702454,-322.65623,-257.884419,-179.5021,-191.248441,-347.761529,-433.926043,-405.51249,-284.201556,-20.531445,117.332802,137.757203,80.943642,15.291287,-124.238729,-183.587841,-223.903841,-126.044083,-72.730688,-59.133946,-114.299507,-302.449751,-398.523089,-478.915993,-422.992326,-187.034971,-23.236706,-17.294058,-105.977161,-148.061823,-165.385322,-135.84147,41.185978,232.525131,243.353912,118.240172,32.591081,-119.235941,-183.96344,-262.254667,-241.885508,-77.091793,85.409506,96.954613,-43.842703,-139.822538,-262.180867,-277.915811,-208.908979,-69.816426,-23.808074,-53.128924,-127.859968,-355.032517,-479.039016,-597.933046,-529.672839,-181.101499,54.985383,39.23592,-140.992532,-243.43108,-407.010192,-447.711253,-363.430346,-138.53068,-64.13187,-73.205652,-142.662302,-304.623393,-351.221051,-309.190936,-224.206569,-23.639009,158.92325,229.801678,210.141333,125.271956,-5.511401,-8.225653,91.170083,227.05437,245.883211,160.042004,97.626593,1.394091,-36.301463,-51.49401,-3.139176,167.322519,271.994149,242.342988,42.425468,-68.91175,-206.661923,-206.694794,-34.832703,161.255218,202.328632,199.212767,157.110474,1.340362,-71.026502,-79.795657,-16.233439,155.835939,285.676213,275.244529,75.178428,-28.120467,-59.50861,-24.911543,2.207065,27.560396,79.790533,145.550777,86.146944,-159.328195,-259.018228,-277.821,-201.323602,-4.414972,88.502198,51.072942,-145.566278,-223.547059,-245.95727,-210.361342,-54.700099,206.267435,325.815895,382.154057,297.373822,31.092659,-63.877898,-67.277349,-2.367357,151.605789,246.144287,254.240231,199.532223,167.959204,146.514732,151.312492,203.288022,329.986515,406.120795,426.769198,301.646779,-64.069025,-156.492275,-52.252198,72.112474,265.665844,361.804577,398.67073,384.519664,324.10466,201.540296,199.716243,352.883115,484.278304,474.766883,360.464465,298.671649,210.531509,166.755655,92.810507,102.215395,205.024978,280.491083,258.549134,95.773562,41.667118,104.89724,155.987566,192.290781,274.754038,348.809849,383.86334,293.402376,7.994796,-108.404069,-160.275567,-85.420733,138.963799,255.037142,240.587471,124.690513,71.357756,7.796674,-22.417353,-37.718934,117.718654,222.159215,286.707324,219.73025,39.845665,-11.898956,-44.997837,-31.107565,85.767759,271.61658,341.785912,299.979738,177.329332,-57.541101,-64.394616,127.533312,319.690974,358.191014,323.906655,258.080549,65.443276,-31.079452,-104.711915,-46.874376,122.894659,147.947081,123.64112,62.774298,23.641449,-54.720659,-75.278474,-63.847999,47.09462,150.890426,272.554443,220.449098,-0.622198,-82.282985,-52.561142,72.829464,404.606834,562.374797,521.12929,296.464321,209.300117,178.153489,209.313767,322.077572,459.716026,521.766915,549.959498,473.11169,161.964937,2.051662,-128.13722,-88.624838,28.296693,77.709585,97.780117,94.926981,58.667802,-38.357077,-70.754706,-18.339116,146.575999,202.756723,162.782854,89.65988,-23.413808,-48.492086,-28.915007,21.322527,87.278324,25.548834,-25.290481,-145.958886,-218.637717,-361.09753,-391.023814,-267.153463,16.057661,135.204593,226.639483,193.882041,-4.432744,-139.652186,-314.83802,-296.130693,-108.700987,76.013074,117.077862,42.976493,-56.381671,-253.444692,-295.624362,-202.503236,34.989427,133.039292,162.406303,92.043749,-69.257302,-102.16207,-113.883832,-119.668064,-77.580297,83.454504,134.932285,21.48026,-85.974711,-250.454185,-301.524915,-281.757699,-111.869247,-38.814518,-38.202253,-83.627038,-111.369145,-90.970037,-55.060361,-26.643337,71.003023,130.674014,129.538744,78.747625,40.400125,-20.076983,-19.946463,94.188608,263.444658,306.332497,293.941706,246.679819,142.136524,119.629447,115.295518,128.895822,235.690051,353.227627,335.655587,131.487129,5.444881,-137.36297,-130.807991,-17.385649,88.294936,133.068329,250.836406,286.329854,225.591314,148.180076,15.620358,4.367131:-24.427597,67.090635,110.075429,139.051756,93.749993,-99.451632,-187.768868,-208.443273,-121.062536,-104.660396,-133.222538,-146.117364,-105.028625,-65.651739,-23.379639,-13.783337,4.622134,18.040472,50.271193,151.089962,191.767702,212.890049,204.600655,229.102082,305.207342,333.60205,351.220196,321.785533,171.304397,90.323982,13.255977,41.255638,212.550967,368.777099,396.159135,371.518708,354.694598,320.162545,268.397722,118.765551,25.663469,6.223939,-20.856942,-59.419931,-164.139248,-173.425901,-90.322596,-44.658462,0.385111,18.460717,8.51459,-114.909651,-188.110269,-231.508319,-230.740863,-272.02996,-293.749894,-275.598776,-215.790776,-203.463268,-241.254598,-266.629374,-293.326843,-285.55111,-179.476854,8.179451,66.078995,43.28375,6.498952,-32.359946,-61.838714,-183.741863,-273.4334,-277.61811,-273.653588,-280.294692,-299.402096,-320.312782,-309.10535,-227.513867,-30.792243,2.99276,-19.720567,-31.085047,2.426402,76.745059,74.750741,49.153916,90.288554,105.977284,86.565757,47.184702,-49.850473,-73.156603,-72.433721,-47.80651,96.271725,234.538013,248.854878,180.024805,97.100874,-147.794128,-262.475414,-359.598731,-292.744436,-238.850298,-174.260071,-167.824854,-184.459985,-224.33237,-318.029956,-291.740801,-65.656114,98.188418,81.889774,-61.495531,-118.005925,-135.875489,-116.943058,-89.185362,-97.658146,-80.746936,33.69915,86.47209,51.253554,-26.774752,-168.029244,-187.167598,-105.409386,15.648565,45.797179,42.797543,8.01813,-149.155094,-223.550645,-186.938713,-63.70075,-62.463934,-73.968712,-61.622222,-58.179482,-63.531249,-74.237696,-73.818709,-58.9562,-111.76611,-159.434004,-223.886703,-230.477454,-204.169091,-179.812876,-112.807481,-14.040901,38.726606,130.79594,157.352561,145.178551,117.844573,89.836319,102.923396,154.359493,175.13336,137.890732,15.577293,1.222184,72.328989,110.049795,131.707672,100.92221,113.718648,187.700336,191.814076,114.8228,81.9347,97.538558,127.303527,139.465601,97.415727,86.017013,43.626396,11.975739,13.701131,56.61604,172.663125,257.114653,302.284379,400.835528,405.815243,276.405575,187.204608,73.085453,45.722779,-0.323507,8.941425,59.162522,186.921319,225.359418,210.911998,177.715647,179.060206,273.137239,306.178538,309.448677,269.448667,98.937698,18.792516,33.461194,121.618724,269.63104,230.564621,176.665728,150.676465,177.204444,215.28933,227.507491,260.116073,262.31731,247.425763,157.803105,88.886421,9.248688,6.800175,-34.379181,-83.980895,-126.442414,-59.58858,-41.405459,-39.187956,-15.994879,32.317989,25.752273,31.313829,108.55966,128.112423,97.354357,70.919724,48.56606,42.555223,23.34529,22.184732,36.498199,88.784,118.083005,90.101631,49.484963,1.263503,-22.766149,-36.176882,88.703028,170.522477,261.57505,239.161969,90.585242,36.078132,5.232336,-35.56259,-179.673188,-164.614036,-75.254857,42.008012,-1.724048,-227.791342,-332.048674,-370.765496,-249.032035,-212.391075,-224.196697,-250.623494,-288.143945,-299.721331,-383.214592,-429.268633,-403.406295,-379.117305,-407.736347,-386.547657,-317.51104,-240.451005,-263.753149,-316.409603,-290.266223,-235.928613,-91.87161,-65.055284,-141.989269,-202.329784,-251.209792,-207.150836,-11.366549,127.08082,124.069573,39.849546,12.384384,10.622103,21.284152,110.496259,273.360124,323.905213,324.490426,280.142492,107.033457,21.564136,-36.710438,-25.05763,-32.595544,-55.24047,-15.989319,118.694608,143.241994,33.285748,-57.738839,-151.08791,-83.07461,-17.64505,114.014169,151.627339,125.087645,70.116434,-30.769825,-22.70164,78.351227,61.824899,2.251575,-64.764582,-48.792326,-56.630097,-115.623435,-199.524663,-92.052344,-19.67025,4.94136,-40.933335,-132.605938,-158.246997,-192.969526,-193.995205,-133.556416,-43.207091,-14.617327,-70.97397,-159.136999,-283.370924,-267.860177,-171.633658,-97.007859,-49.392995,66.245747,93.940663,76.128235,60.79977,39.42673,38.177883,74.50451,119.934723,130.759024,126.480974,99.023959,4.076265,-42.376558,-97.257251,-104.509173,-119.712355,-174.109638,-167.493116,-65.109263,-26.556116,-25.735128,-11.564327,78.117789,144.660998,176.056934,236.711563,240.33519,141.260259,58.259911,7.326268,117.503038,154.899424,159.088817,129.585073,18.500474,-37.707807,-67.824559,-23.93941,116.61445,238.082538,279.374379,204.825715,84.875831,-107.758346,-128.474098,-72.851044,26.413828,82.794965,203.311302,270.988487,388.074969,378.935676,195.745393,116.949402:11.394846,85.76017,76.253465,80.272856,104.124593,91.146983,48.270465,10.604592,26.162466,20.423728,13.875715,-0.889731,-61.674785,-70.214263,-49.484206,-44.20469,-49.724013,-35.975163,-0.286151,121.81126,180.789759,208.665945,174.590961,157.841478,325.929245,399.943115,328.090926,216.897465,67.098192,42.20238,0.130682,-5.438312,64.109122,187.533019,242.039411,279.989316,253.853718,145.036994,90.840945,16.545319,-55.505405,-77.316464,-96.274248,-122.616571,-145.732022,-102.806459,0.609584,11.318111,10.214911,53.657766,27.445045,-171.193287,-254.880737,-239.964613,-197.78328,-208.532657,-284.341313,-282.775969,-190.680137,-170.321091,-248.145552,-289.111062,-311.615814,-301.362896,-185.224922,1.973394,56.491387,49.877797,4.208584,-126.401577,-198.764538,-286.785873,-253.822019,-223.963765,-223.777477,-266.181967,-365.976692,-384.710676,-317.327366,-229.879166,-55.016106,2.194782,18.424227,45.297344,27.822067,-55.060421,-87.352977,-70.780965,30.016724,76.067569,118.756796,112.829026,58.784494,20.068477,-51.499931,-65.052688,-3.825727,186.868007,287.397867,325.986501,253.468642,53.430549,-26.155791,-90.303802,-70.387387,-53.010459,-26.408569,-46.55602,-181.674041,-255.352105,-305.126881,-270.256024,-100.205095,48.910653,46.972351,-58.526535,-105.371816,-130.13823,-113.575025,-62.713356,-69.217652,-88.88594,-62.25561,-12.545232,78.318751,92.239178,25.053758,-17.222178,14.984257,123.383707,143.461886,91.571151,44.767955,2.380473,31.654789,146.547906,189.425535,188.74625,177.513636,141.78392,65.650067,68.894918,97.725936,89.93201,70.971386,53.246092,32.343776,-32.748666,-78.428828,-182.880379,-208.718946,-132.335512,-16.074977,-0.635046,16.010842,41.605425,43.256667,11.390878,5.551048,55.000214,173.146727,194.820387,166.509122,46.20652,-15.298692,2.377843,64.53623,95.994318,1.97415,-28.554064,-44.882361,-63.137219,-108.491996,-93.797804,7.066667,50.308602,86.034575,98.141695,87.207743,0.182774,-41.690079,-59.919906,-65.230621,-64.744675,58.186872,122.847336,149.147072,127.323,104.998027,115.014566,94.247295,39.095589,-81.424093,-17.471932,76.52918,214.90935,230.644986,210.248534,212.727403,283.038818,369.587587,408.815684,435.466522,380.467821,158.822341,55.816689,-2.841234,60.069489,259.135768,341.37271,322.937099,242.404618,213.878068,203.005476,198.505643,148.807163,75.153126,47.213906,11.225387,-8.383603,-55.229263,-79.731888,-120.073749,-125.366309,-96.695199,-62.486894,-63.728218,-77.531878,-65.30761,-30.907996,-43.009778,-72.117766,-12.38579,24.558074,69.544457,71.340097,32.542217,-0.285487,-68.794285,-87.125821,-87.810545,-63.369635,-49.047697,-68.5049,-101.741173,-173.343162,-194.581286,-118.666345,66.835459,130.134672,167.583169,153.980298,67.029817,20.369508,-10.384461,-8.494042,-27.437105,-57.735079,-31.836975,69.231731,67.529821,-75.578376,-150.597894,-174.405879,-73.401709,-25.057517,-26.664847,-69.626632,-101.295989,-84.758623,-105.733642,-157.786059,-275.932243,-314.521182,-289.058893,-173.573066,-112.746552,-85.535363,-129.438297,-225.971039,-174.443522,-97.458041,3.074903,-0.948967,10.131239,32.200378,13.547288,13.263999,112.073856,160.704644,137.835191,78.191236,80.496347,134.506108,129.98803,109.332684,215.482272,281.650312,338.96535,300.603234,154.057566,110.346496,97.020351,101.844638,74.726008,-4.549256,-13.256754,63.73788,104.1566,58.715482,-22.32661,-139.047283,-111.150686,-69.157514,42.327897,81.610229,65.024832,26.39847,-22.999756,-14.282565,9.327707,-21.831184,-36.955713,-77.929476,-117.857995,-253.371587,-332.591884,-339.772479,-88.003383,39.160412,100.79863,35.317374,-164.297239,-242.499641,-264.238472,-211.599163,-88.05039,-25.557177,-15.238537,-25.521091,-31.648833,-20.034867,-9.955961,23.492723,101.359113,135.469419,179.603341,195.559435,177.873626,133.071435,22.205863,-5.952219,48.109165,165.313116,203.385887,210.959961,173.164099,29.794705,-50.476718,-154.22341,-174.068939,-169.390945,-156.72997,-159.788001,-153.678231,-131.032615,-79.120281,-54.956945,-5.485429,33.179066,72.23832,104.020937,52.513761,-70.704214,-99.275479,-94.341664,-3.442172,58.058634,111.409999,73.835598,-36.269444,-66.324937,-122.130737,-144.758347,-71.438394,88.972668,125.522493,52.063711,-19.119945,-101.573863,-103.739498,-41.879082,68.948209,103.254031,143.466165,203.479332,393.40614,424.659713,256.927771,158.351813:60.486153,204.890886,262.617872,209.58488,125.70716,10.694583,-17.596543,-68.551491,-72.086808,-43.706878,0.557115,-12.930303,-80.743475,-122.511421,-192.01251,-165.170038,2.981632,83.545278,95.944643,131.837961,128.30608,52.006785,12.130104,30.270081,154.434266,201.163705,207.763525,181.784975,125.124811,94.160521,40.706139,54.214093,152.732617,238.332787,272.400661,255.358734,206.042396,144.406779,141.762693,125.954387,44.670179,3.151163,-28.930184,-56.253747,-173.683106,-202.01336,-166.061776,-137.192181,-36.242856,-11.452972,-68.566389,-176.99507,-196.663547,-266.093106,-338.789855,-436.255854,-355.263045,-281.266015,-170.357167,-160.187205,-188.153108,-202.469293,-207.018022,-170.310195,-45.268387,52.006115,76.480759,37.048509,-1.059242,-43.446398,-81.304915,-181.53361,-161.808895,-128.163772,-107.662846,-129.780618,-258.381781,-340.521609,-376.124816,-293.115993,-69.45707,-37.499582,-88.286442,-153.813291,-139.78817,-69.366783,-36.675757,44.328658,149.110298,169.31677,92.410974,12.562736,-119.846747,-138.472669,-124.335322,-103.838783,3.117949,78.522546,64.307439,5.639568,-28.010991,-147.968513,-225.975352,-297.670645,-197.194643,-135.91774,-88.48522,-118.439968,-254.762874,-321.845125,-379.271006,-340.200303,-150.284037,-27.323981,-39.387442,-154.907736,-232.182666,-368.855256,-375.73814,-221.815775,-85.532774,-81.244866,-136.353683,-184.982415,-287.156152,-312.067335,-269.646604,-199.412777,-41.512341,61.226114,104.160163,102.507091,38.747556,-109.990841,-141.414344,-75.492149,-2.270062,-3.94E-4,-21.700625,-42.146547,-78.460516,-91.191328,-76.809671,-31.445007,41.254338,2.465094,-37.566125,-116.834501,-141.500416,-144.457404,-132.464416,-86.049718,3.005714,52.425602,104.08306,79.875027,-2.786936,-6.547738,40.962286,58.810694,106.312165,187.625586,201.593381,115.367588,51.497815,22.096829,55.006995,94.510674,92.2707,114.476676,163.795561,147.563121,33.962294,-37.669568,-119.413186,-87.956036,28.951242,-17.587554,-82.659187,-151.026776,-145.904873,-95.911841,-52.997258,71.217683,235.558667,318.483412,408.531796,370.905096,154.512114,64.12492,76.19758,159.506117,270.568609,193.710937,171.148602,217.811712,227.725157,166.600169,136.140918,162.71961,260.32788,304.975116,330.864581,284.215111,95.129231,11.347722,-17.062922,38.123289,188.863951,262.616163,281.341496,310.535391,301.666946,252.075759,246.64292,326.863304,367.225981,300.831633,120.16633,82.807497,71.8665,44.437512,-47.704906,-73.282369,-21.009675,69.226095,69.067119,-16.058891,-33.301154,54.014735,91.796083,95.438873,162.750456,200.929462,185.765482,140.528206,43.117596,7.080547,-13.103186,8.515498,95.878623,189.778156,184.204197,14.340868,-77.845461,-107.614089,-67.349305,15.225591,109.408778,194.29747,330.779354,295.12944,60.209003,-36.714334,-99.211121,-96.541424,-54.854542,85.699912,181.520404,208.905249,93.334943,-176.734309,-228.104143,-137.696903,-16.290558,-22.310722,-111.947995,-152.172444,-220.389385,-245.989937,-249.140972,-229.846687,-210.179114,-253.574648,-280.914266,-315.691691,-313.786365,-250.393276,-220.789435,-244.717288,-206.463005,-131.515636,-52.541832,-95.084131,-200.260015,-202.824504,-140.408829,-82.242556,87.6538,164.699776,143.085122,85.474845,86.003551,139.838841,170.259423,196.223538,220.798831,280.012005,399.455204,382.404665,203.975406,104.486863,-18.614585,-27.682634,11.621556,-23.272279,-50.802827,-7.850233,48.534847,57.403698,-13.207477,-128.62709,-56.976236,22.293238,186.546426,233.976419,191.855922,124.404063,33.973647,46.582305,85.775034,4.01794,-31.588491,-70.353474,-128.30326,-281.279698,-296.794484,-157.120252,-18.39744,7.45553,33.38968,25.317564,-53.800886,-95.541335,-139.774981,-150.686113,-134.042615,31.703229,121.792414,45.244822,-105.049036,-310.552954,-321.191328,-243.219824,-121.6997,-87.9622,-74.957483,-82.900814,-100.056011,-80.968906,-6.762638,14.783771,28.922258,68.323071,100.488327,129.503345,109.104743,-0.911414,-69.31695,-140.651636,-127.845432,-126.219785,-153.335252,-156.293656,-85.572514,-38.692469,12.620108,41.579305,127.98643,174.596859,173.959035,164.664378,191.986145,255.215123,215.878352,86.597248,143.482365,213.102896,279.796642,251.288015,143.107479,112.15056,135.137198,178.726842,275.775445,325.866443,317.525583,180.971517,65.738387,-103.820762,-107.155345,35.439599,147.997892,154.244343,191.425358,226.110685,210.845274,158.020696,83.695425,103.49495:left
75.424847,141.377736,141.955674,162.215711,182.506518,125.619066,36.628174,-123.813113,-95.713792,-67.945344,-77.77105,-84.092785,-77.288188,-63.750698,-51.288335,-72.555181,-105.95243,-75.186839,-72.826684,-149.023403,-203.928876,-247.05379,-223.906911,-154.414692,-136.81422,-149.433645,-150.490009,-112.660471,-25.926351,-17.384794,-58.977723,-82.74556,-88.400345,-61.787381,-44.312433,-27.578112,-83.454632,-313.795753,-400.986838,-419.549782,-293.697216,-201.009465,-51.516897,-38.704254,-120.394513,-143.111309,-84.062048,-57.883641,-60.56899,-54.775769,-23.068089,80.597406,106.644403,98.014051,100.857442,114.279932,115.390297,141.656678,248.367694,280.821621,224.41601,163.364157,51.920731,6.586715,-54.73225,-79.002475,-62.32384,11.162306,37.857911,53.138926,46.61761,55.926399,174.434641,243.071566,339.71143,342.474715,187.312603,79.937009,-14.501496,-9.104118,10.090946,4.812511,-23.558459,-97.03464,-96.538257,6.56715,69.729962,134.120438,144.567045,127.804447,61.03551,26.368439,-49.219138,-66.431508,-34.457611,-34.779886,-115.370553,-176.763919,-178.513492,-165.628916,-170.986068,-233.296823,-291.524554,-392.906897,-386.38216,-366.914218,-346.867417,-337.521783,-310.386627,-306.551961,-349.972125,-401.000706,-522.585585,-526.916564,-461.898729,-308.090662,-278.72292,-332.792736,-370.530525,-327.841094,-139.007637,-70.339079,-10.64247,13.654412,58.135002,82.198333,125.497181,124.566387,77.96468,9.25265,-10.24728,0.212335,9.030382,-7.977784,-28.324297,-52.327311,-30.568012,-29.030319,-57.768048,-66.764201,-38.726429,6.741699,109.919654,111.138033,-34.215499,-160.349234,-132.549483,15.303506,47.505933,7.870667,-24.957339,-124.1852,-234.804211,-258.263222,-229.461342,-203.103281,-201.290474,-201.077988,-186.755157,-228.681881,-409.13882,-476.058293,-429.336143,-297.421208,-257.642161,-207.522975,-170.156653,-130.136524,-236.020256,-281.733642,-207.286233,-139.242114,-136.410326,-200.096948,-322.465281,-340.397365,-251.852718,-27.597941,76.884903,205.33221,232.379032,204.728923,151.089351,22.68691,-41.539126,-48.208368,22.293448,88.375453,118.989276,73.910734,-31.400385,-75.133856,-104.660625,-91.599382,-102.412288,-114.336943,-114.769503,-191.346867,-259.144439,-327.51134,-290.300743,-271.216027,-253.470014,-246.373635,-247.26942,-247.326256,-214.250769,-193.349481,-121.145042,43.041621,96.443198,44.787296,-5.394152,-40.152522,-49.82323,-65.138857,12.625988,52.024324,40.768818,4.252612,-129.729273,-201.611473,-209.787113,-174.075529,-168.191947,-191.179732,-170.483115,-38.684738,42.409825,117.092179,97.146697,77.071026,190.293226,217.367514,134.906756,99.366854,139.449113,162.230009,111.048668,74.934403,100.694398,135.214363,114.703805,90.708092,100.112405,112.504189,103.974984,54.336859,31.162392,70.923644,245.262742,325.194884,335.000659,266.295709,97.483151,34.175439,-40.194994,-32.67921,26.588425,189.253295,222.577192,152.735109,92.896901,26.071968,36.561422,26.554355,-4.681013,2.808288,-47.0099,-133.74185,-246.866189,-226.770966,-168.870552,-157.993341,-134.789422,-87.684465,-95.793292,-133.409095,-142.099978,-154.654569,-81.250429,-19.282798,99.228861,153.991702,115.532513,20.777038,-42.238009,33.935896,205.282674,223.629829,233.747379,422.176079,545.267764,574.760675,475.540257,299.448076,378.730643,470.670782,593.05282,605.221492,563.340734,531.02176,428.404642,355.170392,290.448398,396.505625,458.669955,496.853041,455.018082,322.420474,281.42722,223.250946,130.746978,125.279908,256.471274,332.127267,343.797676,284.30543,125.824463,55.834229,67.712585,288.607659,383.832966,459.955114,445.266124,324.453238,232.203458,76.204247,70.088804,100.970337,123.34126,109.916122,97.045501,109.782001,127.653864,106.235244,38.173546,3.687511,4.323462,67.101518,117.298591,183.514541,189.202227,164.810599,87.073334,68.703248,221.555978,343.407913,400.027881,325.612277,150.996186,96.203952,69.287218,162.569652,254.568815,352.603939,288.029918,109.948474,92.827447,88.457172,14.299785,35.301305,228.304849,326.97476,372.880178,333.142642,217.848321,146.68007,44.55233,88.013867,132.505065,249.781506,318.141398,314.404317,199.529862,-54.830575,-89.379543,-84.807516,-77.272266,-43.103275,-12.438484,-40.113229,-89.980482,-104.318541,-141.693395,-158.872609,-134.168499,-56.738836,-70.384527,-253.52841,-365.782448,-475.550172,-361.165411,-258.429497,-113.674381,-94.928681,-139.215779,-184.781282,-294.883047,-348.433092:67.468851,231.176512,233.668426,218.616565,191.645121,42.94937,-31.983364,-67.467136,-14.300152,-3.629254,24.874479,43.446372,-0.507693,-52.757127,-169.327292,-233.007028,-312.695486,-286.178008,-254.23246,-257.027355,-311.27343,-450.934054,-500.711708,-522.583445,-450.33042,-408.687159,-318.488905,-261.119865,-183.174639,-171.762787,-168.63742,-173.43851,-180.082255,-115.647507,-46.43823,64.089459,41.743054,-172.30865,-275.184037,-276.264072,-135.033782,-97.622346,-85.851345,-80.733452,-82.885054,-86.901566,-46.330312,-11.023076,4.669687,-52.711021,-49.533676,21.607968,46.711627,133.797996,211.790985,288.430692,219.84673,203.444432,281.740447,316.9261,260.790353,208.417232,162.844858,150.409531,75.480467,-7.091022,-10.542157,24.673891,32.436665,26.598824,28.130404,66.121398,127.319443,169.441886,260.880504,253.823934,58.736254,-67.028356,-211.515113,-237.513457,-243.147484,-173.285953,-109.008254,33.731779,84.376767,95.679344,62.263587,13.706628,55.07173,81.226309,96.799276,79.708984,-14.666141,-66.974254,-102.235642,-86.503593,-71.88469,-79.716918,-49.202083,-24.35445,-75.416186,-150.653688,-151.740837,-219.995822,-250.508453,-191.07754,-70.844449,-72.594548,-160.86204,-208.871338,-261.866823,-261.122581,-262.192648,-273.575059,-250.523378,-191.9388,-187.660362,-204.922003,-223.456314,-245.262641,-142.752563,-73.650391,7.482832,-5.297387,-100.429694,-141.078164,-187.062695,-183.934414,-101.229111,-66.028042,-98.970791,-138.841291,-124.157209,-126.871825,-160.47485,-195.506773,-185.534826,-198.491632,-179.079724,-152.778297,-171.99991,-185.966051,-119.928936,-78.591452,-165.945987,-332.512526,-287.682353,-57.301969,-14.456159,-84.990231,-117.562639,-114.276539,-122.061306,-154.229983,-192.41954,-178.042447,-172.320936,-203.01352,-296.401021,-345.312071,-421.563209,-423.488386,-361.266445,-179.104501,-139.424115,-192.402015,-239.133083,-303.260272,-311.580361,-300.630636,-229.601659,-168.171654,-116.292922,-172.131481,-321.002293,-316.59458,-100.977151,97.419269,93.476924,41.894904,71.319752,128.419833,82.357031,-72.141244,-110.887802,-98.03215,-25.853295,24.864087,43.655028,-13.020013,-211.676589,-310.609289,-358.289809,-229.465667,-175.153844,-201.568182,-271.350874,-390.701017,-414.832643,-389.29075,-330.024781,-339.041788,-404.291386,-402.777533,-310.770325,-258.265743,-229.557152,-266.962414,-339.597547,-230.238817,-137.097565,-50.855296,-80.944419,-167.813832,-185.470691,-185.236685,-90.669526,-34.05921,-53.093116,-136.374938,-340.709717,-394.595131,-374.975711,-346.984257,-291.309948,-219.168261,-164.763686,-16.303536,34.696308,5.991312,-40.503431,-0.096008,175.424925,191.650335,103.004901,86.748113,138.275729,142.363116,33.602093,-26.372504,6.812082,120.015106,140.602132,138.478496,126.191157,109.981574,105.400389,56.247216,52.656759,111.877068,292.627432,343.80411,283.162358,207.943955,68.784209,38.923819,59.824257,88.17095,122.688473,203.400612,213.499834,170.264162,132.402101,124.556416,174.713129,157.153058,155.466287,211.201932,209.651934,102.259817,-45.653734,-10.671191,83.690299,61.483874,48.253227,52.232476,55.13329,51.920631,46.523563,40.252078,89.416263,113.835921,151.599202,192.80335,249.478509,217.360975,113.207622,111.718715,235.122925,369.071872,404.884373,495.18853,559.415859,590.785078,521.087901,355.698648,372.201204,425.776707,562.236728,619.104731,570.364231,480.116045,361.993633,372.442251,420.661187,379.019994,368.354482,368.263735,333.868454,256.850918,261.558449,264.98592,185.584883,181.201048,311.449698,392.441197,411.147482,354.367577,205.382381,132.131987,93.597483,292.17879,404.574653,459.554849,419.984431,337.974711,273.78806,79.671165,73.94496,147.817096,230.387837,221.89198,204.23094,225.550639,283.800091,267.553351,158.442421,158.925775,243.015672,415.19898,403.184423,199.817708,106.205707,97.186743,193.772258,226.23795,312.176048,353.833607,359.18801,337.266922,264.968028,215.218487,174.089186,198.698136,218.3401,282.021679,291.244819,209.564463,149.952676,76.690171,100.155004,150.785462,279.585109,307.197101,259.319859,229.406486,152.563086,77.406883,-32.112358,54.077516,127.703652,235.502561,241.005975,113.517105,19.169992,-79.437175,-87.646512,-106.124064,-63.717656,17.371452,82.929125,26.056388,-107.30111,-154.115596,-251.232517,-300.884991,-260.932101,-123.37121,-112.024389,-277.561888,-407.296295,-559.126694,-469.266436,-393.939126,-288.704491,-264.917936,-253.716319,-258.834645,-320.928345,-370.292404:-17.150817,218.06637,248.850982,127.786702,49.541879,-83.353616,-147.573551,-173.813184,-41.338816,13.628415,51.38117,37.084998,-56.553952,-110.611396,-216.123436,-271.144187,-322.221099,-270.510891,-235.449328,-212.811494,-242.623148,-372.802732,-431.825979,-430.221437,-309.372133,-242.252467,-100.817802,-58.958893,-92.317432,-123.252064,-167.398396,-189.042663,-152.053053,-36.440344,9.022859,85.593716,85.232695,-85.490741,-191.212937,-225.117921,-119.50819,-92.879007,-59.637565,-46.102769,-77.342178,-92.046474,-41.696224,-5.880421,26.937426,13.232381,6.976643,35.030948,61.114965,128.713238,166.433726,250.62762,295.161681,282.203547,266.80922,275.917706,250.790036,213.441249,147.943522,127.641377,72.566414,-7.502848,9.922608,135.113473,159.00333,109.20348,70.328118,10.06275,67.950996,139.037185,235.982409,216.181115,20.993488,-105.121586,-272.451712,-287.194711,-182.111321,-54.919445,-22.147554,13.250948,23.952497,53.163961,71.299226,88.306594,95.519596,93.964753,80.02119,58.001607,-30.97891,-73.924014,-112.899951,-100.179174,-62.281091,-51.509382,-23.40137,25.544018,19.717098,4.84314,-15.242117,-99.785226,-104.360068,-81.389963,-89.509783,-130.341257,-190.037372,-172.040832,-127.05232,-137.751059,-190.521164,-151.243882,-104.362462,-110.458177,-163.38604,-251.391597,-277.469452,-278.461396,-168.498854,-96.833454,21.18371,30.207741,-131.604444,-250.493969,-324.615483,-260.286488,-97.701485,-101.39052,-171.804024,-301.048862,-312.010548,-299.640338,-315.890052,-314.301854,-236.631565,-240.265463,-320.698725,-345.046175,-327.794914,-311.673929,-301.039808,-286.606877,-286.448403,-328.030071,-291.555236,-191.56413,-180.428673,-193.260193,-216.271424,-278.979986,-228.187588,-185.566292,-200.116973,-244.275069,-316.383073,-336.319918,-397.526098,-438.545059,-436.255343,-288.870232,-194.29238,-95.270019,-121.519122,-235.670327,-273.429344,-281.592342,-306.362774,-341.551878,-329.488976,-258.037658,-135.072763,-149.253328,-234.56591,-208.005817,-4.604093,92.971801,75.660164,38.42966,20.273476,-52.41605,-115.117353,-264.53207,-308.030503,-280.447533,-188.933272,-153.527116,-161.286963,-197.630066,-342.142613,-450.456321,-586.423374,-486.862716,-393.875403,-325.105269,-381.900305,-525.435323,-556.9299,-539.82455,-510.199276,-518.266102,-502.174336,-435.058194,-213.19252,-118.337569,-76.095227,-127.351085,-207.700524,-110.814279,-40.152539,13.972086,-17.728096,-108.541641,-133.562125,-117.406333,-91.837113,-116.992373,-183.572105,-210.88619,-313.606066,-356.665571,-351.59913,-344.035471,-309.105196,-191.346311,-139.745798,-58.644421,-22.653798,3.765471,-8.167497,0.256924,82.619941,114.627396,150.937934,152.492543,114.84603,93.084137,51.98358,36.662168,90.108317,186.788362,184.656331,95.767164,57.755089,38.053034,28.312795,25.116893,170.198764,248.056716,293.319623,299.549634,295.322348,235.788924,63.434982,29.649917,59.839503,103.747225,131.727393,146.794036,121.129589,43.004951,11.438597,56.560988,177.364665,183.801905,114.380195,102.664105,195.517138,234.195128,171.943786,131.24666,172.171756,306.48583,350.532059,295.728752,224.110183,129.252501,104.88026,93.750559,249.291399,359.662742,426.971155,376.775148,286.20564,287.413788,276.319525,239.739179,296.977315,504.013449,555.615349,581.318651,592.856691,567.820416,514.232035,390.69347,317.955838,316.787361,459.386056,557.408906,542.996672,442.372973,314.346108,327.101886,370.432286,327.119118,326.230395,400.416173,415.782429,305.739335,216.6029,104.63189,138.400236,189.032519,288.73892,318.734816,291.693243,242.260887,106.029428,35.939767,-22.86128,94.171735,190.632256,283.55761,251.33021,165.407546,146.43274,102.491903,88.329935,138.883309,272.728313,267.822567,130.329249,100.439304,168.811181,206.951485,248.115948,265.874965,285.182951,325.440809,303.595096,197.763677,157.655181,124.378762,153.832137,202.929571,303.974637,315.652183,278.827871,248.59408,152.87052,116.543018,132.410548,132.231331,140.022398,259.494002,319.402018,267.482854,158.921978,-15.674896,58.428664,157.346361,329.52868,357.36909,309.378553,280.2855,185.018785,88.031805,-47.725019,111.09705,219.433947,275.348897,247.654354,149.323364,85.871044,27.889747,16.180465,-15.973029,-16.306571,26.876781,32.392026,-10.134045,-56.014489,-72.941817,-175.93468,-227.352794,-172.716518,-17.727787,3.899125,-128.389754,-242.323133,-367.197169,-301.688914,-253.351379,-227.213703,-268.744477,-364.680521,-347.503421,-235.328187,-220.378431:63.05812,161.019863,207.558924,267.579722,246.699152,84.248431,-11.455058,-111.35336,-38.99114,10.478877,36.807439,29.915996,-10.95742,-51.885018,-130.584361,-151.062349,-154.803041,-150.136717,-146.532745,-160.506524,-198.511246,-305.062056,-345.306897,-367.769684,-260.56854,-175.898308,-37.486628,9.605722,53.888521,43.061861,-36.645541,-70.271934,-55.151633,-11.690688,2.591125,16.782523,-5.085497,-129.330672,-215.029125,-335.213883,-340.768942,-329.95485,-250.986215,-192.062454,-153.571819,-155.792138,-111.010092,-80.668608,-46.771142,-42.894363,-34.970539,-5.015746,2.077521,52.017465,104.533829,204.306745,282.696288,306.788367,300.08865,286.238783,272.439187,254.672478,162.317805,111.07105,46.989987,4.019022,-3.581499,41.504767,75.787309,96.009008,78.304365,74.200048,186.703563,260.201497,353.646901,322.18983,73.897749,-68.271693,-204.716807,-199.24068,-156.709836,-147.012129,-127.08149,-54.874076,-33.371308,-10.010091,6.651742,75.252028,206.874677,253.299824,247.562987,196.775487,14.591977,-75.380172,-155.642224,-149.386561,-128.348529,-177.145636,-206.346152,-193.79713,-162.655695,-141.390338,-178.876533,-285.683111,-254.762984,-213.142148,-200.686213,-207.873745,-177.533776,-170.220055,-263.492811,-356.313409,-511.609111,-437.16853,-315.263695,-92.802412,-61.518782,-158.611044,-233.058301,-268.662043,-99.997301,-13.308744,82.201734,107.922505,91.382182,45.990016,-39.465019,-57.200991,-51.105943,-80.677307,-129.934504,-225.706914,-248.897937,-259.55804,-264.642217,-272.239254,-200.924252,-162.967208,-186.602126,-241.972106,-308.305917,-268.448111,-128.178153,-114.687785,-250.676653,-373.879111,-339.194841,-167.038415,-127.481829,-162.84034,-175.378411,-155.792622,-163.207805,-190.242828,-259.743749,-271.388055,-246.35215,-237.88837,-277.47584,-318.853844,-359.855627,-310.388356,-267.524057,-179.285557,-164.140819,-227.807914,-278.945882,-329.560807,-286.965608,-267.066082,-241.345204,-203.370044,-106.53029,-78.890037,-77.576185,-83.534741,20.779528,222.68716,264.243381,265.868698,276.955343,267.186994,194.57119,-40.27382,-110.511405,-58.593965,70.013709,88.070313,-2.725877,-73.849665,-228.774741,-319.237376,-419.769566,-340.903278,-275.30785,-222.081952,-277.058897,-454.655963,-497.205336,-472.567748,-405.267569,-368.488864,-310.511618,-288.789758,-240.914499,-215.100211,-191.976941,-197.868924,-171.918635,-22.883918,50.998528,48.237455,-1.578966,-68.770696,-104.4531,-173.355627,-74.954109,-9.747828,24.052871,5.718693,-110.257543,-199.950384,-347.41933,-377.841232,-318.309227,-202.38806,-164.18228,-67.600306,-8.929365,40.218726,25.883648,39.362037,133.207573,149.658317,147.376098,164.089038,213.634874,230.17084,196.013925,140.304339,87.518652,148.00365,186.590249,277.260202,294.959024,229.084086,179.125326,98.505362,107.304691,159.877281,312.650849,375.157182,364.584545,292.037714,119.730398,61.403393,-0.601454,-13.718952,27.356242,130.641205,132.980896,38.518276,-18.561709,-25.790191,97.443288,115.7498,44.553882,25.172834,66.155199,86.805965,61.098061,14.380392,-49.156217,45.068884,105.459881,81.708206,13.269685,-53.074027,-45.974582,-65.520567,-18.674039,68.313846,221.272274,251.35679,240.8318,208.925683,132.5998,125.849935,236.166129,371.046615,406.546201,536.66779,629.117137,641.089725,525.352928,288.401278,302.289974,368.497074,495.966014,535.97586,522.306124,473.156842,351.922664,315.649208,328.253785,410.890855,467.023621,514.428742,472.409864,320.273085,243.118363,125.419571,117.321713,133.9596,140.554991,142.83526,130.742244,92.88767,-52.098163,-118.078335,-106.456947,48.496949,116.091706,157.720461,154.371211,139.67376,78.012722,-117.730325,-95.262722,-19.594626,76.758126,84.861669,17.268908,-32.751381,-37.027125,9.179297,72.791163,40.68891,38.782891,113.482779,151.273873,140.308546,91.904294,2.15383,65.388841,151.029278,344.614065,409.571137,396.135639,340.656073,222.279493,171.308488,125.882354,157.656399,197.665626,296.011911,306.995532,195.736873,101.536175,-34.408809,31.615752,120.869635,291.320278,328.736494,288.459996,251.659987,163.574486,107.951674,85.186276,200.878792,249.018098,348.863238,388.43152,249.273825,98.696255,-51.282408,19.199893,42.744299,42.684378,47.427502,59.903887,58.159671,9.992339,-57.974832,-201.576309,-225.037364,-187.401859,-73.26691,-60.311627,-209.673156,-328.726626,-468.305725,-405.323952,-350.257722,-252.662417,-213.666254,-189.922116,-192.678246,-228.296501,-280.355078:-69.499422,71.047413,115.565473,115.967044,88.02845,-9.683046,-84.710162,-191.920026,-126.095985,-55.779238,67.910489,89.521753,-3.513684,-80.331757,-172.593838,-206.842448,-268.21409,-192.310212,-122.988529,-110.907436,-179.765446,-308.068561,-334.47776,-331.282243,-223.486681,-131.122661,56.200619,93.186446,4.234879,-58.234167,-112.033624,-111.557079,-102.356849,-93.241416,-57.31782,56.006137,49.178081,-193.720989,-324.412221,-343.105038,-242.685631,-244.28652,-264.986605,-255.793413,-201.853766,-150.617772,-84.056108,-105.414358,-134.230831,-27.410044,16.739435,4.857422,-26.492262,-52.537201,-30.19926,72.961849,150.909856,164.2934,204.125319,229.566243,204.436605,133.627788,-46.206417,-88.288267,-61.705911,-16.367913,25.682462,88.638857,78.952458,62.201364,60.448118,11.303129,6.633385,66.795143,212.781081,199.35457,-86.423557,-258.297213,-396.812867,-356.22369,-180.004963,-45.001875,-21.809775,-33.463379,-27.685949,17.93239,22.132383,26.662826,105.978173,139.536674,185.751032,184.785739,29.289908,-91.413783,-236.211202,-240.84767,-214.561665,-180.333608,-131.66787,-76.844597,-108.432693,-173.150318,-170.961729,-148.567819,-166.886202,-175.531485,-133.718781,-108.407048,-118.083724,-141.827724,-207.138202,-240.229288,-260.413688,-180.913201,-125.164348,-95.241024,-120.546528,-149.235355,-158.740212,-187.485298,-112.486955,-31.206883,113.666841,135.396993,36.643596,-64.285939,-238.370884,-260.996493,-157.466972,-89.798297,-138.771985,-275.554835,-317.228497,-384.009823,-420.282133,-430.705693,-362.536804,-349.956273,-340.620303,-328.049707,-327.080468,-338.439284,-349.303707,-329.082498,-282.877276,-293.216806,-268.570009,-207.153728,-229.159482,-322.168156,-354.336795,-387.616853,-348.125912,-302.868321,-227.254145,-203.68233,-205.691299,-246.307827,-389.756765,-449.352769,-424.314713,-228.509313,-124.600957,-55.796835,-119.910773,-315.750321,-380.246363,-387.852646,-312.279851,-278.165517,-187.066506,-136.862482,-101.086423,-111.556302,-119.036172,-89.467164,60.80729,217.484573,249.034547,276.488817,270.701824,109.725099,-25.301585,-201.438924,-154.87496,-117.100826,-105.09033,-110.560081,-95.154829,-93.099871,-226.926257,-350.011971,-506.395814,-458.161285,-387.446521,-292.659211,-316.174023,-451.517112,-507.560496,-482.462094,-324.908695,-270.635719,-222.025851,-192.63547,-90.79394,-40.201574,-55.045736,-111.486972,-146.511285,-44.506681,10.763326,25.321715,-27.569104,-114.628805,-106.233068,-65.888947,-66.662561,-60.372507,12.533624,31.213122,-124.352182,-248.843401,-364.085894,-343.909243,-266.705402,-203.880545,-138.40584,38.884824,89.035556,20.790542,-70.627551,-154.121321,28.017428,134.744008,240.256515,239.410997,146.612943,92.321655,72.41395,113.538502,238.62606,326.292354,368.802769,424.56694,391.821315,235.141302,189.586161,256.940888,307.744625,292.426472,330.753417,380.614457,359.789646,259.109117,35.175202,-9.827087,21.623884,84.507768,114.35584,130.456133,106.203319,47.566612,32.724784,56.251892,155.749532,190.576278,140.764814,87.996929,88.666962,130.75033,142.402689,117.141263,118.085339,214.364471,263.135379,255.036036,196.965948,104.446816,98.645981,127.14533,210.903454,283.953296,437.449931,467.152732,374.471971,287.818137,141.952614,119.672414,262.095904,496.806866,547.520765,523.493779,507.680149,496.01686,471.887624,412.728341,364.758123,348.52571,446.171429,539.413367,542.317421,439.792736,274.597898,267.061576,323.870421,375.860616,420.680129,499.830834,484.32385,330.393126,222.771005,77.909589,127.787076,179.374075,212.480553,196.485978,147.092135,105.496294,-52.281516,-119.601842,-74.240833,123.574185,205.061792,211.840126,156.124509,68.503109,24.15034,-73.154859,51.667756,203.51177,393.858288,347.925919,101.372716,20.390544,51.682214,113.44689,219.23797,293.457811,311.063486,317.487353,319.745432,276.479492,208.788641,125.057809,257.760032,340.469498,424.261628,407.418328,276.85735,224.316451,187.56734,176.606266,182.337382,243.706709,274.32997,251.76159,187.00142,19.704471,-55.236466,-116.582554,40.723061,165.146057,320.86186,315.910559,218.309744,185.341697,119.670481,59.771562,15.724762,180.627105,260.930186,281.201119,254.034306,169.66803,110.498599,21.215567,-24.480502,-37.391451,-0.592259,36.57473,55.409563,14.979393,-117.231781,-161.987266,-165.737515,-136.605576,-115.100638,-87.65216,-123.184058,-269.889175,-343.483893,-440.309485,-434.855218,-391.196586,-283.977201,-275.66777,-357.908127,-383.828155,-337.089658,-297.063002:-30.797205,124.844563,189.512982,235.072863,208.65107,60.900724,-29.672281,-134.890368,-42.834124,12.727384,-15.541,-66.419956,-130.542048,-132.041253,-93.108565,-78.691053,-93.538616,-65.284487,-23.156306,19.504003,-6.892593,-120.685146,-161.047735,-148.906572,-82.474554,-49.467297,39.921659,84.011274,114.228153,119.295089,116.185256,90.320894,51.152857,44.722375,13.582856,-120.621397,-201.492777,-332.778531,-372.461142,-410.013329,-358.230132,-286.066329,-160.928111,-165.490544,-267.999937,-285.330161,-224.348055,-203.081675,-151.880474,-46.177574,-5.359891,58.371938,68.782369,40.748756,29.303391,64.909269,204.096965,278.807676,322.093738,278.827779,119.447337,45.402147,-37.931389,-50.110934,-30.979123,-15.395292,-4.489271,53.283318,91.948425,144.138963,151.850674,177.945027,262.184944,311.716392,406.230733,415.511301,278.817523,180.214846,76.643098,70.284999,97.006159,80.584718,34.342965,-33.610802,-30.751955,-3.64977,0.183728,18.255988,114.709818,160.859302,149.53998,104.992573,18.064063,-6.396551,-46.119472,-79.536563,-159.137573,-225.363331,-232.280572,-197.588268,-202.856403,-289.637788,-325.604686,-315.471297,-259.028122,-258.363788,-297.260221,-301.251906,-278.844638,-278.833903,-346.80088,-411.184694,-522.920882,-504.346938,-426.586655,-209.555531,-159.431635,-246.860167,-303.891444,-258.879146,-34.895697,60.937455,140.495647,151.035571,168.826121,177.51556,141.346887,89.50554,20.084517,-34.525679,-100.849051,-199.188377,-182.029742,-90.906084,-64.304067,-28.988888,30.415441,42.122024,27.114852,12.062715,-20.49353,-17.205916,33.767802,52.800043,27.199356,-64.525481,-88.161175,-49.799911,-30.948672,-84.749258,-137.062775,-210.03825,-209.472579,-198.060821,-206.604972,-217.39246,-222.79121,-228.273984,-289.61812,-338.543221,-398.332596,-378.057107,-343.702239,-291.492267,-306.050315,-334.532175,-294.799426,-178.567081,-205.286527,-251.933723,-268.835172,-219.527498,-113.100868,-118.086201,-227.554158,-256.596092,-132.468359,60.811616,110.147491,159.038546,156.799792,88.865933,50.647736,-23.318737,-39.63279,-7.37014,39.750028,24.273728,-67.277119,-118.825028,-210.917035,-233.454481,-171.821564,-110.304066,-111.194617,-103.845765,-118.557268,-215.785227,-266.484243,-354.641192,-402.631953,-396.766031,-332.046976,-296.051433,-266.793148,-241.390678,-128.8355,-92.75955,-63.615932,9.653234,21.885743,-11.238105,-14.626845,22.050624,26.265418,-7.467109,52.841605,123.373893,232.754946,227.813032,54.533328,-63.37668,-229.929335,-278.227008,-296.154802,-263.708404,-247.326734,-120.210153,-18.019073,69.369346,17.696955,-82.133644,27.633141,76.123298,56.305416,65.407638,189.436391,232.878521,138.127125,49.365652,65.697389,266.855634,312.753576,298.572228,296.745443,304.708581,265.903512,121.862345,74.111194,107.189916,237.754839,287.796523,238.754261,157.203714,26.488078,-12.689488,-100.340448,-109.863461,-37.580329,124.728161,147.04081,112.809454,75.975853,-16.792317,-61.341775,-78.403335,-110.508316,-99.848356,-68.938533,-84.608177,-131.205062,-141.418161,-165.23725,-141.188061,-89.818184,-19.685159,-45.629777,-127.762333,-126.863361,-33.152613,91.553675,111.487593,72.106015,57.466824,14.407271,-33.32067,-65.129353,-1.222504,157.089063,172.795681,204.619671,427.908345,531.747248,529.719849,451.037525,330.956627,340.214164,337.760915,346.198103,397.62021,478.236279,465.084872,384.945901,347.651727,330.479657,381.039814,428.79165,493.246057,467.516145,388.51168,377.277313,335.625016,212.252931,164.468856,154.608282,167.067871,147.434817,98.511682,-84.120201,-166.136832,-119.046253,154.162128,268.10394,314.158796,267.772525,159.34571,110.15545,24.905019,60.382176,118.15463,170.920896,122.042043,-53.460454,-86.866976,0.430688,51.397994,62.287863,8.779999,11.863455,109.194226,156.791208,149.001661,104.266068,55.087659,130.280651,183.777368,311.996321,389.431375,491.279845,468.515697,252.557503,142.904117,167.381025,357.584589,407.329995,393.380085,318.136981,73.362233,-21.963084,-41.394595,84.123275,141.821186,207.595862,220.081626,171.82287,118.719231,58.534616,71.693685,155.257505,200.93067,204.814783,230.357147,234.661239,167.588694,102.95041,11.52549,29.284025,42.502595,37.471615,21.186823,-38.359978,-57.811535,-84.118932,-118.987882,-185.765117,-193.134224,-186.001499,-181.20391,-204.750865,-314.150662,-370.403055,-434.489209,-414.140647,-356.298101,-211.341811,-178.442514,-212.883228,-226.352538,-179.625852,-166.876771:-157.742954,68.281771,153.556062,187.443048,156.304136,23.679133,-79.115382,-251.945221,-215.920823,-141.742634,-4.295825,23.168885,-79.796792,-174.648133,-257.541106,-243.077828,-201.994436,-133.583379,-82.8687,-51.077917,-92.237644,-193.915802,-218.228419,-219.31171,-162.47197,-107.968396,-0.376414,32.919948,57.996692,47.222743,-40.148402,-96.495953,-117.765743,-37.543394,-8.362172,-15.140974,-55.300365,-222.274249,-335.030598,-494.429734,-423.492001,-324.581067,-162.240814,-151.335615,-258.057799,-305.490102,-310.588123,-297.684879,-232.991168,-72.644477,-1.849658,-3.424718,-46.912128,-52.772016,-13.405754,79.519364,216.422372,282.710289,299.967117,252.113825,138.777844,95.647924,25.242252,11.197832,72.593083,109.656853,92.281217,88.237085,116.766982,164.719886,159.889052,128.671956,141.110752,176.087781,296.270683,339.777908,246.285166,114.662049,-124.318052,-160.929589,-99.603838,-50.180506,-35.342702,-38.303649,-70.807098,-128.090128,-122.483316,-28.426957,133.900282,189.476857,186.946625,141.819359,14.146251,-54.625552,-188.160749,-238.538719,-279.609901,-245.356491,-196.986216,-124.630165,-134.926613,-189.448527,-226.417276,-329.062472,-303.530261,-226.497577,-93.511017,-80.958522,-107.382135,-117.939882,-190.918792,-262.582917,-355.083913,-225.198882,-89.218345,114.973451,102.414841,-111.539151,-225.033593,-260.895212,16.123038,157.959182,225.61246,186.059725,111.356701,77.997803,-42.125008,-112.451772,-146.380034,-121.911688,-165.316578,-278.518846,-291.992195,-278.385253,-297.060092,-332.518996,-193.171586,-89.761453,-5.364548,-45.099303,-136.631851,-139.942268,-153.682348,-202.736353,-281.445639,-194.683411,-107.412852,1.203282,-26.816426,-174.742582,-223.731986,-214.020107,-167.881229,-166.592401,-175.007813,-159.892122,-145.500102,-181.883916,-306.323578,-355.488951,-383.704107,-341.316508,-311.493482,-296.308057,-320.863482,-378.011088,-394.55558,-402.005321,-361.053608,-317.603586,-186.806101,-126.387598,-96.592446,-105.466757,-94.633656,-79.940272,7.1744,184.995116,247.822643,283.254133,283.955508,218.446696,121.21922,-63.24717,1.157974,86.884456,201.907328,190.944269,25.405171,-68.039073,-177.645749,-216.872947,-268.421489,-242.71669,-221.562523,-206.571924,-212.386507,-228.48187,-241.101386,-287.435431,-321.257852,-307.741207,-190.420166,-132.917214,-133.043289,-148.414397,-102.494451,-64.880907,3.977553,72.287497,94.454435,83.194383,44.789027,-47.093974,-80.388698,-93.20919,-31.058368,9.966274,88.024472,108.270402,35.38592,-55.402362,-271.26557,-365.906185,-436.551224,-335.388691,-247.504512,-78.665292,-37.743539,-70.621752,-121.491687,-154.966912,-27.274829,44.533828,220.51834,323.616971,362.523754,279.24102,71.705538,33.368759,188.286551,397.860084,453.443363,482.050685,445.770474,297.399338,222.309294,175.768942,259.406559,295.766441,351.364461,380.372177,334.53865,231.499333,8.37601,-40.163013,-11.671305,69.786375,113.610673,150.237912,118.888149,12.182361,-28.208098,-44.053581,30.588553,69.958044,103.659163,103.415455,89.678774,74.32544,11.046866,-11.444109,22.503343,80.16097,98.145973,114.527939,96.929907,24.930963,-1.427132,0.978506,112.280687,197.220321,316.610063,302.437625,142.069763,72.670521,38.270629,58.550859,160.517703,253.221718,306.883844,476.860119,529.968238,444.208414,350.264019,233.679298,223.002744,236.399154,352.100223,433.790866,451.001218,379.525586,229.106308,204.502374,273.279369,350.222458,383.650405,432.503282,404.030449,273.310892,223.186906,173.111946,158.883228,154.096865,163.147857,181.518177,170.891398,110.95952,-103.820978,-193.296417,-167.371827,55.556228,153.378617,208.879462,172.954828,48.498968,-38.145507,-167.646908,-11.91488,123.706473,247.191228,204.201255,31.114546,-25.369413,-47.610391,-40.864794,25.718549,140.590988,182.591062,231.151554,240.255372,213.552716,180.661491,131.863993,179.296273,250.476328,446.068274,495.418768,400.621882,320.244494,207.791608,177.756206,209.674997,341.443693,400.103205,371.057416,271.258312,51.148215,-35.260253,-133.648443,-24.32087,82.17173,265.489297,316.76888,267.021545,170.06705,-25.376942,-68.478696,-12.868461,102.634648,144.081545,239.508171,278.972786,220.178312,130.153206,8.841592,31.624841,35.093223,10.223353,14.020763,16.340259,-12.166801,-141.145139,-213.354998,-212.670763,-68.614434,-40.451514,-131.155045,-209.562041,-345.020517,-403.761251,-493.851063,-478.339377,-415.906146,-253.42019,-217.370202,-273.089069,-304.345303,-282.161791,-251.77948:-183.466996,-49.98742,51.782176,201.281047,214.114696,132.300199,68.93965,-62.111547,-92.646147,-76.446796,-125.323329,-173.928014,-166.091447,-114.712441,-5.063375,35.833489,72.237028,90.728893,108.819082,113.841619,83.307733,33.292287,53.662906,105.387576,23.629003,-18.252358,59.580272,141.518362,192.453953,172.238667,142.169183,113.227139,53.858201,60.707195,25.839309,-161.519076,-271.660873,-388.774244,-355.274733,-210.233312,-141.579074,-124.640661,-100.157643,-102.54743,-102.654786,-76.582931,-26.867836,-34.150368,-39.448725,78.25463,137.120781,149.291841,125.172614,146.204394,188.81291,215.04916,201.101577,207.047976,186.808173,145.616192,21.289572,-25.676086,-19.88043,9.744103,11.130544,-54.816633,-61.260888,-14.690769,5.189549,51.020859,113.342079,264.004559,286.16517,262.670027,280.898873,330.201812,366.975194,330.09581,302.608111,342.447007,386.159777,248.65917,161.838617,65.870091,44.479813,53.793284,85.7122,84.777741,5.239871,6.812698,86.478814,119.102483,138.551991,150.126672,176.527914,161.688991,83.431117,52.643197,80.153089,139.185925,121.195662,41.2589,13.411367,-51.647559,-69.877568,-44.070395,-31.819878,-53.963792,-56.355019,-28.548444,-32.96981,-95.725962,-207.429661,-126.475811,-45.297852,33.743408,-6.112738,-139.849853,-163.61048,-76.114844,118.187878,192.161399,232.82882,236.572932,283.924087,308.330586,312.60696,302.755038,278.829828,208.133778,149.578907,34.595832,-1.991234,2.528509,46.051205,183.519669,276.706864,262.608774,194.055134,201.206319,286.232909,328.729032,352.074385,333.95205,324.21735,327.745237,329.833533,385.181367,395.256618,296.928126,229.977378,121.767389,32.674218,27.213086,76.575307,74.578664,7.120968,-12.007456,-39.175357,-90.075516,-245.310136,-324.595593,-308.512213,-207.002954,-157.420599,-73.810226,-28.750834,-0.600757,-77.368364,-103.463004,-133.624543,-166.795933,-240.527587,-247.758221,-244.277879,-270.00692,-297.076887,-163.16004,-70.100509,18.122085,-4.206867,-67.977598,-77.261077,-81.910405,-32.280661,13.210573,1.512799,-74.933732,-205.694133,-208.987275,-167.946907,-150.929334,-65.383803,38.718042,63.427674,112.174883,126.119695,57.105184,3.280352,-24.37611,12.070428,7.409362,-39.226358,-68.953923,-162.080459,-193.666324,-124.133064,-57.693845,20.592284,9.355724,-12.815072,15.076137,60.543669,127.830966,152.376444,158.04896,139.082502,164.977646,215.166936,191.607398,58.651647,-18.629201,-205.207687,-312.664954,-404.65275,-367.228461,-363.65049,-266.830064,-150.095272,-17.575391,-70.333736,-232.340209,-213.718584,-155.461049,-57.070537,-33.77727,10.027705,26.902433,-57.802696,-142.003074,-173.865005,-45.710283,-15.996951,-3.429238,21.090548,57.08336,29.402714,-54.657399,-59.515093,-64.543664,-82.64584,-72.598116,-88.967983,-143.585,-290.869346,-356.801118,-437.82854,-376.745329,-297.88052,-181.738335,-163.7919,-147.854292,-162.854951,-233.314476,-267.777212,-278.284226,-249.230806,-203.11087,-178.378791,-222.830313,-318.065929,-336.689074,-342.807907,-332.269718,-294.158245,-204.384242,-206.904419,-250.035553,-234.556014,-160.15154,-102.947677,-102.503593,-164.915891,-195.533782,-268.543938,-330.519766,-425.44513,-412.191663,-280.961085,-180.510947,-151.481982,-43.085344,24.242604,60.334175,8.171141,-135.533668,-139.675486,-84.797739,21.885397,51.956368,54.878048,33.611314,17.5185,40.433091,105.021819,122.275061,109.467547,89.068255,100.459892,162.219795,171.697406,78.00431,7.975535,13.774752,21.074888,17.955803,-13.646891,-66.902006,-205.29976,-241.478455,-194.141651,-44.650527,11.247398,44.330431,50.060124,40.410551,5.924837,-56.823258,-13.869291,28.617698,44.395446,4.283989,-80.953141,-87.090777,-31.634563,-4.064814,11.523524,-29.511625,-58.472754,-56.491426,-26.61543,49.124197,91.923313,139.176553,75.272321,37.29968,86.067228,171.133393,279.370589,246.940574,92.113543,45.138517,112.363797,250.37615,280.561889,262.528464,202.937532,63.371912,40.964246,45.686235,85.122783,130.969388,248.710995,298.709522,329.895429,316.109309,250.447032,203.458294,185.74803,273.502362,292.350934,292.271548,302.027328,308.671045,271.542665,114.590306,1.635249,-16.464018,-34.845822,-49.879321,-64.912692,-40.11427,70.520822,118.395872,117.103394,43.082747,5.296264,-78.719199,-99.028987,-39.140859,-6.448738,-66.359287,-142.233873,-113.626949,34.056474,98.488822,133.292119,135.525333,169.143361,156.2358:-198.498037,-55.206846,50.793553,173.526098,172.17751,107.051674,76.508649,39.019453,-4.854691,-39.103386,-122.27609,-150.147997,-139.202878,-102.222018,-2.465283,42.74309,107.598635,135.373331,127.118884,60.419057,17.943955,-9.836054,12.086602,51.573882,59.932948,69.080303,110.974264,128.260592,97.365582,71.038417,62.982075,55.053771,-40.581974,-142.522223,-158.131201,-189.044988,-225.220014,-271.955615,-274.6508,-292.408171,-213.599585,-111.487511,63.98431,89.177824,31.915992,-9.189978,-29.117229,-11.321336,27.62167,71.404003,93.775935,132.781857,143.976019,146.490961,160.410489,191.529205,145.367756,120.567844,126.821172,160.562226,246.338976,258.697214,167.740775,92.17741,-8.307871,-24.106975,-6.884958,63.388478,104.421925,157.666765,163.597297,188.859752,262.530836,281.78347,290.835466,305.849148,332.244187,321.921844,261.486482,243.398808,306.669801,314.412245,247.248677,127.737972,119.899832,177.327055,206.05982,215.327368,229.559004,236.076312,214.978101,214.253057,253.056668,281.599033,300.911994,251.301152,98.477256,73.852707,115.621118,191.950826,160.480208,-46.932991,-149.630673,-239.045167,-230.782275,-221.241862,-186.208326,-168.62158,-163.518456,-166.282515,-201.8608,-255.59988,-367.490907,-339.058233,-291.654681,-248.324015,-240.585286,-189.767563,-167.75129,-127.661385,2.067389,77.694096,217.065594,278.388085,316.064678,304.37941,332.366402,369.214028,418.598771,362.012015,291.544638,204.670504,221.291759,258.361413,223.025115,138.96688,255.66561,319.795783,302.126272,277.368986,293.735189,320.230868,404.829759,438.357523,378.811899,255.939402,255.070326,300.43545,292.757583,277.034262,274.069785,153.403879,23.212712,25.339516,54.63581,56.161571,60.7201,57.654879,6.463038,-30.839802,-78.819022,-126.587998,-152.006008,-160.906037,-142.838738,-45.444184,13.78742,23.823102,-74.426644,-101.692037,-124.054211,-149.677912,-207.876436,-220.953342,-232.030812,-251.449553,-291.93241,-151.58028,-33.574792,82.436187,61.168513,-0.725648,-15.127292,-43.11222,-23.034328,-16.02455,-61.431571,-86.293263,-110.98969,-99.744716,-32.72468,-12.805166,15.518933,58.6284,49.802468,7.12177,-8.107204,-56.587215,-89.412386,-146.500839,-121.908036,-62.274014,52.257739,51.973894,-61.323455,-109.232842,-73.80904,-23.793834,33.185276,64.335121,92.976517,144.600281,149.451602,132.197881,124.944067,114.017209,133.503675,148.756627,123.375235,76.152665,-58.034738,-108.044293,-114.212152,-109.617698,-142.22413,-213.028754,-236.191591,-103.551521,16.072173,99.856495,33.666221,-152.713003,-155.562164,-108.318821,-62.766667,-42.964292,32.26158,43.17148,-32.927108,-72.984883,-62.879542,-43.131234,-69.350505,-77.320132,-36.745548,23.735043,9.255527,-90.775676,-151.432174,-132.838183,-37.361461,8.133575,34.068865,1.153693,-105.081608,-152.026674,-248.885013,-277.449073,-208.79222,-7.091261,56.49753,65.235116,16.335926,-113.80485,-198.166385,-216.215487,-141.533101,-65.928111,-46.090848,-127.824037,-317.878659,-373.844615,-409.915798,-356.717928,-295.244582,-209.835269,-231.031214,-284.315434,-251.442448,-162.290589,-181.678073,-197.675576,-139.348572,-92.97413,-188.29285,-308.201502,-366.886215,-273.859697,-84.734285,-119.562115,-131.507067,110.385194,274.885978,296.191192,163.672155,-47.309598,22.690119,116.086792,261.218666,276.277808,204.656874,167.939518,156.474495,162.397741,169.804175,176.162208,179.007502,178.238425,165.856504,137.43146,130.450568,97.270614,43.482435,27.753883,55.359131,87.989685,90.389831,57.381056,-5.072149,-21.389267,-8.400041,89.691036,170.821316,332.081344,357.944378,248.09446,151.036886,32.121959,52.345618,48.91643,-9.144343,-17.269185,18.668562,32.07706,6.988221,-31.424964,-78.519752,-55.527574,-53.165177,-39.670052,-5.194203,95.149093,124.914925,79.556964,4.297787,13.46631,149.953301,231.495111,274.060808,229.876037,94.808635,46.992018,69.566865,208.774878,297.817855,400.885545,345.771716,101.669386,24.264249,11.800115,79.328081,115.422525,120.092074,126.593948,248.736951,308.714971,250.836291,172.383228,132.259343,179.067329,175.421296,199.02764,238.539281,251.414029,189.108132,1.967666,-117.07894,-147.323713,-181.128884,-196.304404,-212.1298,-192.378278,-126.253991,-101.554413,-36.923608,-37.520975,-100.146079,-201.002181,-201.123564,-193.686322,-207.283708,-225.756144,-137.296963,-60.493955,66.704781,109.652007,153.899128,148.567503,90.637668,48.730009:-120.52259,71.713295,110.080093,72.13388,41.584854,-11.153163,-56.587597,-172.37229,-143.652167,-90.149322,-92.048307,-144.250889,-203.179124,-184.868049,-130.557508,-124.426329,-98.569918,-58.047515,-71.139352,-95.064848,-63.600246,11.687321,4.962022,-69.091119,-75.201457,-63.135817,-41.264381,4.601062,134.857825,170.394847,124.741364,50.580065,-46.369315,31.76621,66.210297,3.185833,-91.683837,-269.489059,-290.574075,-246.016753,-207.006878,-177.375497,-111.261159,-112.568325,-164.030936,-162.344408,-138.050608,-154.499712,-160.779708,-40.391797,34.082997,131.776443,139.484876,124.233144,115.480709,95.773646,141.248921,175.725623,204.4546,196.109476,136.857567,93.49067,17.620331,6.295588,35.788636,61.012037,87.612461,179.868978,191.231134,159.767043,193.953801,334.210622,347.153009,321.929283,381.309872,445.419488,424.416727,341.453217,204.90899,181.61808,212.657245,171.096293,106.650007,37.889688,29.597471,3.109964,0.063379,33.834911,49.626458,35.906737,30.569065,53.091671,94.48118,94.546364,54.200465,33.340302,25.69029,15.500097,15.034648,37.399266,27.141958,-46.578712,-72.96577,-67.202579,-28.63474,-26.857522,-48.475397,-34.115939,69.472973,105.831036,34.377732,-24.096574,-27.709105,53.118455,89.712429,133.91177,106.985789,-3.156007,-9.881222,84.87989,201.994533,254.953851,289.777924,270.274864,261.605305,272.907359,200.756411,111.67022,-18.073713,-34.6646,-49.597388,-114.104498,-141.117915,-134.928427,-100.205263,11.151406,138.784465,183.900699,212.898024,212.00015,205.714274,210.219119,231.494603,207.848188,73.569045,62.47788,147.972229,292.455295,260.777376,77.980521,30.39596,54.98381,14.202606,-25.786182,11.169357,58.399095,25.12279,-38.755516,-115.389805,-155.453887,-306.893372,-365.195474,-322.916604,-210.473545,-194.34088,-210.851035,-194.562259,-134.143106,-160.656396,-203.296345,-199.189146,-134.486362,-41.215821,-34.327494,-42.217521,-59.416199,-51.059747,122.592771,227.555862,299.706127,256.713582,182.132156,195.355636,226.109289,206.595458,211.429685,239.721945,222.041516,91.882271,35.701047,50.645792,81.200881,58.284159,46.784194,106.491405,203.699658,161.92397,-22.675553,-80.773396,-82.010104,-80.61379,-119.588247,-168.715284,-143.206126,-91.010059,-91.094528,-80.103371,-61.254435,-9.347213,7.140653,-12.851362,-39.41054,-22.652207,73.876418,124.424942,119.873277,28.462905,20.027132,102.027509,129.274031,38.655827,-48.144684,-227.250463,-315.039287,-374.416917,-254.130221,-197.210539,-143.714839,-136.44927,-139.129067,-144.875658,-136.655908,-38.719608,8.851023,27.365575,32.679098,80.546043,84.240299,-1.694272,-44.459151,6.003509,137.567978,156.941457,161.890964,191.406007,210.986026,154.609923,26.492157,63.740759,89.866871,94.639064,99.945551,39.194334,-49.742609,-209.866861,-242.038754,-237.521933,-173.589513,-142.708449,-130.977277,-143.474049,-151.115117,-151.45961,-174.34218,-203.718963,-226.789577,-257.356592,-224.89577,-115.296165,-110.713529,-213.548695,-268.189268,-258.067546,-143.732213,-104.918432,-72.770962,-88.823143,-154.148875,-163.772763,-121.642072,-51.373966,-32.587575,-32.432445,-64.428817,-213.696343,-278.83646,-309.350003,-302.741979,-264.960983,-166.771517,-104.658362,7.363383,45.481496,66.700922,53.776306,22.468327,-21.44354,-57.312045,-42.293058,47.515013,202.89118,193.609966,116.830045,103.049003,86.452508,87.689166,129.132893,228.636719,241.602902,184.710431,112.971189,-50.098652,10.935772,89.127022,127.317792,101.912634,33.631341,-17.769445,-128.22362,-157.925772,-141.921073,-49.261,-6.774217,22.496613,9.485321,-55.189371,-102.499993,-176.894678,-77.557299,-2.190795,36.219929,8.321112,-77.960353,-102.550887,-62.217176,-34.327583,-42.860272,-95.449679,-95.592843,0.893566,43.182994,-14.047611,-81.241476,-63.587624,179.655659,246.327735,177.117872,114.595323,81.97323,115.469201,150.063117,125.377782,119.918059,248.566783,298.513314,248.583629,173.880456,37.377848,-13.570315,-42.067578,55.50265,87.270884,100.634249,125.136398,186.247607,208.389818,205.877683,157.849144,68.738226,118.260941,151.251564,187.9902,203.569296,214.838662,184.492097,39.225229,-62.930333,-41.504755,73.239115,88.896003,16.59406,-5.889235,-34.477494,-63.498459,-57.937421,21.343419,45.928354,1.178754,-78.376735,-238.1018,-257.090667,-246.970684,-279.89073,-273.945464,-175.424971,-124.21617,-109.054333,-117.108218,-105.785941,-95.507237:left
-142.585345,-156.135243,-131.696741,-61.304499,-18.488869,36.486905,38.340076,99.39708,278.574033,354.647983,387.413974,360.600501,311.698797,297.548525,283.240599,259.407008,122.00918,7.892256,-14.189393,-25.638356,-1.389925,81.768161,119.720485,164.805556,84.573617,7.234333,-115.764046,-130.499738,-101.617541,-105.358766,-151.564218,-157.188972,-120.625102,-130.61951,-198.170862,-379.000243,-420.049478,-359.094872,-293.371906,-250.682707,-379.430492,-425.803963,-381.230326,-296.529625,-30.825244,109.674944,278.987792,308.133244,353.822745,340.753182,285.028597,223.039968,246.42375,286.182412,297.96475,381.435806,402.147789,344.714288,179.843886,108.53872,40.156659,60.52107,194.236238,255.911375,285.837971,273.942724,245.874855,131.363583,89.045494,84.143966,108.46317,212.423352,351.636573,358.623245,185.389762,83.798574,25.370456,42.378301,79.906367,96.809366,73.502095,-80.981132,-175.071347,-220.943304,-136.334157,91.963795,166.423513,243.044,265.803294,253.65612,203.824326,211.069557,346.00612,430.208199,559.427199,597.374472,574.24147,441.331236,357.161899,201.705003,154.953698,155.63899,209.695168,371.95473,403.997312,333.458599,109.198177,34.529131,65.205969,136.990023,267.201938,302.347059,295.986435,228.966604,219.437698,245.972058,220.52836,60.102609,11.946609,99.912589,240.634796,257.006017,151.41039,75.86911,47.940886,113.367222,254.715835,269.994365,261.928292,270.149001,256.152154,270.728507,325.921952,425.759864,434.002416,417.061849,422.996881,410.30361,315.161719,265.473052,211.536967,201.410903,279.351799,376.207666,502.266674,402.16615,344.065258,397.100292,497.419769,666.818267,691.872621,639.592836,530.909733,490.188552,404.441742,360.877745,371.113691,401.6427,360.87258,296.732762,219.622333,269.604119,287.45465,222.800013,164.874586,66.312603,52.222635,106.900222,123.325493,93.78266,0.861768,-61.241016,-172.750971,-181.800643,-70.024641,1.251389,26.297681,-88.13507,-165.355775,-252.724606,-231.474317,-129.193715,-79.726897,-21.613771,-90.589924,-164.906951,-287.687457,-299.374125,-230.157221,-175.332019,-62.136752,-9.417383,63.14003,64.933665,59.683549,88.147113,121.286739,188.636508,213.572772,227.590114,164.779186,116.616751,8.618994,-27.393111,-4.76175,39.645673,128.068495,152.347304,164.176292,148.799172,97.437063,-66.965746,-102.883094,-29.116229,25.451312,70.863269,15.925991,-29.950844,-120.033204,-136.92119,-83.962649,-54.521315,-47.108492,-54.96458,-109.683623,-219.412981,-251.03506,-237.639278,-225.785429,-238.801412,-267.737294,-392.36036,-468.266152,-461.412076,-543.541127,-631.907965,-642.650116,-535.442939,-309.693529,-266.565775,-325.078727,-424.773089,-437.609307,-345.308797,-273.19348,-192.281391,-163.932911,-60.992524,44.378092,85.665141,71.05241,-0.247624,-114.07485,-93.273268,23.432034,38.713211,-42.309976,-46.791441,8.177944,76.287944,52.442637,-15.392124,-12.616472,20.977609,-29.180045,-76.578425,-180.047804,-219.186535,-157.765151,-56.548224,82.206432,59.322264,-95.421115,-161.832412,-169.998839,-203.954042,-180.392977,-62.460182,-37.225281,-56.445269,9.379699,80.107836,167.918819,161.432826,118.600385,101.72325,72.794173,64.20523,46.777895,-63.575054,-167.752184,-290.405471,-250.400198,-88.200864,-33.910066,14.559113,19.002311,1.858609,-67.700004,-107.381604,-164.943692,-185.083873,-171.336545,-131.423444,-102.036333,-200.246125,-254.859481,-263.709866,-215.447098,-112.59596,-67.6534,18.033658,-82.655531,-204.288799,-358.485061,-347.307196,-234.822447,-187.798913,-108.054883,-49.692612,18.627131,-47.423781,-91.544101,-116.697809,-92.024836,-46.081237,-54.152731,-135.244748,-248.694235,-285.073131,-301.980694,-291.000198,-244.10787,-221.680932,-177.82693,-152.485058,-164.899707,-313.071656,-390.172574,-403.508368,-332.242486,-146.503253,-76.990523,-39.498015,-151.334387,-206.62878,-193.090697,-153.103277,-122.488575,-134.177312,-123.171666,-92.977869,-95.206188,-223.944134,-303.134996,-392.644712,-355.635847,-186.471159,-139.009127,-135.427786,-114.937044,-114.641686,-195.099406,-230.883654,-158.013643,-77.485071,9.489958,-4.498014,-105.180643,-220.043384,-261.749353,-293.088387,-272.725606,-142.944512,-60.913783,-4.379406,-92.863727,-116.349097,-140.211155,-173.008654,-230.34877,-234.779685,-152.977729,-72.726792,59.932451,31.96147,-52.45496,-235.447943,-270.221518,-213.716988,-144.500889,-24.852455,-88.940917,-168.59703,-279.58192,-279.745356,-193.408758,-150.900365,-106.070005,-81.061397:-299.840154,-374.059785,-372.050824,-287.315372,-199.366841,-6.219665,56.193618,108.471167,190.988678,266.775615,359.018056,342.922113,258.015468,219.336966,179.972796,174.761194,111.305736,-85.328014,-171.050534,-95.61082,60.952114,294.951295,298.380385,200.915075,58.315821,-4.351518,-25.05305,4.79916,62.562106,77.870567,93.639867,85.245208,23.719641,-46.220043,-91.297656,-201.527396,-244.033063,-287.230361,-298.501261,-344.849958,-396.543401,-387.124477,-306.230656,-244.643862,-52.242132,59.006012,218.335412,273.085863,356.965636,387.481279,397.554691,417.124696,410.360727,393.095451,408.019771,418.939941,346.88681,292.699666,118.39477,15.936823,-65.082538,-24.367028,135.362546,208.468195,282.076843,271.089909,216.572367,64.575154,58.538198,227.19515,297.325137,260.115419,199.759449,194.306164,112.518419,57.515961,61.670883,107.000562,159.94079,146.644858,28.505317,-139.118083,-180.14097,-124.483838,-44.488146,169.81244,276.923026,419.708543,428.597484,397.965891,366.5706,395.04289,503.743773,548.723829,619.082399,636.348764,514.83729,260.40423,164.500091,113.536383,127.951948,126.493082,144.599103,245.913781,219.642046,142.977327,-29.292647,-76.459814,-11.189582,76.114975,232.908029,274.300539,287.285208,240.192636,219.399311,222.501992,217.267173,116.852497,47.342743,35.469465,192.757526,225.542079,115.24066,47.406102,74.100482,183.430679,405.077686,425.816501,380.328157,399.921331,379.790074,334.434911,395.253298,591.696264,636.085682,588.743084,406.614483,287.873673,91.054507,43.902274,71.652623,131.75742,304.183415,394.663681,446.051332,269.910553,198.329325,274.031001,397.716538,600.044586,623.899653,603.812481,621.563862,610.404622,477.187306,424.334458,512.242258,589.573194,593.816835,534.270789,463.603102,463.541135,428.968532,356.603695,358.961044,341.932705,296.727399,265.957167,386.154805,418.989244,289.820987,175.556836,38.845779,44.233763,121.909322,137.793138,64.230243,-55.838722,-74.724588,-2.92408,37.796441,43.219042,32.653685,66.310059,70.254426,21.834803,-54.133116,-29.47046,59.487726,73.319904,94.216833,131.354515,225.323008,224.475632,181.369583,155.76601,188.298586,202.069467,155.42306,49.977065,17.173781,14.831399,-10.017534,-30.293303,-73.459439,-91.00862,-54.115312,-11.919628,7.210808,-48.982691,-92.121032,-192.400956,-210.490567,-167.40489,-147.830277,-152.767974,-153.460416,-141.859632,-140.071665,-138.825402,-114.383696,-113.560897,-106.746031,-92.508715,-128.524168,-262.958135,-324.903585,-335.384485,-288.038877,-246.634945,-292.618516,-459.449344,-565.647103,-577.419089,-615.663858,-647.590103,-661.760438,-626.174948,-486.233771,-417.015126,-366.167445,-402.41331,-421.047665,-375.037629,-291.392805,-123.832225,-98.279267,-121.300017,-56.164484,30.770282,202.81452,233.222581,172.733476,140.194262,147.259246,135.854896,42.006883,87.508762,178.582449,254.736454,194.432278,70.076472,65.825909,55.239965,-35.146957,-74.046937,-149.452789,-178.876384,-121.793853,-49.611346,33.356776,29.613472,-38.358542,-141.470325,-173.414693,-176.186511,-153.098447,-51.452422,-9.813882,-77.442704,-161.502675,-139.715437,-73.526991,-49.668444,16.752554,41.900061,45.035703,45.93999,27.131189,-100.705362,-181.530685,-253.201518,-219.700302,-72.61804,9.647472,130.546373,143.973374,119.490464,-3.896266,-74.615437,-122.060878,-100.737906,-13.631486,33.916462,37.068993,-102.584739,-173.131272,-210.23497,-160.102523,23.092627,115.697058,192.288926,25.171502,-130.499579,-359.698107,-344.215714,-139.436497,-47.960876,45.928216,83.566956,156.21246,90.360688,1.195697,-83.241613,-46.145022,12.145564,-11.205661,-104.813818,-210.465116,-261.969147,-284.479505,-252.008886,-217.245555,-239.892581,-270.36878,-259.837786,-276.140516,-365.917378,-388.44886,-328.918465,-287.871703,-263.322561,-233.028103,-109.409581,-139.396798,-225.925025,-324.179748,-289.678971,-162.061462,-116.453099,-74.75067,-78.463641,-103.548671,-119.503096,-150.171193,-219.646973,-201.527993,-78.270969,-52.578721,-126.262069,-151.676667,-128.279277,-132.652737,-151.689914,-116.838428,-68.39201,4.190214,-0.532759,-129.196047,-336.112619,-409.8802,-421.756226,-371.100095,-222.441375,-142.91496,-47.060075,-92.379194,-125.110318,-154.918375,-156.609048,-114.977984,-72.36746,20.717258,56.577724,106.671056,132.355834,100.751975,-29.268914,-67.703379,-70.034247,-55.611654,-10.162142,5.479231,-28.505232,-188.321686,-257.852685,-249.702296,-187.979885,-40.293359,-15.03664:-295.014174,-361.800289,-368.870593,-256.220757,-148.559941,56.00761,118.072682,179.938107,260.430394,295.305814,300.420284,298.939847,326.605003,335.433429,269.078561,170.362282,-106.241908,-310.746154,-327.591855,-120.372483,65.060879,349.158867,384.458326,299.549555,193.547824,145.490045,13.066803,-25.922673,56.122589,129.578608,182.710505,150.305238,45.026275,-39.611557,-90.378511,-212.05589,-247.550049,-221.326206,-193.144812,-201.522674,-260.322269,-272.079463,-220.434282,-144.387276,88.983653,202.410156,336.984781,364.856886,391.913951,370.095146,351.784273,405.897041,478.723208,577.089443,575.961715,499.090913,327.136195,215.225275,17.789926,-35.847892,-49.627903,-37.33615,-6.702899,15.854851,66.576201,58.935258,13.622062,-43.576873,5.842444,207.16654,273.768681,243.831404,188.219824,171.483743,67.938969,22.307524,69.901333,129.649316,154.522124,95.619508,-85.382285,-231.788958,-278.517683,-241.03055,-147.812436,79.138913,177.510791,304.744802,365.432478,382.038144,353.224834,332.755885,384.875304,447.620474,567.305056,578.606307,409.939465,164.908231,120.756222,201.890575,252.842481,242.581689,225.912583,231.448825,113.505461,11.331116,-107.2824,-89.578128,-5.490863,16.698878,55.033334,84.45656,137.891879,117.335544,89.025021,96.966038,112.233368,27.689513,-53.49613,-101.910202,41.250992,81.803387,-27.436118,-101.6872,-83.633772,12.400119,233.951203,288.060207,276.481437,262.477158,257.202379,245.083176,270.515754,365.494824,393.224502,371.884036,286.682637,201.523599,-23.85582,-79.290323,12.165366,91.768946,196.852945,246.446968,287.063593,91.810798,-13.321803,-28.898354,31.446711,187.502207,285.762267,436.274111,402.525922,349.35053,272.278903,267.210879,332.232454,376.606136,388.573338,348.046587,300.655903,311.144082,277.635173,210.328896,221.150381,251.803463,243.119663,244.729742,294.582793,297.536821,218.087032,175.285407,131.851047,121.658822,120.889013,98.535129,-7.082992,-91.747257,-112.317823,-67.264826,-19.561344,22.573628,46.437341,180.693255,217.481652,149.479175,15.898511,28.355231,147.051522,179.309476,204.020997,226.427661,261.19214,205.679146,142.914813,64.425736,58.070936,7.684258,-35.542307,-61.614076,-2.580433,16.24643,-20.920768,-45.551406,-44.834865,-37.711904,-24.402011,-14.188508,-17.223887,-85.415876,-157.026416,-268.608982,-242.929336,-92.164557,-42.942098,-53.511549,-83.209184,-82.200764,-108.650837,-121.593928,-96.501092,-87.27306,-100.669251,-96.213702,-77.068335,-137.50825,-181.801953,-210.041196,-185.205016,-126.958752,-140.042356,-276.629884,-383.172738,-392.814122,-436.376434,-481.729085,-529.62415,-507.284543,-395.169009,-346.014025,-308.496768,-322.949523,-341.441088,-310.547551,-244.034631,-86.504809,-41.202719,-77.608442,-54.245238,42.196842,219.537612,231.065413,146.950406,107.768613,96.292252,111.225285,152.138367,208.282847,217.456051,194.86684,191.108928,209.373674,216.571889,171.146088,58.833581,16.867631,-23.295255,-15.636887,62.776501,106.172017,154.214055,149.752315,76.248635,-30.643705,-95.513094,-133.557005,-53.2292,117.427827,96.438077,-66.283163,-87.653784,-65.19578,-49.819346,-28.032914,40.763004,56.651239,65.460707,58.541905,-21.248905,-128.428971,-157.215883,-171.740655,-168.628794,-101.619327,-9.732504,186.153222,179.360594,122.994739,37.310682,21.190965,4.684145,9.215343,90.770463,135.968686,92.433992,-99.160543,-156.132341,-88.274696,-15.421253,97.909096,148.129414,203.601857,71.687315,-63.929121,-251.239219,-229.459668,-87.57599,-42.303131,7.68717,28.180709,15.963942,-57.855931,-80.047988,-24.907203,35.252953,87.869602,59.023525,-47.176918,-187.045431,-274.437996,-370.862597,-346.556916,-268.840132,-274.985303,-317.109368,-298.829929,-256.365617,-369.238446,-443.21538,-432.75136,-348.577454,-187.4981,-154.978502,-157.790775,-202.059978,-256.185934,-329.722731,-288.117493,-125.647497,-68.771159,-18.241423,-17.890165,-75.94084,-172.706133,-203.680904,-185.021651,-151.456721,-121.22734,-131.081287,-167.11887,-185.523516,-194.936256,-259.721613,-291.244858,-241.932906,-162.745489,0.405024,28.386433,-108.92749,-366.685928,-447.303746,-407.663727,-308.187619,-117.670556,-71.881993,-49.197325,-51.243324,-59.502291,-59.3433,-41.739874,8.102125,52.19489,183.392852,226.080803,228.484201,204.045075,159.775238,16.724843,-9.251531,124.056767,227.603171,301.930652,208.552213,154.976372,8.922534,-75.63336,-132.919442,-105.442384,-24.322276,3.200595:-266.34931,-223.040371,-184.958141,-65.538452,14.957108,120.943264,130.034468,154.38654,224.725302,249.961966,290.747148,318.315848,368.07225,381.106193,356.530554,306.430549,149.486121,-5.82256,-52.69049,-9.36138,69.474083,207.100937,248.271524,275.011823,166.888753,63.635502,-105.780522,-103.987747,15.064977,43.530154,15.443831,9.376795,15.687906,-34.583401,-96.410854,-242.172102,-279.571497,-261.499609,-233.24068,-228.944169,-303.99107,-336.142707,-323.094015,-248.369277,44.08391,202.216773,388.776586,431.087585,479.082853,448.104603,405.072607,343.131382,339.773068,367.863,398.050953,457.772624,373.024542,271.567461,71.279596,1.234887,-74.940063,-79.357269,3.100626,69.539544,155.189887,127.95854,66.260532,-79.967251,-106.810149,-23.190962,60.470634,242.224672,385.285695,401.030334,275.232491,176.27958,51.639536,44.513087,115.693994,152.186718,88.484658,-110.101617,-188.344106,-196.528789,-117.797794,91.806472,171.173834,276.653785,344.566645,348.943595,285.929658,254.639306,311.032106,381.863666,504.614413,530.660559,468.933395,311.529385,235.009803,133.235932,126.196458,215.293312,294.368727,423.032648,341.706643,213.257501,-48.003938,-91.815559,25.025881,107.862268,178.835654,172.298948,137.610456,82.540462,51.598195,70.235358,98.805481,38.897384,-18.967722,-13.286377,74.474291,73.620464,-18.683149,-55.49715,-40.073909,9.83378,175.594787,249.598775,308.404,325.586973,320.875933,277.391285,272.589104,320.688007,355.191255,415.237438,406.761388,355.392093,202.051183,145.902021,152.708052,208.339123,374.920552,458.100854,467.023321,213.90072,95.271436,78.582953,154.712784,309.479397,367.304391,464.497749,455.442711,372.126655,142.476233,82.314442,164.611948,248.414782,293.853844,243.614816,146.840083,178.609934,196.673666,184.830463,180.35201,135.55254,104.215922,167.872712,244.135198,207.884135,58.965564,-3.592753,-16.349438,27.221072,91.140405,71.909656,-54.387333,-179.705349,-213.484751,-215.513598,-198.484699,-164.983018,-129.259795,2.536775,47.344714,6.902386,-103.941845,-130.866966,-107.851668,-85.514193,-29.903264,10.693691,72.836169,40.023979,-6.518545,-43.550501,-9.22162,67.841731,70.170465,33.57071,44.508143,55.263898,-18.15054,-67.108662,-29.313908,26.915533,85.428809,90.116225,105.816062,65.533312,-25.271365,-203.015233,-201.044483,-53.168726,28.483293,113.547907,26.708077,-44.156896,-119.680239,-109.284099,-37.922259,-15.965975,-16.485794,-17.819249,-23.154696,-85.399613,-141.632585,-196.515603,-157.338814,-56.997723,-68.182742,-200.472843,-284.275123,-297.01442,-359.040412,-400.23811,-440.276619,-435.274468,-337.446903,-265.766092,-243.139243,-323.414026,-334.626685,-289.237272,-249.661181,-200.500466,-187.271289,-103.076874,25.011894,52.88874,54.576829,56.55989,30.233742,-0.946727,-36.622801,-34.507044,-13.008263,50.817428,93.4906,127.804391,108.111376,74.422967,93.436325,114.495196,47.074256,26.919266,-23.415585,-64.056418,-45.399042,21.601928,107.744092,87.018718,-11.99058,-88.410933,-126.070341,-188.342117,-183.392318,-110.490733,-84.39778,-100.037157,-74.958765,-28.500965,25.614273,36.041335,110.628719,151.370015,143.307767,109.60039,51.252297,-3.095573,-53.897567,-130.026853,-105.488149,4.079068,44.966655,78.610718,24.536701,-23.478177,-117.597385,-144.657234,-131.847031,-95.175889,30.611457,73.366771,-44.653241,-292.554079,-332.625671,-217.417622,-157.706844,-133.309717,-99.536897,12.360523,-114.492553,-249.104627,-420.205257,-415.75412,-291.096042,-220.870701,-99.843048,-27.804238,100.082129,80.60927,32.811817,-15.997506,-8.069734,-18.615423,-47.616068,-126.231711,-284.448249,-358.051956,-383.441809,-350.88254,-292.195348,-288.198908,-292.269645,-286.795416,-316.094996,-417.970493,-461.157825,-461.380471,-409.633694,-237.937603,-149.286271,-78.130107,-167.003427,-217.81413,-294.279669,-321.609915,-292.547725,-224.347474,-63.36108,-26.488783,-92.844591,-248.521583,-324.223156,-379.444053,-317.5931,-118.305937,-71.644904,-119.266729,-190.305893,-205.624717,-251.329558,-268.706019,-213.963723,-164.167069,-73.020669,-39.295581,-77.825929,-261.287605,-358.477584,-405.469621,-319.505247,-66.199534,22.332396,78.621109,12.385161,-40.027646,-120.953924,-132.091999,-79.486383,-37.223909,28.126724,60.076064,126.102198,122.648682,82.207769,-41.338728,-97.304438,-97.104135,-18.239248,169.3088,155.199057,83.325848,-60.738555,-100.568194,-90.359619,-63.395868,-8.096635,18.277282:-248.185223,-257.153756,-236.467728,-118.764929,-15.055317,151.255784,187.659595,230.484485,287.412629,308.455153,288.138399,274.085079,333.906686,394.121111,434.194483,360.667573,78.919812,-145.572484,-178.574625,-27.911298,105.913033,310.36523,366.911322,375.009536,218.74569,106.479028,-31.169763,-13.012973,107.34043,145.678904,146.131343,129.90611,106.832504,63.365135,2.908342,-138.607257,-174.969099,-159.488154,-135.514103,-165.697347,-259.350433,-277.733235,-249.467241,-197.75784,8.526048,143.677545,351.147983,394.946235,426.470246,407.906041,369.558543,357.526197,400.467672,469.890087,470.307693,407.784256,269.199032,177.254095,-17.576566,-81.693308,-107.664389,-105.741209,-86.930511,-59.328243,-27.481077,-75.41262,-126.766472,-211.929514,-207.685893,-67.57833,46.22342,213.236576,213.585359,181.934019,104.906865,71.436458,46.785683,55.559628,86.419684,80.064184,-32.421102,-224.879622,-303.429771,-335.421216,-303.73567,-232.678831,-168.033207,27.133604,106.700718,98.60983,83.793122,99.189219,186.983515,247.759699,367.734655,390.342074,287.673163,128.345596,94.470119,111.899856,121.109929,155.561067,216.548623,322.578577,213.706085,97.451407,-140.571513,-209.633429,-199.566746,-145.07838,-15.955033,1.69546,-73.937836,-167.818041,-216.63219,-234.197945,-184.964481,-101.468669,-105.668665,-129.343781,-104.345727,-117.939219,-223.221944,-268.63968,-222.792931,-107.339936,177.48481,236.395799,180.99567,170.280755,175.691032,156.307716,179.499528,323.95341,395.776552,404.134655,284.478532,239.274528,188.846329,172.709086,178.864183,217.641387,361.110829,421.207691,357.23373,83.115131,-14.778315,-13.676322,39.096167,169.541718,244.552851,356.993934,300.074267,205.047816,39.409482,42.551118,211.672622,297.879033,314.223929,257.70986,170.070011,211.397098,246.26883,271.41758,283.102377,326.087493,338.673813,370.307225,370.91789,326.744307,206.553624,184.975872,233.739468,254.818541,214.684799,155.197377,26.457158,-10.228842,-15.200176,-25.977065,-12.997695,74.553941,139.760413,205.914954,165.063427,150.037287,144.790589,133.978994,98.062243,105.333846,211.070369,273.38821,321.859758,256.833285,189.517048,94.871767,102.799761,154.635711,168.626088,207.532801,244.906972,224.897034,124.032983,87.697372,89.644631,110.995695,147.278748,158.122117,175.438845,113.960625,26.223796,-150.337614,-165.733966,-40.354281,49.863037,151.685042,78.432075,12.367854,-72.734218,-64.41405,6.432019,24.560651,38.780285,31.935724,-42.399154,-123.32293,-176.843259,-238.285299,-184.054192,-6.24248,21.973423,-75.872663,-173.103626,-199.950448,-296.178307,-354.539797,-396.043273,-372.900446,-269.987491,-199.640135,-117.927888,-219.820534,-277.627162,-228.025003,-134.813974,-10.109786,-25.55973,-112.228502,-69.332159,-6.369487,62.549291,62.143378,44.699146,31.738096,14.120195,12.207277,17.459555,71.549247,102.258797,111.559205,102.7171,110.011843,125.762762,118.389008,18.843303,-32.607957,-90.028375,-90.083493,-19.207917,40.936499,138.475609,149.968917,78.35374,-53.787857,-108.912582,-128.939197,-98.667421,-39.124188,-27.096428,-75.321042,-157.342372,-159.295798,-85.205652,-33.566648,33.001302,45.958459,31.083261,-9.297979,-73.667545,-88.72162,-127.198733,-185.053007,-155.163961,-25.350509,30.342807,50.364679,12.731851,15.363631,-9.338825,-46.539409,-62.323821,-28.872812,45.570614,41.919657,-78.725115,-203.110166,-201.417674,-85.211839,-32.27306,19.929207,52.982505,113.952586,17.733575,-99.000787,-300.710938,-313.414514,-186.768252,-110.488873,-22.960556,-23.567059,-75.891778,-119.330427,-141.57182,-103.203212,-20.031885,92.2542,66.126729,-62.916773,-209.321716,-292.837533,-420.318829,-436.252767,-388.551106,-353.581742,-289.646574,-269.979866,-296.241493,-362.643717,-373.594533,-311.029408,-248.361322,-93.524677,-14.407353,36.748787,-67.411407,-129.394845,-200.531423,-191.76744,-105.810336,-40.421665,122.735414,163.385036,56.531425,-152.123195,-223.22611,-211.035824,-146.348396,-12.509264,33.959167,36.308322,-80.421002,-161.590176,-288.661537,-291.499938,-198.678466,-144.804683,-37.32019,5.685485,-26.397206,-237.214853,-347.236261,-355.301995,-239.192635,14.733276,81.142905,85.135073,-13.933119,-74.719021,-162.907778,-156.69431,-27.524524,53.413078,144.12464,143.88292,89.409724,36.2025,-10.748821,-120.562291,-122.083503,-3.416471,64.752316,114.128657,34.470882,-45.13625,-224.023248,-255.149813,-137.846471,-59.653569,0.468878,6.796784:-110.660501,-166.667436,-130.442562,7.519979,63.778172,99.447982,91.095639,115.127086,205.913861,235.902494,258.084966,277.954127,366.618181,414.081677,476.598456,492.635183,459.833506,313.750769,235.797183,143.602244,128.224491,116.436143,114.130912,119.540442,43.347681,-32.989011,-177.948127,-215.312337,-198.802146,-175.945886,-149.132853,-137.478338,-110.464616,-82.332226,-88.649808,-165.004135,-193.878625,-169.915969,-147.91436,-182.390103,-276.027125,-302.684403,-292.416896,-248.61892,-55.911631,63.164234,222.55381,254.421232,281.210848,271.513948,238.695132,157.378415,139.837516,167.425756,203.764975,268.93608,276.223059,263.607947,210.139567,174.386112,107.906835,103.45451,169.625752,193.532157,120.63297,9.312871,-12.053824,-65.002369,-105.988844,-81.529614,8.166705,212.482275,299.806226,277.449876,92.03435,-7.334139,-27.25362,21.086183,54.359166,28.362807,-42.292101,-123.606937,-168.363859,-162.615119,-102.411221,-1.7382,20.639094,60.318863,58.806976,36.769802,22.666132,77.730918,286.32052,357.806394,392.430511,397.381037,359.706683,215.634628,158.903818,177.366609,226.862842,284.725016,302.083972,357.715075,328.633991,266.032221,92.198828,22.098929,22.915656,73.679019,113.97373,83.630004,0.717549,-41.481318,-29.852286,41.33621,59.948171,-9.842167,-58.760782,-43.325841,73.18283,99.779567,37.960429,-4.290124,-19.471783,2.958193,82.682167,124.764473,175.366646,167.931753,148.511002,151.467118,189.009258,244.113875,226.590237,148.344025,149.115171,180.005693,182.872741,147.880623,137.242606,178.894199,284.673085,320.569706,296.402544,177.537326,136.406115,158.469845,206.634968,331.319344,390.911072,447.974091,389.764889,327.507457,203.118946,182.633877,226.692335,232.567816,144.503478,80.09576,21.512944,60.642762,51.042197,-38.004503,-68.066017,-55.058173,-34.006362,7.544034,43.970104,41.202018,-25.049679,-67.102414,-110.737782,-110.690897,-66.953366,-28.280423,28.174791,-16.974411,-75.133622,-173.18263,-176.338877,-95.35346,-39.544926,52.690701,27.012435,-38.400724,-161.193669,-175.819578,-119.817838,-79.745748,-18.456872,-5.422206,19.363326,51.751424,47.000011,47.793347,77.584053,129.464028,143.049015,203.155257,181.515712,102.619669,-40.109666,-29.969118,143.944468,211.919484,161.805489,118.223706,179.27919,236.141101,185.237594,25.502468,-2.227161,107.914396,192.342648,274.206906,205.361918,145.642302,69.117976,61.516289,71.57729,74.187466,53.731585,34.406223,-4.899431,-17.620362,-38.052096,-114.207803,-115.057883,-34.228398,-23.646952,-130.927044,-218.825207,-207.08416,-180.570177,-190.493698,-205.472086,-208.496366,-197.865486,-170.895401,-146.54984,-246.955483,-294.610481,-262.372441,-204.096254,-179.05042,-220.171195,-201.127581,29.011123,115.146571,25.01608,-101.664228,-257.146757,-246.523409,-145.601536,-116.234747,-114.008263,-55.805209,4.175654,56.106646,11.71457,-109.705622,-116.227076,-38.584759,-24.175366,-46.530162,-101.056725,-129.415329,-89.240619,-10.713584,66.585912,17.892993,-118.914245,-131.538369,-112.817904,-118.294559,-138.768665,-156.362684,-146.677014,-96.513728,-54.991548,-42.301192,-9.629505,17.919263,120.864878,166.316038,172.717259,146.202353,66.195596,-43.403099,-106.635826,-162.649259,-122.573121,2.143537,33.796391,32.489907,16.14233,4.708306,-100.332761,-196.914417,-319.460003,-296.899358,-143.995831,-85.928701,-156.489258,-299.3969,-288.449204,-183.149972,-159.150994,-135.351665,-81.088861,29.713447,-100.940083,-217.209773,-338.317669,-326.746613,-242.282464,-202.402525,-94.784979,-11.692164,70.308025,-46.968705,-111.745018,-179.485526,-168.789513,-62.33568,-26.84814,-99.708082,-258.55019,-300.146672,-274.842341,-226.801082,-96.454448,-47.793784,-30.755309,-26.892522,-42.637715,-191.718606,-270.638199,-330.097875,-295.775804,-111.32587,0.216319,125.037469,-10.09225,-121.818755,-231.170876,-225.086037,-132.758015,-56.1031,112.995698,170.167878,91.193781,-191.928473,-306.885585,-324.519866,-242.096486,-75.162799,-32.340077,-41.662817,-151.336365,-209.559178,-294.693273,-298.648699,-156.799177,-51.891025,32.403226,-4.824145,-145.359114,-267.736786,-301.824533,-255.158152,-170.003229,19.717713,84.1444,110.844931,-16.164566,-94.321148,-163.666812,-161.058805,-127.894211,-96.668381,-12.654773,18.901247,21.421734,-16.440051,-36.10592,-53.079031,-46.589268,-31.911634,-0.672088,78.401511,-38.123946,-134.660647,-202.109428,-153.438807,40.860755,114.66,87.9206,28.429191:-150.995136,-137.605494,-112.027019,-17.335565,66.278811,225.484333,262.610804,283.621628,284.038694,274.929919,249.243704,266.585912,403.087885,474.775766,552.419508,550.362553,414.779381,196.439048,131.873784,180.484982,243.302193,269.77739,255.815282,254.595296,111.89238,-22.48488,-207.052755,-198.878175,-47.752531,9.570977,6.771357,-20.113061,-48.406988,-29.096921,-42.549205,-143.041706,-168.719086,-67.683688,-10.222471,-79.084753,-257.46665,-313.192433,-327.832986,-271.712762,-47.997878,71.607744,267.001356,336.106947,383.889266,349.517122,316.131124,226.075273,190.264593,224.881968,304.21938,425.109726,280.744432,158.944272,10.009461,-5.680225,3.376803,21.987315,98.796878,110.252481,5.328781,-127.067944,-189.504862,-293.293023,-287.034456,-136.955135,-31.418376,146.927291,228.608433,210.188554,34.241303,-49.150575,-12.325313,74.069027,191.562774,179.355723,23.803588,-175.750049,-252.780918,-263.571529,-194.357541,-47.028448,6.427297,106.445691,79.143026,-0.586619,-82.612133,-21.127452,176.952334,237.212599,307.832346,330.220485,256.09796,91.343783,44.927165,67.57144,113.72695,193.708522,233.718469,328.29576,259.169039,142.249498,-99.029113,-150.788455,-75.480407,-1.923721,80.596746,77.700195,0.975226,-169.771169,-240.168626,-193.243837,-105.353827,-30.121149,-51.907066,-56.645104,-15.258684,-36.510027,-150.311271,-178.923071,-120.807662,-60.80162,64.607368,110.434519,139.607277,78.909414,27.204544,-6.851895,41.291153,191.682224,259.035844,345.658415,330.699242,294.538189,213.324166,190.593797,236.545084,307.008024,460.036646,492.017589,398.164379,186.339768,110.027517,118.1969,175.476175,291.622529,352.253687,442.307797,354.621179,246.891926,49.904123,36.840106,213.377629,316.517363,364.322798,314.749676,191.238804,174.227196,182.861985,180.074799,196.6712,235.586284,238.445492,266.462939,261.354027,221.26484,158.42732,156.243824,165.426072,168.824695,178.988696,172.223014,106.281928,-16.006545,-84.095617,-131.049413,-93.689355,-10.237123,12.222221,70.918239,119.122678,99.491139,-25.447935,-73.02779,-36.274663,24.306355,163.0518,226.423215,270.092554,172.627984,108.451878,56.233034,81.209676,153.480195,179.553546,242.829718,237.178827,169.46101,-4.417634,-42.31061,54.913686,140.035193,199.374231,177.819666,181.704253,204.477618,136.984683,-60.555945,-94.731829,9.483753,109.752519,244.843713,103.648107,-21.841587,-132.743803,-111.093847,-61.491084,-53.118748,-25.766644,-11.979304,-31.778091,-81.781904,-112.091608,-148.329555,-123.334556,-39.164438,-26.737231,-74.495416,-132.228399,-168.300136,-297.337657,-344.258967,-294.600845,-221.582605,-87.901588,-57.893028,-106.424438,-240.122571,-310.734274,-356.211829,-304.037503,-206.59716,-208.442846,-195.849513,-92.708031,-62.885161,-104.674867,-143.932801,-179.82682,-163.356239,-79.73951,-53.687485,-58.478818,-37.179342,-18.626228,37.518376,73.962405,89.141587,72.408524,43.266822,-9.412721,-40.173688,-106.655883,-134.523781,-64.753704,20.745776,64.837813,7.88982,-101.184411,-181.31597,-215.195166,-205.909167,-177.986414,-147.266099,-139.281928,-130.075794,-140.632202,-145.582299,-149.000055,-125.465978,22.815165,103.82962,163.699654,147.436487,70.760197,-61.751007,-149.241716,-230.675182,-166.305854,72.864625,151.744813,116.914532,-20.529832,-53.108542,-93.548918,-135.940198,-199.378552,-181.617031,-38.416892,22.891885,-95.60238,-353.209422,-376.684865,-212.517035,-116.333842,-3.408132,51.176051,156.184428,13.303446,-147.416788,-423.922031,-459.892059,-283.570145,-139.612398,78.327891,131.292324,97.109013,-87.722675,-159.704427,-118.105186,-29.938432,110.125523,138.20598,94.315911,-127.684197,-250.5968,-360.803695,-334.840379,-207.974605,-161.630894,-114.340489,-92.432004,-105.808145,-267.439533,-356.802962,-348.85794,-247.885246,-26.751445,49.145275,76.006015,-64.83921,-157.869966,-284.317351,-282.538947,-145.340253,-46.555815,147.238253,203.761813,101.106867,-175.063193,-271.102633,-275.390486,-203.434708,-20.142338,44.78431,3.398376,-211.044091,-291.63004,-318.018554,-275.016616,-125.588509,-51.867117,27.837911,23.332377,-88.402439,-300.776445,-386.37389,-353.897628,-234.721689,56.820492,160.02764,173.949919,-19.371519,-111.380019,-167.006943,-133.42905,-10.925418,49.795512,139.984387,164.50203,148.901099,45.896626,-28.156705,-148.896045,-148.761874,-40.281448,27.422566,99.591615,-19.167783,-130.463884,-305.751274,-300.923703,-86.200528,30.897764,120.940585,105.527938:7.20737,-83.138688,-122.375578,-93.939455,-44.323118,-34.003667,-73.975988,-122.82429,-96.612812,-72.218061,-31.431482,1.938373,129.879119,199.066639,294.173776,325.902049,338.768911,230.212299,156.888835,62.844702,43.864118,28.782984,21.213712,-74.741736,-268.450576,-330.807665,-408.486744,-450.517242,-433.452844,-356.053869,-165.659261,-102.075004,-94.799536,-146.734406,-162.552997,-183.148999,-175.767778,-114.354257,-82.64164,-93.429982,-210.083556,-258.163285,-276.631936,-263.43226,-221.869845,-193.974809,-116.216615,-62.848144,40.980279,100.829242,103.505579,30.670436,-24.212993,-113.525587,-113.06547,25.395366,110.242749,88.326492,27.621241,31.385394,132.539457,175.20603,126.062183,64.022612,-25.679498,-71.55389,-97.654848,-168.296765,-201.885964,-249.239297,-236.587509,-81.355675,83.036121,95.646008,-13.892486,-60.827534,0.093271,48.559565,32.640721,4.079932,-5.007864,5.24196,16.810002,66.404329,84.836861,81.273794,85.090332,97.428558,14.380479,-23.499811,-20.795796,6.22935,86.047905,125.64721,191.588017,222.049622,227.468454,157.934117,132.132535,122.618869,136.040661,162.887542,183.702799,249.255041,210.156989,148.458147,56.086102,42.211407,65.46135,99.930343,162.205639,160.878873,75.07276,-35.346556,-54.689167,-58.98442,-84.626256,-182.213027,-213.540156,-143.987506,21.850665,51.984705,-22.592599,-52.56962,42.392067,115.201461,161.969168,166.04455,207.517073,256.977901,259.839557,199.550314,167.210058,129.947448,104.19121,47.469498,34.766537,66.970646,167.070705,170.566208,65.304889,12.276384,27.094137,75.467468,88.063172,0.016784,-29.850849,-19.966721,17.750098,88.242027,97.790962,84.36508,-11.222533,-99.832222,-216.710557,-203.41371,-114.977371,-99.791646,-184.156799,-233.652099,-229.938852,-193.170795,-186.431366,-164.21623,-173.606431,-301.484522,-366.000152,-333.083097,-186.507788,-127.904018,-85.574971,-113.435311,-195.679134,-207.869285,-159.773101,-123.903075,-100.800561,-136.427564,-161.822868,-208.476016,-192.788134,-78.010409,-17.150791,59.335193,24.892629,-7.676865,-45.635119,-53.865653,-47.238466,-37.832355,-18.006366,-3.364206,57.351668,124.256703,119.134732,56.561337,58.560782,171.370963,219.478193,166.702627,55.817651,48.435615,92.029905,114.621755,161.845797,174.801091,140.129886,113.907618,133.023253,221.832201,215.540092,87.2897,53.569019,155.22019,238.068861,309.634328,204.45013,124.002897,62.085655,94.868196,152.373912,129.242209,8.534168,-46.720082,-66.993411,27.377452,71.631591,77.74528,59.55326,58.779009,63.319927,-11.777913,-87.27065,-50.561636,55.956449,62.215307,20.611318,1.455171,-10.747507,-3.989082,-23.759227,-45.020349,-17.375217,30.053052,5.586239,-114.051874,-151.418974,-108.045756,-33.73465,-26.3867,-95.378238,-151.969236,-189.834163,-168.069805,-137.909323,-128.412503,-70.558035,-3.854376,21.224295,56.824316,34.646794,-106.661021,-142.950446,-74.602999,-105.067513,-158.117168,-160.113259,-104.799772,44.953578,98.190761,103.626674,79.267174,18.207144,-45.221946,-44.235011,3.25129,9.101196,-26.289422,-47.801361,-82.398223,-68.433447,-12.19199,150.891385,198.790062,195.876594,185.761146,197.524687,191.22481,132.578809,95.960765,58.591188,-64.684856,-89.672569,-44.283635,-7.328026,63.127559,108.408259,101.807475,-28.453839,-140.389747,-260.005915,-214.665871,-77.6092,-78.092703,-170.898961,-154.294979,-116.034897,-84.384913,-83.084968,-42.74619,1.065418,59.407193,-25.358908,-89.039035,-109.024178,-73.425584,-51.818944,-76.232534,-100.629932,-90.448936,-78.336127,-92.830536,-120.933549,-202.71321,-222.472154,-220.106137,-220.035068,-183.410826,-117.310219,-126.154809,-197.748695,-192.489402,-63.615013,5.291049,70.236634,71.867989,35.58015,-29.019398,-77.700115,-170.012646,-160.260356,-5.197717,74.902812,54.231066,-164.590947,-225.937348,-173.2554,-124.202614,-42.905568,-1.221782,41.36559,32.477955,-17.810763,-144.371412,-232.589085,-327.048768,-295.178847,-159.68905,-112.626029,-110.486805,-220.959997,-279.200237,-278.798335,-224.278586,-96.971734,-36.137218,33.890948,10.325579,-108.028613,-142.917631,-115.580755,-27.891068,20.48197,105.838408,141.766167,179.405874,77.671424,12.150968,-16.004472,6.660259,39.116327,32.941055,17.178329,37.881517,109.997254,91.20615,37.840692,-50.668677,-47.103715,16.964624,35.404551,19.163948,14.922645,27.157546,38.588418,48.197198,127.620577,174.879056,179.358257,143.629179:-116.651392,-54.46848,-34.344204,-52.503593,-61.239846,-48.672288,-35.985786,-28.11177,-7.346293,27.919952,105.111285,141.126905,254.457338,322.523912,360.130821,302.029589,126.997901,47.656245,29.123963,-41.029845,-75.055871,-96.76876,-82.07759,-23.459738,-55.595404,-111.52256,-166.357426,-148.406339,-128.138208,-153.63703,-175.807383,-140.879971,-114.915837,-220.87794,-273.261986,-326.264898,-311.880902,-204.003345,-160.596786,-194.074568,-285.592545,-298.360376,-292.227755,-293.589893,-230.178224,-156.577562,-27.1895,19.951913,124.295754,163.729619,125.520846,37.299267,22.145529,-8.244383,-23.870694,35.567203,159.061612,190.679473,169.72247,133.159026,94.278483,115.408347,187.538927,196.129898,138.750814,127.508409,131.709095,30.425629,-47.000295,-88.588668,-51.107082,66.001213,164.427518,154.434514,7.495566,-50.700232,-18.633087,12.514405,-22.465143,-59.94216,-90.144039,-113.874186,-145.167076,-164.024396,-136.393285,-82.07955,-59.509606,-15.097267,-47.343255,-75.943852,-70.012796,-19.418291,159.24734,258.530603,422.289211,460.69591,399.329491,288.819421,240.796453,115.342923,59.42651,24.728052,64.983356,220.216403,269.493051,245.730534,152.261329,98.768891,51.838599,70.304689,124.94321,114.895207,26.535452,-0.634867,4.013537,-26.235361,-64.450734,-163.326333,-188.557898,-143.013376,-56.687838,-29.759715,-2.977818,8.905199,25.697238,36.040801,95.810433,133.161137,161.9744,101.337497,63.07598,81.033013,143.497822,241.154076,231.980867,148.637634,116.32253,133.915005,159.424988,151.622542,97.156141,54.675042,42.641361,86.57815,142.31881,82.107084,50.444162,96.918077,168.610768,264.016994,250.564594,148.603694,107.719572,118.579854,99.129553,74.975423,75.931187,73.181594,-30.707986,-95.659484,-169.669418,-162.80004,-141.542997,-176.588394,-237.478775,-353.744582,-369.943891,-319.623672,-287.466603,-270.996204,-238.647581,-270.998309,-399.929948,-414.776465,-285.040236,-192.674959,-98.159584,-172.481665,-231.267292,-289.286609,-276.043662,-180.745416,-110.948034,-29.522068,-149.410289,-227.146962,-301.130965,-307.175515,-233.908874,-169.145372,-91.476123,-68.800555,-8.651651,-9.60145,-29.639899,-2.501986,47.856374,124.193582,131.397314,102.918032,79.99681,95.071556,134.019878,135.454545,152.188431,177.008555,172.112944,135.804568,98.715858,156.476787,167.101177,93.548583,65.817303,104.283815,146.488302,227.180414,210.540417,168.222312,97.081455,92.20985,151.335538,168.296355,92.381216,28.386339,-52.302953,-66.959231,-77.927715,-94.599928,-67.678731,-40.882508,-121.759566,-357.292781,-351.70805,-272.912365,-216.482601,-264.13611,-329.21592,-303.519298,-213.330675,-185.839013,-201.481015,-237.379486,-231.615374,-178.045493,-136.487096,-95.04287,-115.835534,-142.096279,-29.620842,32.065691,0.718285,-75.166017,-157.232004,-134.953845,-63.086066,-56.427777,-99.294029,-71.064564,4.699762,126.332768,99.75405,-49.193202,-82.746371,-39.22798,-48.578514,-95.708803,-173.198867,-158.988734,9.083333,101.004824,136.315649,96.435782,1.647764,-18.978464,-7.017959,-23.722,-42.981671,-50.18536,-47.795314,-33.192851,35.319116,82.837262,134.250648,135.311612,155.972415,172.017999,151.029836,117.07783,47.342291,-51.789042,-116.927712,-188.884196,-176.30101,-125.977769,-114.385652,-79.892426,-35.231747,-37.662969,-99.770414,-136.833204,-171.340144,-181.862925,-211.020043,-204.905654,-146.444292,-84.839921,-59.425672,-43.293263,-52.777499,-65.75623,-51.728914,14.949011,-0.772484,-68.03342,-177.129793,-174.235891,-147.640269,-169.284827,-175.718814,-121.498873,-33.175433,-55.439961,-106.640837,-248.12443,-280.811049,-235.962844,-209.284224,-201.518591,-210.602241,-214.02339,-197.788454,-171.809112,-80.256381,-25.076709,82.362226,122.741877,123.667304,51.728999,4.230469,-85.225142,-95.493009,-7.486381,65.277688,119.503982,-5.093101,-48.152032,-8.50682,26.247882,55.498907,74.470185,187.284505,245.174002,189.879842,-28.377036,-114.739883,-187.961103,-172.843254,-98.804268,-76.397113,-60.633956,-70.292382,-93.11933,-138.940816,-129.92498,-1.16981,107.332354,264.310625,237.749925,40.151094,-2.3213,36.78796,25.573761,-25.501655,-24.730594,52.400677,148.438561,49.945406,-0.863396,-62.823497,-82.475574,-71.652449,-41.345244,45.615137,87.738175,133.805124,79.13424,13.189303,-97.927517,-117.412975,-102.258399,-71.851799,4.286959,30.925546,21.807955,-14.165538,-18.395131,29.251234,49.548031,51.372033,73.077175:-48.039486,-66.772417,-59.595624,-40.964465,-9.500823,64.628896,63.746443,-0.934793,-23.833492,5.469092,97.169958,151.273769,309.177078,398.295741,524.651142,546.498589,495.856911,378.412903,332.578378,274.273269,233.554846,100.221471,49.512386,23.394834,-70.854474,-170.119306,-379.939082,-426.156124,-319.086799,-233.542703,-173.614369,-181.500908,-173.703559,-138.059982,-138.31259,-175.054804,-177.604696,-118.908811,-93.937475,-116.074523,-230.722763,-301.81747,-361.901353,-323.81395,-165.947493,-100.81017,-53.958281,-43.043982,31.846201,123.372134,107.426796,-14.542473,-32.662847,31.53792,67.305366,156.475706,182.105828,150.432186,110.303824,116.044537,140.208,146.802281,128.04373,103.896493,35.210632,-70.97132,-132.838973,-211.95297,-220.81015,-231.20587,-221.346148,-88.528942,86.41692,107.559565,-4.229685,-61.556415,-17.032831,42.886719,103.620379,110.415377,77.67205,-11.693033,-49.614521,-40.486911,6.143992,73.265664,75.430507,69.067248,50.828559,35.559839,50.330622,100.548503,228.7714,263.147474,276.029134,270.141889,206.695833,128.635296,122.833906,157.097895,176.497147,204.690545,244.458971,386.651015,379.13286,292.161881,81.202163,25.804503,108.557637,177.704869,180.724094,128.362095,-5.527549,-91.138243,-92.096484,-92.780199,-116.97037,-145.281611,-114.901244,1.757883,47.468764,27.326098,-34.403713,-52.451014,-81.076444,-78.571802,31.516127,100.790749,124.823304,86.991127,90.317871,115.78706,136.118,155.237717,140.596813,120.28116,159.086996,194.399502,241.204247,240.438753,238.507105,235.07487,193.105274,167.506178,129.300811,108.018185,94.299893,79.596751,106.157554,203.486064,240.88805,242.524965,108.023132,21.093361,-70.264531,-56.376697,60.465951,114.124408,105.259158,49.082308,-50.416795,-6.890473,4.392332,-70.008717,-78.718684,-6.406036,16.923674,38.060391,83.51806,96.949276,98.436811,84.698051,14.940288,-17.492815,3.72877,34.964811,13.936764,-87.39516,-137.763321,-210.890273,-219.378281,-153.81184,-74.46932,57.639806,29.914668,4.031858,-69.221139,-136.047436,-189.270392,-146.55799,-33.896801,11.38868,73.637336,80.923731,79.58212,75.458018,76.449046,103.87763,136.622682,190.526978,107.429277,32.897585,-55.992114,-40.434595,86.412123,135.362979,95.852892,61.689404,113.781237,173.669736,116.273146,-72.151982,-99.778086,23.735232,119.198568,209.039859,95.395976,34.55548,-7.085988,-17.389742,-30.379532,-17.490178,0.693877,-16.15407,-64.324605,-39.636255,-19.356164,-23.275722,-20.847851,35.971723,57.601796,17.17442,-36.124728,-32.784875,-6.295181,14.546528,51.40647,61.584983,109.472611,110.260621,-29.825643,-122.560292,-116.549654,-168.83893,-232.87218,-286.430886,-260.85461,-204.659531,-108.588081,-42.437547,-48.717323,-134.376191,-250.799558,-226.243692,-151.166449,-160.049308,-166.374359,-52.98449,-16.682783,-37.456638,-54.615799,-68.586386,-79.805921,-102.030637,-110.704945,-91.886524,-21.863235,-17.942297,-69.424541,-86.394388,-71.400008,-60.852685,-103.105957,-177.388853,-194.181657,-182.509047,-167.470317,-173.917122,-201.337878,-225.579265,-120.286053,-50.247217,-0.531373,-14.296538,27.550251,76.279049,110.199496,104.222287,70.290922,-42.298354,-92.661498,-89.419968,-46.952708,51.931961,90.89665,135.635328,136.959216,109.948342,-34.398874,-136.967041,-271.031326,-260.904108,-132.055096,-85.364256,-174.317086,-330.222627,-324.284053,-198.994435,-153.768657,-118.765859,-68.768744,85.341825,6.726685,-127.678353,-313.301107,-302.330054,-183.22292,-139.150728,-40.714638,32.883189,79.059042,-65.011057,-131.953526,-158.062873,-115.776418,1.591972,20.182678,-60.874526,-188.625764,-231.213987,-223.111111,-174.324523,-68.458672,-44.853814,-61.740535,-72.923134,-60.926979,-96.704906,-154.541721,-198.669301,-134.732401,36.597923,93.590729,158.568872,27.890219,-101.397954,-204.842669,-135.425504,60.15551,106.118835,119.508486,118.14205,31.225943,-177.674902,-247.712331,-203.805958,-142.210084,-80.152252,-59.893573,-39.132,-127.835458,-187.218444,-223.420656,-189.557817,-87.546823,-40.999441,19.732826,12.382429,-85.658827,-219.745974,-272.017176,-229.65111,-113.412502,159.339117,234.519086,175.205544,11.508736,-17.262157,11.051405,53.088292,147.658496,138.802241,30.96446,10.003615,43.849037,34.714738,4.16433,-29.906649,2.629401,110.500186,148.575662,169.586632,96.700062,31.80581,-88.827599,-98.478531,36.015422,114.751443,134.52859,101.596675:left
35.044466,-140.487978,-166.767649,-121.280334,-102.677567,-105.207486,-139.113926,-278.838479,-337.422915,-314.670874,-229.701167,-178.004146,-75.865488,-38.479,-11.899917,-9.061314,28.359051,63.866886,61.407427,49.57055,45.483332,7.002958,-29.871188,-127.268464,-242.184276,-265.6704,-179.459581,-120.447218,-120.398442,-168.642624,-237.871949,-226.198958,-164.741367,-152.488047,-159.795724,-189.308547,-200.302381,-164.580221,-120.789674,-44.564234,-75.642931,-158.210477,-300.447311,-284.959852,-122.359409,-30.48411,88.582817,110.838898,92.748383,23.4219,10.136905,26.104062,22.00976,-38.228649,-91.171424,-195.358272,-271.809587,-322.69661,-413.121353,-416.02988,-310.05777,-243.483499,-236.983691,-281.548806,-318.912976,-317.266232,-333.478499,-337.327545,-292.572145,-171.475673,-147.509411,-150.900003,-126.795896,-107.036918,-47.343725,-7.61654,62.92381,90.859634,117.025494,101.44637,29.422879,54.27177,135.295376,220.776652,171.756574,22.227883,-57.092591,-272.676803,-434.235465,-449.117114,-385.363153,-343.984591,-317.265851,-326.465054,-331.865008,-315.69141,-292.519225,-354.711285,-378.768053,-323.936941,-270.40008,-177.850121,-150.55824,-189.01358,-321.562442,-365.833172,-317.436373,-232.4959,-46.619891,34.694137,186.387191,232.44378,213.457839,185.03752,227.539388,291.314327,259.95113,232.349161,262.295365,232.351843,57.355986,-20.596647,-81.423715,-71.947225,19.028231,95.886317,165.676303,122.373864,13.689784,-67.724111,-113.809204,-120.421159,-64.491156,55.621686,42.1339,-160.615351,-276.455158,-240.129869,-174.829072,-202.855436,-248.027663,-200.361195,-25.305364,29.886043,21.487032,31.731254,80.523944,144.80016,142.961759,130.458017,101.084665,-18.023684,-96.963501,-108.811316,-37.893467,28.941204,93.6818,79.747694,-17.733653,-75.147674,-101.937637,-47.634309,5.722412,169.799737,242.407621,327.506449,344.50373,352.497915,325.696157,281.847188,177.74497,136.219388,149.767698,236.873043,453.481203,515.018913,529.411509,461.780173,418.516856,318.436353,273.160922,279.379018,306.397162,206.069219,-31.514149,-98.134969,-77.847974,-46.82154,-19.255677,25.976069,183.155195,208.631846,72.614938,-88.076052,-86.806247,39.676973,99.977077,173.786511,189.947677,141.067561,4.143721,-52.553422,-106.84908,-131.731801,-161.738036,-131.0863,-19.59351,20.364658,45.813239,26.442247,11.066939,-10.265222,4.000636,78.186406,85.608401,-9.811596,-61.575094,-51.428206,-45.060536,-39.011157,80.518148,184.24511,308.833341,287.278429,131.39607,8.100723,19.605058,171.195432,249.081852,317.068982,327.733034,356.816813,277.4516,184.473685,112.753775,160.111737,252.1291,268.311574,251.504849,216.739159,110.260649,8.978475,7.526708,97.337804,129.770763,92.831846,35.977469,-76.20937,-138.380166,-155.302121,-141.90215,-107.800031,-5.34803,40.457315,52.208184,33.488016,49.384663,96.622245,96.998335,38.333395,19.376307,96.368847,122.903554,-14.023907,-172.403749,-198.467779,-202.791134,-198.898215,-146.584281,-72.006766,74.791447,90.196299,29.125151,-52.844784,-66.76443,-64.146858,-77.939199,-86.663208,-54.109922,7.207209,-86.370905,-148.082818,-105.621659,-25.310856,97.585113,142.912105,242.475183,291.501097,330.098844,246.72166,210.992926,224.221049,244.015386,231.008757,195.739498,141.961293,155.687313,167.283569,154.461122,121.968809,85.983143,129.060171,254.121316,266.266801,156.17782,13.302233,2.145139,80.468761,108.098683,61.538013,14.598349,-32.733591,-2.644364,8.114932,-10.092196,-15.513478,-21.264252,-50.705465,-154.952929,-196.889315,-248.669272,-295.855204,-296.429584,-240.229612,-208.516926,-217.48225,-269.060408,-362.946583,-374.547738,-359.708665,-293.668046,-268.460665,-226.424731,-188.228931,-189.860846,-256.834073,-371.922962,-374.505663,-366.309653,-386.878666,-411.700507,-419.945576,-407.205268,-427.676666,-560.937814,-621.324809,-545.388718,-431.630632,-227.153597,-145.930994,-36.864469,-22.375774,-8.354169,19.492398,33.799676,95.199197,140.707829,208.465589,196.81199,52.88165,-134.267432,-163.480112,-29.448945,58.173429,137.900875,163.350478,173.498913,125.737761,-0.571757,-74.985261,-97.699772,-99.934174,-53.669645,121.336371,166.610532,43.288735,-174.458665,-254.731909,-298.979597,-256.022977,-116.113935,-62.890467,-89.912165,-153.727224,-263.564352,-345.367431,-356.396345,-316.447751,-290.603291,-230.121913,-207.951149,-249.432847,-348.585584,-357.776143,-233.327339,-131.772924,51.993185,102.466679,55.157075,-13.209242:-53.443786,-138.929815,-100.58149,-10.817403,20.128543,33.341474,-9.313544,-127.656441,-169.209661,-178.267945,-143.766567,-79.022477,49.246541,76.532779,33.686996,-37.800386,-139.590878,-13.817766,58.638792,67.668197,40.683661,16.758348,15.374016,-1.350269,-93.665271,-156.421158,-158.361912,-88.986263,4.54496,-20.326068,-137.932212,-175.873225,-193.757782,-176.564502,-129.051101,2.338461,33.431398,20.06259,12.094437,-3.729916,-97.330896,-139.524485,-134.025637,-118.147375,-101.415035,-74.218186,9.524777,15.562473,-78.944853,-142.646597,-130.035918,-58.473765,-6.081173,61.728151,24.671643,-118.957135,-221.552414,-272.851245,-281.386614,-214.924068,-78.529987,-76.408979,-195.422513,-239.912633,-235.169499,-238.777363,-256.015299,-272.295691,-230.345829,-52.069932,2.195183,-25.81909,-65.961061,-56.699947,12.132111,53.559554,140.340545,177.47035,145.888573,78.026507,-25.774877,-4.143887,38.886044,135.56208,170.116401,152.340925,98.772291,-49.146625,-221.68234,-275.218409,-257.985284,-217.733003,-132.919126,-102.836598,-121.707377,-177.638799,-317.500982,-352.104909,-308.7306,-179.824473,-117.531406,-26.908686,-35.544055,-154.208095,-258.509552,-279.564415,-217.271297,-134.665991,21.380461,66.76979,159.408596,221.139224,213.334841,0.730359,-31.130384,122.147642,203.383668,212.354753,168.181033,111.963678,16.468971,-66.858527,-141.365746,-101.031314,48.675007,117.055094,155.805899,107.18486,-71.366816,-186.510855,-171.352125,-33.38436,43.946289,114.718461,75.083549,-96.63962,-200.517092,-222.380533,-245.039465,-262.276301,-295.79313,-282.215821,-200.448129,-175.464586,-216.04758,-211.850567,-151.746779,-29.706353,17.473083,125.620387,144.170671,18.45447,-146.066891,-176.841756,-114.392942,-44.613776,63.450907,80.313817,37.508773,-3.395055,-66.83716,-70.027599,-31.9383,121.448721,213.687239,318.653504,315.688858,315.979352,303.379328,231.138362,76.970377,66.090856,160.012074,219.610883,311.079162,336.498196,289.520598,179.354493,157.741283,180.56411,215.371079,303.802076,301.243905,122.303809,-109.710805,-178.773488,-192.369296,-155.019666,-51.727904,18.065367,142.686685,144.642914,14.889171,-123.225103,-123.472914,8.508694,99.567405,180.739909,123.405366,-56.341716,-81.717788,-59.725713,-47.652998,-66.498521,-112.383859,-108.135934,-41.046981,-9.736133,-16.008418,-72.838993,-78.067485,-33.466543,-2.201877,20.673451,-6.621273,-108.947284,-120.253071,-82.612182,-7.303347,16.818342,76.19214,120.839337,153.291739,122.954764,32.289651,32.628884,86.138975,176.173125,175.269315,166.467239,191.957486,212.461794,89.919215,20.233093,-11.998727,21.076241,105.063093,123.928808,88.607688,66.737684,31.233728,-63.898746,-98.340496,-72.003447,-33.276281,33.491086,39.746534,-22.92793,-167.711291,-231.778982,-235.604327,-201.162831,-119.260541,-56.148306,73.173121,102.648697,71.356985,36.51053,65.066178,148.654214,174.407942,210.583424,203.584392,68.685897,-92.845468,-116.456572,-104.468966,-103.819526,-65.576901,2.075468,135.122925,141.485153,56.90452,-11.242371,-19.663132,-9.581445,10.09876,86.638895,119.742509,84.8759,-70.205574,-118.657817,-62.085518,6.652661,112.645065,160.291728,320.219959,388.250685,299.086516,123.937801,139.164863,264.209154,285.142677,220.107127,175.286031,123.618211,117.961621,133.484172,165.700634,140.090483,59.844496,75.856034,147.708134,140.254871,61.766634,-11.216215,0.152061,108.356883,150.748043,152.967202,120.867843,42.776672,-4.641316,-14.626877,-1.83214,24.679933,62.837676,27.313429,-120.100547,-175.91191,-254.175713,-330.588589,-324.487273,-234.735536,-204.636846,-206.461455,-223.775582,-286.866424,-355.101433,-343.167913,-237.316643,-212.188646,-242.60923,-237.22736,-192.789197,-209.747869,-323.291678,-406.770253,-387.954338,-295.952829,-277.661122,-295.789091,-324.334562,-393.811713,-471.499077,-500.376162,-417.953595,-316.126864,-125.79339,-66.067192,-23.073236,-27.838995,-12.805685,30.117027,22.355021,3.341586,43.791026,183.725555,202.937626,33.774459,-198.896512,-209.822942,-24.221349,57.240244,77.156766,87.262812,129.659474,93.779488,-58.670986,-113.189387,-86.90258,3.6792,59.730619,188.258131,207.847423,37.139273,-217.98623,-270.780877,-229.595775,-182.668921,-90.801952,-46.480355,9.116392,10.033861,-81.835567,-273.750543,-328.288753,-285.460347,-218.591847,-100.181764,-106.771986,-255.161612,-345.410375,-330.119291,-226.066693,-152.150464,7.730724,58.651936,18.036087,-56.170066:-122.088091,-151.837939,-64.586353,117.194349,131.134793,52.351474,13.224865,-48.573772,-93.882408,-107.255076,-74.997353,-16.619818,107.302271,126.462763,30.286844,-45.129158,-57.059096,103.551396,154.525402,160.478092,142.570684,91.800618,73.310384,24.219043,-95.066191,-145.028421,-122.778895,-69.270237,-33.057437,-64.166743,-121.42191,-124.272395,-108.908146,-112.46285,-100.891328,11.44913,85.781839,177.222372,188.903066,118.964022,-22.142499,-60.800077,-71.006343,-61.692909,15.233197,84.244061,176.555169,149.549487,-30.548963,-74.937831,-3.898856,89.863143,74.437548,56.243359,61.583472,-15.425662,-149.257213,-164.148747,-97.734402,-77.829941,-125.969842,-155.25826,-173.276136,-178.517355,-224.24676,-328.475435,-357.864271,-278.839096,-189.864197,-52.739878,-41.070899,-56.473983,-10.684131,20.212457,52.131318,55.967358,78.297109,88.339777,22.55129,-46.902736,-107.699626,-6.314585,59.559162,129.24612,127.562057,98.750909,78.586831,-34.658543,-259.289941,-320.096416,-248.091415,-194.207694,-161.565509,-155.713598,-166.283339,-205.388828,-302.327164,-327.424322,-299.118,-195.701426,-149.993379,-100.536839,-87.797465,-119.683835,-265.53546,-322.51393,-294.508593,-224.461968,-60.20377,16.473161,163.725498,224.47903,204.155336,63.966256,60.796597,181.225339,238.979374,260.451874,230.218486,137.507761,23.012538,-9.907931,4.782697,8.944267,2.979472,43.936947,135.157624,95.885306,-125.904343,-233.968698,-206.110567,-65.623651,21.566122,116.958177,69.887194,-129.682973,-201.430835,-186.358417,-146.530629,-126.606015,-64.79741,-48.663967,-149.90574,-246.448697,-351.364626,-225.064055,-120.085027,14.624258,46.89272,82.192946,64.654852,-41.790637,-151.406291,-158.909523,-41.291612,26.570924,65.094914,56.678848,29.106745,0.518665,-79.454539,-79.021745,-16.021905,153.458475,211.245987,261.874047,280.840116,309.462635,232.485574,154.950384,86.318051,119.001822,219.524567,255.361759,278.050991,269.676337,211.538477,145.192517,145.792464,191.083002,220.946436,298.395612,303.849055,146.202973,-78.483276,-133.738928,-92.592647,-36.478373,42.290951,69.810577,108.067775,102.598117,10.823427,-116.533803,-100.089371,110.337399,209.468019,268.587896,251.476421,152.288165,1.82483,-53.884555,-81.96537,-60.187219,51.291794,122.790669,128.777069,55.714831,-54.592499,-107.323567,-125.986446,-55.924449,14.334698,71.017061,50.09326,-44.900089,-201.704123,-251.87804,-198.283322,-119.518095,49.140224,110.567923,133.845225,105.86187,10.957511,-72.965067,-58.617328,84.447166,147.255062,119.652545,57.452284,-19.683069,-37.794279,-34.769312,14.679687,40.089499,74.595794,94.323141,99.918434,75.234218,-23.379716,-122.081341,-121.840387,-63.974485,-39.032455,12.099549,28.175839,-41.175218,-217.478184,-271.929131,-196.141985,-93.076531,84.471197,115.330231,85.023301,73.373711,80.091233,51.63788,49.574252,121.736077,175.538169,239.505623,228.226588,127.825932,-9.614855,-62.591334,-86.907203,-66.738865,9.945494,70.52073,182.089134,200.406102,162.68448,108.179223,85.177809,49.482502,67.258775,148.778898,159.282398,140.04795,99.929315,46.462886,-48.049447,-43.208885,79.817943,149.992375,210.993263,216.712762,208.322176,190.601378,195.167122,209.712062,214.675268,196.027375,169.73662,144.674427,110.861634,86.254069,85.626196,101.102496,143.565123,158.515882,116.779228,66.162019,-44.236082,-53.166366,15.891067,175.271043,196.040978,101.053926,20.496664,-122.47493,-153.376751,-114.92425,-38.830448,-35.479955,-14.706161,0.256496,-78.325635,-151.644329,-269.990953,-356.914698,-367.109999,-271.035088,-188.881641,-96.551853,-113.733835,-210.894474,-347.566338,-391.969511,-352.646529,-305.178029,-242.74223,-220.412145,-178.087582,-182.629175,-339.360951,-523.338279,-497.615922,-325.038708,-275.51749,-229.077155,-214.469246,-247.250403,-358.116337,-398.744182,-349.534086,-272.79987,-76.219024,22.832306,83.998075,37.937994,-63.285708,-126.939003,-127.505484,-17.482975,62.369978,120.541569,56.125931,-157.704986,-178.640052,-80.232202,104.80048,95.506466,13.176939,32.690125,105.370792,104.621663,49.21523,-31.536389,-48.170023,51.363369,158.025073,327.15386,311.213519,77.545311,-96.099878,-83.694676,-21.372419,-37.13025,-107.550683,-104.533726,-23.210315,-17.622713,-157.792681,-249.472446,-221.615423,-126.950829,-75.922357,7.170516,-12.689948,-176.350941,-278.349264,-257.931199,-135.283139,-64.056736,57.288765,67.858726,-52.357945,-118.199742:-12.57945,-164.155254,-182.762496,-58.555791,18.483289,28.528133,-39.991183,-210.0317,-285.295316,-270.134235,-175.666671,-136.53203,-80.664023,-31.74757,54.224386,63.642239,83.394123,111.151737,103.097172,107.686752,124.214316,97.750187,40.207804,-98.473494,-176.120708,-218.651807,-304.778336,-303.026349,-235.589937,-214.854182,-213.054886,-213.471069,-205.798753,-183.899674,-157.411053,-133.149963,-146.316299,-143.73684,-107.901903,-43.565802,-117.12145,-175.21205,-188.032335,-139.693108,-15.526014,49.38519,207.703328,272.701619,269.695972,222.217358,249.60796,319.702873,314.443443,253.13378,204.96726,45.927586,-154.101042,-229.497444,-236.212367,-182.600705,-116.714855,-139.991748,-251.867974,-304.316176,-351.596016,-369.418494,-404.123019,-480.769009,-451.010544,-219.398988,-113.109102,-67.744433,-117.681322,-130.022945,-94.46572,-59.314957,23.037225,79.620389,170.543499,165.837675,84.609563,84.324734,160.301195,302.364791,287.790564,138.134175,34.553493,-226.508857,-446.180979,-489.590974,-431.179195,-374.291007,-307.969465,-305.29589,-373.384046,-424.544588,-483.761638,-535.422264,-552.312813,-464.689073,-371.963663,-238.329672,-240.976756,-362.042266,-475.465513,-476.655659,-370.305641,-287.823114,-114.140314,-14.840835,249.812556,383.359965,450.625626,274.887084,237.119732,321.201243,359.068755,343.462989,302.990629,191.984099,77.532341,19.521263,-62.01367,-62.961977,24.787256,78.568421,65.438607,-7.818,-143.720535,-180.148379,-190.325978,-181.008842,-151.661324,-106.149964,-116.937323,-198.599458,-257.948414,-262.764478,-239.257785,-220.460677,-149.796389,-96.24303,-2.657611,27.91648,34.160604,33.396885,75.612384,164.197629,170.802555,146.553415,120.084748,18.229468,-97.067405,-129.443121,-135.369913,-124.827991,-60.316584,-3.608284,32.734707,-8.476953,-89.969157,-115.336686,-101.068652,23.698884,112.729592,224.139729,226.13415,202.361035,187.82297,139.893813,53.296124,79.051099,227.025753,309.59486,430.22424,465.383716,522.996689,565.66586,579.8547,550.267657,507.131638,451.104068,420.811793,239.869376,-1.597298,-83.564279,-130.642314,-106.934008,-14.330794,48.955533,139.832129,131.277352,26.912001,-39.075693,-3.628452,123.691856,167.045889,226.775554,237.311237,117.870743,-103.284678,-160.151336,-128.316075,-85.595813,0.075942,45.770794,84.372164,80.844676,78.065753,24.656409,-4.789082,-9.816024,9.413537,70.471813,84.801626,24.44477,-73.00648,-87.893851,-36.73929,0.306421,116.492331,206.768985,295.76057,259.58341,120.89086,47.531859,77.665903,189.696297,210.675632,195.971805,198.550204,203.817259,121.844717,55.949033,23.669889,90.130014,240.840272,262.313218,208.395636,165.553063,68.69302,10.786685,45.303174,155.201693,164.151253,129.110285,111.628296,29.801802,-83.316795,-112.462994,-61.019504,1.761976,105.342053,140.316837,188.579355,193.831987,159.994976,109.153592,102.451259,131.112554,151.402846,147.338648,107.59528,-16.169852,-109.589555,-131.756257,-120.679093,-79.556129,64.35734,149.47246,228.402418,197.412839,126.383715,124.203534,116.799425,75.697662,72.168906,127.008034,142.55121,100.133456,23.629157,-21.084664,-46.628221,0.266094,183.138352,293.550728,436.884923,427.309721,318.388607,285.478583,309.791704,351.761381,333.157689,226.199225,188.005122,188.913795,184.702602,159.050414,106.709472,94.042217,87.042726,91.33854,84.265751,58.360309,-15.287423,-72.563256,-67.064372,36.316296,95.076718,126.807567,90.516417,-47.225668,-136.902706,-112.832988,-17.443835,-13.801081,-55.464898,-65.562353,-120.752292,-178.273743,-298.798417,-383.798751,-396.02607,-361.67575,-331.323004,-282.975043,-294.469339,-401.305905,-498.637955,-504.986811,-429.657988,-382.102952,-327.825677,-313.707156,-305.106491,-322.59494,-414.535458,-502.219869,-495.545752,-428.200837,-408.880694,-369.961002,-353.545441,-397.564667,-478.512971,-490.831054,-432.659921,-378.288284,-232.265902,-137.6433,-18.49615,-21.491068,-42.273966,-5.577994,27.845381,98.633099,124.801962,154.338998,130.562965,-12.752963,-100.168542,-89.797775,-56.428325,-54.662081,19.276369,103.480424,166.199618,98.548613,-75.68531,-102.040901,-40.104278,148.990889,217.174848,278.796517,282.186531,193.111253,-14.235529,-104.115326,-138.389223,-102.633655,-33.357332,-7.744507,-7.756575,-48.567972,-171.993034,-265.68036,-275.132214,-226.036719,-173.944658,-66.606018,-67.108795,-175.077992,-243.315896,-234.126738,-156.831587,-104.966348,17.64393,66.706194,34.249056,-40.719537:-122.054904,-237.454065,-213.809285,-110.945565,-77.59832,-36.871203,-36.669221,-105.730792,-231.257602,-282.00977,-255.546978,-173.88349,20.868567,84.140146,88.940009,61.340966,62.18424,89.686135,96.168319,160.231854,199.65882,163.954042,73.216615,-150.849768,-264.87777,-295.919742,-365.946381,-369.182195,-261.305226,-192.217267,-122.819114,-141.096092,-254.860106,-262.095849,-215.596898,-141.371292,-102.66648,-11.331927,-7.232228,-130.500138,-271.051507,-290.059396,-222.853631,-153.952727,5.952452,87.515407,254.359251,314.804571,317.238382,317.315602,367.755819,429.576716,411.42799,350.736123,313.268764,186.93186,-12.117753,-107.919655,-156.791113,-112.175399,-43.243822,-58.038612,-149.401389,-196.724416,-309.772728,-445.776256,-471.024144,-419.446517,-347.461104,-143.071589,-88.928347,-170.187945,-240.020305,-193.550984,-73.380676,-57.667848,-11.325074,55.57943,139.188703,118.248894,50.10996,92.420385,154.195808,240.145536,248.956404,219.473796,147.639187,-126.786135,-420.05437,-512.877566,-507.10541,-431.148367,-299.613081,-287.618897,-333.386869,-365.814023,-444.15447,-475.733232,-447.701571,-341.793611,-283.056748,-225.01338,-251.264143,-375.665333,-496.252277,-512.424983,-426.195422,-349.608301,-123.278591,37.460852,316.430575,369.395588,325.203292,296.016341,345.173319,457.114082,449.839171,314.781769,229.079029,92.575919,-28.534709,-80.852654,-75.858927,-28.7896,75.084706,123.285666,140.868829,78.702524,-141.313436,-241.250695,-217.521666,-126.352979,-77.584969,-27.522008,-53.712409,-188.13679,-277.668064,-282.452666,-242.835202,-200.853676,-66.6458,3.009909,82.716139,91.604342,24.011246,-72.137743,-54.57799,46.2582,73.493854,74.704764,51.813452,-40.026884,-117.611189,-132.160104,-147.229729,-157.59182,-128.574107,-87.956271,-78.623575,-122.592378,-196.036764,-183.148401,-145.700971,-28.643336,40.743049,133.418711,130.843405,101.52012,44.048097,-20.466719,-57.850616,13.515869,223.893702,315.697428,421.856387,428.188672,366.717278,320.578091,350.021785,458.430277,489.279181,455.90773,389.944669,200.794496,12.972176,-65.257113,-149.955765,-122.833055,89.92044,208.408356,250.092688,167.414554,-31.175995,-77.655703,-24.707496,116.704438,158.639198,204.75307,219.751447,179.541438,-1.63747,-90.223067,-97.034632,-26.608931,132.751395,181.018775,160.385581,119.386572,30.096961,-63.851236,-53.953245,63.775741,102.824405,92.685397,59.189607,-43.074515,-138.878992,-154.932165,-102.543582,-49.645023,92.901966,163.576282,167.097251,99.100062,6.023025,11.559052,9.359383,54.188461,126.757304,244.230063,228.521537,87.569507,-59.270347,-94.201044,-46.297361,13.208207,138.024004,191.389989,221.325107,180.375211,41.0598,-28.005601,-6.478608,91.949309,135.343771,123.252142,52.75659,-93.007257,-166.596603,-188.279527,-144.532746,-69.438677,106.500449,158.800926,198.35316,210.703871,138.739412,-15.215293,-17.739364,112.281039,153.649248,120.214885,87.454079,22.759486,-102.979787,-163.013561,-145.233288,-58.546209,152.48474,225.111538,241.940919,196.250951,92.176538,75.246221,98.660896,115.123011,109.786565,156.936079,180.994183,104.331834,-32.819224,-71.263013,-93.354594,-61.327719,137.781999,266.143417,427.95401,444.013809,352.040827,200.568655,175.956328,224.409882,247.5772,244.670434,243.153417,232.170432,84.743268,7.450293,17.902953,68.485855,111.924935,105.508123,80.104264,56.433571,-33.640676,-61.942908,-15.69228,110.381576,152.742435,143.840539,89.085179,-39.685828,-92.821502,-84.352305,-19.310997,23.18995,74.800929,53.555891,-88.964615,-174.565666,-327.607173,-398.284493,-375.166854,-266.353334,-195.545466,-78.922217,-93.080876,-244.780754,-385.591419,-412.854719,-342.672293,-277.349598,-166.299712,-133.877489,-141.175932,-182.737132,-340.689858,-436.954617,-381.831528,-164.010134,-77.40686,-22.837038,-64.974914,-201.166379,-289.1932,-300.136554,-257.449449,-228.231711,-114.369089,-17.914696,120.487044,113.194764,-6.109553,-53.470722,-7.927738,159.755142,244.318473,300.701401,232.598324,-7.917444,-131.160495,-110.040688,13.075955,46.465952,79.063918,138.420942,233.553153,191.597844,-13.134193,-136.171194,-102.598184,97.160449,200.517809,303.801287,284.500181,134.685856,-16.457505,-50.419813,-43.123067,-20.52638,11.462386,9.711789,-36.930721,-81.575671,-201.814837,-275.765737,-267.059797,-180.579848,-113.296141,9.337399,24.591725,-51.801046,-153.606314,-172.464256,-155.54744,-138.79726,-44.043975,28.272967,21.075515,-81.040315:-133.750289,-179.350461,-162.065589,-126.244365,-106.677235,-19.976809,4.020931,-128.646,-305.31257,-312.958744,-218.37246,-164.045232,-48.21952,28.464775,166.289002,196.836589,195.846008,159.6695,144.116302,163.694426,185.133664,135.164681,41.471417,-182.684455,-305.201142,-332.995026,-303.682135,-243.475517,-162.185974,-177.780473,-246.022863,-258.560557,-256.415398,-246.012487,-214.013213,-157.682558,-169.438316,-194.204126,-185.805464,-206.011072,-288.714548,-322.923737,-314.436115,-268.462499,-109.503597,0.289665,181.001829,209.93447,223.479711,283.049147,291.322111,223.634695,195.438792,186.193439,143.706364,-34.387828,-182.940191,-253.378491,-369.984546,-376.911705,-327.251731,-316.984482,-329.722872,-336.510853,-369.410488,-443.949351,-479.382888,-499.952849,-454.944814,-237.829375,-135.196984,-107.349898,-204.502698,-225.032517,-174.593875,-135.455431,-62.241542,-4.322427,109.603225,118.766998,47.656422,23.665397,64.584239,128.396852,101.532574,-32.521374,-129.922379,-385.959875,-570.648827,-597.742958,-585.906083,-575.71078,-512.277064,-451.147684,-376.275347,-385.98978,-461.978856,-516.495239,-492.19632,-401.65539,-373.627971,-342.251144,-344.170326,-384.147262,-457.669408,-489.192218,-401.968721,-281.098188,-17.054975,91.217755,243.445025,288.42142,287.116109,258.540481,299.819751,373.228208,344.249584,243.819387,205.674556,115.844352,14.828959,-44.744647,-154.588496,-161.800546,-54.268408,17.811842,61.466785,11.429302,-126.671836,-170.468701,-173.492547,-198.567646,-210.653325,-211.28079,-224.822047,-290.75116,-308.566512,-293.528165,-230.08865,-188.87184,-90.660467,-25.93907,86.379798,110.473431,138.892621,181.625026,203.883598,201.044952,170.243254,141.57084,140.536776,51.988395,-114.600456,-166.519491,-133.743668,-69.411663,24.514399,26.899891,-63.337445,-141.707335,-305.958,-316.654086,-200.241265,99.547397,179.024912,243.349365,277.695494,315.015813,235.988507,182.191016,185.840381,227.947198,268.453487,280.169135,372.198488,448.77515,587.696541,614.743494,593.723808,559.016709,563.22548,587.822466,562.668364,349.581039,86.09151,22.927375,43.649325,86.671505,172.976311,237.212726,369.447551,370.869594,201.324853,8.864975,-1.628633,134.788473,209.858164,290.257383,291.828059,196.874638,32.989628,-14.786311,-29.310344,-47.638428,-66.453847,1.633293,212.278906,260.704356,204.999758,129.404772,125.419268,169.191351,218.459231,321.563659,317.59344,196.387081,90.599929,53.024668,15.686836,37.791115,171.981726,250.169677,313.865357,296.415497,239.542897,199.224942,195.559999,249.307185,301.366196,414.357853,454.861637,488.624755,407.789947,313.530326,222.132453,263.441948,349.18611,352.030558,321.020047,304.325273,290.240017,259.753182,229.813049,212.124551,233.535676,204.005497,119.988156,-62.619857,-119.82283,-116.152901,-90.738506,-74.495697,-53.584226,-29.04901,82.115594,119.439337,69.612876,1.860471,1.729724,-22.500271,-57.579938,-47.618389,-13.885402,-97.112064,-312.92023,-340.502427,-206.381491,-115.43065,27.072919,67.76399,58.037863,27.627598,-24.353228,-47.658529,-27.800324,37.513581,42.611734,-5.179455,-34.493818,-94.927425,-186.804272,-236.830228,-214.331289,-116.50015,132.565849,230.821063,307.467813,283.142215,190.487934,175.110262,191.378285,201.975411,214.560764,291.095629,304.587651,218.955876,106.408327,63.427379,26.831445,36.420404,109.601654,186.833781,319.608831,300.554858,113.939699,-28.37633,-23.833141,73.606522,113.069673,93.635152,22.814355,-149.38906,-160.848999,-122.184433,-32.883394,10.629549,27.600381,-6.332646,-114.674864,-159.001096,-183.306898,-246.863301,-294.701094,-280.467055,-236.271711,-232.415243,-283.679548,-380.110738,-390.969542,-373.212866,-304.1533,-272.715443,-208.962944,-162.140608,-160.114751,-245.393201,-431.250645,-472.129706,-462.54692,-429.813501,-416.012013,-413.580755,-424.332221,-469.700845,-517.72085,-516.96484,-462.654167,-429.518114,-322.162865,-230.73061,-94.784723,-97.300682,-169.225519,-164.694305,-103.005679,66.154447,128.211974,178.299616,151.98467,4.667378,-107.090359,-120.261011,-75.569277,-52.016338,6.133441,98.029473,274.388346,249.841029,26.389144,-103.056401,-87.921483,24.647472,108.412132,251.933415,245.86827,87.675252,-92.38147,-176.451305,-264.677526,-238.87471,-120.796158,-79.488202,-110.918845,-169.7917,-286.064274,-354.819336,-352.915696,-292.785858,-253.09452,-175.420855,-162.572501,-231.260519,-317.405464,-313.033,-177.448743,-79.912337,57.619797,64.626918,-58.499961,-153.934291:-193.72155,-294.467825,-272.777139,-142.733655,-67.709291,31.084778,23.172748,-106.757686,-230.948827,-248.301873,-206.251172,-159.104729,-25.973667,39.811777,96.633801,93.930103,103.196135,123.005682,127.133996,157.618104,184.888476,167.971647,96.115966,-109.194756,-293.483176,-359.820773,-392.830554,-351.737582,-213.113998,-161.110851,-185.478139,-251.034473,-347.051083,-297.015871,-239.095671,-165.947756,-162.653806,-130.654532,-103.950516,-156.050559,-304.197239,-349.831572,-313.991541,-226.34818,50.399136,195.074489,351.500636,347.857301,274.276172,274.347886,310.388715,351.437309,350.367563,337.208052,289.791125,93.259575,-77.919296,-139.257111,-194.913613,-166.840735,-53.419969,-28.088879,-124.791161,-221.767793,-403.881197,-508.93096,-519.839428,-459.620007,-388.691933,-211.360792,-167.128344,-226.312397,-287.870452,-269.070219,-186.191835,-134.512513,48.329776,161.113754,253.583082,208.568348,81.307214,98.807861,157.169001,220.644801,203.971174,117.073365,37.564069,-230.503665,-548.032819,-636.472837,-567.389538,-461.751536,-304.871422,-289.469834,-356.225196,-405.438097,-488.153203,-555.616196,-575.317234,-536.712282,-470.645349,-309.988395,-278.224813,-399.357966,-555.686674,-553.924223,-426.620631,-335.595151,-89.370823,57.59479,271.025247,302.96212,250.229973,189.3567,208.172301,314.786522,362.76811,372.205823,317.156704,99.631361,-139.181595,-202.885921,-196.882768,-164.937338,-84.280124,-39.170591,-36.083662,-94.371082,-231.494038,-283.895036,-270.252347,-222.303104,-206.709306,-184.36372,-196.152789,-301.492192,-365.516378,-337.349434,-210.509778,-144.064416,-38.792278,-4.43908,31.844074,47.643231,41.844488,7.491019,37.684422,146.724056,182.433687,184.757825,134.769127,-27.905052,-165.516151,-223.403214,-257.943062,-205.516842,-19.342886,49.215632,15.215177,-62.002529,-212.372683,-285.876689,-266.567929,-96.175897,26.721747,204.443334,218.744012,140.98735,30.413052,-10.500768,22.247737,89.489891,249.824279,334.684889,435.557231,438.869962,451.147184,532.419692,581.886176,653.535012,673.583866,648.804951,561.709106,253.966833,3.117103,-49.208993,-22.232704,27.675304,111.881519,150.198904,226.438015,214.911532,52.907416,-29.336658,19.271586,160.384521,204.495003,261.199878,269.329637,158.654725,-23.414477,-60.420598,-27.400461,-0.174939,90.173378,169.74109,270.797914,243.008761,108.05595,27.387356,51.719499,204.443036,288.700253,390.576501,377.272832,235.803126,58.141639,-17.179823,-57.149758,2.794921,251.13012,374.593442,403.168793,310.398267,134.462483,100.041578,116.22251,183.788653,249.705804,411.575332,442.690905,345.927407,148.883819,56.976424,12.490485,65.66014,218.342887,289.569369,341.510188,304.430685,142.676308,-3.301944,-2.155327,125.758917,180.940441,163.322986,91.546986,-103.348591,-221.064149,-222.642552,-144.718902,-102.862752,-40.540402,4.065433,109.468067,141.436776,116.711367,-12.48905,-55.229126,-29.356852,10.8773,50.976337,14.465178,-165.223302,-324.262489,-339.471625,-230.200794,-138.562733,44.991279,117.084431,172.071725,160.688438,67.484156,-81.010932,-106.704941,-39.105067,4.14441,35.322986,19.328364,-67.711354,-191.315311,-239.0739,-217.884521,-135.865185,121.348238,254.947402,391.971825,377.141061,260.327686,144.562536,118.975941,146.267481,180.647995,240.714562,247.413029,196.544181,102.75941,59.761617,21.250747,34.979114,114.53347,164.720259,211.655907,181.32087,20.369837,-123.947813,-108.054885,78.365532,170.931197,228.508614,171.526315,-69.90736,-219.388933,-197.004116,-40.86155,43.714345,164.73295,179.9131,74.533346,-22.996839,-213.412155,-325.182566,-315.783883,-166.021701,-83.01876,-64.80537,-147.002301,-355.000409,-471.199843,-478.621968,-352.038262,-256.4556,-106.550316,-62.020338,-125.040207,-237.872079,-453.084183,-465.74806,-392.642531,-243.765332,-209.098504,-170.872429,-177.02011,-282.914172,-386.905089,-385.603864,-280.521047,-218.3895,-119.81772,-64.619246,35.442609,38.336918,-81.565589,-152.14298,-77.40455,177.3622,248.53013,234.337204,189.107674,46.100003,-112.105533,-138.124937,-59.425489,-15.805237,45.408598,111.105513,221.696779,199.017437,15.090944,-188.413446,-191.996085,16.042798,127.101827,195.317268,156.5269,20.951462,-85.458771,-123.84643,-150.940583,-130.641403,-45.398716,-2.541174,-19.402942,-95.303698,-279.228731,-362.52808,-366.025644,-303.16008,-226.992096,-63.652228,-45.297182,-187.34512,-337.174238,-338.352793,-216.468727,-133.128942,0.667189,17.449592,-85.382603,-168.025189:-191.540492,-163.407792,-133.009556,-157.190231,-174.550613,-94.081911,-28.419272,-3.560567,-100.744028,-146.442369,-158.765242,-119.434283,0.046669,50.545038,120.933262,159.938584,260.060753,247.274686,179.383271,71.18089,50.388457,17.540652,-6.998297,-110.778105,-217.040149,-234.647396,-194.862638,-154.903155,-120.263863,-132.533742,-179.184585,-190.482113,-167.999722,-229.735755,-299.384559,-392.342944,-385.691109,-244.765509,-156.620087,-136.478402,-264.53475,-298.536785,-320.754313,-332.40861,-267.180962,-168.285941,37.154365,79.86971,27.67823,-23.874705,-0.872634,61.190509,63.588542,33.603644,12.703983,-46.234705,-155.929267,-232.129829,-331.070645,-330.225883,-333.385724,-357.712138,-365.352273,-335.865062,-275.626676,-285.067804,-301.091652,-308.504042,-291.036384,-196.674612,-136.351297,-57.545837,-57.597436,-67.566702,-20.93801,24.56242,88.573942,105.608978,75.008003,25.361338,-26.817766,-4.709241,-17.272814,-83.199018,-111.1778,-145.700957,-173.000371,-312.975235,-512.893789,-578.709147,-587.548825,-536.344725,-385.524963,-324.14632,-276.612665,-273.548302,-261.133907,-289.696168,-299.655504,-236.17752,-168.163089,-7.296497,30.229531,-56.757833,-145.872971,-146.922932,-94.879191,-43.200063,99.390027,184.287063,333.873765,371.745993,348.202014,265.778745,243.203233,242.460615,264.78174,324.864381,312.770852,189.468227,62.94407,5.76338,-102.520206,-126.372059,-87.171834,-52.841071,-60.372195,-116.979148,-219.761283,-216.618644,-206.156779,-247.187213,-284.234892,-256.03847,-207.218878,-197.268841,-244.585784,-228.19618,-87.014836,5.049904,104.412692,87.870755,31.767059,60.418214,196.660811,250.902549,253.977854,245.484266,236.372442,235.008808,218.779186,104.119489,-48.190295,-111.577293,-153.979786,-135.161084,-120.682083,-139.657571,-194.878693,-226.603573,-302.992549,-356.733989,-349.719775,-274.582534,-207.097211,-31.910059,37.905365,117.100331,123.590755,67.80671,-77.263656,-99.853263,-29.317622,33.883328,145.812123,186.729263,308.986341,497.480294,554.926585,498.607718,432.865444,395.428597,386.856393,251.063735,133.077468,148.23491,224.58844,237.415967,265.62901,321.443999,423.125434,401.878026,230.208605,89.634534,94.365752,194.932672,242.958264,360.00673,422.05121,398.300878,208.051373,142.668777,90.272043,53.169991,-13.623526,23.569111,216.997703,293.749932,321.140948,319.210287,358.322549,425.994378,408.310647,305.604957,257.179638,159.972104,25.542757,-31.005177,-10.194247,71.688339,246.011269,290.965734,266.496499,226.276314,174.628854,124.207289,99.11899,156.122366,240.27887,385.33085,420.5031,461.033154,421.566838,358.444471,283.215279,304.5641,390.435339,417.965575,400.412686,370.47187,324.788792,251.163747,215.901967,209.193507,205.121883,112.44358,55.955694,5.805146,-55.114748,-90.098254,-87.229218,-83.364106,-148.577855,-186.025019,-200.974338,-184.199793,-131.770466,-94.242424,-112.802112,-179.379782,-166.143911,-61.107664,-54.763276,-217.056695,-406.343873,-433.402249,-357.679619,-290.858597,-140.766534,-87.757152,-130.144422,-181.179106,-130.488351,-36.90747,-66.227997,-199.003763,-246.669771,-252.271874,-222.787422,-209.081482,-294.630658,-320.6971,-273.659106,-223.289785,-81.941265,22.990517,183.424512,173.2489,63.508581,68.525888,114.192013,181.717267,175.659876,159.714545,179.633152,179.797228,37.154386,-29.852371,-44.034172,-6.627233,104.689778,163.745143,209.239285,179.294181,81.674248,68.383943,100.158311,144.255962,118.445174,-40.313792,-134.762632,-237.213892,-207.573597,-163.588493,-37.444569,31.534481,109.905417,103.612399,21.176943,-33.876678,-115.777541,-135.629386,-128.910206,-117.716534,-121.954387,-132.095417,-142.941751,-178.237673,-169.405526,-144.406142,-81.573767,-54.486847,-13.281358,4.423443,-9.273032,-65.129804,-231.39975,-301.545219,-287.092648,-276.939356,-303.276787,-331.15523,-327.873011,-382.1002,-465.336438,-480.090231,-450.536494,-410.787382,-311.737611,-249.434326,-104.773638,-65.293176,-99.021562,-112.87369,-76.475061,-18.650961,-0.201782,55.151141,55.165502,-9.399166,-53.691479,-87.4961,-142.018055,-125.101618,-2.768039,80.309584,157.874304,126.663436,25.739288,-32.956852,-54.268405,-55.039609,-9.006142,120.603204,132.65393,-6.531967,-188.525736,-259.498844,-327.208916,-304.776649,-201.902774,-166.666324,-178.979156,-207.373837,-256.083308,-294.546432,-294.872212,-232.267754,-187.995063,-130.899102,-146.067259,-228.412235,-184.238622,-117.522363,-9.120142,21.206632,88.841464,133.81643,116.92657,27.645861:-128.904267,-174.309274,-157.510289,-136.14413,-137.749411,-104.038928,-64.253872,-24.741251,-125.734989,-196.558174,-223.228738,-165.608572,-26.741708,20.910847,85.843548,118.565126,186.699176,159.462934,105.243242,15.475879,-14.522172,-76.054657,-97.707528,-142.127404,-238.98065,-267.214312,-200.866873,-143.585275,-103.631549,-125.025864,-205.734033,-230.502612,-199.584613,-174.120359,-202.174085,-316.770924,-345.693201,-257.845996,-199.469916,-193.813635,-274.646141,-324.756352,-379.295156,-341.404203,-171.586025,-90.653687,10.795842,37.613868,56.04697,46.711904,39.154814,38.102044,40.881295,12.724511,-33.762552,-167.653911,-304.54536,-375.289329,-442.403998,-414.235624,-302.550723,-267.691112,-263.233996,-255.984823,-215.724317,-257.747199,-287.272401,-268.597492,-235.26253,-155.570439,-114.086581,-61.945027,-49.301813,-58.713992,-83.108725,-83.443703,-39.679667,14.633355,95.34033,80.547225,-1.702107,-12.873677,18.878742,27.456214,-28.893273,-171.370958,-234.633622,-375.733491,-505.768408,-544.064729,-539.426186,-500.283316,-394.801911,-347.64748,-293.395457,-279.531967,-263.50104,-278.724872,-262.022107,-136.770124,-78.300915,-39.641933,-41.897034,-100.033265,-266.0442,-348.927449,-325.64239,-209.810086,65.864797,173.719179,305.443378,332.293758,291.214454,214.843539,236.034106,326.139626,327.576687,276.381074,262.126762,224.566353,115.886039,32.685876,-103.163296,-114.957818,-32.645202,32.454683,81.109765,39.471529,-71.266192,-103.471547,-94.58527,-69.041751,-56.816354,-40.590641,-59.262575,-152.278999,-177.641402,-154.291066,-92.087098,-71.111112,-76.143437,-83.050331,-41.769999,6.635924,97.969339,132.412378,165.165571,237.995411,226.601651,108.191485,34.683823,-69.875791,-123.657072,-139.463958,-77.316947,-20.265373,-8.649935,-45.870241,-109.652716,-128.976481,-168.395459,-202.104334,-165.282307,-15.652159,41.691451,137.154864,198.355898,300.322235,270.550315,219.33992,163.106065,173.854085,244.651293,287.773131,360.534506,410.284913,546.466337,573.27342,538.808597,426.074656,368.778655,339.048521,344.447197,250.684939,58.493635,13.719801,98.892744,167.592922,229.849152,255.705606,319.940222,310.288969,187.435472,59.28532,41.843595,122.08921,192.50674,307.733317,333.362229,288.339093,145.901902,75.525409,-16.584978,-38.122374,-29.695405,5.517958,74.462397,75.362064,48.530627,94.948823,130.902514,137.142735,120.614714,135.63556,145.236833,75.370899,-11.800233,-24.987892,-14.818133,-0.231685,71.26472,130.078143,247.420016,268.396954,191.331391,104.813732,103.973863,170.818517,226.82136,359.288556,424.3226,498.007686,429.182076,348.627357,247.351498,262.843694,337.755926,365.614594,375.796292,356.412934,291.914024,213.911992,200.706534,205.14137,168.03018,44.503981,4.058725,-14.159218,-77.519948,-155.29483,-198.287476,-132.068827,-19.86013,-14.56125,-3.590473,39.744324,156.704724,120.711931,44.482843,-54.921204,-55.900789,-3.34268,10.752122,-66.318613,-187.482247,-218.742237,-237.679932,-238.554011,-162.437887,-87.077259,-47.943838,-84.888557,-48.954262,28.701821,-13.523503,-156.310607,-189.127464,-165.536692,-143.4148,-149.08076,-209.23538,-230.690319,-189.311975,-128.479097,-5.680545,46.685966,177.347765,239.471703,251.98738,231.36289,278.509959,310.214246,240.442192,141.080688,161.83443,192.676139,127.880179,81.026313,-17.268801,-40.388384,50.714534,139.626419,190.510089,124.559542,-22.770067,-67.091606,-47.307545,57.45195,91.353265,23.464482,-56.639302,-147.885423,-77.822465,-52.768532,-38.388516,-22.42918,-60.177786,-123.340278,-184.466205,-153.12587,-106.563995,-188.410722,-214.338405,-183.693839,-179.274055,-246.129535,-281.844802,-279.279763,-235.294405,-217.968405,-155.196874,-121.612611,-98.034497,-91.929643,-93.962531,-133.708339,-286.707409,-379.841865,-362.027756,-295.231642,-285.514548,-287.246292,-301.851517,-388.245873,-519.168169,-559.137504,-484.529562,-400.200889,-287.342659,-253.031971,-149.029234,-78.463314,42.645659,76.987401,72.116191,49.905892,43.793988,49.611659,34.557919,-78.581548,-219.20232,-253.422207,-216.333992,-157.676509,-8.336496,62.102029,128.294327,112.426493,28.548226,-46.99391,-77.204913,-92.537957,-47.980783,71.844428,69.485911,-85.274979,-229.054691,-261.029462,-301.897935,-316.074566,-256.048157,-169.828471,-60.356104,-81.840503,-171.632777,-267.191094,-284.218955,-224.021411,-194.035279,-189.166818,-206.032317,-255.358877,-276.932767,-250.777738,-95.140738,-3.014909,121.452708,158.666942,142.918896,74.135138:-174.903776,-215.637447,-162.762772,-48.856362,-24.899557,-6.258168,-4.851306,-45.288571,-105.927244,-116.305887,-92.239249,-40.731508,115.607099,163.495574,182.397781,199.250759,275.283174,296.954372,254.375529,142.473156,124.008269,128.11892,98.329666,-28.378886,-142.96409,-190.871036,-236.001572,-218.384676,-145.632209,-117.23487,-115.349141,-133.23644,-185.830098,-267.638981,-285.003348,-241.039112,-211.628729,-199.080637,-208.101988,-212.942709,-229.012809,-247.265114,-254.035816,-227.035144,-83.710846,37.306684,243.238971,266.485171,213.944965,183.093218,187.167314,197.103001,193.152542,179.205675,172.783389,126.819625,-22.048774,-114.38233,-222.809475,-230.04872,-223.816889,-232.594188,-282.458888,-308.4805,-308.374013,-323.366674,-363.348179,-442.563056,-442.21831,-322.771925,-249.602983,-190.224424,-203.128158,-218.311596,-195.135134,-145.314522,-37.79326,12.265275,98.012287,112.546546,73.774082,13.855214,-2.297914,-34.111575,-59.370233,-116.570988,-170.575617,-368.106406,-549.892544,-613.164753,-651.544016,-597.959887,-434.318434,-387.501482,-373.768303,-369.361101,-335.08806,-345.852017,-351.972338,-313.848119,-277.945757,-184.774257,-155.478641,-232.623801,-422.110343,-482.792613,-418.265198,-305.460944,-48.718739,66.295604,240.581527,280.631761,260.466851,226.478558,245.584905,314.338667,328.609528,318.783428,296.505206,184.026653,77.973836,52.675056,-23.691437,-88.48403,-124.968416,-61.084898,44.350348,21.518574,-102.400008,-186.712332,-207.41528,-255.540448,-272.102569,-223.846371,-192.939426,-201.838148,-164.097611,-105.390416,30.077905,70.864256,47.882202,31.716413,117.077435,193.94737,265.637358,205.227435,185.064431,171.512504,142.386654,105.164439,117.339974,75.33309,-89.278062,-157.577342,-176.70988,-146.109734,-73.060373,-29.195903,22.165702,-3.219651,-126.934278,-226.733088,-225.738055,-135.70269,-76.804751,49.419797,104.983213,172.744978,141.0545,77.084844,-8.594191,10.868581,155.731617,258.077382,351.150529,319.114308,312.715594,439.471339,471.608973,478.67044,505.162948,576.100846,547.636175,312.728974,83.550651,39.476836,27.76936,30.968277,116.574526,212.701803,313.470146,252.955978,88.131468,37.383982,40.581385,116.868274,171.156674,264.89395,311.680577,313.450224,92.827519,-6.477647,-8.27451,32.64344,63.460751,79.535932,139.390662,159.301776,181.121166,212.511347,261.953312,399.216032,430.292805,361.474449,293.911838,186.363734,103.992411,56.324519,0.649598,4.909039,47.937512,83.923596,136.511248,144.530451,187.901204,219.957936,206.727134,174.477867,191.015717,325.116429,401.454555,429.650128,325.171909,271.638417,244.645711,278.154708,326.574512,315.512809,272.045165,261.632426,260.954909,228.833784,202.341543,182.586535,197.16966,220.726644,193.514268,63.85349,-50.31185,-86.257035,-112.857002,-112.170926,-107.940154,-95.919431,-85.872038,-101.099377,-128.463471,-116.828708,-96.22608,-42.948329,-26.36271,-26.821776,-50.51768,-177.51035,-331.588131,-353.206217,-253.430225,-182.089306,-111.836251,-90.246768,3.311454,47.903647,51.494655,-29.989047,-60.800071,-103.672034,-134.700449,-126.625646,-79.974502,-79.528804,-241.714985,-314.987365,-311.160755,-234.915232,-22.063391,103.998485,326.101143,341.065785,136.774135,-35.970733,-35.143979,5.723656,17.09297,89.626215,133.407596,153.181214,113.420584,90.785805,55.683153,51.836824,93.062934,121.407335,118.086504,92.954461,60.050554,32.544044,25.316858,50.307321,79.022878,108.187926,60.420584,-115.199069,-131.670153,-79.048732,2.031085,26.113854,103.800929,137.233131,60.433483,-43.687797,-196.814949,-145.146521,-84.519686,-55.997596,-107.295885,-204.261983,-220.467129,-264.477292,-299.317559,-285.068591,-201.076585,-147.621889,-76.176589,-59.775564,-79.633656,-138.392966,-311.686907,-407.902799,-397.710002,-293.752249,-240.62452,-217.451268,-246.239084,-333.858639,-419.245377,-446.529918,-426.122298,-364.587996,-189.069446,-118.6556,-52.650119,-43.691275,-62.371762,-104.797215,-90.794076,36.929431,106.191425,152.032932,134.462365,52.547593,-20.765432,-28.397938,-13.091719,-3.760005,39.574663,94.122015,188.119503,163.835419,38.510966,-2.036482,-3.784771,9.158051,42.155562,142.998588,156.704488,52.64758,-91.756494,-153.365455,-226.072754,-214.92452,-95.064758,-16.047788,37.360927,-15.884755,-203.438182,-327.310028,-309.277409,-147.674023,-72.474461,-58.294535,-115.86192,-240.065092,-238.64412,-196.74831,-69.653563,-13.271391,7.156401,-7.015091,-5.710041,-9.241092:left
72.233651,127.760356,80.417441,-147.440257,-233.392935,-202.542357,-109.8534,85.628325,135.893024,122.226609,102.21148,99.559471,70.12522,32.940782,-12.915755,10.518573,150.640823,305.204197,308.869443,124.308336,25.137712,-11.988587,2.962837,-16.973023,60.124769,150.777283,230.156825,209.137872,186.91878,176.607142,89.237908,60.665814,119.076173,209.707729,205.214819,73.111879,19.515179,31.660055,36.904032,-45.773011,-131.276225,-132.304234,-88.641659,-80.65997,-104.112683,-121.845952,-148.323671,-154.502963,-196.301843,-206.029492,-133.560982,66.421667,87.639073,-59.770053,-138.33152,-140.443389,21.978799,90.678621,107.031837,75.106936,11.152969,-11.767225,27.606376,111.922443,298.113566,309.190243,244.624501,124.23228,98.301135,58.887801,45.381685,52.105198,71.656863,86.470815,118.024969,132.329128,132.530545,93.854914,-39.183408,-95.849143,-114.335632,-13.538343,44.839292,136.098248,147.198859,29.660779,-68.562578,-156.881659,-12.265695,108.309332,251.890162,229.147682,86.195737,10.915894,-58.195688,-18.062169,148.980381,193.669839,144.905182,-35.890499,-145.951792,-244.596058,-174.316983,55.40174,91.481277,58.942868,14.225462,-14.526505,-129.964391,-187.093817,-180.814681,-110.54959,39.315244,49.275404,16.800629,-10.875188,-5.5192,-56.7085,-116.15926,-211.776149,-202.537982,-170.162149,-148.557782,-160.03497,-162.027441,-140.640401,-92.536428,-99.90354,-100.720568,61.350412,132.40636,156.268253,127.231044,-39.963716,-159.613301,-270.466586,-106.66043,37.575731,249.346368,261.137189,132.144967,25.977901,-120.652213,-119.836218,-60.897575,-64.634543,-88.281505,-147.780839,-200.100304,-324.344561,-344.972644,-228.656146,-2.822396,77.885604,127.081021,141.404816,201.166323,198.074995,70.415848,-4.225599,-89.873706,-117.600683,-112.448687,-93.308218,-94.110301,-133.980749,-161.028131,-157.731831,-92.41195,-44.910575,71.924452,115.759283,73.188042,-34.988369,-231.156394,-234.380009,-162.711771,-202.390845,-262.42191,-342.77611,-339.334883,-340.808983,-367.400459,-366.300615,-317.188775,-326.032993,-359.147651,-363.999713,-351.346436,-336.252621,-279.19266,-212.339205,-29.412336,57.572355,70.513203,77.449334,60.384826,-23.305182,-67.423551,-78.102435,50.505155,145.206705,257.519097,231.596809,51.275879,-41.857908,-64.06161,3.69545,85.09832,45.952263,53.441896,119.037816,134.148917,96.954449,79.617127,98.776967,81.447772,51.073749,11.271082,8.015838,-1.166076,-29.699191,-102.224538,-103.99832,-59.159787,5.651001,65.267511,161.63708,137.538396,-83.904223,-197.418832,-223.792241,-98.233404,-54.357324,-44.424065,-59.66507,-97.340144,-138.088845,-191.005204,-149.384728,-51.895195,-118.703797,-167.054138,-206.967561,-216.20353,-276.14117,-304.458726,-233.407704,-10.619734,82.480333,112.342795,79.656702,38.045389,23.41295,-11.929293,-11.498562,19.568224,21.579788,22.43529,32.654652,5.253465,-123.944705,-165.749197,-129.137989,-77.343279,-72.782053,-58.877505,-52.623969,-78.580568,-130.852571,-273.807242,-311.191154,-254.048654,-75.528294,-12.611874,-70.227104,-156.64765,-265.643594,-267.478522,-232.688845,-153.175275,-96.559007,-70.276662,-86.571724,-62.460954,-68.146515,-187.411683,-211.473499,-59.192674,81.111334,74.924417,10.04382,-17.397866,-116.937305,-189.390332,-261.875362,-211.694517,-190.957228,-253.245395,-288.044286,-291.772261,-350.195121,-597.406323,-635.630558,-413.949601,-154.853737,-117.667934,-197.754987,-230.770559,-233.332298,-262.890633,-342.190429,-278.801431,-206.384171,-113.484443,-118.166475,-170.90603,-199.47025,-271.081493,-314.504588,-373.090077,-313.070562,-255.829904,-249.292431,-311.344894,-448.434728,-461.994943,-316.769654,-196.973885,-192.783634,-195.871994,-218.79316,-311.14423,-337.521843,-315.461979,-283.154056,-244.703143,-265.253984,-280.046855,-277.044436,-243.558009,-141.447173,-101.337889,-25.193927,38.591793,48.948704,115.548126,177.941731,220.257441,165.508416,21.041073,9.029989,122.461686,208.074597,211.90618,152.971718,74.224227,-142.631157,-222.907836,-216.951495,-71.873572,-5.809224,59.810328,67.213345,57.937793,60.220766,127.739649,165.885534,171.101836,150.553094,125.218241,0.884101,-43.64378,-7.359954,29.703422,74.13077,127.440855,151.70397,105.132348,46.850398,-11.685032,-20.919048,-45.648968,-34.667773,30.762771,63.009414,69.691654,83.410464,86.471245,66.261415,41.921153,-16.700682,-67.525882,-86.833659,-75.058407,-33.536299,33.742288,33.308125,46.851577,91.184519:69.946945,19.190272,-2.308562,-180.414265,-272.948097,-223.620628,-69.902388,302.397402,441.522101,432.137627,353.859405,290.126035,144.619932,81.980609,-1.321115,-25.75128,-7.779503,92.687195,110.829689,-23.682731,-108.413049,-77.842797,-11.87879,-25.555334,-40.04403,58.013245,219.716425,196.472844,98.117221,72.929124,38.649768,23.888613,8.615444,65.031292,94.113657,44.085887,-6.503727,-77.603948,-91.456612,-64.252535,-57.844795,-104.440044,-208.529886,-215.158512,-226.642538,-264.247065,-284.017445,-243.2695,-156.505228,-73.473558,-6.732275,109.686269,109.167626,-37.113375,-125.5973,-175.955162,-108.125865,-85.05157,-86.267668,-109.183639,-167.098732,-161.67723,-16.573931,96.548171,269.986245,240.780762,167.929157,90.221917,81.113474,-2.558057,-42.632718,-44.291803,-12.365102,11.955487,52.00191,59.310418,41.434405,18.445418,6.704341,13.628076,-1.652743,4.636981,29.376946,105.89685,122.221994,-5.435809,-96.500037,-113.284045,-7.533525,31.0863,95.600992,117.13249,101.866502,68.063561,1.363205,-2.981301,70.639775,131.278656,113.745468,-7.707163,-90.82888,-136.772367,-61.928875,63.881919,83.713534,121.281867,127.463024,62.360148,-82.397864,-110.558572,-71.811963,-42.606124,-6.932262,70.676621,103.454084,49.963328,-19.530379,-110.853888,-109.167176,-71.07304,-26.51619,5.452819,-25.534289,-86.94844,-84.755212,-3.091542,92.078505,34.538948,-121.557118,-66.493985,-20.866355,-38.770564,-91.21686,-212.68102,-253.658435,-228.4259,-45.799333,59.591548,213.100019,253.850931,170.305516,44.526624,-98.618795,-57.731179,50.327156,62.772132,77.251,70.665842,-19.905376,-305.677862,-366.998814,-209.791323,11.989419,68.56449,123.819572,146.595832,161.622757,131.396739,19.331778,-16.80982,-16.141768,32.980603,49.924221,-25.984472,-124.437585,-272.332358,-252.390107,-106.979611,-18.979785,27.584846,165.256682,197.022859,44.704618,-102.969397,-261.651318,-216.225757,-39.391681,-21.121154,-97.659289,-238.548438,-237.211718,-199.235907,-207.142062,-239.120393,-275.89552,-280.273179,-245.385047,-250.823719,-341.775606,-375.426451,-287.021336,-166.627455,-4.682992,-99.35811,-165.71508,-219.958682,-219.671841,-217.911089,-220.135296,-202.104204,-68.181543,41.044051,145.567951,97.04179,-70.607788,-131.967933,-170.911978,-141.605798,-30.168745,-43.25578,-93.842124,-76.629265,-24.318006,-40.518216,-103.72857,-167.248476,-112.088205,-80.559671,-91.566136,-127.269407,-169.435646,-161.326017,-126.934733,-122.0969,-97.202416,25.529833,70.754185,23.778917,-50.714637,-202.898608,-223.328017,-114.108473,8.051177,7.912578,-87.233284,-123.945123,-111.871319,-113.962603,-183.812937,-179.299597,-88.101174,-103.397603,-124.087557,-119.903403,-119.700945,-122.796567,-113.833611,-95.09383,22.258689,141.122005,273.584949,221.740018,46.734239,19.313051,89.711272,128.796404,155.989758,136.030011,126.372458,146.682258,138.00727,3.840588,-76.195489,-97.754994,87.780753,159.586853,86.110672,-5.874656,-120.112234,-158.813206,-269.180189,-312.729081,-280.893274,-115.909884,-48.376543,-128.640118,-257.047591,-366.400414,-283.747832,-110.781361,-142.629346,-137.15615,-57.669491,-54.568489,-145.552308,-204.978793,-287.047999,-296.121147,-197.846166,-23.764944,16.119727,23.532612,1.132956,-126.657689,-183.84857,-167.288794,-77.927459,-69.769191,-184.901483,-245.906935,-282.642782,-339.625376,-533.581767,-557.084896,-386.496319,-124.219435,-49.857955,-80.305617,-129.475271,-206.275995,-235.42617,-241.036787,-154.619713,-82.560288,7.628581,-4.694181,-80.66271,-129.120371,-226.780691,-239.740192,-162.875905,-70.600487,-70.800299,-168.571203,-230.080855,-353.61433,-392.782603,-300.199202,-125.101192,-95.900029,-121.926519,-124.384178,-104.7919,-117.849418,-180.445403,-204.022281,-242.147173,-277.752691,-277.374201,-233.474904,-210.142469,-171.876206,-112.162991,92.169458,125.04755,76.313042,103.688972,173.999237,217.596983,181.325318,73.914952,7.723531,-61.724339,51.833736,126.300388,155.093236,90.550074,-133.002302,-247.508566,-339.687897,-204.235227,-105.783367,44.017726,66.631552,13.191133,-26.918995,-40.484004,-13.509781,31.098742,68.286963,76.600301,29.284101,1.906159,-30.220294,-54.193439,-80.212682,26.839995,76.728779,20.298821,-38.149348,-80.928056,-100.839192,-168.302936,-161.140766,-25.651851,70.848772,51.354563,-10.216292,-4.552906,-4.636408,-31.369712,-43.568706,-41.418807,-59.63918,-33.859986,-2.184284,-56.682089,-104.010589,-46.43302,34.521326:73.861685,49.690114,21.877201,-124.549376,-195.649159,-172.28225,-67.668365,216.944776,432.019874,492.316564,464.969937,387.267309,215.96004,145.636926,17.32536,-42.012057,-56.259787,84.990518,126.471832,64.995585,14.50047,-22.086414,-14.872429,-11.959552,57.730872,131.469408,145.951726,86.364449,6.728677,-11.128802,-19.06989,-13.788416,-43.628216,-62.506361,-48.936853,6.991105,34.59325,8.44436,-27.19925,-54.628973,-92.609528,-116.465529,-142.427371,-147.978193,-147.225698,-146.006319,-154.933529,-159.494364,-124.418808,0.329959,54.935655,61.318872,29.457742,-45.929286,-67.564976,-77.772402,-99.250527,-110.71056,-128.019747,-152.47315,-217.577874,-211.787288,-65.876258,42.520358,206.152105,240.99951,214.237595,135.744204,91.681279,-56.442655,-128.173347,-134.140334,-4.568336,47.971494,112.353947,141.124114,143.13127,110.295515,34.75645,-8.122119,-37.499627,65.262674,99.707396,87.019795,68.883607,18.73424,-12.148144,-17.316247,13.603883,25.93688,54.30857,59.459197,-11.396153,-67.803143,-93.204588,-77.951883,-60.545325,-30.524766,-24.87888,-14.466702,26.037497,172.830856,233.323541,221.820744,105.905579,61.191877,-10.24635,-29.346534,-58.014246,-96.04186,-137.954725,-107.037951,-5.35173,49.954326,36.182866,-42.630462,-74.929066,-116.705693,-127.707289,-85.867931,39.766972,84.930376,39.563739,-35.862172,-118.85544,-83.495661,-15.39406,-69.134329,-184.357118,-85.596613,-63.601222,-166.117899,-227.535833,-256.327572,-231.223947,-158.908957,23.623299,149.496529,262.161812,211.44261,5.57972,-79.148612,-74.597213,-12.535529,36.976708,-20.312574,-67.300474,-208.895456,-274.768876,-333.870203,-328.328588,-243.01597,-110.273295,-58.182537,-5.045707,-4.968859,-65.628412,-108.634059,-135.514245,-112.720831,-51.799143,-19.665914,-34.223867,-141.10706,-200.494841,-221.518229,-175.93231,-89.281251,-95.294779,-79.386044,47.268862,96.165488,-28.919933,-175.141321,-322.60664,-268.1169,-55.362023,8.040817,-59.758172,-194.400118,-190.376294,-166.926442,-193.665228,-208.165004,-135.139517,-104.223641,-97.159929,-134.998454,-289.429926,-358.906485,-309.140854,-188.790079,0.422366,-35.569543,-71.590909,-111.020957,-163.119848,-326.497693,-336.745639,-137.620677,81.772076,145.670051,126.969569,58.626612,-91.497766,-152.944523,-193.410347,-162.538788,-67.271873,-78.250847,-131.898074,-204.66438,-210.288524,-229.384053,-237.647095,-193.538413,-110.01408,-94.380105,-109.959382,-112.788124,-119.903611,-134.158843,-142.12968,-131.827322,-56.032891,72.404285,67.363307,-133.40772,-236.589152,-288.785804,-249.7991,-125.337757,-45.728864,-39.734407,-63.505119,-57.87153,-51.945372,-100.724611,-198.17889,-157.270736,29.145267,27.31385,-17.117291,-44.107581,-50.615304,-72.77692,-64.453892,-29.319231,43.761305,117.854546,243.254409,254.63195,205.870104,183.82295,213.106796,255.752373,317.068861,333.137379,330.676879,275.496737,207.206039,46.037035,4.671331,9.920074,130.642175,222.296129,214.939736,82.088943,-158.55989,-176.108033,-179.994008,-239.564517,-255.052976,-8.529168,77.186152,-56.783017,-221.734908,-373.210368,-298.907133,-98.618177,-90.401841,-99.031594,-49.57616,-57.049673,-214.330207,-297.876253,-327.235071,-284.174997,-108.858833,101.514946,138.6746,125.767611,103.604121,-10.925834,-54.541214,-27.205069,-50.201943,-98.674228,-117.655425,-82.020083,-106.468874,-216.147268,-388.913812,-351.594202,-165.976445,-60.830987,-34.570229,48.429744,75.747876,14.083814,-34.084852,-61.580978,39.884906,116.934889,174.795518,135.38372,-49.987655,-172.896078,-304.068992,-249.491449,-29.942052,4.103714,-69.217407,-228.572251,-285.054155,-416.535325,-447.140021,-307.857929,-152.386662,-139.665083,-102.744613,-48.772936,-22.982171,-70.790967,-134.675737,-127.370605,-138.116963,-203.695038,-207.385095,-151.253988,-143.329372,-211.472404,-214.824007,-48.444254,86.53054,88.754131,87.712227,94.126742,123.474749,163.183934,153.920739,55.718875,-109.068496,-49.440947,4.894478,98.650406,105.32979,-24.791389,-100.447945,-159.763822,-110.041885,-54.63283,28.436617,43.344448,51.710186,47.906787,42.055268,38.19576,63.203278,213.601598,255.85563,103.247971,-26.52742,-105.915192,-28.995368,144.92323,250.634164,286.848352,239.429736,164.384284,11.225024,-53.75602,-155.586339,-161.206828,-48.352578,67.848188,70.809541,-2.865366,-28.784357,-5.035746,22.856925,42.276743,-38.922301,-56.512849,92.712387,174.515581,90.536727,-29.438092,-132.390247,-85.510902:-7.352843,-13.750031,-31.899421,-111.893148,-152.486983,-211.731734,-217.82063,-139.368463,14.191553,88.054531,121.901554,82.60679,12.852025,6.168499,39.993555,56.924933,103.507817,220.382061,226.962162,45.981239,-46.737041,-59.056804,-24.033713,25.776492,140.274632,219.008642,265.909756,226.894593,123.478991,67.953296,-32.314629,-47.021277,27.94477,161.542992,179.451204,80.020344,15.648991,-58.077189,-73.085011,-84.280254,-80.62618,-63.634367,1.899771,13.348412,-70.532659,-133.937659,-188.158087,-171.966516,-115.718729,-44.723911,7.767667,102.103902,102.94882,-27.713995,-120.600504,-208.110396,-108.152069,-34.60078,53.289316,48.010185,-37.454796,-78.56415,-48.303343,39.286416,235.113307,241.887444,195.753047,154.311947,148.386093,61.525173,5.438325,-2.916942,88.399855,130.495155,195.902653,223.30972,217.819536,163.731406,32.586451,-8.249106,-57.86779,-54.792611,-24.820481,14.427541,-3.75898,-106.650748,-152.220423,-129.015735,0.875528,72.495352,158.211373,153.277362,47.232675,-29.906744,-92.376414,-51.944084,62.080954,92.157231,63.521225,-38.83102,-70.272389,-46.278806,-3.424385,75.913633,68.36246,51.82712,41.581189,27.88802,-82.174544,-164.896165,-198.617721,-121.473518,24.842631,48.029873,34.662832,-13.468555,-37.341974,-89.077923,-110.419842,-121.6323,-100.552239,-67.130101,-26.375045,-44.521176,-76.09541,-79.475195,-109.302422,-138.667402,-168.75985,-93.592156,-61.656786,-85.343647,-122.583904,-179.627356,-171.668403,-49.634037,129.733214,200.760062,236.152645,193.633763,44.607914,-28.065746,-78.248088,-51.834179,-18.333545,-87.01198,-149.41703,-308.372121,-389.581866,-502.161216,-494.668541,-310.47482,-53.051354,28.092052,44.313322,27.348333,29.148415,14.422946,-75.353559,-115.770053,-155.686379,-147.93263,-139.115197,-159.57151,-186.818078,-229.212631,-224.086718,-173.1284,-118.520545,-83.897329,7.48149,38.902439,-43.114604,-158.533879,-297.571891,-243.758182,-57.82347,-75.407367,-138.217697,-224.744737,-241.14509,-309.134327,-370.55981,-397.857966,-280.380104,-243.25657,-294.788676,-362.461963,-457.035543,-448.950183,-318.474539,-224.090475,-64.997725,45.955212,72.843509,24.187998,-26.804857,-107.355888,-111.590979,-12.538846,162.98919,232.464724,228.696612,165.771012,1.704753,-84.005823,-153.175944,-107.806808,-10.950345,-40.737007,-69.957203,-75.81496,-50.860332,-39.56377,-58.293445,-39.043697,9.814281,-4.762567,-83.621622,-117.011814,-144.847157,-141.691056,-84.696033,-32.56255,65.224421,116.943031,124.415979,98.531128,55.201032,-88.07428,-142.8632,-147.361498,-49.050437,7.755876,21.420329,-22.964752,-91.11748,-103.672102,-126.180725,-109.282429,-1.869844,53.427152,40.622774,-21.079629,-50.26332,-86.104875,-84.200404,18.266453,205.75594,256.253397,213.039823,172.875944,163.026613,173.435579,140.079209,111.824358,138.689534,222.650762,220.683129,139.477978,85.384889,-33.30482,-65.772367,-57.821248,-17.151861,25.664431,66.279386,9.015578,-225.224661,-347.057936,-466.15198,-430.369834,-238.288031,-109.810379,-99.542387,-171.950679,-238.663874,-297.967982,-254.000772,-123.593985,-96.199155,-100.211089,-72.711118,-50.137299,-37.651652,-81.948589,-237.60327,-254.959832,-55.223215,206.472349,248.300029,144.068939,62.455723,-50.567948,-76.105017,-71.965397,-92.762706,-111.181984,-68.142937,-31.65927,-85.980397,-199.271258,-414.254583,-410.41503,-207.27022,-15.939886,13.175786,-18.34985,-29.801473,-56.215693,-99.174382,-165.398438,-40.134399,72.503925,178.545603,136.23039,-37.116293,-136.725611,-288.295845,-292.381766,-185.211738,-129.825745,-162.532365,-312.622295,-391.263541,-525.826192,-559.490304,-449.428266,-253.468357,-216.131755,-245.970452,-268.397989,-293.322369,-303.443937,-299.534774,-281.841429,-284.138769,-343.304875,-348.816997,-304.398003,-276.793908,-222.208755,-186.13351,-121.565569,-122.748679,-111.592555,23.375817,113.03581,176.743806,141.617826,56.789306,38.878529,41.529512,47.749435,48.080434,78.148695,87.122881,-60.789647,-192.760582,-268.904509,-94.935957,-22.402758,18.574898,19.317103,71.836274,119.103872,183.688591,172.897072,92.608437,64.717898,68.80444,53.362991,40.046478,36.813375,57.079143,160.188859,269.595201,285.461157,240.611826,198.614954,107.759566,56.645808,-31.771989,-21.626928,114.522035,187.600341,178.279106,151.405552,144.100317,129.020118,126.365785,146.672584,159.343148,163.695651,162.108947,127.464778,25.95175,13.119154,68.921916,99.772726:32.478973,31.575815,-1.376307,-122.512964,-195.190035,-297.232736,-316.663718,-283.474144,-80.538013,54.827642,178.968449,146.960501,0.056425,-68.433976,-80.550988,-20.739428,120.425046,166.186775,135.80502,38.367632,-1.618566,-4.992771,50.692094,188.014523,244.525784,241.630636,192.679,166.374886,79.773165,8.129346,-71.15988,-50.37313,43.474847,151.09382,164.465008,48.674472,-24.993942,-63.239774,-32.994295,-8.580221,-43.020672,-34.855091,-10.495962,-23.926638,-108.655381,-143.566122,-114.843248,-72.235056,5.62767,96.670736,124.986251,57.45865,-14.602274,-106.011283,-103.30064,-62.035723,-54.332293,-39.265376,-19.441413,-46.660459,-158.933667,-201.900164,-150.472183,-59.81073,141.070062,226.955683,213.179862,143.765076,84.083469,-72.084335,-96.707055,0.33018,109.724785,154.439262,189.98079,153.654751,31.192701,-7.924958,-16.847791,-16.647427,-44.826533,8.701658,63.336731,38.327782,-49.978836,-167.202497,-144.677813,-16.725322,61.034626,76.857623,104.569443,99.69118,-22.758479,-100.41604,-92.269041,-27.097389,35.449376,12.068675,-19.659283,-90.089892,-82.194784,36.267303,106.635654,194.094302,203.816497,185.169054,127.145817,97.719737,-18.09893,-108.77264,-185.145487,-135.539177,-1.140718,38.345381,15.418862,-51.237877,-67.720262,-95.935706,-107.005216,-65.262849,18.030901,47.786402,47.692392,-1.478265,-142.800817,-182.502871,-159.615983,-145.309878,-163.604679,-120.128243,-92.353494,-118.031164,-149.338628,-138.56418,-97.8487,-17.967112,118.772814,218.361738,307.712642,261.404481,72.897352,-10.205841,-55.234354,-45.284408,-74.464629,-149.622829,-204.616073,-362.430019,-444.533255,-560.221835,-553.01133,-350.668711,-93.787996,-15.321717,27.233298,-1.545462,-123.891091,-182.608455,-177.446266,-118.563049,-16.770231,29.531285,37.538432,5.657218,-33.768854,-119.796538,-135.284143,-90.505691,-7.444671,27.29941,57.224621,38.234914,-94.135087,-181.856862,-237.413334,-176.376228,-5.884155,26.916211,-10.540317,-96.579503,-129.716421,-212.663543,-243.861757,-190.970429,-99.991283,-101.147594,-175.542862,-212.533348,-247.523925,-244.996112,-138.514063,-32.668198,147.745048,212.992559,220.778568,168.914193,95.384513,-62.300249,-78.455524,31.037526,189.374225,244.888744,239.037784,186.714341,37.222879,-38.345847,-97.489143,-63.073744,57.502742,86.764441,41.708321,-82.042498,-128.616983,-182.787585,-172.934928,-41.848829,84.614822,79.069313,-11.970919,-53.044472,-122.918837,-142.509733,-92.956815,-40.505124,80.09643,222.22148,241.36384,98.697353,-7.106899,-124.096116,-127.287284,-96.87052,7.485338,90.436487,140.066901,69.680056,-159.74387,-257.849379,-275.82582,-189.794213,-23.071579,-24.174536,-36.065449,-6.881811,-6.903246,-40.996439,-21.910731,81.75485,213.683769,285.197836,321.811036,283.932843,205.40705,185.606107,200.510492,235.230429,293.71225,301.508632,304.227049,272.445296,204.919528,10.82868,-40.668309,0.833727,100.068621,147.775423,104.45061,-18.034693,-263.956854,-314.625121,-311.111512,-284.272732,-185.33872,-101.093488,-110.694782,-232.237126,-290.025916,-304.605522,-288.274442,-259.09112,-109.36241,-3.738667,55.843698,0.699187,-136.481235,-186.91748,-202.571954,-147.303403,53.691487,189.426847,175.535742,57.0255,1.071774,-57.887918,-59.572346,-40.494834,-32.461356,-17.494656,29.318462,18.232539,-119.033648,-205.015983,-277.591157,-255.503798,-137.148176,42.812636,95.329326,68.672076,31.925726,-31.447015,-56.122281,7.649751,174.483072,224.10558,251.244135,234.543358,82.091539,-45.878537,-210.172714,-186.323981,-39.315294,-17.776017,-64.783693,-167.215524,-222.823238,-379.222468,-433.503206,-372.376245,-225.313165,-181.650252,-147.938966,-140.913991,-166.674948,-201.510293,-230.678702,-210.862397,-149.178067,-122.508272,-151.677366,-238.907737,-252.238314,-259.433778,-259.950074,-184.874903,-64.966652,1.314133,122.391074,129.255636,67.237222,52.046693,44.931913,34.393923,71.252926,182.10598,197.277291,118.775047,37.332411,-162.101009,-211.221887,-134.116528,29.857211,92.087909,131.256065,109.281407,21.85562,-20.500591,-39.072653,-10.592262,79.378915,126.022884,94.484241,-33.273396,-87.630074,-91.844358,-23.814361,153.250697,298.516168,336.133046,270.398018,193.934541,26.813681,-51.434199,-122.574387,-90.923391,71.386161,205.484206,195.713996,36.870137,-39.023575,-95.961059,-82.491076,20.520907,78.381736,87.506419,141.093613,137.691795,-19.235733,-108.08112,-129.524313,-74.692169:41.473469,61.536703,21.182452,-160.606635,-242.568233,-279.55473,-257.620096,-226.362708,-225.372938,-212.651626,-162.293117,-136.502834,-70.76505,-28.863834,45.452453,86.234095,202.779769,261.089181,215.731426,29.857071,-21.071943,72.137817,159.19885,246.952559,221.507926,216.190518,233.12957,236.780178,178.926426,94.826779,-73.832863,-71.494767,94.462732,262.667945,286.952217,139.47421,21.551848,-87.564229,-65.670457,-17.397102,-71.893099,-72.610707,10.014094,16.918014,-100.295816,-163.725865,-150.984257,-101.722898,-102.1895,-164.762467,-145.439356,-34.364162,6.731114,-17.372294,-70.173492,-94.308788,60.479622,130.758975,161.502013,136.404244,51.83741,2.241257,-34.864422,5.856783,132.451223,160.668767,132.355497,69.805133,48.043471,-6.205408,-26.001671,23.513261,120.505124,135.692358,125.020215,118.930347,76.558492,44.85612,20.897793,25.572775,29.980918,57.304179,57.462137,2.18147,-14.84351,-41.708378,-73.139598,-69.965366,47.942697,101.375454,132.184176,110.823058,29.836038,-24.812735,-76.742567,-35.29667,95.37632,125.618931,84.935642,-57.206481,-115.745983,-143.335131,-110.404514,22.920838,124.623049,124.494397,62.859007,27.657076,-65.727573,-117.64994,-135.428502,-99.253136,-24.44518,9.436971,20.824237,26.15339,16.750339,-9.739841,-19.975897,-51.612101,-65.061966,-27.15657,51.090517,32.552977,-125.290365,-205.823536,-239.676783,-212.74199,-123.463381,41.060507,115.619584,193.056726,216.591833,207.509868,164.41973,129.41637,264.95613,363.84028,455.825532,408.576183,183.058011,61.331027,-54.127952,-46.376629,-39.959764,-160.932807,-254.818976,-403.981626,-439.381678,-468.757813,-443.249137,-234.805082,12.640914,87.115823,183.856576,221.942422,230.009114,188.212324,49.885611,-13.530581,-83.63547,-111.109215,-122.891896,-153.887909,-170.081553,-162.412185,-136.119095,-92.478501,-3.673539,77.215073,199.530939,208.783956,129.711748,48.597279,-91.980198,-106.313287,-72.147721,-111.116797,-173.777772,-289.400951,-308.020322,-323.770659,-354.723585,-405.383438,-373.176156,-327.03161,-198.631426,-155.539574,-161.992869,-190.099852,-164.876388,-70.137833,173.584001,314.063763,361.091606,361.384192,285.688338,129.88731,129.544153,245.656063,383.960447,461.102994,493.110286,393.157224,104.419794,27.317209,73.131091,126.410092,168.522962,174.116548,173.232608,157.83773,159.23074,181.348229,194.268987,257.62764,289.196558,259.07083,183.794187,163.598565,135.643373,96.992956,-15.489845,-30.146925,73.232464,211.689556,247.951269,246.561133,212.802032,33.890247,-72.131267,-113.813716,14.578432,66.428107,62.062684,15.43191,-64.541322,-100.536595,-149.535565,-96.953198,86.310022,71.548036,16.192504,-36.073821,-34.470552,-62.599759,-69.349981,53.560428,196.98666,206.480414,120.785126,62.84564,21.47037,37.056427,61.464059,58.694287,34.714092,36.799172,48.527121,27.871847,-35.870006,-216.439548,-262.462667,-245.804924,-167.20307,-108.676004,-73.36427,-136.217665,-313.694347,-373.21687,-419.592943,-404.88251,-245.207116,-22.766127,17.176233,-94.610561,-171.602117,-191.365429,-156.478669,-100.366153,-44.966776,-19.47657,-10.090407,-21.696389,-87.667468,-147.973255,-198.688263,-124.479305,129.98852,212.653898,171.57724,59.143435,6.700877,-111.39899,-167.683546,-234.449872,-227.680239,-190.536991,-73.314163,-27.089451,-71.161403,-178.118275,-383.276898,-388.556716,-222.322923,-26.022166,20.337787,-4.214931,-33.337039,-102.490253,-139.663746,-140.870495,-71.177628,-36.180785,-4.494996,-20.060124,-88.995256,-133.303632,-199.452191,-199.12317,-151.715886,-131.360481,-155.386083,-277.249132,-339.855466,-428.482365,-466.914479,-471.943004,-376.975722,-327.418242,-270.945066,-294.509952,-442.792016,-497.81095,-407.338485,-292.652751,-169.541704,-274.14493,-333.77883,-338.722909,-308.614329,-276.574248,-267.491509,-210.682961,-138.843725,-96.695292,24.339363,79.889298,130.420158,117.168865,28.721864,-13.323065,-5.478168,48.747917,30.272686,-74.585506,-115.2643,-188.845536,-233.271511,-199.588609,19.31446,88.954371,48.733437,1.43846,8.668038,54.760204,127.971048,144.787483,150.005063,131.51487,99.713879,-34.269498,-86.143325,-71.935924,-29.414543,94.147889,264.510077,314.019332,217.523264,95.681575,-105.744523,-132.872043,-58.838589,-3.627531,78.103757,106.115644,83.301201,25.052838,24.79359,32.513521,24.2015,20.031912,-44.6754,-102.409718,-129.710781,-88.389559,-2.353254,11.380838,-5.394088,-4.680535:29.163224,110.131289,97.785256,-92.356338,-219.31571,-372.795678,-383.033814,-331.510578,-197.013508,-95.324449,0.683863,-30.076156,-111.827462,-130.513414,-54.590797,55.705911,282.306537,297.738674,209.072527,-8.400028,-64.951373,-42.272302,14.853517,132.583043,184.634746,215.423877,267.78728,240.670256,50.423491,-63.600548,-132.807163,-66.502024,120.045392,238.658878,225.675305,-19.383434,-162.536733,-214.882724,-145.158263,-20.691349,13.318002,20.478975,30.598818,14.066202,-79.73931,-132.335812,-168.904466,-145.633116,-88.015726,-82.541612,-83.903958,-77.17929,-84.382934,-129.1231,-143.473667,-105.952712,-16.754389,46.578615,144.097537,119.914612,-60.956468,-147.009598,-144.457783,-42.700974,213.330327,277.584069,220.275368,82.997024,29.345949,-84.230489,-119.866145,-73.628794,90.509353,188.309449,272.957899,217.368709,28.114264,-33.825482,-25.985727,26.839348,111.984149,72.269107,21.050652,-73.816524,-107.938139,-175.966237,-194.964556,-106.150675,26.708628,45.860998,29.25815,13.274406,-47.278096,-99.842702,-160.635711,-111.692915,86.882144,177.527915,145.379388,-22.733734,-108.903319,-147.105746,-76.477731,111.665996,177.233222,195.46645,185.644127,121.251065,-70.311932,-150.547967,-173.942458,-104.818366,84.243766,165.103843,133.220944,-23.376317,-96.329879,-127.011991,-74.18236,79.172112,141.692689,135.953659,101.003175,69.276394,-70.057566,-167.41402,-269.401697,-241.809834,-105.235906,40.510549,74.75419,13.658714,-42.356007,-104.296792,-97.070251,15.326555,215.866601,322.732756,449.999577,414.497079,122.432529,-42.146414,-132.099038,-63.431415,41.635654,-87.920019,-208.810773,-416.594116,-474.104749,-519.113743,-485.949279,-194.746727,182.700812,261.262698,166.170508,79.357446,-3.18894,-32.831527,-121.552968,-120.496793,18.521701,118.68596,86.919186,-69.798259,-129.313105,-141.331994,-113.843248,-57.020715,4.089679,62.934005,169.821745,168.530593,36.456748,-66.280058,-162.776368,-106.056814,70.057205,86.091277,29.414889,-102.154317,-140.306856,-204.793576,-237.654341,-185.988377,-61.313156,-53.608079,-116.535378,-165.346,-300.495033,-337.583524,-197.128829,-48.068763,203.935316,334.009716,359.367862,271.177032,161.878117,-6.914792,11.206776,189.613348,338.179413,380.21064,374.576128,303.310055,37.776855,-89.310242,-150.203822,-89.063013,65.923441,142.718793,133.617098,48.755677,1.158892,-78.559125,-83.506151,54.453848,218.740699,219.342377,97.346139,41.144997,-15.678471,-37.543486,-38.377484,2.768046,124.135953,231.899444,242.813592,127.790169,38.473814,-75.220055,-73.602281,-11.896833,72.366401,120.128075,140.040363,91.791011,-86.037884,-176.359839,-209.135362,-115.367448,132.996804,183.649214,157.981535,87.433443,19.776322,-136.687479,-147.357021,43.873396,314.599104,392.193497,338.545262,232.809716,50.792489,16.098641,49.113796,87.170039,140.997098,242.700406,291.960889,217.362567,98.972551,-103.925076,-127.004794,-79.740821,-11.049212,49.021395,85.408916,-8.263865,-309.17572,-405.690775,-381.152006,-305.948274,-151.833899,-2.057653,40.439097,-43.573995,-142.661737,-275.537568,-269.325475,-158.916331,0.046519,69.7637,76.280485,14.640106,-142.937891,-209.629523,-230.969774,-158.783467,100.247338,277.419449,260.944365,71.499955,-38.120358,-152.654695,-146.936241,-121.439663,-122.764227,-84.918095,35.546233,44.255926,-124.344426,-253.103225,-359.553986,-292.22207,-74.074685,44.077137,57.60438,28.841261,-21.81359,-169.710534,-194.993965,-61.313497,124.913644,177.32139,182.826485,154.952725,50.043567,-59.026731,-276.001093,-283.23265,-99.435802,46.250638,17.461457,-223.130533,-363.079886,-540.33119,-564.195692,-491.109327,-322.937704,-245.81839,-198.666448,-233.0523,-349.137628,-385.415858,-305.108927,-217.633038,-117.913061,-151.064994,-183.61933,-223.408373,-245.593324,-330.042618,-342.131346,-211.406076,-56.105594,-17.890868,27.53285,31.521038,-13.843479,-33.89467,4.165805,48.756268,113.187016,103.76744,47.713255,-92.234878,-133.454583,-211.876316,-253.367401,-212.107068,22.596606,129.64299,144.851448,73.770829,-46.155712,-56.9642,25.664397,93.07212,131.680138,39.526674,9.694615,-21.019843,-52.018299,-104.094022,-85.355889,83.043654,303.377816,332.10445,165.619651,46.169798,-109.440142,-142.328121,-123.589354,-72.234283,69.666965,146.280506,126.161556,23.372613,-20.049191,-48.560187,-32.073866,48.459825,90.219214,69.713496,-3.616317,-42.500723,-134.984196,-170.843453,-116.745606,-24.697415:-71.927432,29.488016,41.357681,-39.664242,-88.718982,-127.02807,-143.471908,-210.026163,-259.391917,-258.592348,-219.38145,-197.310805,-127.06464,-55.156932,131.932887,213.853986,309.496411,311.123435,286.906552,228.272754,224.771822,304.743769,352.374153,383.468301,373.533286,376.935024,370.707538,344.552485,259.148172,193.357253,67.527736,59.993715,156.459022,321.258137,366.935182,203.065341,61.581595,-67.801805,-79.894393,-119.969554,-91.151956,-27.11778,106.232662,122.318222,51.885673,3.118341,-63.786877,-79.125736,-119.890828,-185.590808,-182.68917,-57.189846,13.824313,1.112248,-72.88881,-125.154638,66.912827,182.794885,301.766015,294.889195,191.478696,129.33436,98.004252,107.99187,2.753281,-158.976239,-167.804094,-98.567325,-90.789269,-166.536047,-207.670095,-174.216416,-5.485942,49.272575,32.213357,-16.491613,-118.20001,-139.233237,-136.009631,-121.292393,-24.948236,81.034212,78.344028,9.025849,1.7201,34.268729,22.728496,-75.353968,-72.371265,3.561648,134.483566,138.354255,102.434944,94.401856,88.998475,108.593553,183.771048,172.117473,113.657013,-62.105409,-139.351862,-178.841626,-129.253062,-1.302933,-7.922297,-27.209607,-9.818954,-5.00404,-57.409332,-91.963647,-133.138718,-136.753144,-116.309746,-82.430782,-63.487226,-33.084789,-23.450234,-39.933285,-73.171113,-142.010091,-144.107975,-106.411256,4.388586,14.442458,-103.221136,-169.103749,-207.706543,-179.457196,-36.712255,158.474694,240.215193,376.38193,441.377049,519.411774,504.50403,390.405538,337.339478,367.109753,397.317995,350.141353,206.804059,142.113821,14.898685,-51.510348,-180.419676,-272.207076,-307.739583,-366.109088,-395.258465,-456.290723,-435.218448,-192.027203,99.363232,185.323036,277.162748,305.582068,285.220497,228.033582,125.592779,102.876772,35.480646,-53.643935,-89.016998,-198.711819,-256.117057,-248.506182,-173.289344,25.556323,181.939499,241.410964,332.802736,352.544504,318.107281,278.289657,209.934504,187.406937,112.608435,-39.093167,-116.962013,-185.702744,-180.892273,-206.981726,-243.940038,-263.848741,-221.74766,-193.234893,-66.870437,3.286107,20.858452,-26.478568,-63.296579,0.1083,224.102119,448.836246,545.491642,630.198239,610.656532,510.572546,473.000333,512.501664,643.117673,671.693198,532.504074,389.35056,183.016765,170.385235,235.052248,266.324228,301.222408,331.605333,335.699053,294.390364,291.580929,328.198129,310.740063,248.084491,278.058421,310.937671,347.527819,343.435682,302.200637,256.182559,126.175348,78.6319,64.116963,150.181588,227.601336,354.733625,359.750676,226.118491,130.102353,76.288288,229.255226,308.576046,346.333011,264.28839,-24.931975,-127.862136,-80.253591,28.332941,152.718211,100.51933,72.226884,55.781925,63.235961,76.462747,74.975706,105.248844,159.209671,174.512595,180.546551,154.211308,51.624577,3.618203,-7.954784,51.789449,191.752683,150.535974,96.983869,54.227658,41.902234,-47.479623,-92.641105,-73.175532,-51.579189,-82.335825,-104.246874,-81.849387,-100.644643,-158.316773,-192.977156,-122.618418,53.233717,156.736805,183.077301,137.116599,86.634866,26.889367,35.731477,112.415098,97.02965,32.200058,-78.481992,-79.390488,-18.889602,-24.208578,-120.267004,-126.169664,55.363906,231.74276,216.430841,42.802364,-53.406437,-202.723217,-250.811394,-293.630997,-296.286003,-273.416413,-169.984874,-125.210472,-140.891714,-211.531245,-357.189791,-358.12118,-256.102321,-197.069948,-163.566671,-76.357594,-77.622265,-190.011962,-226.813947,-119.711147,-19.538726,-37.740572,-29.932929,-5.817414,-71.871928,-146.56376,-204.535572,-140.254461,46.469513,53.39076,2.365265,-125.887795,-184.518693,-261.336072,-286.319762,-301.360688,-266.324276,-260.023281,-327.484343,-384.960268,-444.518998,-443.303219,-374.202232,-292.381232,-164.40834,-183.676894,-181.936248,-110.864151,-82.358491,-109.56742,-155.296652,-191.438596,-109.253524,-69.650672,12.172532,79.197309,185.494936,174.942472,71.684787,32.105896,7.420786,-21.688613,-46.611361,-108.20884,-142.253648,-205.380583,-223.424499,-131.843513,139.798907,230.54392,150.052331,58.082837,0.968451,29.868947,122.037186,160.680825,102.734764,-72.823693,-91.863827,-28.981585,-21.02665,-52.53909,-54.665411,25.934153,120.33439,110.752355,12.284316,-42.293042,-116.146812,-128.769516,-111.721494,-95.075937,-94.869229,-72.356282,-42.554353,-38.537838,-66.884181,-100.116891,-96.528655,-122.770005,-217.895779,-240.575213,-176.753379,-138.660904,-146.172023,-159.277711,-120.062712,-78.472989:-32.877377,-5.050399,-25.761987,-116.77457,-140.963756,-131.147093,-117.910943,-116.721976,-172.82195,-182.098772,-123.39298,-97.615543,-106.035037,-94.873856,18.992579,78.464742,153.94048,235.166869,244.424555,137.077658,80.932321,82.647432,114.692025,180.322472,244.929198,288.354508,351.589149,343.932874,295.173308,265.860167,182.165716,148.634949,141.016976,209.15907,232.462878,129.284893,38.423694,-70.04175,-92.978535,-129.535329,-98.024915,-31.612998,65.848654,27.808332,-119.497514,-151.906578,-128.012188,-108.806263,-153.949093,-268.025167,-258.207333,-77.236758,-10.948488,-110.797256,-206.224759,-173.487738,113.080827,223.324047,258.240056,208.501709,88.363954,50.888081,73.660588,110.235018,124.291986,29.298102,-16.285716,-20.954351,-27.172756,-113.921055,-134.215796,-62.386272,-10.942231,-12.189893,-16.012527,-20.399342,-60.464807,-101.888571,-158.743571,-132.039238,-18.053209,-6.472859,-20.938025,38.33789,88.382102,56.776455,-41.857664,-206.540867,-77.741484,61.637215,203.887887,149.953607,-11.28264,-26.8212,25.650749,47.098284,105.189466,169.090922,148.08709,-52.321556,-185.603005,-297.610327,-242.975944,-52.410652,57.502676,80.755046,52.934016,6.654325,-57.338035,-74.115876,-123.607594,-136.625682,-92.495313,-2.022929,33.840541,61.986661,61.676309,16.06617,-34.53366,-138.716824,-188.836666,-178.110465,-119.08667,-103.701495,-113.265338,-109.279131,-52.514906,-19.238282,65.660347,251.370733,341.327149,402.53077,391.705453,315.905322,240.847842,83.551735,87.993009,161.803504,262.638373,247.363523,156.387292,98.389953,-39.201949,-101.718305,-194.244968,-235.075423,-235.195605,-255.318472,-312.407318,-484.401406,-506.895521,-315.594168,-30.473675,58.024917,129.511147,160.041463,197.428267,164.285246,6.756973,-65.015852,-95.185524,-30.867903,-22.278572,-117.031235,-192.50395,-323.70107,-358.886365,-280.47825,-63.995804,20.690778,89.801778,98.909385,96.918571,58.236001,-77.86055,-128.064226,-202.851968,-324.52924,-378.850855,-399.307436,-387.576649,-440.181349,-485.624696,-481.731173,-397.912506,-349.031118,-223.160592,-199.772379,-302.629371,-344.268429,-206.266223,-50.08707,208.371352,301.356716,325.594871,340.038389,332.8073,290.312434,255.323281,233.454239,313.932154,370.513976,404.909334,349.76566,188.884467,136.627189,141.268011,192.109208,254.870121,232.507732,272.176457,398.788719,402.601758,339.452718,335.034844,346.733074,304.465901,291.96561,295.863672,288.232387,242.613513,202.738038,86.49074,41.344413,43.542767,181.947084,268.325376,382.245261,392.274238,254.931659,137.227401,-22.546611,-43.6245,-16.085066,44.747838,41.035932,-31.913242,-88.079971,-173.529706,-145.781724,12.878035,-0.387973,-85.441067,-211.08632,-209.407581,-184.230405,-192.251532,-127.05305,97.442858,201.887791,262.357992,210.588341,82.93941,61.312276,75.549887,84.110592,82.943106,35.75748,25.175445,72.018117,80.13105,-0.036555,-46.326162,-68.538787,-35.325698,-12.992078,37.936526,57.830287,28.007921,-33.419288,-131.069241,-116.048756,-0.639198,108.538468,137.736141,97.490352,44.360142,-51.321652,-82.760457,-72.955026,-19.193288,-14.511841,-31.767085,-37.685562,-26.085059,-18.453726,-15.364568,-2.459615,57.983883,100.469877,93.902559,13.373344,-54.416612,-203.367722,-265.776649,-341.159478,-361.307108,-359.941769,-323.247356,-292.966476,-320.71329,-421.085273,-616.166437,-598.801351,-418.554029,-300.463883,-265.868082,-221.690541,-209.37799,-224.354597,-252.86466,-230.94571,-102.952845,-69.74794,-115.745072,-173.424896,-254.661621,-260.93577,-249.252486,-233.475293,-164.187509,-70.71339,-44.662072,-77.770998,-106.734734,-158.281729,-178.568735,-138.584729,-108.924564,-132.707673,-183.690084,-233.069461,-382.718,-419.228174,-358.286969,-294.829943,-206.611502,-172.363908,-146.13285,-88.243382,-71.915984,-74.161237,-86.798581,-48.513071,65.66753,84.8901,49.007235,59.667915,161.958894,185.926779,129.507788,103.107568,135.421845,204.722246,217.539206,172.985204,128.280462,15.567103,-52.234511,-113.692701,3.094608,60.402453,98.667352,126.550448,214.102378,234.873596,219.751921,200.57294,173.894456,193.995118,198.39868,105.117563,43.648637,42.66398,70.842378,80.532289,91.390253,98.922845,61.404437,13.533193,-57.668254,-45.313113,93.408957,186.109639,263.494317,172.441057,127.940022,121.64823,136.026609,95.512348,37.654527,-86.714038,-149.730934,-138.41368,-33.081323,30.314698,74.917729,65.52487,111.858885,158.764153:0.375582,17.497324,7.041516,-75.144068,-130.673915,-222.996666,-273.052417,-352.097812,-264.692507,-163.526417,-51.237673,-86.315757,-152.491783,-110.770739,66.781066,167.043999,316.56738,296.451567,236.865071,105.21124,62.48101,81.640125,136.458766,221.293022,216.887309,220.467491,254.72887,241.750204,85.580185,-29.022117,-132.037669,-69.665089,147.452777,270.34009,257.426746,48.226497,-69.759108,-103.998054,-40.868766,34.861507,-43.8431,-55.525695,44.351968,59.887471,-97.223707,-188.793417,-188.515872,-123.002806,-67.624144,-70.701383,-43.710484,-29.776057,-46.943434,-18.636681,9.730868,0.300178,-16.912547,22.015675,154.169996,181.476586,94.49368,33.292986,32.165579,85.479763,124.178421,44.232932,26.191126,0.791085,-50.636819,-180.390587,-210.588423,-121.029606,80.99312,130.784317,50.898551,-22.60147,-68.248984,-55.8265,-83.808694,-118.906864,-144.917814,-89.067551,-63.435126,-63.931623,-68.35277,-88.714348,-106.93454,-72.049399,-6.25113,14.432108,76.891357,103.456126,81.311011,28.68434,-48.663246,-24.207454,103.466468,191.304928,156.899277,-92.762579,-200.758134,-198.166999,-128.96889,22.82618,82.372283,71.253873,50.971386,36.862581,-59.65736,-119.302389,-124.927236,-57.56835,72.483738,52.907973,11.217221,-36.107175,-19.61957,20.759989,-4.717325,-77.621423,-37.598665,15.504106,86.917634,77.952263,-24.180969,-121.271359,-291.509808,-280.785162,-98.958386,63.007455,91.195829,96.786448,118.077822,156.925462,158.456127,200.661725,273.15928,300.59798,285.569366,216.01741,35.887682,-18.392953,-49.493492,-54.754216,-104.304986,-176.887934,-217.547135,-355.688092,-432.990383,-476.357146,-406.301692,-134.896081,152.187024,244.592291,223.983013,149.630253,80.829309,90.516339,76.573086,46.452284,2.727353,-29.044106,-98.288961,-302.425712,-347.444534,-292.450278,-244.747281,-112.694046,53.625654,101.33869,142.953158,163.187593,205.263229,196.221577,78.910049,29.868086,45.914254,82.809887,66.317383,-33.285471,-79.113575,-146.989958,-182.707143,-227.715784,-245.318025,-217.846548,-69.721955,-8.696601,-27.720611,-80.275875,-91.862792,-5.468602,280.788456,449.463633,433.820238,316.39691,268.940851,221.661494,216.176796,278.240648,442.382347,498.99191,428.80571,319.057481,120.765966,70.645324,59.009446,90.495177,155.747143,153.145024,152.66674,165.240585,166.580353,147.47196,132.850226,162.778333,237.423047,265.839626,257.047717,201.908345,90.410871,71.983808,67.615944,71.204745,93.936814,130.678802,164.294378,237.24482,259.276821,221.107649,148.306575,29.907606,149.254601,239.167352,244.416897,159.369219,-24.929359,-93.811144,-134.602121,-72.35219,128.504686,196.494592,180.789419,142.618178,140.352688,99.96234,41.113413,37.858126,245.935066,301.79404,194.971656,104.165212,24.321483,16.427795,-1.382889,6.367219,49.293542,75.504672,78.210223,34.287842,-21.034173,-151.280423,-173.614547,-103.110599,-25.915964,10.326581,42.091683,-22.175312,-251.262096,-327.487427,-300.287607,-212.625482,-25.437135,37.896985,10.368128,-75.675576,-71.86918,-13.471883,-16.257068,-48.647317,-29.353877,-13.128133,-0.497124,-12.637357,-64.120561,-108.72175,-183.617262,-144.119143,90.994726,256.8104,237.669856,50.813778,-29.429162,-70.921907,-91.699058,-210.798485,-225.558604,-148.395562,5.329078,2.254708,-127.471025,-203.86003,-291.318078,-276.901634,-197.079473,-86.610569,-20.040014,11.533005,-30.651419,-103.521485,-104.615905,-19.814188,147.210406,211.361484,191.9831,130.903252,-4.53469,-78.720585,-159.747425,-138.572738,-57.154391,-32.194797,-54.137037,-176.663914,-250.594862,-376.89858,-416.384294,-375.419782,-247.652808,-214.93261,-235.878247,-273.800544,-333.728354,-329.93969,-273.615074,-223.909836,-87.018241,-38.880984,-66.539782,-127.342851,-146.410541,-195.860563,-205.625342,-160.381471,-178.506021,-181.256407,-60.403109,3.030397,22.811984,-4.637352,-43.688488,-10.886611,65.498426,-66.787008,-146.800151,-136.496716,-89.10199,-144.354322,-223.567252,-211.228232,12.946505,105.164322,165.563244,141.839147,52.444447,5.405583,-40.167174,-11.175261,81.056342,114.42581,116.085203,41.43562,-25.096581,-81.913542,-53.392392,82.89519,207.578559,224.555456,164.629078,91.347998,-42.96593,-51.984763,0.54845,27.101519,100.701189,123.353857,85.919811,21.202029,21.217782,26.402059,19.038244,52.352629,88.831358,58.784766,-27.058013,-53.378826,-72.639606,-63.27327,-31.490944,-11.799655:left
-398.634846,-296.743208,-268.962526,-241.831875,-236.064481,-265.25524,-275.84491,-229.248413,-156.950646,-122.791386,-88.18835,-111.682188,-248.538533,-319.396142,-291.060583,-190.31176,-25.164767,-60.756666,-114.468512,-128.542882,-85.150941,-17.620803,3.221158,71.533508,65.319665,-17.67488,-185.535859,-179.744958,-70.054552,-47.317336,-41.52908,-28.522166,8.244328,81.125728,116.252135,143.96436,134.783753,47.340345,-12.478954,-80.455419,-66.048744,-57.346796,-61.004568,-51.05989,-23.151646,-23.807059,-8.369516,16.011486,87.028081,172.177069,183.457664,94.257282,13.616813,-125.481999,-131.138122,-18.543557,20.982027,-10.852321,-136.328227,-195.937969,-251.606896,-280.352041,-328.94425,-295.73627,-138.588267,-125.051268,-178.677826,-202.453208,-169.026057,-149.283578,-164.909291,-170.172279,-75.434025,0.955952,79.331934,57.257519,-19.479771,-30.455592,-8.397515,-14.948957,-67.563479,-146.656348,-224.72181,-354.639274,-351.698663,-252.14509,-188.091029,-77.301425,14.589711,71.93297,120.244125,82.499655,-66.156973,-152.20508,-226.303862,-185.567535,-79.852486,-131.134859,-212.751145,-297.296309,-254.593827,-131.073885,-101.104997,-93.614319,-65.355533,-14.703101,60.196603,34.028743,-113.413905,-175.816649,-145.184619,-53.358421,180.571908,359.310166,378.776563,256.691848,159.086278,52.926745,97.793054,326.165081,485.282621,491.873178,394.107551,312.35803,116.794277,37.963422,-12.427978,3.079907,59.512867,125.713758,154.177483,128.008099,49.430241,-155.235636,-203.585081,-130.615781,-7.941151,25.07982,79.085728,109.420658,88.61048,40.492391,53.608709,131.086975,216.966859,112.789636,56.604109,49.615841,70.703673,37.61698,19.961025,125.270641,239.278573,228.295244,159.394765,146.10416,135.135131,105.633507,30.168792,32.047483,176.876526,289.590726,239.759581,53.293384,-7.531506,-63.892169,-72.328631,-45.453796,43.058568,94.034758,127.734157,115.763191,76.329741,43.956974,-12.40834,-13.678732,28.452402,70.492797,48.34908,-139.104863,-255.235658,-358.151516,-319.736804,-147.177733,4.259019,61.403189,92.944077,54.102091,-41.757052,-69.028134,-89.476166,-88.950937,-13.173889,129.851367,142.106657,38.574889,-27.797078,-82.278466,-34.985904,120.759382,127.22364,83.076343,17.990883,4.512982,-36.131157,-74.606073,-96.728481,-41.768472,134.124167,161.722587,80.11848,-133.384614,-211.832783,-267.468988,-235.748824,-88.538465,41.174467,48.023585,-55.069128,-102.431055,-95.993492,-67.352074,14.617961,64.70158,136.155838,153.280116,148.24977,167.398491,192.673132,202.995298,177.786063,88.431102,76.265219,131.236925,190.368339,116.766758,-156.419792,-251.659501,-260.436551,-222.785516,-160.658304,-139.283632,-174.39339,-290.507875,-306.700757,-230.261606,-186.39208,-148.069389,-59.644196,8.514678,37.999952,1.08189,-56.411691,-76.912963,-80.55693,-23.774881,170.463735,281.140226,285.804171,284.020686,272.976496,197.388522,183.886556,272.739409,297.258612,233.040844,101.270719,83.99141,54.314249,28.034434,107.793411,222.557504,408.487816,415.956154,364.067746,267.8507,268.181259,288.882448,261.266901,191.533971,257.297377,317.565134,318.48871,251.04864,121.565716,81.459389,73.804474,134.610027,321.714954,353.878317,317.92026,348.166629,393.37196,335.632256,255.735068,209.68136,361.332826,452.553113,574.535322,607.762003,567.137517,485.082934,377.810113,383.178911,381.03299,374.309328,388.356919,325.412825,232.475544,74.165086,72.678556,189.330462,276.503971,269.82508,179.446535,133.754142,85.976969,71.529661,37.175054,8.760533,-39.691789,42.544582,108.760687,159.411176,149.813087,118.370494,92.387641,55.502221,126.574692,176.58225,148.896267,91.57154,42.03225,33.689023,23.965545,53.716479,147.045485,90.776446,-7.52766,-170.09948,-197.715765,-209.747025,-199.169203,-124.989215,-15.25645,45.372052,138.729365,135.867928,18.131965,-37.669468,-5.52343,70.543446,249.29194,361.842347,368.991019,347.151789,318.528334,169.436125,88.761135,39.343574,169.247456,267.688062,337.082432,302.698545,242.795815,208.112157,92.009793,52.216526,72.795187,171.486946,198.332236,174.052666,158.369803,183.27733,213.831448,205.399122,75.637607,47.803328,103.605154,99.026994,-48.372539,-95.375699,-3.212094,69.339049,121.722569,89.534887,77.810569,97.40123,85.037404,-27.120612,-52.869523,-7.795813,-31.234643,-71.875295,-113.377162,-97.035392,-27.521437,-1.032443,41.875825,76.226473:-276.947024,-188.190047,-183.960696,-219.069108,-246.307153,-254.951521,-223.622208,-152.79526,-110.726308,-103.403513,-139.007009,-161.989294,-233.789053,-279.643394,-223.74985,-124.422246,-6.479342,-37.758768,-69.951203,-191.789837,-276.850455,-353.319974,-301.672425,-90.921001,4.855586,-48.81955,-200.760479,-218.797555,-181.865831,-158.984147,-56.161392,10.573003,57.184416,36.478889,37.054465,38.126164,28.813545,-9.47445,-31.831851,-41.207387,-12.008321,-39.001591,-189.793058,-238.75753,-239.894675,-228.417619,-146.867713,-74.082238,15.106548,-15.842672,-39.023983,-69.601297,-98.587282,-160.68409,-141.985233,3.722751,70.285589,34.887878,-127.605632,-214.319699,-275.288563,-251.299743,-197.840978,-167.669645,-9.909947,125.325395,103.528076,-21.535151,-60.434345,-48.163,-26.767148,-51.602171,-46.252163,1.408048,28.065882,-22.977334,-151.862465,-182.23359,-190.020077,-193.988992,-159.132679,-102.050551,-135.278894,-298.112569,-355.8606,-287.591351,-185.242018,-25.155443,50.620949,81.719073,43.122798,-26.682389,-148.080364,-191.518008,-242.570107,-229.222295,-114.704441,-43.402039,-77.382238,-190.153497,-225.046749,-225.078684,-184.029204,-81.106756,-38.702824,2.808742,84.421877,50.150018,-140.866026,-220.640315,-203.273226,-97.560398,185.609264,387.838754,431.298731,330.04548,186.936825,-15.697307,35.190394,331.766305,493.282966,459.959006,260.402037,170.22008,71.423917,29.949973,-30.965452,-13.008894,96.276226,140.136502,123.4612,24.817276,-65.228037,-218.159529,-212.568513,-62.769816,14.197774,-14.361912,-29.050188,19.095573,40.921197,-16.266374,-3.16564,123.514158,332.349224,233.692432,144.610366,31.921634,-18.896417,-110.483843,-86.975504,130.43014,266.885803,235.09093,126.642715,100.598831,58.034549,19.868663,-37.476144,-19.829666,133.447677,303.520436,312.681501,100.123341,-69.121109,-253.092266,-229.504541,-132.267497,-30.784056,39.303247,126.034836,133.791327,96.617523,62.432852,46.876638,58.880603,33.910095,11.146182,-5.433169,-187.889953,-318.865525,-420.818459,-368.27121,-156.418296,54.338832,119.357518,120.784738,69.646534,-30.04203,-48.675523,-16.753942,23.01137,126.294327,175.670206,141.026628,-26.714335,-134.391361,-269.992873,-236.469993,-52.534768,-4.771323,-59.449672,-231.563842,-292.770497,-315.510298,-291.887283,-175.034909,-107.145932,-91.834919,-197.402164,-223.585652,-258.74386,-340.639783,-521.302956,-499.633261,-259.572053,-91.610559,-92.520079,-171.495601,-188.844164,-155.875623,-130.706149,-46.064881,6.065297,34.878797,4.988479,47.801017,243.845738,294.093589,156.963759,50.268498,23.159951,143.018884,150.914333,60.015312,15.677868,-56.952128,-103.151682,-176.519902,-187.708073,-152.485328,-144.771192,-184.78562,-246.226544,-228.490808,-137.735894,-103.261325,-99.677648,-103.399709,-90.230294,-120.273424,-149.221788,-131.81831,-106.117235,-85.086726,-67.288344,13.010363,69.689119,99.135749,210.757513,228.701369,84.216127,18.617879,144.174659,328.462579,294.027704,99.105971,40.379959,1.654097,-12.962306,26.009966,115.533623,337.800585,327.243569,209.213801,52.67499,110.251855,270.726044,263.465433,235.891656,321.697979,307.430806,158.799489,102.091382,65.293555,62.182107,110.267827,151.121147,212.155091,267.660548,278.288318,291.703301,318.2842,333.109627,306.788667,306.307265,467.837536,550.429338,587.027449,571.655856,544.474381,532.912932,553.92533,591.296643,670.183807,658.964913,579.403096,334.426404,258.061866,261.55027,285.406486,328.413117,401.6379,406.941023,344.215359,327.825001,343.255172,329.036791,231.380435,201.110693,237.118707,276.022775,272.236381,239.770143,220.066442,200.02083,181.583579,68.036316,73.288822,186.793896,365.921671,338.621908,135.462534,46.081454,68.104595,173.269024,376.355353,277.717979,114.815036,-135.830032,-181.544066,-241.6954,-244.080202,-103.68847,122.905884,213.136143,291.856581,275.438383,166.63636,128.179167,194.79676,272.574428,433.832675,528.721256,518.930412,399.209568,314.380244,166.464672,151.091908,245.039334,337.996203,382.168786,465.031656,461.488352,307.115319,209.240355,178.05499,238.176013,312.9982,242.327568,191.281116,129.863886,117.993474,114.577562,139.49055,226.650773,212.694391,185.485953,127.182013,56.470776,-122.23429,-149.598745,-1.58045,102.593156,154.523714,87.181793,97.12609,170.473491,140.20738,-50.366567,-84.670907,16.821191,83.431061,80.985433,59.518024,61.74697,43.5941,-1.161871,-44.605136,12.236228:-97.827079,-120.755947,-170.851796,-280.593735,-320.924709,-343.519896,-309.942874,-182.784096,-71.834728,-60.549944,-90.364467,-65.680435,26.901888,36.672225,36.658782,57.683369,51.025012,-69.203808,-120.747471,-168.729373,-210.194837,-341.514282,-371.625833,-273.376781,-110.55141,-96.176097,-205.18697,-258.969251,-254.794317,-205.517944,-86.669336,-52.801505,-54.539338,-39.824154,-3.629312,35.095418,20.694829,26.795027,57.037877,62.490756,-2.034561,-17.162327,-27.289362,-49.867376,-136.290124,-159.389273,-110.324289,-80.919829,-59.308438,38.197182,96.228937,93.962597,32.234763,-67.61614,-54.845357,2.634484,-34.17922,-58.07109,-101.116568,-134.531486,-201.127688,-215.554957,-175.003329,-123.884884,36.919309,160.699826,146.811798,100.229788,113.10955,92.073407,45.250606,-3.599776,81.278143,128.988155,101.882298,43.203669,-92.879176,-152.087483,-202.840744,-196.943994,-129.151576,5.662191,33.092605,-94.907607,-160.843085,-71.716876,27.926339,119.22196,87.697498,81.185187,89.568184,56.257395,-99.524604,-180.20491,-263.33083,-245.242408,-90.119272,36.955121,16.417922,-104.591306,-151.699283,-184.134954,-149.578446,-10.145243,51.161495,50.381309,47.160483,34.659392,-87.042413,-161.741975,-150.472931,-72.437274,89.930624,267.074015,353.725918,321.328122,172.56502,-77.397556,-57.209098,162.198481,280.750101,273.1348,215.019635,174.521864,33.201915,-64.042657,-178.032038,-148.912994,-24.238102,-18.739665,-53.126582,-112.514042,-136.790283,-223.113122,-248.503295,-92.420512,131.658634,106.141023,-74.529149,-92.894859,-99.796222,-156.14557,-163.952563,-58.154984,172.887285,112.285556,0.931854,-119.798859,-130.372777,-125.427225,-64.775334,182.068712,298.231038,247.993239,106.435702,68.24032,15.51336,2.402447,16.033332,16.473057,72.614726,251.600739,290.550849,148.110975,16.909946,-122.609207,-105.11968,-59.18708,-38.97216,-19.354656,-25.253599,-41.053347,-28.09272,-1.075573,24.761317,7.200166,-30.308952,-44.043712,-67.558699,-145.467739,-197.083502,-275.871597,-246.528558,-43.839368,149.676083,199.891048,183.311026,114.213628,-52.068621,-91.102292,-69.46295,-45.925689,11.883751,68.49658,48.059751,-90.791128,-185.199319,-325.719682,-312.365675,-136.563091,-33.864141,-70.236135,-197.316564,-221.651742,-236.660256,-253.340942,-206.174011,-143.739629,-94.713507,-180.127182,-222.103843,-278.254238,-349.069743,-529.022165,-516.121025,-249.048113,-65.074945,-89.649503,-202.595003,-227.499798,-230.70415,-225.359589,-195.933907,-165.200568,-51.545412,56.82249,83.165643,128.252916,135.37281,102.848015,92.855608,122.993437,204.752194,232.304616,193.016722,115.280834,-107.069447,-185.868637,-184.604348,-138.797548,-67.971241,-91.678911,-133.900695,-234.772291,-287.10387,-309.827361,-239.493323,-71.589336,-36.885504,-48.893875,-153.614701,-207.987835,-228.956761,-233.873435,-263.48094,-241.437929,-106.197052,38.883718,100.555946,156.333189,124.115717,8.217343,11.21647,214.890739,365.323694,315.271742,120.677075,71.384312,43.181303,19.738775,6.524662,40.909734,135.529052,180.786792,179.444939,189.051249,211.582749,206.107482,184.300614,252.827064,367.670726,367.27631,324.140383,301.374696,219.485814,167.219407,96.227348,101.811215,221.788665,337.699901,350.926891,310.638115,262.107515,202.33083,230.226992,333.249964,406.86587,443.949443,550.380588,597.496345,563.119399,489.711685,403.739652,444.526469,617.487122,628.659423,529.204368,264.572133,192.882099,217.761084,245.913924,279.292613,384.01402,431.741185,428.21284,390.760145,313.096739,286.060704,251.702646,237.3865,216.628494,203.567106,213.897164,242.803982,214.929666,96.644199,62.371214,87.383033,171.639963,208.2793,231.82604,209.943701,90.302442,40.295523,80.000118,147.586995,266.775212,213.885025,101.690181,-152.894208,-250.72625,-320.333883,-253.448159,34.923425,251.475315,261.448084,168.610817,125.453638,37.604965,-2.422718,35.220318,115.095296,325.063711,505.340623,518.778077,355.808185,231.069753,35.049353,14.980735,172.487248,318.926224,310.892819,303.416067,339.420387,324.330439,257.435142,175.211308,181.90333,228.367285,252.749803,230.119491,123.363794,67.040761,17.872257,34.037444,89.118168,138.758528,180.617219,188.669801,92.530825,-155.432895,-184.20939,-7.763503,118.084976,248.444102,221.23347,205.857503,152.967565,75.371765,-45.542328,5.958007,214.55458,262.244299,235.874847,173.956184,145.524537,64.469769,41.831312,137.173484,208.875987:-438.872451,-285.635614,-250.223178,-278.609947,-315.244335,-355.275591,-322.029577,-179.830256,-69.493928,-43.808999,-47.572674,-40.763952,-11.485599,-27.10196,-51.378185,-23.910646,40.096376,14.208517,-27.244236,-98.436156,-111.728956,-119.202808,-106.60924,-11.376556,77.806268,64.230056,-53.122316,-104.661826,-134.576137,-122.015401,-70.37163,-50.951794,-20.100847,74.341285,129.720275,163.980926,126.013186,-3.47502,-44.224504,-18.742958,67.675469,77.705677,28.6088,19.319125,32.871086,25.111435,39.260684,71.3351,128.254678,192.515198,208.879727,153.553027,81.959808,-53.117494,-49.968402,44.702982,37.495876,26.764844,10.481748,-46.876907,-204.372363,-242.257986,-216.715908,-175.037496,-31.045109,104.039153,82.364011,-40.227257,-54.144496,-53.750074,-79.568408,-115.897894,-32.8867,27.752739,56.868604,24.386531,-55.707893,-70.571768,-24.622845,12.149391,65.876931,61.418512,-0.687896,-246.38707,-343.007067,-284.493625,-158.810753,53.309699,104.097682,117.339601,155.323909,131.283507,-18.540499,-79.616025,-90.83584,-66.299431,-16.408716,-7.966953,-43.507907,-176.66109,-236.185052,-272.756444,-236.98926,-87.081048,80.138682,157.093091,219.184772,178.402927,-3.951514,-86.596165,-66.761543,25.345176,236.522275,385.642373,388.028113,216.515818,96.966076,-18.588347,21.440924,188.633281,308.98246,321.540278,225.748216,147.229917,-2.479782,-50.289724,-51.755679,-33.244075,-3.039189,45.885901,53.314911,-5.315974,-47.626252,-93.714079,-73.155244,60.667473,182.103019,175.332334,83.041249,62.410281,35.193233,9.874896,73.389492,168.744107,297.137053,245.166658,179.087343,50.935438,5.945353,-27.520884,18.97504,201.64432,271.826274,255.507898,202.085319,164.013801,35.6352,-24.074924,-23.230732,30.843839,192.004304,326.044932,321.864654,186.772144,97.404604,-51.097422,-84.36716,-56.906141,62.311604,119.266694,131.069145,114.701379,102.465392,79.627289,-1.656021,-18.904259,28.379498,64.95033,29.100166,-107.932007,-168.085122,-218.716946,-195.635612,-80.666771,42.255525,96.44513,152.700002,128.692221,-5.804916,-65.99802,-57.270929,-4.382315,130.361458,228.17198,205.713527,78.477487,13.771478,-115.336185,-143.775048,-47.070351,70.780566,76.403505,52.722332,45.553038,-11.688781,-54.759695,-51.331455,-1.919404,76.059895,29.58329,-12.106535,-74.049616,-114.182351,-211.459059,-232.868543,-167.741612,-18.246011,28.189228,-37.295744,-130.731242,-242.505405,-204.151492,-45.771316,1.377233,5.945988,18.409872,58.123092,155.045209,157.691578,49.618586,-3.871558,-36.270134,16.703814,55.94532,67.629909,17.303057,-164.948014,-252.043142,-316.260598,-300.488376,-236.040219,-211.46873,-240.986259,-341.225328,-377.395738,-346.916118,-272.059668,-113.579945,-67.347348,-69.027826,-133.684027,-184.970204,-218.825384,-193.675033,-117.952731,-79.005627,26.922706,144.889646,182.06745,221.593247,218.924739,185.392713,207.855688,357.563048,411.167848,364.947983,252.12561,224.163944,189.072886,156.730702,113.577467,134.693683,230.67721,292.044668,293.904092,310.783058,338.690532,325.251411,279.01182,269.238174,378.424753,423.812708,410.242979,340.612384,209.556392,179.465411,102.286891,60.017756,110.141728,260.222131,304.185665,306.467053,259.187346,153.831364,162.700661,286.723161,368.460404,389.929484,447.553597,470.327878,421.512073,370.558607,378.512919,438.906198,535.699573,520.27721,454.337848,261.125758,204.79966,185.140784,175.894117,171.865698,251.981596,289.959826,253.37128,195.394392,118.739528,98.920692,54.374162,37.370376,28.031973,41.601943,44.858658,43.950325,51.473266,60.641431,57.444991,48.802803,51.248946,70.983939,108.962122,118.682264,101.369889,56.59351,-49.099818,-68.934539,-34.181807,-47.613883,-116.678936,-273.567741,-330.171585,-414.225846,-401.129359,-228.738904,-111.382411,-99.93888,-79.502001,-77.745755,-109.790395,-109.47885,-40.523859,12.158142,146.553667,251.61527,251.224495,174.370436,121.1225,27.24707,14.20267,76.22523,196.084262,263.94397,356.904899,364.274507,295.843485,230.802294,140.132096,122.75271,105.704268,137.697587,139.305873,86.341298,67.732855,70.290233,76.340508,76.111509,67.9996,83.336448,107.323141,65.599096,-76.800239,-101.012472,6.180811,88.694996,162.176103,123.877196,96.105482,64.437543,45.736038,-46.488058,-66.477839,26.789273,116.942923,122.577373,98.515089,90.338106,60.387306,23.845262,-14.157024,21.650552:-190.721174,-189.158236,-260.201035,-404.018054,-435.420903,-404.527681,-343.922124,-198.09638,-66.497607,-25.246596,-7.008196,1.062042,-3.644825,-31.524113,-35.12423,9.548623,87.474754,56.262003,11.408659,-104.605012,-171.418903,-266.880489,-259.45142,-137.786274,-17.853882,-26.344484,-204.183686,-309.712579,-373.151763,-317.475589,-184.808917,-167.894081,-155.704448,-62.580659,-12.314853,2.126928,-46.284463,-112.743529,-74.496484,57.127825,104.433267,93.042398,32.882821,-1.493414,-70.206175,-91.874012,-36.480758,28.544673,131.22971,191.247138,197.557579,113.176709,33.440576,-53.903167,-26.025234,28.888979,18.301378,31.913,24.345894,-30.597522,-177.809075,-232.899792,-257.423986,-221.896145,-51.353663,107.309999,95.754125,-5.60121,-27.993236,-58.570224,-86.591843,-93.361772,47.587008,123.251126,121.908776,57.69925,-92.921359,-137.573168,-108.079927,-52.735256,45.607545,11.71434,-53.295546,-199.226658,-241.062963,-192.98762,-121.619934,10.158561,93.101486,119.637128,113.437775,60.869292,-109.436456,-167.593064,-151.824068,-104.980606,2.470584,39.489666,-8.239553,-151.57321,-211.546195,-277.734612,-244.98051,-32.310737,203.243364,269.297272,252.591166,173.677659,-26.194575,-71.692703,26.822471,117.602622,235.082159,259.989847,261.061752,215.863899,154.055507,57.808354,76.927477,208.27385,307.955015,316.116923,258.773066,200.044361,4.106477,-91.604972,-123.297005,-79.170419,-8.512841,15.938684,8.52612,-91.323338,-160.352478,-223.990149,-189.047613,3.776516,176.029391,175.177091,54.653109,-4.56576,-107.227465,-148.695979,-119.81718,-32.81546,169.930725,208.865444,152.89278,-24.986073,-114.24992,-155.319336,-61.232491,231.838715,369.153146,352.365257,228.415569,130.358753,-102.633318,-171.983251,-92.704936,13.207656,190.30956,299.682266,326.834916,278.036658,208.755014,55.853382,9.32161,8.381285,98.576308,127.158228,42.270848,-42.089614,-160.497708,-166.442647,-113.21539,-83.74946,19.552556,81.668095,25.237281,-185.914601,-276.479522,-307.010493,-229.928189,-15.405986,102.827201,120.447751,99.782523,53.845865,-104.608277,-163.412742,-132.988684,-64.214435,118.495335,230.815114,198.084563,15.519333,-85.198329,-204.808486,-185.963548,-19.053531,119.260862,108.156428,9.639359,-2.42333,-2.372941,-27.282992,-27.744924,14.681549,76.519689,15.503072,-32.489935,-71.681607,-84.661608,-165.217465,-192.098077,-103.663207,62.086785,75.399218,-59.169529,-140.764844,-237.378073,-241.053222,-161.465388,-93.847315,86.24853,168.675442,138.881903,72.038586,50.799687,44.544258,68.448154,85.535365,74.363945,76.924052,32.015035,-21.405185,-165.055091,-236.405145,-275.293327,-229.751837,-69.421067,28.235522,4.622646,-183.465339,-297.387859,-362.575242,-289.383676,-100.547072,-9.741724,-1.911557,-61.875598,-101.768751,-155.890072,-170.136718,-147.622101,-104.778556,33.850485,186.597639,241.173005,254.781972,217.966023,199.00221,273.573092,473.759183,503.261461,468.473408,356.764411,286.102859,152.896258,100.891363,83.304043,129.201629,256.950419,325.47583,312.42842,246.704522,229.972575,219.438892,229.168269,319.315333,464.277918,529.503639,530.860813,454.140046,279.90961,225.819044,198.555592,222.189722,330.330889,415.474559,401.026831,247.432338,154.631768,110.476121,171.986455,336.64474,441.469454,473.494889,518.186387,518.770002,446.830465,406.787272,400.816918,427.864805,514.67794,535.778678,453.518843,193.471819,118.113594,144.938388,194.480343,257.961001,300.770104,331.035279,342.09303,298.166135,165.192708,116.118739,110.298792,149.793542,258.887439,307.683306,296.680967,218.439794,140.80487,-6.752644,-10.876382,95.738474,169.916381,185.816317,203.632675,191.612993,140.950677,117.452929,30.077939,-38.37352,-104.134641,-68.870227,-91.078674,-243.463875,-333.656564,-421.115335,-377.523484,-166.128736,-26.949843,-24.140751,-47.26013,-47.63558,-103.477656,-154.585328,-145.342417,-60.558863,172.078552,309.81463,305.825797,191.632369,111.813833,-15.104998,-31.91287,73.453912,267.40144,305.173935,241.929709,210.182985,191.798109,168.222123,101.441482,83.016386,103.557663,138.351987,109.203025,-14.30148,-65.42355,-101.892266,-88.284173,-0.87867,117.471194,150.620781,79.831478,-16.838266,-151.880008,-127.20106,36.92647,109.915272,190.686659,168.006258,97.180825,-48.956724,-75.999277,-88.605201,-94.585375,-72.478003,28.125602,85.99009,124.553406,100.310815,19.754052,-9.484728,-3.448573,30.398756:-507.888547,-297.140745,-210.883648,-225.60899,-278.994199,-338.698485,-324.753403,-230.813434,-173.069273,-139.354142,-35.145468,-10.132813,-47.537675,-74.050952,-68.661348,-43.677244,-0.527893,-4.366528,-38.351085,-111.805107,-119.158153,-84.725961,-41.463204,98.068107,160.64033,118.077392,-8.572765,-46.028025,-101.959909,-121.164718,-77.27531,-32.469085,13.57563,45.486006,87.833473,185.043446,193.19987,77.233649,-10.239779,-89.38854,7.621546,52.785253,26.217675,-2.296496,-13.241166,-2.281026,104.218959,174.181876,214.529236,239.946361,265.426342,211.403714,123.088437,-72.304731,-122.75066,-68.61028,41.885432,34.099752,-146.713429,-247.96465,-312.515563,-303.469846,-254.171213,-200.290221,-102.106723,-133.965734,-180.631905,-203.027791,-178.385995,-162.134079,-159.486398,-90.858679,32.744425,106.722827,185.948981,150.983769,38.930046,37.037513,133.818934,173.046353,173.983592,13.249851,-138.032659,-388.233637,-409.957351,-283.353441,-198.299597,-58.211759,95.587572,166.224008,177.793829,135.458805,96.763534,78.446574,-25.306556,-59.547739,-37.937724,-80.228161,-163.577317,-308.755886,-320.824983,-257.036529,-201.007364,-72.557125,81.584359,170.903829,246.220645,205.933784,55.352398,-6.087366,28.494441,117.659849,261.86914,293.113141,282.413566,214.285176,165.269637,103.837753,126.358863,265.925664,394.795791,409.65955,311.832356,228.792073,69.790288,3.530085,-79.802749,-83.833178,-18.119554,44.881658,54.207399,19.115562,-35.800108,-155.577483,-161.915228,-31.929603,108.70029,153.907085,205.314237,189.033428,84.002307,44.705901,101.94697,188.190511,320.719624,284.389115,225.683811,142.235601,130.142135,142.056483,183.527005,332.053336,413.909371,405.984402,319.452746,250.974116,113.647539,68.437704,35.931501,45.790435,135.042216,248.787575,257.385721,173.538447,116.262807,16.675095,-9.797387,-12.755327,37.387053,88.184626,138.740742,128.072683,99.481205,72.334619,9.768538,13.845766,61.320712,24.932525,-5.744689,-26.536102,-51.184668,-163.1708,-184.443001,-69.071546,63.339511,71.468423,-14.243104,-74.92601,-162.954407,-167.2938,-94.013036,-55.508929,19.81379,102.986603,97.578101,61.326142,67.26762,44.238279,30.866707,159.368974,329.177641,315.846476,198.574876,184.0178,198.002927,164.637402,78.818358,92.165952,208.678683,221.98647,165.301846,46.249575,17.77075,11.692734,25.737969,75.321575,83.895957,44.386619,-89.15397,-120.889464,-54.206161,3.062973,86.654372,104.942794,90.305385,36.365369,22.340131,60.858979,82.33673,42.404226,27.68051,118.658529,176.810371,144.913716,22.849392,-60.539293,-237.929511,-277.203108,-237.619835,-219.999795,-225.995012,-161.285415,-128.049868,-127.135399,-114.886385,-39.908735,-24.105382,-38.185626,26.601438,85.218762,101.87412,56.374139,-13.287077,-12.069192,71.182391,128.872914,227.581769,359.234722,429.096061,459.498449,395.211867,219.43764,188.085835,283.512609,373.593005,368.309464,287.254776,231.757035,126.52034,83.300247,94.344513,169.436303,347.276826,384.750561,356.075868,322.169121,336.044112,362.160308,359.352151,337.59735,346.600842,384.103328,441.153171,423.603579,328.780793,278.757922,239.982984,266.449825,355.351768,367.796183,332.551521,220.032106,157.969769,90.323769,116.662478,217.775794,261.957181,306.600763,462.854332,507.18184,437.625769,367.297793,319.364905,355.764789,427.695859,352.513414,293.790498,250.65215,245.698123,206.733728,187.38723,188.272212,204.290222,186.022166,125.915115,108.811516,74.866234,46.739491,1.195856,-20.728082,-86.528332,-35.699347,35.267882,80.695707,58.009317,52.358401,68.151453,80.918694,90.804163,89.392308,15.147353,-16.361845,35.776768,70.015821,58.297606,42.299128,59.59146,33.74074,-32.938468,-146.679622,-168.05992,-214.13281,-226.636728,-164.651954,-62.984113,-26.605637,-23.860611,-60.398289,-151.400961,-191.130388,-217.207596,-196.207628,-90.841,89.49093,136.027392,43.998541,-28.045946,-70.788839,-70.529879,-87.124436,15.776376,98.341635,118.518018,62.096079,5.208495,11.23348,-6.147155,-30.308803,-32.589615,48.377734,76.707843,85.156265,86.243705,71.109546,66.830766,89.947547,71.498573,56.089996,30.801941,-4.329357,-80.922763,-75.984195,49.242524,138.072889,259.840011,250.447882,201.525569,62.85886,-4.661567,-79.317182,-71.390025,-44.369164,-79.996919,-85.050985,-59.481652,-44.197162,-29.728012,-38.138563,-37.680731,-3.559301:-242.641201,-160.742019,-191.989326,-342.104257,-390.363234,-348.470178,-285.546025,-167.787336,-73.723248,-43.998889,-65.481731,-78.078744,-59.358411,-69.069181,-79.666902,-25.315297,134.762834,135.627833,69.64142,-88.899029,-151.449075,-178.756946,-123.468829,64.269779,156.895215,136.177599,7.785981,-78.816866,-213.225706,-230.574452,-166.988021,-102.398434,59.694166,137.257543,109.129016,21.470966,0.6052,14.636863,45.106724,104.904425,102.302608,74.505033,6.543547,-12.77457,-22.786559,-8.70404,79.386411,134.644361,213.294745,247.946084,235.325768,145.362557,89.187701,10.276489,4.214154,46.677654,74.658676,48.094715,-101.503119,-196.030914,-326.816539,-350.6052,-309.416213,-238.243675,-74.507993,-63.513525,-118.44087,-221.780607,-244.825554,-255.109779,-247.671099,-199.213368,-61.141665,20.518148,40.429853,-17.124277,-88.874612,-78.009406,-34.169319,-11.595875,56.023327,48.957868,-38.084945,-301.395445,-380.816725,-297.993925,-185.79882,2.129562,133.361447,180.530068,147.385803,59.053114,-130.685439,-163.110459,-48.188496,43.580296,124.417318,23.138033,-83.373306,-283.42392,-334.638977,-336.243521,-279.3031,-42.093115,228.93619,308.828108,284.182448,199.513452,21.561861,-14.836252,108.730964,234.282689,382.019096,307.444918,240.005652,118.648436,58.948734,-2.979623,47.580409,259.505617,389.459002,387.449141,250.525256,156.317424,3.062297,-56.773267,-127.152449,-118.433529,-20.654987,19.778817,-22.350854,-126.943908,-143.957064,-125.18571,-99.856295,5.810588,165.804538,228.510652,220.713125,146.389711,-39.675085,-83.784472,21.047866,133.902608,319.502749,316.560752,234.291161,40.579823,-22.8688,-12.2962,90.268051,358.442361,422.56336,396.181764,307.071268,230.529925,33.895504,-48.900476,-60.689638,26.60572,265.942754,351.413901,298.14575,134.853303,75.305045,1.468706,-11.660281,26.863391,122.153833,159.445724,105.176138,15.159042,-158.621009,-183.211595,-89.323949,-28.435815,28.114583,54.111301,47.304905,-55.531894,-114.828574,-115.972839,-55.485845,77.808057,153.716631,168.769036,129.166846,76.025595,-37.285163,-56.041823,22.890974,80.054675,205.181681,336.334508,312.692116,77.187284,-43.322404,-126.529454,-72.38629,139.508236,225.229936,203.791057,164.248036,146.38393,66.288321,22.333038,9.482931,55.697288,210.418553,246.465371,178.105625,1.804894,-51.889704,-69.900588,-44.832265,39.034011,119.058863,128.33672,40.98141,-33.839018,-122.787231,-116.637205,-67.711946,-28.109594,120.325264,180.76196,130.733695,38.013704,11.671713,-79.926045,-99.072048,22.411203,186.419045,215.634269,97.082354,-42.583977,-287.744995,-325.99139,-276.695813,-226.00445,-80.607564,-19.450112,-72.947691,-197.455713,-216.021552,-203.89648,-181.9471,-93.426599,19.268073,59.279853,14.139233,-54.529087,-153.507072,-156.450665,-43.897787,51.653089,247.016834,353.417528,333.125821,221.892043,188.539903,233.086138,293.845319,361.244537,339.833298,329.539826,273.306704,212.992875,92.179064,66.390978,141.87672,234.650892,407.653898,409.42189,353.426516,294.006927,301.733136,226.607644,149.532239,166.745273,414.010954,505.854582,494.238521,421.419561,301.042605,279.105086,268.838516,276.821791,355.983681,433.855762,411.457952,236.984544,133.698503,56.555534,104.67243,236.860985,279.068721,307.154822,396.500103,406.85579,323.208176,287.61739,327.249039,371.826307,465.477929,496.217949,422.644299,200.04135,143.934757,144.482217,151.532143,196.424971,306.243903,317.109311,222.840031,172.927697,73.913396,7.706718,-28.916683,32.455685,151.695655,120.807826,86.11011,33.172792,4.889019,-27.502942,-3.597774,95.77198,171.722309,175.433939,98.401199,56.520464,26.572693,6.690204,-70.684425,-89.317969,-40.181151,0.952088,-30.867665,-188.123506,-289.771545,-427.978284,-404.022242,-197.020955,-57.238713,-57.569899,-140.675563,-193.22245,-276.738687,-308.011978,-303.24574,-249.094779,-71.257073,85.894651,111.497486,56.524328,-7.944651,-133.329144,-135.562688,24.848616,214.663846,249.096095,231.234876,222.239047,165.097032,91.951174,18.746013,65.205122,171.80554,155.601341,106.424785,12.468156,-20.934567,-87.031869,-92.3133,10.489068,139.510818,168.91461,135.736204,70.604558,-67.391712,-88.425839,-20.912355,39.449183,152.149038,176.346009,129.546007,0.037834,-31.059419,-9.708206,17.181405,42.340752,16.746378,2.404099,-31.767237,-62.811207,-125.718333,-118.296485,11.089882,90.021688:-285.245771,-161.65295,-109.286359,-121.222578,-158.035322,-174.923149,-137.055114,-46.100772,-42.190505,-47.141667,-29.350817,-30.783574,-64.030478,-66.434357,-15.119356,17.878351,68.398774,129.521216,142.836064,128.412309,116.751454,72.45842,51.964597,45.081608,93.889579,135.215411,203.96422,215.584845,150.763109,77.670608,-3.645964,18.893247,74.058385,99.785177,119.498567,150.33055,146.530795,84.206903,44.32195,22.914759,116.043037,155.757711,89.580713,27.973913,-21.205946,-26.216942,14.516082,61.323863,99.131586,61.815472,42.484257,-1.992609,-30.442668,-94.662162,-114.093721,-101.639741,-80.609389,-82.949256,-123.109158,-160.698557,-245.234343,-267.78656,-229.108479,-188.242553,-168.907789,-235.849661,-260.488561,-242.317419,-219.097482,-186.545105,-159.059573,-84.388046,7.67853,66.306918,143.518926,155.024358,128.114682,88.636437,65.691175,113.923229,200.319009,74.016839,-60.515014,-309.846964,-354.608462,-251.520644,-156.870827,-19.810021,40.13835,64.117035,79.015557,70.580178,52.812266,31.654588,3.590597,34.894771,114.944872,83.468177,51.99684,26.752249,24.011879,-0.350534,-10.330659,5.411626,25.226634,47.210996,98.471141,104.471046,82.378433,57.533244,22.222957,46.795025,177.668538,250.717742,229.620398,145.965253,108.566571,51.507675,46.625972,119.506377,188.446925,194.793289,172.069835,146.424181,66.100094,-10.04156,-179.370436,-205.066912,-142.559576,-94.299638,-83.626169,-67.805236,-78.307812,-152.914539,-184.182531,-143.873707,1.119688,81.142513,180.504331,187.588689,166.992699,141.857405,91.855055,119.05515,274.830946,357.855692,350.759485,321.708591,301.629941,237.09425,221.123532,272.621122,340.125912,324.093642,187.007875,110.602367,12.052925,-34.061991,-118.545822,-114.788623,-31.026058,22.471897,6.618404,-93.376205,-159.449514,-275.499055,-292.903571,-232.737024,-149.43756,-115.64331,-95.59248,-106.484724,-116.956461,-123.378049,-172.871328,-192.648896,-161.810383,-97.709054,-81.092319,-108.10176,-158.53665,-256.427973,-252.846199,-136.452091,13.082204,66.941404,58.253912,10.686711,-71.423373,-100.636315,-122.91696,-101.703546,0.203377,85.783529,89.571746,79.119932,81.85718,85.238046,109.721685,234.312769,314.21947,298.31328,216.153189,215.147379,302.515954,310.398521,218.370435,195.372288,275.476156,343.730626,310.879159,162.169974,101.101752,89.605508,129.313925,213.810651,238.890449,220.547359,122.628728,71.067873,35.091974,48.732097,123.174171,165.876956,162.730794,49.689233,6.074908,49.732796,105.008666,108.965142,89.482889,155.410832,178.268027,124.484743,14.287168,-0.924313,5.587206,-15.487152,-60.854448,-32.514411,89.815,161.701867,154.065788,115.275253,132.283167,206.588141,216.923824,192.77188,231.347652,251.860024,216.801068,193.249836,130.172541,76.630799,53.654675,111.257193,238.256356,259.905715,244.726055,209.794023,187.138067,120.829313,86.682115,45.91107,43.10501,40.993554,-7.327314,-43.318723,-105.811585,-124.819081,-67.979621,10.543383,174.129081,234.864877,210.094899,138.561314,125.901104,98.066335,76.459655,97.774391,198.627299,251.006758,330.965519,353.583731,327.055426,265.450448,188.199257,239.344936,381.841206,293.364442,195.368836,57.441422,34.044802,60.877418,99.294888,163.246948,182.752796,210.197117,297.660044,323.531081,299.499246,256.505389,173.183562,151.864614,168.200598,213.52648,189.284998,66.613765,24.400987,14.009407,20.670999,3.850432,-39.101858,-49.663691,-39.739098,-30.963504,-69.987366,-132.960947,-245.492406,-249.564305,-188.11944,-106.639678,-70.623848,-66.1068,-80.16677,-55.219211,-38.500741,-79.841384,-155.144621,-167.962593,-108.111984,-30.4125,151.743579,197.408405,168.065018,133.941467,115.802322,109.88186,50.796999,-75.481591,-73.949489,-36.282669,-38.277986,-21.717781,-17.747204,-32.671313,-100.691884,-162.671863,-268.973495,-284.081087,-258.93738,-240.195478,-202.421316,-139.304106,-110.708273,-106.641397,-114.855187,-126.208633,-156.321956,-237.884386,-196.114233,-142.0223,-105.762355,-132.199905,-173.012952,-176.910048,-212.753252,-239.127332,-211.231552,-87.382187,-55.814577,-41.287316,-19.261502,23.565093,40.06077,120.213816,183.237704,159.116851,49.514916,24.571549,89.692484,147.788286,258.862497,295.289437,266.926703,204.797254,190.848111,119.87592,60.674449,-12.969858,-12.112513,-17.888508,-86.291174,-108.601537,-99.128805,-81.052268,-34.976197,-19.372299,-22.801736,-22.714584:-334.933305,-268.708314,-230.917126,-179.079625,-159.603627,-113.419801,-81.556772,-38.532002,-143.679693,-211.538552,-193.126597,-138.315522,-140.017183,-189.045206,-188.793642,-121.492522,8.130646,39.674366,20.754302,-19.080386,-15.930901,42.761232,96.371055,195.008728,153.568138,70.872968,-71.676025,-75.46481,-19.585905,-11.907718,-16.918448,-8.114637,20.899707,82.610015,134.376706,213.617629,196.285988,37.695377,-38.865334,-75.928551,-50.667633,-56.393825,-87.618134,-82.145466,-31.444553,-14.026392,30.326737,64.22955,101.898552,94.359305,63.40408,-31.157349,-72.938569,-126.432074,-115.276729,-1.508875,75.044654,52.347571,-90.466164,-156.411956,-188.230011,-185.374429,-198.447613,-184.603106,-110.74368,-150.584011,-219.537474,-267.425689,-224.673825,-119.039926,-65.16172,40.487731,147.295649,217.955514,308.294598,311.183313,275.31155,250.188152,240.206633,241.396708,152.286401,-45.251955,-151.648277,-278.067054,-278.872017,-160.294411,-54.61254,142.129734,203.287982,194.068432,153.48079,142.594198,135.804958,112.175921,30.382216,4.157514,-11.016178,-30.577027,-57.843257,-123.864633,-132.839444,-103.461633,-90.331838,-77.939511,-36.783631,-14.654753,-32.16305,-60.22942,-94.553181,-93.873274,-46.667662,-1.812646,134.609344,282.878187,314.181944,271.221881,219.436727,128.740238,127.309995,228.857398,346.333533,361.459816,238.361791,127.995794,-60.603506,-104.334834,-52.776054,-0.236429,30.898132,30.744983,44.835819,60.952589,28.626466,-115.197573,-172.585229,-183.977327,-106.444175,-49.523038,18.984514,17.044391,23.490386,46.617585,101.586945,116.23421,131.483072,222.610226,276.266028,310.969855,289.284814,177.59063,119.747165,116.53905,182.883938,190.665028,146.753462,115.074844,52.885024,1.499391,-74.884107,-43.253891,81.458013,91.379941,40.457179,-101.319074,-158.890484,-183.234567,-139.886302,-42.676401,-6.013999,32.156921,144.017881,164.97911,42.114747,-64.958082,-156.097258,-136.994015,-102.707608,-43.173213,-23.335386,-134.612012,-245.707509,-385.826601,-375.075938,-263.023541,-90.0768,5.847479,59.637326,5.425912,-112.055282,-137.920946,-119.174405,-73.76488,52.270097,108.701675,95.272238,88.909477,109.101803,103.394673,93.230778,183.111249,286.743699,266.077332,182.422673,180.903853,207.031112,193.419192,173.618657,205.261635,326.485324,342.909362,247.350119,-28.478205,-112.145097,-113.402814,-61.664827,48.646306,82.931154,74.160395,22.378757,-0.755229,1.582855,15.895819,56.939157,81.293314,108.73794,59.78396,8.665085,-11.300518,32.529977,98.357403,111.165914,146.68273,190.410785,186.87135,70.473533,-16.054761,-122.210192,-135.170483,-117.782333,-92.552985,-28.732247,-10.711113,-55.056406,-157.884573,-142.834716,-29.602181,3.352981,25.331673,86.250552,114.757826,83.579229,58.22886,85.609636,105.243171,106.980357,105.29986,151.994486,295.568071,340.938725,311.252898,264.215832,158.101878,112.931421,71.133629,44.2269,12.3757,-52.414389,-63.152578,-72.839859,-84.291625,-15.48828,88.359648,299.840672,346.121295,313.725633,233.72538,203.206608,138.05134,112.419848,132.749069,227.265074,277.997909,336.599259,339.675739,293.53218,239.171795,146.260525,160.140875,285.294946,331.248524,311.036433,322.717185,349.946974,321.649582,270.904429,200.346854,236.670249,277.913867,344.015826,367.900751,329.123992,244.86628,107.159431,95.262662,76.477973,31.981896,28.036564,-1.384332,-43.754904,-84.518458,-54.242108,1.671867,-36.291667,-46.931092,-25.723957,-28.050621,-104.536267,-150.596952,-176.661232,-185.273072,-227.961353,-152.440656,-88.142177,-53.773321,-65.996477,-35.029425,-9.19806,-17.990418,-41.450047,-30.866127,-17.987399,-16.429071,30.123082,54.642942,68.216876,75.587451,110.386424,80.994942,10.744589,-144.495925,-179.506123,-184.729676,-171.831951,-89.461196,42.304206,94.285407,126.160236,111.130088,48.256804,6.864309,-17.905946,12.11778,94.94366,151.031439,143.56769,77.023458,50.938455,7.21631,-27.295938,-89.435723,-18.248334,62.834067,99.611258,31.509808,-102.807062,-142.091175,-213.491934,-231.897982,-168.273973,-6.421677,71.465696,149.91598,137.939772,90.827785,110.798809,170.72166,79.785666,44.215429,73.940868,74.981281,-13.942447,-51.13579,41.215716,140.927845,217.242028,193.924227,213.242191,218.945446,166.422511,30.307421,0.344604,-10.373311,-55.33035,-67.927786,-37.555683,-13.580425,1.937123,7.229357,72.187493,111.45336:-243.725803,-127.22257,-106.961978,-138.945939,-176.605739,-254.863092,-233.235711,-65.195111,7.001964,8.967996,23.959938,30.589803,63.279651,82.475518,101.835991,115.606831,135.990093,154.341617,170.694765,148.548157,94.187749,8.982583,41.340671,191.682484,247.3695,237.929967,144.782442,63.035291,-48.445641,-39.574402,52.085785,91.155958,124.195168,168.83802,205.626762,242.764973,222.633458,106.106787,53.390607,73.369161,154.040882,157.27473,121.368925,119.437875,116.347195,93.027982,121.07819,186.602201,259.500178,258.565671,257.891823,193.550162,130.542979,25.119738,-8.286221,-85.317982,-55.653998,10.639303,-10.245186,-111.88722,-265.776474,-290.823749,-294.809523,-276.114045,-206.280012,-195.098416,-234.522244,-306.793587,-304.394617,-243.740218,-204.143419,-151.897399,-115.788328,-55.289061,75.611836,87.854496,19.625694,-18.118207,-31.328316,-8.343576,28.786173,-39.860131,-131.524671,-315.644996,-323.017021,-169.813467,-87.568329,5.357714,74.5417,107.617078,144.71201,155.661765,161.285112,134.799938,49.209078,16.886946,-8.725478,26.08621,16.052246,-127.162683,-202.864135,-247.90839,-226.408865,-120.018154,24.110414,86.065701,157.418031,154.049612,113.665874,95.331024,101.088451,134.71612,186.648132,190.796963,176.292784,51.948022,-36.922958,-123.673325,-97.373126,49.996344,186.61994,206.717362,157.405538,130.357829,107.031197,77.571892,-41.703682,-96.078499,-105.483821,-13.728522,22.088106,-25.903382,-95.269788,-144.683645,-110.306197,-55.844904,-14.275482,38.271067,131.92128,114.081722,-16.662329,-51.723247,-6.042824,31.550627,92.943124,209.198251,248.162776,191.068402,137.337219,97.541025,123.745129,214.353604,234.570108,210.371889,116.136243,87.448593,95.075726,73.96478,-51.529678,-103.531509,-74.971962,84.855156,108.873519,-10.227491,-71.7254,-146.975602,-182.753649,-181.917338,-127.84492,-129.150636,-146.969124,-149.128593,-169.416195,-181.292088,-152.466258,-121.824374,-105.197984,-74.434132,-38.149525,-15.938805,-32.383801,-51.803934,-36.068282,41.987137,124.956249,162.749533,162.013402,113.396232,33.835898,20.7944,19.087027,27.372223,63.868116,138.798902,148.660155,71.439411,28.181118,10.110257,45.449697,166.516959,232.929695,240.449027,203.571282,163.193951,103.379381,79.186533,5.639763,-2.734935,138.277003,260.303752,208.918134,39.428898,15.760508,58.033771,76.401348,74.112183,75.950743,102.93305,118.348836,83.625479,21.392921,26.669881,99.484348,139.649403,164.209466,139.689619,111.425714,57.941758,50.736053,53.402144,67.635118,93.467322,45.226408,31.42404,50.500883,42.818942,-25.29096,-53.471068,-68.134785,-50.495497,39.332428,132.567611,128.086091,25.863877,3.395164,88.924585,149.184195,195.894109,120.979887,72.578137,49.197353,71.347896,89.417916,74.858007,82.976108,115.702304,166.94409,190.632064,195.395711,162.850173,152.228233,188.170022,201.449215,188.746287,163.391725,171.378389,211.133622,182.532975,37.130438,4.88057,103.733522,174.453182,212.925428,152.218821,121.479562,99.500515,115.081925,153.151977,152.712627,138.524288,171.926652,221.571409,320.719893,320.452126,206.97162,138.749162,80.540532,93.515882,162.301476,223.334486,206.638299,57.536849,-30.619001,-107.056043,-58.66899,144.347843,232.117222,221.70673,175.803124,136.809243,82.635582,103.074553,218.405584,266.442588,269.259434,212.614569,170.164116,76.503107,45.470445,28.608722,36.866107,41.879454,10.32399,7.153195,33.993964,37.510427,-19.404208,-86.849049,-197.246772,-185.783064,-99.804643,-45.643371,-25.675989,-27.655688,-51.264073,-67.88168,-46.629789,-32.919501,-63.529158,-53.644544,-35.060255,-43.327802,-35.990698,-19.561901,-14.566551,-29.354877,-71.824489,-114.637513,-115.454001,-65.943098,-54.360592,-145.405689,-195.230642,-146.85169,-100.439945,-132.713778,-198.805386,-205.691456,-203.640911,-224.451986,-263.153388,-239.821255,-146.405229,-81.804752,-57.84124,-34.6009,-57.180285,-138.717654,-140.926842,-35.418664,20.125446,13.732753,-34.286969,-87.107098,-149.452461,-138.14359,-109.034563,-98.702307,-46.44083,86.00572,130.144122,89.318857,43.54605,22.483433,66.698076,169.268755,142.738759,121.167029,110.324535,83.692017,23.781186,44.650286,158.253286,200.465672,239.91228,269.568013,245.348827,102.545202,40.639265,16.186481,52.352215,137.204906,54.504312,-21.903321,-108.857097,-126.656515,-142.19509,-135.231647,-61.996261,4.740809:left
141.129212,69.332944,66.204772,150.092108,216.052804,302.596936,290.876433,180.873386,44.935764,-0.0561,1.654513,15.037161,-7.046811,-16.757937,15.250413,14.751953,-116.265466,-234.09902,-231.019786,-158.783617,-97.601258,47.361403,91.561003,25.78996,-192.076126,-266.384238,-230.986975,-176.820673,-179.105864,-228.181477,-292.738981,-295.078189,-314.921612,-355.155581,-338.674672,-203.479998,-107.855858,22.865804,28.542648,-15.9575,-92.632787,-134.203432,-153.632329,-142.798481,-150.94327,-154.681351,-124.43534,-125.254286,-206.797206,-233.860869,-193.50662,-101.025924,-75.304572,-38.359663,-23.150512,-56.780973,-155.9016,-191.890086,-217.958443,-226.826587,-220.279576,-184.224603,-136.970826,-163.048375,-282.263566,-405.281198,-409.907314,-304.40738,-260.87794,-271.686857,-315.438547,-444.055483,-539.872116,-523.974056,-385.090849,-310.488143,-165.347168,-94.787394,-81.442548,-160.552954,-355.72033,-440.113337,-429.816603,-322.973145,-250.532758,-167.203275,-185.210085,-332.865803,-475.890997,-476.259044,-343.230585,-269.608156,-194.131831,-177.083131,-167.837884,-184.560841,-230.109099,-224.173572,-218.854857,-279.900343,-308.104481,-247.669341,-206.500086,-260.725406,-422.365196,-456.684183,-398.04363,-356.540942,-295.365278,-260.324188,-172.633242,-123.872165,-87.654902,-161.430008,-170.382528,-74.907965,10.51917,173.950629,188.193397,52.106808,-96.96488,-117.211063,-1.909965,108.297139,293.538783,322.944516,201.966431,115.289199,92.282503,158.578782,165.314781,153.347014,146.36087,92.266907,25.918272,-166.138204,-303.292018,-312.091264,-280.674939,-257.571233,-192.581243,-199.079425,-309.621513,-336.94357,-316.693853,-386.87788,-429.488146,-416.143351,-370.619522,-258.693562,-209.5831,-159.768309,-207.182082,-226.195096,-155.54345,-98.964839,-10.85846,33.38751,73.570362,31.991983,-137.924903,-234.269836,-226.065793,-172.035171,-147.359385,-102.362686,-84.291535,-96.520206,-233.691238,-296.126988,-248.24296,-177.844116,-88.616364,-76.621394,-113.42256,-154.996077,-242.90266,-224.811292,-165.952479,-72.06844,-57.395195,-67.635692,-81.323542,-47.498992,0.002161,-14.674774,-0.563272,61.303958,208.999674,250.80846,244.045482,214.059262,143.271068,99.029696,102.617189,133.727193,145.840076,144.334478,120.549465,35.97024,-57.669841,-88.037779,-39.258341,40.694949,164.772605,162.243022,113.837171,130.681237,223.070876,267.044896,278.621162,312.209474,328.669094,326.565975,322.334787,370.373978,390.977367,369.223911,364.370773,394.217419,498.861253,540.577933,494.996551,421.102826,235.132631,69.655409,45.683957,128.436692,177.342904,159.322927,113.304195,70.602816,43.943195,6.267561,-25.23905,3.857523,83.295143,117.334346,197.216387,231.243073,197.84342,93.59734,81.882799,159.581248,223.126446,315.833223,320.392494,285.512906,244.103374,212.883858,210.778541,254.602707,374.25447,429.73878,494.749655,494.713662,420.577051,353.429487,373.216377,440.063912,430.402925,339.88867,305.818394,312.080217,300.491767,264.108477,219.537727,234.198387,329.661868,380.221183,416.5567,408.129174,374.188548,332.40373,320.169229,317.814172,324.884916,335.557078,314.398774,192.483602,8.481502,-63.399198,-51.28657,9.217926,96.459997,112.87033,136.773034,148.228748,108.66206,-62.392179,-149.759471,-190.016706,-154.581532,-142.699818,-185.838454,-246.449261,-279.838601,-323.293241,-330.061322,-263.996971,-141.04251,-115.430208,-67.75709,-44.738469,-101.862102,-231.30277,-256.269703,-210.664199,-167.142542,-107.05787,-84.383109,-18.781465,-23.271356,-57.914122,-101.658147,-94.735867,-28.037613,-1.853513,-59.515053,-111.930691,-140.187914,-104.149179,-87.511466,-47.243515,-13.430081,48.280571,60.729758,69.417336,-33.685504,-134.492087,-223.960396,-167.414309,3.621014,34.430437,-41.381669,-82.078015,-101.287307,-72.229311,-17.983466,97.745934,123.481557,135.701655,122.765675,38.458829,-79.867124,-114.782788,-126.155331,-137.293728,-165.044444,-138.140292,-45.807345,-44.16378,-127.562691,-220.926809,-259.98374,-317.239997,-319.821546,-250.741442,-212.984256,-161.974957,-117.130218,-101.923412,-36.4089,9.667391,41.966744,14.865893,-59.437407,-70.436263,-65.942952,-93.483995,-84.70112,19.720982,84.613837,171.998313,199.44267,206.816078,107.058705,49.646691,15.357654,38.669499,106.274012,124.111186,79.25873,33.202809,-15.266884,5.692939,5.097629,-22.025687,-14.887259,21.208477,17.038868,-23.033657,-79.098808,-103.907961,-97.345131,-77.121981,-26.37943,4.952513,51.062635,51.167742:30.595692,-39.54229,-18.364139,79.543115,85.667293,-28.587164,-81.573167,-47.473113,-20.038867,-52.421288,-75.293662,-45.4298,6.028462,4.064655,-24.453213,-36.804079,-84.706866,-181.007973,-211.236468,-162.442374,-83.724494,52.120506,52.753065,-51.071677,-170.711864,-198.128109,-185.981854,-182.232401,-214.007912,-240.725866,-272.482848,-269.755337,-290.967614,-339.666772,-323.475219,-173.179534,-77.726113,12.750583,6.354666,-17.450934,-114.142849,-181.299993,-226.470195,-205.436951,-144.002755,-128.923767,-130.68863,-139.16322,-206.391821,-256.470397,-233.758965,-146.156547,-114.830837,-111.444778,-123.501381,-141.954741,-174.586425,-191.787926,-204.192094,-176.634356,-92.91247,-97.377581,-232.638948,-312.984532,-394.509505,-369.779435,-340.228896,-268.260334,-233.619724,-204.254051,-231.05415,-408.315305,-584.53266,-588.374804,-472.141164,-402.96793,-252.710781,-180.401425,-167.821568,-237.362776,-354.486868,-283.636851,-220.683867,-156.322671,-141.56396,-103.565131,-95.035781,-192.795906,-396.359992,-424.126222,-299.496954,-240.951005,-214.239841,-216.225597,-236.138768,-253.022954,-291.967262,-294.957827,-272.425983,-259.249499,-267.79022,-254.929389,-242.527307,-267.909891,-337.151407,-350.040795,-326.456925,-304.790065,-238.253511,-198.588907,-158.94768,-159.547022,-201.017816,-275.379003,-266.164932,-141.167949,-78.600088,-7.916567,-0.1704,-46.416577,-108.728833,-125.923465,-81.293071,-2.834213,153.729005,166.779305,66.105835,9.790825,-24.910583,12.272665,37.460169,39.519792,17.156035,-8.679398,-13.492925,-93.542993,-289.003545,-351.428892,-306.725916,-226.694339,-68.59979,-54.422065,-180.357941,-265.256195,-400.724039,-454.869161,-435.109554,-309.901012,-224.38434,-106.619499,-116.484443,-250.651174,-308.574776,-273.860988,-171.877812,-131.629659,-66.674532,-50.162495,-95.042113,-140.592364,-231.309856,-287.154031,-257.84444,-82.044002,-0.709055,8.128796,-45.254733,-114.654777,-159.799836,-190.988082,-186.229647,-140.576228,-9.34934,21.031324,-71.751426,-138.128622,-182.76406,-125.411041,-76.880201,-2.013225,7.341335,-49.827318,-102.659762,-198.821628,-266.859096,-246.746515,-42.861888,85.43061,268.650593,308.640487,238.579188,149.004487,5.656564,2.920842,50.4153,146.064688,153.801798,53.768301,-23.716131,-115.837145,-132.400632,-123.487222,-73.379041,-23.373748,144.002647,214.567903,239.871216,198.801637,48.61835,42.555185,124.568083,271.579638,307.458564,347.749971,342.983685,270.830301,220.58677,232.607748,286.023631,305.697775,347.692093,355.060577,293.04512,242.97161,121.644563,-1.620068,-14.629641,90.247432,159.482408,193.186296,157.59584,48.553332,-81.354467,-126.476727,-98.093006,-34.927426,99.147132,139.526227,141.474785,113.910746,27.563604,-21.956386,-8.409508,91.76538,166.887398,293.156876,308.209017,221.383008,94.391765,77.400345,157.963016,214.718637,311.155621,369.705622,473.121446,487.464801,450.931222,374.743364,348.042016,358.155572,386.969052,429.891491,426.383267,372.509767,246.737531,185.492968,196.409133,263.764146,410.825062,451.597053,446.107935,424.871189,365.591808,318.274867,325.015808,388.857263,425.621472,418.525904,357.297507,185.861845,23.584266,-14.105201,59.257262,140.788146,286.599384,312.492416,255.595341,213.093064,148.341995,84.461474,51.189952,-13.065047,-33.615936,-73.444369,-108.034281,-133.446759,-132.48722,-160.371414,-210.192525,-198.185149,-115.936041,-73.158963,-31.839972,-31.563445,-50.010502,-110.647292,-146.879558,-137.662392,-60.712685,173.713091,257.997542,249.547841,75.641549,-8.998684,-45.065716,8.15015,160.314398,194.357959,92.980549,7.980342,-51.034542,30.781116,57.499089,67.235813,95.821447,181.758766,176.006848,43.902242,-72.904554,-76.584771,-34.095128,-29.343555,-26.904314,-24.400336,-73.726611,-99.643146,-78.364253,-2.794784,26.783363,36.213538,39.334216,84.787564,109.960996,119.676808,53.166104,-8.111592,-105.229762,-103.612544,-18.218937,12.547562,-44.257834,-107.319927,-194.218866,-196.37153,-178.153995,-184.811849,-208.990221,-192.469782,-147.281922,-89.205695,-123.096087,-126.211534,-2.109714,90.5173,195.944031,202.095798,173.445135,144.323734,83.208786,96.321279,122.576149,199.065009,249.256923,268.120403,221.582463,108.00873,19.876979,1.397144,39.058764,82.991365,166.280518,183.263307,138.970526,77.061115,-66.988522,-112.193954,-92.576532,16.187006,72.971984,94.457058,76.053591,35.386196,-60.367274,-101.925195,-77.473822,-30.731194,53.340887,73.140738,41.850261,3.923076:-58.582526,-67.714953,-92.014616,-87.815752,-45.305287,-1.124779,-27.962463,-128.082474,-196.863369,-187.964185,-95.405311,-57.785864,-62.569586,-69.277042,-36.535911,-56.55093,-207.684117,-221.316936,-170.47235,-93.957803,-64.53387,-24.307045,-39.114221,-120.629927,-177.98027,-171.277479,-111.174109,-89.907912,-85.269097,-103.111424,-190.143008,-231.951388,-253.816525,-232.415793,-220.09851,-159.042894,-99.119344,30.674595,48.742597,-72.447769,-204.042593,-208.56281,-164.613407,-151.589691,-119.076183,-97.766237,-114.327791,-157.240592,-243.638169,-211.611676,-154.191948,-98.690896,-103.054827,-95.371244,-104.744085,-189.880118,-200.564321,-171.691568,-172.632458,-183.699519,-141.874972,-124.042837,-173.327224,-235.116003,-373.847565,-359.26814,-298.429333,-223.415164,-234.15117,-299.119106,-310.588909,-335.541294,-437.749919,-451.132915,-368.944916,-322.554639,-237.890033,-199.130715,-203.175734,-247.719732,-338.420744,-313.641941,-251.708393,-101.840669,-49.383508,-63.135693,-110.882741,-188.918622,-262.694598,-273.175889,-184.383494,-119.69695,-39.063575,-40.500154,-132.989376,-205.356518,-299.29264,-229.481044,-161.44705,-47.457745,-12.660847,-15.678406,-45.156693,-114.166259,-204.025992,-237.023312,-218.764551,-185.411567,-171.225722,-184.391235,-158.588137,-149.634645,-242.433317,-265.462086,-212.162072,-117.42922,-94.19619,-44.472928,-14.232005,2.284131,-19.144775,1.86418,87.746571,121.027529,150.980307,145.282094,103.665709,80.911619,10.500587,-61.26217,-55.14148,27.511269,55.559808,1.765719,-64.225635,-201.801811,-274.950364,-273.94719,-233.22139,-187.360055,-67.077748,-64.378344,-243.116258,-353.974151,-437.910034,-349.436849,-286.976594,-120.73276,-17.933926,66.564162,11.901244,-143.312281,-138.237001,-74.717482,28.330961,35.718991,7.529207,2.247707,-4.11596,-45.16021,-187.588381,-243.62816,-215.840584,-76.393218,-10.195328,-25.900844,-81.368285,-138.666841,-193.980081,-229.050974,-250.915524,-236.727031,-150.431322,-117.107014,-165.140743,-203.39242,-191.897919,-127.687407,-121.430877,-119.095542,-87.301889,-27.229084,-51.206084,-216.532673,-335.473278,-296.474775,-79.763066,16.110591,112.088791,134.828,132.665367,104.482454,19.147861,-43.699786,-39.944125,1.369628,5.558695,-68.721404,-131.149531,-196.840127,-135.373312,-89.854126,-41.512512,-4.023342,176.111576,256.127367,255.168443,206.190385,108.545296,55.96462,73.324081,188.879093,249.644457,308.04232,300.200857,261.635327,282.269285,305.71281,321.960428,320.009435,324.632894,307.415434,220.232551,180.249769,125.029653,97.617984,94.784056,89.816725,99.162245,142.220654,138.02987,-10.638814,-243.48855,-278.820253,-157.360581,-79.725527,32.01473,74.921435,105.903623,78.247955,-41.077009,-90.535701,-71.893119,-45.970615,-33.588136,59.7866,123.970081,181.275267,143.91686,135.135803,199.993481,266.513701,381.730907,404.026607,410.698818,409.33691,377.967315,350.590847,359.885356,410.755376,430.110083,398.584112,349.884192,272.115646,281.61165,290.254536,270.996544,274.221032,353.308013,388.833612,393.746997,384.363489,348.847363,324.402804,344.857387,408.969183,419.525202,368.791881,330.896083,240.242838,88.429826,44.015641,117.627814,227.925633,448.863912,474.614976,330.981421,231.542615,155.11201,214.306989,204.618332,80.869084,28.889184,-14.279162,-26.565343,-30.842983,-61.156973,-83.150594,-86.456398,-72.454185,-19.689578,15.707907,80.686575,81.57498,-18.432757,-51.102931,-4.843595,88.008438,114.971415,164.584965,183.12395,146.863987,11.353881,-36.435398,-8.657639,51.240587,182.350382,217.156557,142.297665,41.732295,-84.577496,44.549034,105.485316,46.28134,1.231092,7.979087,17.469499,-23.745533,-147.543474,-192.909747,-157.986436,-112.686397,-58.622211,-45.580017,-22.539174,-25.76633,-104.164077,-144.437105,-108.932793,-6.30069,37.204359,55.715214,23.573195,-21.718571,-16.667517,-40.753709,-114.00268,-112.146046,-23.367452,8.695656,-47.878852,-120.205502,-244.279286,-215.709411,-157.767924,-101.527968,-123.097538,-203.999441,-219.121596,-161.92745,-134.521107,-141.969858,-110.640738,-66.218535,45.315984,81.02386,88.686653,82.356059,72.877487,61.957184,64.049876,91.075502,127.801013,204.016744,185.702899,33.081197,-53.998176,-40.709275,6.809338,23.373678,41.253505,31.657005,-17.055755,-49.113642,-142.24141,-147.425207,-91.504324,-3.905779,8.158622,30.588327,43.768102,35.06338,-44.683238,-82.306525,-66.776115,-11.920237,122.152977,150.765383,93.044165,48.432698:-7.149143,-85.792909,-65.374544,105.689961,200.192829,286.425021,269.558865,169.0649,-7.933804,-85.889208,-101.264865,-60.188468,-0.48624,-3.506837,-45.715912,-60.681749,-99.31402,-189.900142,-222.45814,-203.888698,-151.260353,-42.745635,-43.979316,-159.648385,-248.12401,-246.102913,-184.764596,-162.401299,-183.862846,-214.60836,-267.347075,-285.58948,-310.224286,-286.584131,-248.546539,-122.046944,-49.352494,22.338403,6.510007,-68.147692,-159.834367,-183.157719,-141.24844,-125.236917,-146.770075,-145.737377,-131.038395,-152.924425,-244.045098,-257.179727,-213.742569,-107.650726,-69.131644,-50.291117,-74.233022,-137.646855,-182.41703,-189.720384,-154.648259,-127.401826,-93.763242,-83.996883,-68.500455,-81.429129,-227.022979,-414.599244,-433.114806,-327.501146,-265.299782,-239.358365,-275.793579,-374.512856,-480.440605,-511.275878,-434.513601,-341.625209,-180.456816,-157.528874,-256.618148,-348.511643,-498.131535,-469.033986,-382.452085,-165.063682,-71.432515,-7.365481,-56.669303,-243.951495,-342.476833,-309.827258,-187.613187,-163.119343,-160.473665,-153.375771,-167.63056,-184.622052,-150.225703,-42.287383,-13.897766,-53.213409,-88.88379,-115.742018,-110.464807,-136.22819,-251.293135,-294.029958,-273.838487,-234.161293,-158.908156,-124.89034,-78.96562,-92.588872,-182.357299,-218.783741,-197.976925,-123.648327,-81.572423,26.176552,81.95982,97.07692,12.026155,-1.867065,60.293442,107.865322,210.628469,255.280807,247.501825,209.757508,184.397945,180.24191,164.476683,138.625142,121.56394,35.536086,-24.316665,-128.175824,-230.457882,-285.583545,-336.197898,-312.018165,-218.750174,-199.103101,-241.138015,-269.969738,-324.244423,-359.440539,-346.209174,-250.509817,-198.878754,-159.0337,-138.865461,-21.937041,62.638123,63.335349,41.220269,41.741469,109.781328,157.227998,144.39985,71.72676,-106.273455,-198.991122,-195.4505,-119.762115,-81.458376,-67.429156,-83.273542,-126.29373,-218.552202,-265.323103,-281.277116,-249.25491,-108.607102,-39.248039,-68.024415,-155.091642,-270.34912,-195.097745,-129.263401,-69.834652,-60.688658,-20.223824,-21.252842,-102.717786,-190.337783,-185.23747,-25.068235,90.390681,234.091664,239.133195,152.866752,103.819099,47.761609,7.704154,3.975219,32.511787,44.694682,29.132718,5.285599,-56.576157,-138.473683,-128.983316,46.432067,145.53345,252.188632,265.941892,265.005148,260.817123,216.630075,191.383284,210.630118,258.180903,297.898709,406.928319,427.053495,397.446262,380.355922,362.324621,338.113576,372.523198,508.158891,542.296328,465.266101,388.606576,210.976684,92.903565,106.387438,216.783296,259.392557,241.760553,183.489695,20.867402,-121.002423,-156.226831,-146.214806,-111.418118,16.106839,103.234553,205.66637,180.176242,74.956054,71.609873,108.648853,167.610522,169.155049,194.713455,243.404876,304.825491,207.246688,172.618679,247.875244,307.506628,387.631869,413.067189,448.363441,465.908554,424.354203,297.308227,288.655999,357.24495,381.385167,379.782099,355.47693,259.976113,135.619193,116.736641,211.576383,281.181902,403.496232,449.652904,446.074603,410.029235,372.876833,351.250743,338.813433,375.298706,406.466706,398.68329,361.421651,249.534095,86.927999,31.956463,49.001997,83.881003,116.208299,124.118339,181.666802,230.434903,267.144382,124.678781,29.335302,-79.218484,-85.775974,-63.437054,-60.236263,-98.381653,-195.060521,-226.107306,-179.570209,-133.728414,-43.656439,13.493183,86.476351,67.976807,-75.903542,-243.611896,-271.859199,-172.621373,-71.980054,40.042387,2.313086,-116.460921,-158.345995,-178.891973,-192.363905,-165.187262,-77.296397,-49.516681,-90.957216,-148.861288,-270.933424,-251.933424,-165.74278,3.56586,45.709053,85.252713,80.953953,25.956226,-66.201803,-121.883695,-149.089688,-110.523197,-27.823436,-13.363895,-30.636869,-49.84468,-111.368763,-122.16207,-76.040488,21.852625,41.633323,59.489818,64.148983,26.932613,-78.341604,-122.2179,-141.668171,-136.490111,-127.596173,-130.156192,-189.843249,-237.496921,-301.317188,-293.423603,-261.077336,-209.665164,-210.913,-230.791131,-232.714983,-200.354003,-198.511326,-220.126277,-193.904982,-125.276106,15.933748,32.737105,-16.297928,-31.828431,-44.983592,-66.835343,-31.398608,133.212225,200.022595,214.226738,189.091339,148.498905,41.855781,-17.000379,-5.303903,47.159879,129.726596,139.0885,76.524507,25.472218,-41.81594,-22.242204,18.257979,101.741723,119.100345,84.78218,55.761358,34.074983,-10.227487,-30.927836,-21.282351,-22.33898,-26.862999,2.664664,76.533504,73.458885:-146.924611,-123.285031,-44.986706,158.282587,237.163707,281.226147,241.586869,53.07439,-153.459856,-182.378163,-73.828769,-6.621634,12.829281,-19.188408,-58.268694,-82.918013,-209.04961,-265.093934,-217.754045,-44.909563,18.606118,-20.61107,-105.546457,-251.947888,-269.953377,-239.331435,-154.856233,-117.976184,-57.580734,-45.726636,-124.051728,-203.114972,-289.234176,-195.290101,-129.93778,-15.38092,44.305407,129.678682,130.898977,29.666321,-145.258759,-192.80235,-188.227613,-170.709949,-126.022602,-106.222612,-91.60466,-96.831172,-164.379626,-200.620766,-160.100263,-65.644171,-36.056087,-4.351221,-36.079322,-194.408108,-255.800269,-226.982125,-138.372589,-87.180257,16.279718,39.41792,12.834345,-27.222794,-156.669303,-253.186699,-264.372731,-236.236091,-201.34269,-145.921,-159.177538,-300.449578,-472.864475,-479.524154,-356.22253,-293.541862,-211.365978,-213.394246,-366.562776,-470.9471,-569.205723,-467.651813,-377.868566,-174.907416,-70.330421,32.739557,-17.107136,-236.716364,-323.208642,-273.055467,-146.723004,-115.894979,-30.851485,17.585181,-24.367552,-100.514141,-142.954815,17.424256,94.827634,166.854905,164.651602,71.365843,1.969262,-116.903986,-211.253839,-229.123097,-178.705821,-132.359828,-46.381051,-23.026801,-69.725298,-136.485761,-247.044379,-213.023868,-157.493632,-20.448523,43.654109,92.068453,85.413428,62.783919,-24.337938,-56.499789,24.338954,105.918679,223.620452,232.374118,156.969598,106.148524,40.928156,68.530541,89.627179,80.98869,81.366964,55.913709,-14.453393,-195.562632,-307.832869,-326.09938,-286.979408,-233.745586,-136.319404,-134.687514,-204.350723,-241.249202,-305.076805,-291.511648,-231.820992,-57.304913,27.529623,113.234194,112.086826,106.729769,101.882163,98.191253,133.815887,172.845021,270.083255,293.276546,214.691525,142.944135,-21.319965,-184.485262,-200.128313,-91.847579,-41.329928,-32.395488,-41.957552,-88.938477,-228.59937,-279.889159,-267.079715,-216.086943,-57.962897,-2.537837,-78.083446,-181.013197,-330.583246,-267.94313,-191.533818,-88.515344,-70.309703,-60.283697,-68.194899,-137.347834,-239.444506,-250.084001,-112.051517,7.853872,196.199151,215.113445,102.52155,7.20476,-167.728285,-186.905268,-135.287444,-34.671945,-5.342969,-9.674237,-47.160112,-130.443275,-212.112149,-224.799222,-104.327491,7.207178,253.386719,342.185923,313.989917,215.456905,40.05089,59.377601,126.377748,276.348638,351.413111,420.006113,370.320211,202.136259,118.949415,111.627652,165.484436,229.708603,361.94276,384.023188,311.286037,249.043314,124.062643,69.8734,95.513444,183.062164,215.694391,207.986967,157.796131,-11.147013,-207.787206,-262.141934,-201.948242,-117.633419,52.535715,102.312822,54.602714,-17.390913,-102.742805,-95.530873,-97.390364,-50.42271,39.71724,234.902299,274.957736,235.659009,118.846429,83.738337,117.104168,177.852437,322.419396,346.374296,277.424272,236.23537,171.046801,142.329172,151.528304,171.720707,187.022497,244.110948,247.221963,135.65074,-5.550303,-30.168777,18.770057,78.007507,221.961084,272.84287,295.895927,282.947388,217.332738,135.458494,141.900894,281.606348,358.373847,377.563782,318.732741,119.450064,-40.261045,-47.457942,50.405667,133.784585,276.310038,277.722608,196.508754,176.858033,128.978132,59.845676,56.625678,85.33152,106.046607,99.357173,50.910729,-59.36324,-81.916459,-58.909973,-8.754933,7.426596,69.213378,110.765268,124.030615,70.603754,-117.630384,-219.03464,-203.562746,-67.98523,40.385293,156.105412,113.733813,-32.034778,-135.528844,-157.207067,-98.994731,-41.390522,25.640193,10.675823,-64.141218,-104.767158,-191.997287,-135.961564,-47.883709,87.788559,112.192377,124.161809,121.669485,81.114763,-42.373779,-99.050433,-68.114695,3.750876,88.137081,75.912542,42.037215,44.832399,5.150332,-71.754311,-54.443266,68.343307,126.660458,170.571707,154.984579,65.372371,-61.725355,-99.819383,-94.669542,-63.366511,22.151164,39.753528,-42.12162,-103.760678,-145.2481,-95.965036,-73.254373,-69.598039,-74.603367,-80.035757,-95.848111,-154.216458,-180.141624,-156.493624,-65.975197,-24.825811,65.389186,94.960986,49.651836,-1.921675,-83.021858,-84.9082,-34.959828,118.228467,176.633645,209.217064,196.997993,123.384302,-14.727249,-65.152956,-45.40512,22.034599,166.268053,168.595114,-2.057076,-91.92931,-100.527584,64.877378,135.561971,191.8273,200.070582,178.404968,152.950289,112.682987,18.779409,-28.263594,19.087269,99.091519,196.988774,188.426593,148.520514,139.642561:178.448476,131.723475,150.45017,320.770013,405.509474,447.792002,425.690528,372.794778,253.611318,184.679578,121.135257,115.201975,66.518815,14.34362,-41.577718,-15.334631,5.217404,-86.839598,-96.644066,-12.161462,36.078219,70.011071,47.579534,-52.294306,-144.157046,-171.110099,-199.062111,-206.715505,-200.235275,-196.567329,-237.34422,-252.447081,-209.83369,-172.071143,-140.452219,2.231772,77.652343,137.127856,100.805319,-52.388794,-127.23808,-117.20736,-147.494237,-215.116735,-299.265328,-269.878984,-191.537103,-194.138851,-223.316529,-163.53599,-102.796306,21.176501,69.039969,128.148885,132.476291,95.925656,25.115329,-13.000839,-15.348221,26.768586,106.016775,110.464901,39.359495,-25.711927,-183.764146,-277.525241,-264.742512,-166.729116,-116.481211,-102.769178,-160.319291,-344.473836,-495.875007,-491.363484,-326.405545,-268.569904,-249.472622,-215.887227,-178.908116,-264.185937,-579.493653,-730.366884,-651.96516,-314.516364,-187.454179,-140.238876,-161.082413,-206.697609,-257.557869,-262.667432,-243.015464,-238.110639,-189.374569,-131.56768,-44.740115,-43.867087,-76.095823,-63.669435,-45.207115,-15.293719,2.28494,0.673924,-55.208226,-254.951111,-424.188842,-447.651354,-382.650638,-345.586238,-286.303995,-237.674919,-127.630713,-87.749524,-53.760622,-44.669591,-19.50374,37.711368,60.09416,143.855135,175.726156,119.485775,11.218,9.287006,176.617818,297.733065,430.435847,420.569319,337.261842,300.598146,245.753325,236.325163,239.013171,172.756326,121.562658,73.959248,52.722537,-60.213708,-189.51368,-232.419715,-288.878352,-287.835297,-222.601767,-214.207105,-302.982068,-339.593161,-311.403316,-269.653059,-265.230695,-230.965225,-192.55677,-142.648688,-147.433968,-132.048788,-50.029757,-16.083711,65.641127,113.684222,168.422238,178.299467,159.49684,106.590371,-100.459636,-226.660515,-202.231111,-123.827494,-109.020151,-73.69596,-58.619354,-125.167551,-278.069995,-337.381493,-350.420726,-293.41879,-116.690993,-71.681408,-208.015837,-338.797485,-505.576348,-437.691232,-334.913415,-195.227649,-179.750172,-103.755813,-55.453541,-53.631544,-89.636572,-67.821282,54.062527,124.521843,240.528153,265.693892,214.62086,169.859086,125.809163,124.351393,120.778177,92.732821,76.202843,42.998387,18.972454,-10.980736,-25.056323,-29.368046,51.511701,124.38871,199.582298,199.661796,246.650488,296.144256,297.836544,233.305547,252.093613,309.637354,315.749105,297.807949,286.383468,347.170968,431.225851,407.547419,330.798225,346.435688,479.844937,533.880292,476.811048,381.37587,194.273141,89.262353,75.846666,151.543496,210.348785,209.997392,132.164389,-41.020849,-139.018181,-183.665241,-213.099402,-167.354648,-21.603738,28.20851,52.212116,51.043737,62.466605,108.8219,143.84599,198.547716,219.212615,298.069342,341.725952,320.826442,187.921046,150.27148,177.990808,225.277536,342.647684,376.144081,349.495616,327.342305,289.33682,190.163147,169.707955,256.164084,311.306409,322.598848,276.458758,162.784213,105.402322,89.927076,84.456372,108.879105,189.092334,205.521509,191.301713,206.189553,244.117799,164.290601,131.839304,185.508385,246.517272,305.359123,273.687458,147.680261,-2.373147,-75.830271,-166.153455,-183.904059,-119.252994,-42.843123,73.143566,89.257583,23.169469,-156.221601,-227.980858,-216.617969,-152.920965,-75.887558,-95.92472,-208.122173,-330.496778,-344.723173,-226.093666,-143.072158,-84.022955,-98.692518,-128.987044,-160.886775,-305.914596,-377.477179,-341.075844,-251.607251,-238.702511,-279.240029,-295.444347,-239.03975,-199.874115,-204.955746,-181.377965,-157.063161,-136.651789,-134.25449,-117.600698,-109.219782,-141.537061,-172.578775,-149.889881,-105.235665,-92.313924,-6.565221,60.160123,100.233237,-37.42047,-113.382643,-134.715692,-91.701134,-37.286488,-37.805452,-34.329062,-24.800334,-34.865804,-71.192798,-77.513843,-40.641155,13.634418,127.365861,119.438954,-36.726291,-203.261406,-254.832866,-258.347237,-228.493004,-204.672464,-218.096525,-243.111351,-254.427617,-319.650289,-357.169401,-332.225954,-300.07423,-308.19329,-297.412835,-287.854399,-293.160534,-243.777477,-205.679721,-183.484683,-180.603252,-150.50269,-156.30297,-194.126206,-169.197982,-110.206143,-222.170732,-245.517415,-62.923133,60.866304,161.236736,152.796111,134.234588,71.535728,17.095078,-7.086002,46.63264,144.246641,110.733741,-80.261391,-137.24444,-46.740614,135.648634,160.908766,60.377092,14.091167,25.83722,31.308348,-3.301673,-17.469677,0.100381,99.047994,139.509333,133.072511,109.819968,81.470013,83.07366:103.31862,80.516684,110.840591,311.99391,434.885225,538.713413,496.102877,314.248489,135.259564,86.192002,89.750455,111.033547,122.054158,91.503348,-21.177371,-55.28937,-94.458579,-159.428441,-139.445147,27.976184,102.798448,111.391774,64.816196,-61.503992,-169.707064,-165.335377,-71.306067,-44.645555,-78.259516,-108.285016,-142.191262,-161.87999,-231.069842,-201.649878,-112.885182,104.323572,178.5074,235.133217,212.726437,29.705701,-238.667658,-321.378374,-300.644217,-226.451619,-93.473591,-85.567375,-195.771429,-261.416224,-325.887291,-266.831448,-182.522663,0.917923,63.625014,99.796374,59.178138,-86.475278,-174.942914,-182.702884,-111.768621,-37.001958,130.291376,177.8396,127.582632,49.321397,-153.816646,-275.34571,-243.823933,-116.786571,-101.088986,-177.74986,-244.143728,-421.649456,-595.082706,-622.908136,-545.15624,-477.437724,-343.683618,-301.636997,-365.026017,-460.821127,-646.715746,-684.783097,-609.845278,-311.37062,-161.752023,-45.298416,-88.901903,-275.534773,-388.405453,-358.647628,-197.47645,-124.242109,-21.636102,3.806995,-39.803888,-93.346784,-174.934343,-180.592509,-153.252585,-64.334213,-20.995736,11.690546,-25.444723,-225.852883,-423.478247,-438.010052,-321.666744,-256.839681,-171.389888,-138.806785,-134.706149,-178.371085,-286.189177,-323.021515,-308.85656,-177.320331,-58.372471,129.911415,137.462635,12.317932,-105.206674,-108.93703,5.247187,103.768696,280.254323,296.802528,191.365841,139.297688,80.104873,58.529749,75.123099,107.740815,100.528363,52.078512,13.169819,-144.724697,-383.256507,-447.678581,-354.994488,-249.920455,-116.171073,-112.367373,-204.077859,-279.468428,-383.087106,-330.725613,-273.340657,-148.667939,-75.411969,38.797963,54.331346,59.411381,23.530479,-10.905559,47.37135,148.26769,303.217033,305.748342,205.214422,129.521371,-66.469008,-202.034375,-186.688485,-35.512888,35.338076,55.191449,7.528938,-157.002282,-360.514803,-417.627953,-336.571467,-218.153168,43.196427,107.102353,-30.646072,-173.57474,-351.742551,-302.823675,-233.621401,-95.025616,-43.518961,-2.477805,-17.753415,-111.97973,-231.684369,-233.993802,-56.719449,67.046356,244.176096,277.872777,223.132777,140.123713,-57.291194,-123.562911,-94.280481,-13.654666,20.212591,58.837359,42.371244,-75.586822,-211.026471,-215.440589,-48.778105,65.397449,228.017448,264.427909,243.778221,196.383148,92.878216,100.445188,155.492947,286.855735,347.648521,417.461698,400.81197,322.621408,278.070081,274.145652,316.937566,355.270983,454.074873,498.466756,460.027931,354.225708,105.027378,54.588431,94.726672,185.687245,233.166965,286.743328,256.112982,67.903058,-174.159605,-249.382579,-205.711813,-101.105638,127.830252,195.70938,192.035622,148.744523,50.522637,24.731037,57.286206,127.126728,157.892569,243.468165,258.958614,154.36909,43.309716,48.471957,112.948037,149.003062,245.91564,293.393078,296.968298,230.493143,11.013783,-85.137244,-23.350083,177.544116,235.426927,215.235426,151.401057,-15.362015,-83.915796,-58.884004,68.201872,149.668635,299.277091,338.840506,279.146325,191.558217,5.162216,-68.912611,-26.114839,186.041733,269.244472,212.071091,116.784821,-5.407819,-51.817146,-67.185627,-48.663865,-28.841506,8.23684,44.071389,123.780679,116.395987,-32.87461,-184.447297,-204.633144,-131.629348,-67.442929,-7.148185,-41.076041,-170.562278,-285.606976,-312.718257,-233.742792,-136.113824,44.029973,68.680312,-45.316118,-139.449837,-311.444813,-421.890952,-397.153578,-165.234436,-55.085041,-66.925372,-156.493126,-296.442448,-383.049523,-415.037707,-365.576977,-288.500165,-145.82547,-119.006854,-135.077022,-163.157626,-276.144663,-300.817987,-213.262747,32.017451,109.18884,127.006718,105.226402,100.539388,80.022868,29.199912,-34.284751,-2.266815,102.144743,119.402247,87.915922,63.5978,-20.915037,-99.229366,-68.086916,109.070013,185.194657,204.24268,148.586213,-53.368655,-284.303724,-340.331618,-259.695238,-159.676168,0.222847,3.170225,-132.108252,-199.993871,-257.294216,-278.237848,-264.762012,-203.975935,-186.61754,-181.629225,-191.745934,-241.010064,-302.533602,-309.07591,-188.515837,-74.251779,56.121811,18.863959,-124.520206,-162.813227,-186.801679,-178.722622,-144.789752,-3.798184,106.335166,311.391092,337.197448,219.480245,20.034481,-43.37197,6.580689,82.425109,182.542593,189.355789,130.746646,74.915557,-39.737475,-10.725246,83.051543,274.828984,302.137603,224.676144,172.150575,109.366542,79.567708,86.661751,173.970608,231.997774,338.888213,375.292931,341.508254,268.13857:398.311396,280.575028,234.831672,270.676953,338.32631,418.640576,397.621828,354.690915,339.041312,290.160515,146.121308,116.725206,161.809059,156.309426,66.201868,65.363702,152.100472,156.161289,127.776859,104.230933,126.100735,161.343862,145.328031,123.435121,105.853635,34.918961,-145.126588,-178.575027,-110.590922,-60.112771,-33.1763,-42.410089,-45.304269,-34.643552,-2.416626,158.733303,243.261132,270.736396,218.914703,122.528165,60.156227,15.162198,-101.007629,-159.375255,-189.431092,-154.219097,-98.930143,-94.750148,-102.148581,-92.386808,-46.837594,120.61136,200.439823,249.032154,217.458091,151.519796,139.280559,136.44977,122.476987,103.47311,77.79882,95.672497,97.073245,47.371711,-61.838449,-118.348755,-133.822958,-133.510819,-109.385007,-44.485311,-46.001342,-139.853898,-240.96397,-260.48352,-228.055019,-200.688405,-124.330973,-81.531515,-127.018004,-241.926048,-492.137253,-534.574821,-485.261916,-383.432001,-351.471882,-302.001989,-279.698983,-254.19093,-273.864047,-275.691923,-223.109652,-192.185067,-97.357269,-4.042461,162.424483,163.930817,61.594946,70.008415,108.94345,97.928946,61.765991,21.411395,-8.830675,-149.420771,-321.717914,-366.082962,-344.815232,-322.041098,-286.811891,-254.155122,-156.319692,-92.449428,44.720766,127.654074,173.185213,266.287098,277.851343,275.358999,298.593673,346.705596,252.067883,196.605934,264.916236,370.287813,558.520822,584.281247,455.098068,368.477264,313.120316,299.005851,274.89307,258.430398,269.188556,249.816678,184.802562,-35.364803,-235.674681,-292.015117,-299.705764,-263.286257,-192.526456,-183.629172,-189.137237,-179.300856,-173.254774,-226.385799,-230.100164,-135.920144,-65.058175,4.069345,10.423737,124.084142,273.683927,271.31902,155.282966,123.049909,222.122895,286.264899,234.303083,147.150463,20.822812,25.765927,67.677655,110.737954,88.85707,32.963366,-2.436479,-119.791874,-249.063111,-319.334042,-391.452376,-346.292809,-157.809241,-92.8447,-157.360509,-255.156188,-356.492622,-240.199546,-157.413339,-73.240175,-69.395609,-90.115962,-111.05487,-157.181182,-146.754496,-95.215693,22.206455,38.948985,51.356074,82.83513,144.627911,151.219428,137.727371,133.419522,119.660473,5.867749,-67.821534,-120.600581,-102.318571,-50.701583,-47.155315,-63.832934,-56.789575,-29.231356,29.538413,47.564957,20.396886,3.115936,74.902314,170.879849,188.687585,198.464358,193.522664,193.402251,216.779044,301.773757,298.577513,229.885982,87.116734,79.571051,241.008414,336.841513,309.616781,206.522569,77.360339,40.741256,-6.09151,-71.719433,-40.20697,73.970644,73.317507,-85.773203,-278.2036,-356.023217,-428.565969,-410.635303,-358.063121,-339.746066,-236.433233,-150.139327,-31.983087,-23.374822,-17.429031,22.287727,51.684868,156.99691,227.510795,269.969558,85.121695,-12.047028,2.413008,93.452279,233.072874,260.508971,307.377461,319.800389,237.910489,106.359886,116.651774,288.803233,363.148481,314.292974,224.507342,104.0173,61.498587,75.006384,168.481009,176.162447,111.667847,101.009962,139.537201,177.971801,233.759993,162.485587,133.929977,180.640822,201.644866,153.674244,116.646754,59.681484,-45.550343,-96.350993,-76.769281,-35.121052,-16.378775,-22.296049,38.674775,100.808473,128.632082,-37.451779,-116.03999,-140.339155,-90.113871,0.604068,-30.523814,-217.935779,-329.006242,-320.061866,-245.288422,-214.243912,-171.014359,-156.079548,-196.098263,-254.106116,-348.352406,-283.402115,-201.111886,-110.687346,-139.421667,-227.273441,-236.368912,-196.365856,-183.572401,-181.071628,-92.713768,-30.701805,-19.511191,-72.932511,-130.869751,-95.532459,-29.866883,-81.067755,-103.253279,-101.03251,-82.458907,-37.838975,-37.275824,-60.227719,-73.505137,-91.932166,-125.682725,-128.779287,-115.516215,-89.497871,-12.262073,8.339466,-23.96688,-91.941942,-90.65159,-32.508726,-13.207751,-35.401804,-88.08797,-213.194294,-285.898798,-302.745981,-283.697505,-272.565493,-268.155682,-246.577925,-181.696564,-187.315861,-329.380102,-439.968753,-424.175527,-395.733402,-404.208541,-351.842563,-297.990742,-259.731417,-331.037822,-368.989067,-356.118962,-301.051512,-196.757903,-175.921382,-154.463817,-151.261855,-241.069968,-394.908028,-407.671635,-271.463409,-187.623929,-134.976277,-150.808922,-119.742942,-50.359123,-47.582852,-36.338096,-14.341087,-0.37616,-12.782276,-37.368971,-38.657873,-27.333065,-17.649856,-3.736587,18.122894,6.084524,-31.034165,-40.380764,-65.852379,-90.11663,-82.024554,-10.288399,22.150594,42.31765,60.996307,133.280328,164.660948:294.946857,278.772587,259.459985,206.767951,215.034338,321.841256,361.909103,353.43413,233.745853,149.805496,99.371012,134.245723,154.986893,121.242907,64.53358,68.205358,85.106195,65.414205,34.748314,-53.776378,-57.813234,84.535635,169.418967,155.26901,-53.388093,-128.167542,-121.827146,-87.550255,-69.408827,-69.239745,-61.081848,-79.40651,-187.548687,-261.313965,-220.108217,-14.482241,81.20441,158.040023,131.828879,30.711482,-23.80963,-54.658386,-131.169322,-137.046707,-50.844742,-10.530776,-52.623595,-105.701825,-132.629642,-97.313564,-91.48628,-17.210235,71.032201,189.395004,173.01271,86.615887,37.923537,31.293282,54.703665,59.892618,23.362262,3.149989,-54.345511,-102.248299,-183.72955,-233.394533,-250.344561,-264.373604,-246.549202,-165.901512,-165.093451,-311.321756,-440.382733,-422.889284,-287.208533,-234.096496,-135.090167,-59.665161,-24.318247,-137.115672,-468.338846,-558.839435,-487.49119,-330.838637,-309.299458,-342.229955,-347.922275,-285.661339,-252.625185,-274.954129,-282.641553,-253.648206,-207.332649,-174.761748,-10.430335,70.848775,47.780317,-58.980929,-56.449975,-55.644056,-78.881155,-95.301566,-116.444313,-267.32198,-406.160217,-390.684011,-235.4045,-189.342659,-233.747302,-263.845542,-199.338052,-101.25796,61.377856,70.362135,76.427102,128.365772,157.079641,225.427768,249.468803,198.433116,66.503546,48.14839,171.34987,253.031207,342.944099,347.685682,258.750223,194.29049,140.030332,193.469178,240.58778,278.829394,240.15526,102.305526,43.194859,-62.194621,-223.080043,-296.243017,-304.190963,-243.644341,-124.352317,-120.019152,-209.036861,-228.905847,-199.054945,-298.640976,-372.562393,-368.947176,-307.41152,-210.352218,-173.267035,-81.809934,-78.195049,-125.692659,-161.380647,-120.273905,3.218451,52.690972,75.494163,52.996519,-33.228625,-150.929412,-178.417851,-163.425935,-149.98017,-97.091626,-59.456757,-85.30494,-273.078337,-336.850561,-272.395939,-190.676883,-92.294917,-101.061705,-224.456401,-301.019621,-390.459778,-313.762153,-207.214954,-47.67534,-55.614204,-134.309767,-134.640233,-48.869718,-19.615521,-38.889989,-43.962771,-13.382938,112.113664,171.430046,172.624918,142.309634,153.929589,200.370197,181.808084,77.209399,24.885569,-52.761524,-71.580976,-25.108672,16.025502,-21.428872,-81.216923,-56.31059,18.87463,43.730987,89.807426,110.74562,136.051498,150.944028,164.800052,181.882159,178.748231,212.024042,257.082896,322.042897,288.933686,256.381517,246.826978,281.41358,395.069672,434.172891,361.502053,268.167191,99.557423,-0.861142,-22.571155,10.212091,61.950193,160.039526,155.939201,57.202656,-13.235841,-35.238232,-53.977332,-41.089908,-13.525833,-10.456311,49.234889,114.217401,170.287821,74.196778,52.445686,173.51196,274.337046,395.592771,401.849044,377.909868,302.858128,244.374058,215.745034,262.924198,377.426392,403.32527,389.90679,370.723875,310.807758,288.471917,321.361951,392.313971,386.046795,270.406282,206.29004,223.341339,318.884896,306.078735,226.857578,208.954025,216.891703,227.654519,276.990276,337.026159,436.758272,305.580582,205.727765,173.963183,239.692512,362.036871,365.806856,240.070278,11.621354,-85.493702,-112.033576,-58.001291,50.293758,96.597858,176.962801,184.667645,98.618642,-37.235736,-84.43424,-132.038293,-155.994503,-214.722841,-238.508512,-296.873702,-362.797785,-366.201197,-255.129842,-170.409814,-92.792781,-112.334619,-168.998809,-182.659136,-219.192484,-234.979094,-209.330301,-160.042544,-155.636144,-152.24437,-147.70746,-119.950711,-58.341409,-36.994065,-46.743181,-71.486068,-106.080311,-100.170423,-78.640519,-71.847795,-93.44264,-169.62673,-173.693151,-106.347711,-73.855113,-66.133272,-68.290265,-28.208275,-94.45628,-166.386543,-201.094321,-165.584129,-104.736659,-93.540322,-95.242104,-91.806166,-74.794479,-80.468856,-80.907457,-85.418588,-90.401046,-80.721951,-78.618529,-111.381995,-206.070572,-261.625659,-301.403965,-283.718819,-228.723025,-197.592861,-139.860285,-137.636687,-214.07827,-306.401495,-339.527406,-404.772661,-415.572633,-332.224871,-271.103968,-193.356336,-195.674968,-221.366151,-236.700883,-219.090745,-169.942876,-154.619199,-185.106762,-210.738789,-245.445087,-307.753451,-309.97003,-179.38742,-85.310456,40.73487,66.339194,69.957862,0.890662,-49.414687,-89.06658,-63.351561,-25.588414,-58.334642,-141.893117,-122.377476,1.188379,37.520037,11.510091,-64.549533,-79.236842,-38.564636,-21.336787,-63.294457,-121.261582,-119.332335,-72.199391,-48.630083,-34.030477,-39.871332,-18.04816,22.091361:223.58513,140.394304,111.065013,242.890113,362.677136,492.935229,469.933998,351.861494,258.716609,228.116968,194.545915,184.814344,175.766991,167.954139,119.019112,96.247776,48.790575,-53.92702,-68.078703,35.181986,94.350532,104.915062,64.139263,-8.100236,-72.478333,-116.084216,-155.362966,-149.416967,-99.294244,-59.988604,-29.925894,-46.88085,-88.730343,-54.477474,10.666082,204.83605,294.843465,338.451704,279.957076,123.783884,-18.862099,-102.760341,-197.435733,-190.226923,-165.952029,-171.228437,-174.716485,-152.598831,-142.247191,-201.1783,-173.194832,-19.61448,36.683399,65.212721,59.778978,61.607426,42.091075,18.870939,31.04575,60.31584,89.975306,83.082701,19.396553,-33.988271,-179.20753,-274.189814,-246.632889,-105.100214,-50.480513,-48.096104,-92.639159,-199.200989,-338.918038,-400.126075,-384.500862,-332.060843,-253.351,-264.312009,-421.442254,-505.642025,-553.436572,-512.109573,-462.002697,-309.144681,-240.140523,-170.574105,-162.929284,-159.333912,-215.856218,-262.259239,-259.363725,-188.369391,-9.885226,30.615018,-14.718966,-40.236864,-22.881841,34.551687,75.273392,115.915115,102.739383,78.721066,57.513949,-104.793569,-377.464516,-450.981488,-349.472629,-260.230565,-226.9202,-255.832054,-234.672515,-172.818454,-52.482844,22.221025,62.57646,134.744583,178.500794,293.4978,301.317808,143.698359,18.217538,50.653941,205.801417,262.651065,332.910089,370.50661,419.660012,415.311387,351.270755,238.062698,191.736929,194.694781,237.765192,244.23607,158.045238,-81.326855,-223.056296,-266.214052,-297.919389,-264.126966,-172.754222,-169.029635,-235.524417,-248.194486,-177.750633,-109.334825,-90.794963,-7.735807,56.82049,86.06088,37.105711,38.134598,185.153849,203.388776,143.514746,135.531895,228.21334,289.793421,277.659639,192.335817,-17.251464,-128.807029,-121.781902,-26.61237,19.461661,22.125201,-20.783323,-152.599917,-313.513046,-367.477844,-325.263784,-240.134111,-38.559545,35.874315,18.138653,-81.555027,-304.178745,-303.830165,-230.520324,-137.406765,-124.239342,-76.767935,-60.632006,-86.471596,-125.09194,-119.696862,-43.62483,1.24582,79.025346,109.243181,105.528728,83.484521,48.933657,-13.396632,-52.504573,-83.366387,-44.066493,69.910692,64.29075,-61.850532,-165.178502,-183.866614,-114.537604,-34.891908,111.799149,153.680971,139.506339,103.982877,130.379952,251.382125,270.328388,217.649819,196.377736,220.989836,253.100341,359.077055,376.005513,301.587303,202.529013,227.421837,351.161839,406.251572,349.348242,238.828539,29.414937,-83.61075,-103.529582,-51.130023,24.416213,166.701132,156.663428,-66.31138,-311.701914,-373.005427,-382.383389,-318.916449,-128.496976,-85.281157,-100.416396,-100.82435,-105.683964,-91.314113,-25.236468,87.235536,80.519524,93.293916,144.816259,201.194714,122.293614,87.585058,106.604705,141.505362,233.301323,275.179659,261.879195,213.673679,105.57458,30.30298,38.927505,116.97584,151.376286,188.600139,178.565689,58.343142,-107.610361,-124.933391,9.975902,88.582462,153.56355,158.171856,158.83872,164.943429,164.816373,117.168177,101.174528,112.205483,133.237748,138.298346,88.87525,-35.913895,-55.16608,-63.235577,-129.35324,-153.224081,-127.435619,-88.788307,22.240389,89.023561,117.399057,-56.114051,-130.686439,-182.531338,-185.460715,-129.934343,-90.675104,-134.674107,-298.969861,-339.828127,-268.419536,-193.588831,-92.051641,-84.683879,-171.32429,-257.684631,-389.344767,-351.866153,-294.161017,-187.922398,-169.2494,-190.070246,-188.633672,-158.064065,-210.347846,-263.10685,-279.151172,-220.875343,-105.441998,-97.720634,-146.426839,-152.567286,-120.597693,-130.761411,-127.905527,-71.243501,-32.975601,69.924177,115.309697,101.993085,-19.379431,-71.901515,-61.44676,-19.043413,1.940557,-7.165466,17.868147,29.470733,-8.801333,-42.853538,-29.601931,8.265411,34.180597,101.207437,94.598033,-56.477017,-238.698195,-271.824535,-191.790617,-118.571837,-46.526183,-57.854873,-116.526776,-170.072897,-312.743307,-315.647929,-257.428968,-195.569397,-195.64575,-171.635959,-180.698562,-276.472182,-270.539179,-197.197128,-50.587425,-25.65383,-31.062288,-51.751949,-129.076621,-147.084821,-191.272665,-354.355688,-360.103294,-90.673889,74.777926,224.910375,212.548503,129.05589,10.385999,-62.805517,-102.505377,-37.832972,123.769467,154.411872,83.926254,31.285959,16.540075,99.384474,125.141453,55.927631,-1.063609,10.626506,61.216987,118.514238,91.078946,84.623067,164.37822,206.33201,202.453931,190.884128,204.536599,223.770733:left
-29.37185,-59.038676,-81.924453,-102.906939,-93.13503,-58.738539,-28.581668,52.944717,124.65256,152.275679,145.61396,115.925497,98.052816,132.225448,170.54693,109.366101,-59.274492,-31.799037,27.520918,74.589303,23.036418,-106.441264,-90.190771,77.847276,201.540083,206.263472,130.770689,102.292444,138.720175,159.57694,114.35609,76.301333,29.374229,-23.005735,-24.60563,98.600515,165.68392,158.49496,121.922179,76.637307,44.221142,36.4685,22.384079,10.600603,-20.891829,-38.86602,-69.784051,-83.116835,-60.901971,73.830039,159.567734,283.744741,291.527073,196.655825,131.6369,68.188449,149.453354,200.298413,190.943679,164.886286,187.317477,204.812252,161.632688,108.465476,-1.253535,-86.735605,-118.379492,-102.872337,-67.49906,-42.164709,-60.691878,-112.444653,-115.43979,-110.492824,-111.576783,-101.926161,-85.819893,-96.804253,-145.312374,-172.241616,-154.341968,-34.253302,14.388715,69.503923,63.575345,-51.465358,-125.345715,-204.163029,-199.379962,-195.225717,-200.317249,-196.141434,-188.232128,-188.752949,-136.776373,-81.451692,24.377587,59.535904,42.49288,-11.42576,-39.739892,-152.775817,-225.475851,-266.170745,-129.220864,-42.246305,44.024302,39.390155,-8.961316,-29.231216,-36.066932,-36.181794,-32.341838,-22.542303,-15.586311,40.984145,79.742551,53.5498,-26.881495,-173.515115,-118.97886,-42.529225,58.666505,65.992189,-1.85125,-55.496011,-137.22579,-169.455494,-174.251472,-41.419952,47.188943,159.887655,141.940981,3.593845,-58.852041,-139.40972,-155.003655,-135.385958,-95.556168,-68.272438,-10.735939,-0.575535,-3.312577,-7.957163,-15.868308,-49.907646,-68.593155,-72.437193,-86.542557,-185.68976,-246.263372,-302.181274,-250.09051,-209.527026,-77.807737,30.156087,200.786437,205.160604,97.699603,41.320912,8.188526,54.701714,45.770786,-72.613693,-119.293093,-85.304634,-39.469401,-15.524835,-26.85211,12.139727,157.568032,208.095934,185.824739,131.759599,1.635255,-65.348375,-139.717292,-91.233997,-57.27324,-49.225218,-81.737537,-166.334672,-191.790232,-213.483233,-214.87612,-217.840143,-229.144648,-222.671015,-197.899038,-187.90269,-202.839822,-220.643049,-152.648771,31.890425,99.777749,158.829821,158.577634,99.254595,38.631016,-108.364097,-106.907979,-24.354945,170.74398,253.171435,369.834323,391.229789,349.695158,291.827712,172.522727,173.733751,194.289911,191.21328,185.047297,159.346609,90.103048,-164.112408,-273.876602,-220.316341,-38.518839,38.405529,89.785223,49.489079,-57.479556,-59.25376,30.934242,5.827909,-73.937929,-193.970431,-207.982829,-210.099584,-210.497411,-249.19106,-328.111662,-322.164272,-138.68314,-14.29943,59.709285,-9.117624,-148.858513,-153.986454,-107.221366,-126.807518,-156.982257,-178.499159,-167.934448,-141.9447,-126.258335,-93.739709,-56.815775,-32.721489,27.352798,63.963686,91.551297,67.536777,4.265734,-26.917987,-111.487851,-178.598021,-179.583658,-146.73923,-151.688215,-209.442272,-243.693004,-339.069788,-403.744103,-378.294033,-198.995234,-100.790642,-71.630912,-119.68969,-160.290174,-152.0016,-165.963444,-180.251533,-147.38305,-18.753843,35.618951,72.486815,76.296998,65.938069,22.727898,21.965623,80.977659,116.985981,96.699933,18.819431,-152.033494,-190.123463,-163.626958,-94.110534,-78.19082,-74.083741,-69.684736,-53.531469,-44.312281,-25.166319,6.465212,18.358089,25.645517,42.612763,74.18747,48.575186,-31.518273,-34.388684,35.571202,148.03875,199.091086,222.926555,189.635756,84.367023,40.624454,33.008032,106.213084,137.150578,203.016637,246.218772,268.606991,239.478084,165.671714,140.36879,156.660841,177.207325,151.057113,93.551799,85.800341,55.146345,19.637725,4.074543,87.781209,88.757407,12.648636,15.485306,123.75677,172.516351,161.93741,108.511645,43.159921,103.836107,125.183643,148.484223,185.717815,238.118254,193.962405,33.844009,55.685362,133.995737,168.098893,83.542397,-101.712325,-125.406939,-74.428152,-61.490906,-63.521766,-37.179859,-23.844771,18.170795,37.449178,13.782322,-29.477836,-99.843275,-1.35102,78.725404,159.004062,172.241663,181.240508,167.329244,114.071618,80.387209,4.401574,-7.108413,56.008734,265.388663,333.112676,305.757653,242.508931,135.718873,173.624816,227.412926,259.678555,230.337459,134.207258,85.695266,-4.792214,-54.237735,-109.493009,-70.548181,-49.325597,-54.306373,-89.246656,-172.531474,-183.672759,-166.398764,-185.741697,-215.908902,-273.843581,-275.635473,-243.408064,-223.003379,-134.985147,-67.803694:-129.709153,-172.757151,-176.079888,-138.377088,-103.315958,-48.079858,-44.794726,-55.586643,-3.055026,23.402457,34.04315,44.617196,93.703002,120.511293,143.091359,126.98627,94.59502,103.763496,91.408838,24.034595,4.512616,37.624529,57.991364,35.813035,71.290962,131.120124,185.663006,165.607071,136.917782,130.113433,81.125218,48.273105,-16.647258,-55.991384,-38.524816,69.41498,114.884258,100.0187,44.823326,-77.237313,-34.218823,24.384031,71.996162,76.364767,55.678263,33.817459,9.780607,-2.149975,8.334193,115.590311,179.958869,232.67271,197.906311,116.501594,117.974326,160.994068,198.114542,198.619389,176.704365,196.000455,277.882663,279.907232,185.986405,140.439577,86.453577,15.401883,-21.518881,-77.280574,-95.915481,-126.143949,-149.431793,-185.326789,-149.719866,-126.75456,-99.71791,-80.407643,-68.569743,-96.880064,-155.665836,-147.211163,-59.882285,-3.66285,12.895149,91.359138,126.808599,112.50887,67.685873,-39.349937,-109.011318,-127.357092,-100.149366,-74.01554,-91.615154,-104.354284,-56.034923,-33.297336,-36.113544,22.212832,83.447663,144.617188,99.026859,-95.894021,-166.374724,-136.951792,-9.701486,50.026467,140.502128,143.524597,80.498804,61.703492,68.603624,80.276941,123.364983,137.93365,130.015921,142.743565,151.072861,77.47895,-2.018536,-139.827053,-85.541469,11.744564,162.170359,147.127967,-26.155091,-99.594942,-182.684138,-226.550321,-210.82017,-27.05092,55.513041,155.12855,168.855692,101.179137,20.735022,-161.020383,-123.996919,-5.347569,167.678077,170.367172,108.820336,82.824462,48.046769,12.549451,-94.88818,-105.190391,-47.020684,48.65894,14.912758,-143.267514,-198.943951,-198.250867,-82.823165,-20.675622,49.316431,69.076498,129.806416,148.660962,75.274479,21.309394,11.221717,33.102053,24.890091,-14.5975,-33.1357,-35.912259,-41.923007,-121.65984,-132.812458,-68.712224,78.41362,119.187476,117.949134,84.480854,-42.876674,-110.785526,-139.903711,-61.746234,-15.403812,-16.29433,-109.251929,-352.012444,-407.106975,-355.992854,-271.297088,-263.125742,-285.957318,-290.980665,-288.423315,-291.287081,-278.436545,-248.898877,-156.123706,-77.164486,-42.494831,38.336332,60.451626,14.177023,-48.277955,-152.457735,-87.237408,-24.964468,76.910067,134.874265,240.370858,239.258519,92.090367,-6.842376,-72.331953,47.358402,100.706676,142.504996,141.33916,57.679916,-47.99098,-304.35572,-350.778928,-270.100587,-81.489204,-36.257694,-48.660705,-83.48839,-190.29754,-236.632498,-210.695285,-174.362494,-209.436292,-254.134338,-239.233525,-228.043793,-272.830343,-416.861162,-412.301762,-343.126233,-186.569676,-147.569889,-179.623591,-214.367687,-296.950595,-347.121986,-376.479178,-309.110627,-273.031958,-202.27598,-197.97678,-300.794616,-354.088242,-333.485037,-197.277047,-159.241178,-179.528002,-165.516422,-46.111859,-25.725636,-148.669478,-228.217403,-260.299958,-137.07923,-66.634137,-1.588432,-35.052724,-193.339767,-265.094006,-323.18368,-290.306639,-234.785607,-42.858291,20.356443,-34.838396,-87.568225,-146.32376,-172.459311,-182.505229,-130.13098,-81.280802,53.279153,90.631507,72.451085,48.389178,46.201935,82.612243,79.53631,45.126148,29.576753,-9.824999,-28.647171,-82.861332,-125.9126,-165.556857,-100.461935,-39.912445,64.81113,65.53519,-13.290664,-44.019883,-10.286901,117.154267,167.178576,168.716475,128.454835,17.203387,-46.148134,-108.418547,-72.401218,58.991097,113.289601,119.944591,126.778345,95.663166,-44.560183,-101.584176,-93.882389,5.928114,47.043027,128.796294,160.916057,92.91569,9.433727,-37.944187,31.646169,205.754878,222.140267,179.045411,92.852224,78.390411,105.606627,94.722824,20.892742,77.866351,120.400179,99.624883,76.219497,87.095345,103.493606,129.350561,137.880931,140.165668,140.089285,149.954478,191.45975,205.140622,172.851266,136.145532,97.399597,167.078592,214.550627,196.227024,125.50062,-8.355204,-29.975913,-32.101601,-45.762797,-19.248553,103.230325,127.601017,83.737721,56.112743,18.211815,-7.776547,-33.223077,29.671057,61.860814,165.27713,238.128616,252.072851,198.314418,153.898681,147.556991,57.55036,36.013487,100.949143,243.638107,274.294627,260.910175,210.852391,105.665208,191.992635,251.245267,235.647589,190.670166,109.924228,68.106771,-20.680653,-58.544988,-94.12301,-55.515106,-12.743229,26.565704,-15.045218,-112.692903,-116.391235,-127.935802,-227.356883,-275.385637,-290.557194,-247.452069,-156.035957,-143.010716,-139.72366,-126.283108:-77.805244,-78.5005,-82.40917,-103.175614,-120.423345,-126.630079,-117.27594,-90.084243,-12.397034,36.765314,135.632392,174.093448,130.910778,71.817724,42.736411,64.772319,87.027651,117.616092,151.652779,181.215954,148.538593,61.658276,29.569184,-30.667607,-30.436262,-5.87437,45.799581,62.203729,54.218589,31.23803,-41.992605,-70.882584,-28.710343,46.785136,64.299471,113.99935,123.996477,85.121924,62.991731,31.324175,44.059361,73.243933,132.565044,135.166084,53.781332,15.939756,21.9808,31.086441,43.617479,130.447744,179.19873,185.454985,139.793258,30.428005,-10.26562,1.629249,162.144496,231.641682,289.219713,311.703499,335.953771,320.176797,257.477412,216.610567,145.759482,103.822191,79.369694,0.640608,-41.16658,-94.139359,-122.321306,-155.377725,-58.398068,1.353558,50.282631,36.415412,-63.04822,-124.804766,-191.117186,-187.169256,-104.493069,38.291262,99.870118,151.457587,136.204991,56.949398,20.546031,-11.279812,-51.987271,-82.963661,-66.862987,-22.103423,3.573495,-38.017265,-114.336365,-103.550914,3.70442,107.584997,145.050779,203.369363,190.856443,38.632563,-50.515687,-99.292549,-10.773892,33.021255,121.182772,161.604306,150.941409,114.351736,90.761294,109.592819,156.921408,178.714445,181.531104,161.720152,127.507532,18.682756,-33.453327,-62.310686,47.752203,116.94007,186.32937,172.507817,53.303691,-24.832419,-140.959961,-173.292991,-173.292998,-61.677525,29.885076,164.785819,145.391476,-30.108837,-113.562869,-160.978189,-60.664801,20.491852,176.481746,221.221872,174.537783,103.592657,-0.467751,-23.826405,-59.122715,-68.023022,-44.699818,-13.263068,-33.164275,-85.242424,-99.237573,-105.494695,-37.73674,19.733291,109.547104,110.656524,43.392857,23.514642,17.865591,-1.547087,-39.704645,-14.795299,8.862726,14.355546,-21.383832,-121.954507,-153.323509,-141.580604,-87.344258,-81.63136,-51.143772,5.194371,89.644413,78.791003,-4.877794,-34.115101,15.774927,84.058546,74.237967,-5.817497,-76.858197,-241.789785,-312.386256,-392.446608,-306.805424,-242.226257,-211.304932,-259.706105,-398.560357,-424.636192,-372.429496,-334.987345,-264.537903,-189.220119,-148.226382,-94.457932,-103.623365,-150.880065,-171.348247,-210.435996,-133.485076,-35.581055,140.473986,167.94985,111.071012,68.313775,-16.008399,-60.867595,-73.381893,14.405043,49.487517,101.320754,117.95843,48.232508,-59.363728,-312.77732,-371.142278,-307.884987,-138.833272,-92.990767,-118.741036,-162.024156,-244.392476,-275.82706,-289.151945,-227.693032,-183.766771,-125.818406,-136.379087,-208.963077,-235.393418,-266.317971,-284.69903,-280.443004,-221.911892,-178.829648,-172.619492,-213.554586,-317.551318,-363.113625,-367.1247,-271.330223,-234.569242,-242.634576,-290.646698,-406.861845,-442.391951,-465.28447,-422.360093,-378.944134,-284.480438,-241.858536,-207.882031,-247.199349,-398.117876,-432.024097,-324.598176,-163.806677,-105.525582,-45.793054,-73.64162,-248.10171,-332.870026,-336.040898,-194.243758,-144.61683,-77.627601,-46.022237,-40.142721,-80.671734,-229.742076,-295.414836,-240.551087,-12.147714,75.078377,150.296223,150.706985,110.146644,81.614921,42.162417,72.980477,109.289697,164.230634,168.344018,121.331225,72.317599,-75.972186,-146.372148,-142.200456,-17.002386,25.310859,69.188878,77.060729,58.526652,37.393478,27.119889,106.362558,153.043785,190.717881,178.082727,89.635712,26.920733,-64.757983,-67.316313,26.213794,150.928904,190.622224,179.175355,118.749863,-48.957239,-112.050234,-108.38497,33.439164,93.411264,161.314796,178.043549,106.168118,19.050098,-95.623254,-77.199378,56.323084,107.777689,80.365865,26.700209,21.606918,44.728685,56.245752,52.079692,60.191877,78.350144,134.048754,158.650004,136.845184,87.665997,20.744736,46.704005,160.788728,236.899138,264.042164,301.983826,297.052075,217.053253,147.819766,33.050788,35.888705,74.255152,145.581084,139.533479,69.331251,39.371455,-15.251974,-27.983212,60.398939,187.131701,214.701914,224.295481,209.102277,149.225676,117.763056,68.49845,71.721996,109.226895,260.685862,339.748795,406.972084,385.076628,244.102916,168.649999,123.604412,196.098259,248.841406,311.043733,303.64836,254.372748,219.540977,158.446102,183.690888,214.085839,254.098006,247.615878,140.480621,47.749896,-114.065117,-137.241057,-49.963859,61.989601,92.575481,100.394116,72.137215,-11.414785,-53.202113,-146.164265,-186.952447,-167.482328,-106.096892,-95.481542,-133.919269,-158.204203,-162.991552,-147.773471:-86.324928,-108.619192,-140.862312,-192.716969,-209.264191,-203.921079,-168.030057,-88.847821,14.443649,86.587693,141.15761,109.740995,50.786912,51.869742,46.232474,7.317116,-62.69196,5.231162,51.546449,60.378435,21.964345,-38.705945,-34.529263,-16.844635,30.878547,73.195759,119.248715,124.13714,154.939074,170.368739,108.09109,42.316192,14.096654,105.75815,124.859707,142.111872,152.108316,133.091752,117.846431,92.315462,70.703043,85.068067,118.570957,99.915463,-3.251543,-43.055801,-45.845574,-38.121223,-7.200216,116.622423,173.586309,215.632139,230.796082,250.105643,232.594346,205.216683,266.173704,310.140379,370.916591,380.42082,367.325566,343.247963,227.627815,151.948682,97.492463,178.82511,200.029931,154.539735,112.104807,-4.266764,-77.852452,-146.53529,-72.679996,-42.510263,-25.601493,-15.984048,-14.384491,-34.398053,-94.193132,-116.693675,-64.269008,78.397824,127.604681,187.643536,197.674147,154.03365,114.144148,7.991796,-111.632047,-142.384185,-126.641159,-95.070888,-23.594633,5.556654,38.023514,45.166417,99.114003,191.453646,214.410615,168.8874,86.175287,-148.431979,-235.257992,-234.550726,-76.849288,-6.36614,60.327585,78.646113,128.171538,147.608821,129.103333,106.055991,100.455961,91.550113,93.701425,164.434156,192.618009,114.055699,15.157398,-153.377747,-122.355927,-36.700868,144.349434,177.07618,93.419785,31.029812,-58.2416,-95.79042,-96.102774,40.766444,96.586644,111.951505,92.820141,35.960272,-8.830839,-111.899649,-93.182249,-25.990345,80.131674,95.033395,105.465681,102.211174,31.997572,-18.96769,-56.494465,-43.571502,-30.083839,9.587314,-0.711049,-101.401724,-156.048458,-200.763782,-174.884281,-138.249688,11.698333,94.627576,175.203702,193.38317,224.993243,203.733069,102.589452,58.895573,33.947445,-71.775467,-104.474951,-46.866141,-7.495575,-64.565232,-160.708348,-137.394112,11.203652,76.498013,96.457866,47.737303,-106.093708,-157.70106,-124.96892,-35.983899,-28.297636,-80.177617,-127.494643,-258.769628,-322.838374,-385.466756,-365.416747,-360.630564,-345.449406,-307.744599,-249.29291,-271.524493,-351.541779,-352.632951,-262.7153,-146.007779,-93.197122,-39.056714,-54.831654,-110.615149,-139.294191,-210.197176,-134.455692,-50.411777,34.674793,43.956414,93.561224,125.548468,113.169744,57.49489,-4.037848,110.654967,160.107543,170.34389,149.961614,63.639366,-12.684031,-220.186837,-347.576682,-329.068816,-199.579324,-147.754512,-133.901167,-147.587396,-124.704601,-89.522211,-43.575419,-106.706363,-159.396359,-194.572445,-181.186619,-187.649794,-230.658048,-319.834766,-258.531634,-199.656041,-149.763628,-145.446928,-117.858102,-118.529397,-189.578954,-219.446516,-214.331728,-205.227514,-201.010144,-189.009187,-194.631305,-244.725331,-280.38505,-316.777412,-277.628572,-243.782274,-154.619874,-107.631437,-115.100894,-177.288019,-265.081199,-260.86558,-227.67815,-190.27444,-162.294886,-128.917253,-147.985598,-271.801489,-331.792854,-326.122604,-267.520482,-254.729663,-177.868882,-130.06536,-141.787438,-183.164757,-251.005448,-287.095326,-298.930783,-145.554891,-57.482916,37.035638,51.917396,89.173,110.769441,105.889684,101.418682,130.353538,209.06245,229.586814,143.919335,44.864801,-116.090879,-135.1125,-42.274183,71.603063,88.944817,102.0678,119.467437,158.456104,166.688098,146.090399,172.351999,200.233105,182.328195,142.319809,58.339839,30.428703,-1.830317,-12.194768,48.644958,179.697045,208.218472,198.166985,170.019403,67.790411,17.580386,-22.560425,-3.855667,18.255729,103.574551,139.550184,88.301222,28.358757,-11.837951,7.787869,54.386933,34.936911,13.667691,31.178329,58.199642,77.752405,72.805175,82.988275,110.678636,100.784328,56.474086,62.871504,104.513107,94.389366,27.262422,11.345078,64.81868,143.164213,149.856895,134.85196,126.635618,64.484139,10.959626,-28.641524,74.874916,122.104713,103.900879,48.623281,-90.911789,-150.286593,-175.134948,-129.449147,33.55008,171.118911,203.900946,185.680818,130.318238,39.117335,43.704408,111.975202,179.888798,197.826453,242.196989,272.724497,281.326993,263.063335,220.877455,188.787397,162.484104,229.794525,270.353031,354.356384,381.635685,355.145545,301.109186,173.317543,170.279965,206.357871,233.365304,220.883573,160.442421,108.732883,-0.530138,-28.990925,-8.292671,4.978646,-7.443731,-1.308194,12.616616,8.967198,-14.34844,-71.616223,-103.084565,-127.307922,-185.724717,-195.301578,-197.081572,-206.344459,-212.059251,-196.489877:-38.375748,18.428304,52.319372,30.489418,-36.819649,-126.550538,-119.740212,-77.180704,-27.126332,-4.20388,35.940664,49.037729,29.079311,8.112523,-31.563484,-57.501649,-41.368598,117.208157,177.909762,155.998051,98.909241,8.796527,-17.903198,-74.702304,-54.751498,1.351266,125.693298,141.115789,35.882143,-30.583069,-84.55129,-77.282752,-36.971978,-25.25312,-19.962901,26.367848,53.579415,81.649994,76.64492,27.871039,-29.24527,-45.133122,-35.745152,-20.027356,4.089427,8.986623,-54.902779,-125.65147,-184.410545,-20.364593,94.796716,233.938951,217.136659,78.204131,28.847049,68.581529,184.730851,207.419187,221.42295,257.000298,327.573368,302.873172,105.058439,7.930395,69.605944,271.887248,284.726795,164.593213,89.697092,-36.775097,-97.367747,-161.431184,-83.072107,-37.173839,8.400956,19.135513,8.994312,-29.937273,-151.598458,-187.309118,-163.006203,-81.980913,-7.817523,165.516747,191.683096,89.154456,18.137913,-68.610756,-98.244371,-97.634175,-36.514568,18.717142,73.166083,56.748851,26.615456,37.294844,88.324477,147.431578,175.867217,139.813387,45.337331,-194.14196,-269.043267,-264.029236,-158.559455,-106.603086,6.427494,52.572721,49.559809,23.977209,6.069246,13.747435,43.841618,63.632357,80.54374,117.1355,99.280964,-13.443499,-69.619654,-99.130096,-9.469502,46.90679,162.696913,219.104225,197.370452,104.903979,-72.165587,-101.923419,-66.771116,6.747315,53.84006,108.027547,89.905328,13.837006,-31.389012,-98.581574,-5.979238,71.793981,156.551148,165.641375,149.021115,119.786654,4.188943,-67.46925,-151.658591,-128.407843,-85.636271,-14.636585,-33.004418,-157.56263,-199.376801,-134.87825,14.251362,51.714872,93.890316,129.657402,202.45053,217.991056,148.696189,75.944201,11.810956,92.531966,116.065799,69.877671,33.393142,16.35251,21.811495,-31.107331,-102.314947,-98.569525,-0.533442,64.365322,74.809511,2.892584,-156.452201,-182.441969,-82.683654,30.451542,37.000192,4.285216,-34.548535,-188.785702,-274.555784,-322.392166,-216.277509,-177.86158,-131.188793,-107.759714,-139.74886,-204.519003,-361.233928,-405.282296,-322.80976,-148.026087,-97.092223,-60.761971,-61.266878,-104.442178,-149.232366,-197.684818,-103.302703,-34.863078,55.297194,71.524778,76.262548,60.440597,-10.823465,-35.548508,-4.377511,74.159911,118.031875,194.218576,185.60475,74.999488,3.979265,-159.003191,-245.274085,-215.024089,-94.876593,-59.904926,-79.382987,-107.551352,-152.553016,-167.376157,-158.256473,-122.953977,-98.244013,-41.213138,-52.306877,-154.153913,-192.582083,-248.803101,-292.228045,-246.905781,-48.018772,9.751012,-65.264188,-149.185164,-287.390684,-322.230588,-281.858902,-172.944452,-140.227725,-137.322176,-170.094844,-289.354497,-357.658205,-450.176418,-387.526785,-321.231336,-241.196239,-227.798706,-219.517631,-232.96269,-307.283478,-342.548373,-334.376761,-213.494037,-139.659691,-96.530414,-146.532881,-292.923145,-356.50161,-425.491265,-335.500185,-242.406778,-58.758695,-8.450229,-80.330078,-173.61542,-302.762212,-317.411509,-232.607433,-34.412118,61.427602,176.596874,177.396041,114.497792,81.147063,46.480448,86.960098,124.859219,207.198614,241.008466,232.311857,182.195915,26.466405,-43.35952,-48.05104,83.055432,145.375466,219.963083,235.593808,226.531843,199.863173,169.579504,259.699432,298.250783,269.173603,232.547795,183.245582,156.591667,45.667017,-4.841244,68.368231,244.561043,271.266159,245.161784,228.528638,145.124295,66.641326,-54.031264,-40.560746,-7.924708,115.86829,179.697552,124.141889,29.965237,-61.284698,-51.73472,-6.738705,40.8792,61.257252,96.316791,109.366271,104.04802,66.230721,-27.535927,22.888405,81.907062,168.894221,185.855852,150.79356,101.415426,1.381514,-3.68481,101.322792,182.58198,180.04713,171.843036,168.367596,91.456083,44.108344,21.891267,23.846739,22.171613,58.361823,73.911374,23.606427,-26.704834,-83.432304,-67.759194,30.410662,172.541837,259.239817,354.848203,300.933621,100.617488,51.383744,65.55848,121.31069,162.23056,254.499795,285.173014,294.754343,285.797411,250.499841,225.410438,198.19497,218.6805,246.027595,303.120701,313.180178,252.928243,170.243126,30.5307,122.944114,214.175625,302.417495,270.32195,114.148308,37.017206,-54.330137,-73.164922,-40.712851,69.168095,109.888847,95.40601,52.992808,-3.065045,-17.43249,-83.656547,-100.469145,-67.32912,-1.584655,-1.250436,-81.433609,-133.935897,-188.284521,-187.288694:56.421811,-8.511777,-31.938183,-71.277118,-115.434846,-165.120064,-121.400444,54.566048,211.32081,240.340207,155.530805,73.937809,-27.344177,-23.654741,8.655884,-18.83247,-130.739025,-107.672244,-40.352431,40.182406,1.049299,-134.156461,-149.675268,-80.832595,5.152283,58.669689,187.080243,231.831527,212.923576,150.112475,-6.447015,-49.060207,-12.677764,29.081563,38.437753,122.922111,157.997331,81.001277,10.29578,-46.928903,7.808347,45.404221,58.911099,32.736765,-9.199864,-16.895949,-73.345139,-121.36328,-118.766858,73.61367,168.388867,209.89394,174.79964,120.656637,115.078985,105.042354,121.608264,162.977671,260.06528,274.548561,208.394404,160.857327,93.775577,78.224162,117.100852,202.82165,219.705774,185.547869,147.624054,76.551514,48.105762,-8.04442,2.414425,28.849489,33.766173,22.236184,36.908846,52.174249,22.56229,-19.780444,-55.031373,20.615643,61.599795,95.736305,88.065111,21.633902,-35.9398,-165.345844,-215.567064,-209.465769,-178.105447,-141.906055,-46.197537,-13.259949,20.310214,32.344425,52.179747,45.461334,19.242352,-78.984546,-133.187276,-222.908341,-262.112194,-323.609376,-285.207918,-218.445748,-49.943747,24.730658,64.107378,7.190571,-122.301111,-126.051356,-36.173882,36.593191,48.102344,50.088307,47.076329,-6.018425,-78.544309,-255.263287,-226.038413,-121.835515,61.546897,100.895145,105.653664,94.965904,70.180256,34.944033,-6.028969,127.200626,198.783676,233.099924,201.536201,50.218305,-60.31997,-193.791583,-75.748827,-4.785535,14.788575,13.471565,71.602236,86.267559,32.455758,9.509821,34.406977,5.665984,-37.07849,-55.368099,-41.34416,-99.954599,-180.069973,-297.501841,-210.479026,-149.189224,-55.914535,19.928726,178.249471,219.81348,242.658842,210.853083,51.093255,-19.17294,4.617697,9.741558,-30.633383,-66.482183,-29.542271,9.743419,-50.026099,-25.390804,137.939599,187.407175,142.538733,81.435966,-83.535067,-164.464048,-167.695164,13.264207,50.430534,-28.674565,-67.326373,-85.060231,-96.472651,-168.766285,-238.782596,-239.377532,-167.485438,-108.430643,-12.990253,-16.03205,-152.620893,-224.433739,-167.939644,68.606708,159.975535,197.398639,138.630544,-14.897945,-59.410951,-88.897161,-1.996461,53.781072,89.459114,116.79435,271.536974,331.790021,244.457427,135.117511,48.673235,154.545745,194.937654,232.105606,231.959518,163.796134,105.927952,-34.144872,-139.86427,-141.138651,-57.70581,-12.694064,6.34113,-9.409576,7.231142,49.348138,88.697178,-17.725006,-62.462079,-34.625846,-24.376728,-117.796582,-157.373975,-101.610451,-9.643051,9.712253,79.522816,139.039762,172.033983,128.289448,75.934584,81.828765,56.351609,2.619895,-9.131814,22.588228,52.897017,20.115332,-43.581011,-79.62631,35.709671,89.1421,129.734665,124.903511,81.467087,51.129263,22.888606,12.662678,-62.314854,-114.66212,-91.578766,-30.790418,-44.902607,-160.106907,-220.072734,-320.168352,-402.096688,-398.865833,-291.049305,-233.03667,-192.981503,-197.504041,-219.939687,-238.185625,-235.734977,-122.591303,-51.935831,43.108611,59.86338,50.820243,64.35169,158.388589,176.932578,156.673027,172.759356,189.127331,96.832175,9.536374,-73.618523,-78.55807,-83.59867,23.294558,91.441989,126.762739,83.904569,-43.266031,-72.346077,-37.307406,34.497217,65.886915,108.561263,112.289654,83.50112,62.974247,36.221433,43.702716,149.288802,291.58332,331.962708,320.645987,264.505445,126.724259,73.062164,-25.479423,-38.541137,18.686709,159.392953,187.410454,134.872749,97.426334,70.585914,65.263934,47.376914,78.500873,115.19974,154.826026,144.735877,81.532296,46.789436,37.803388,72.674619,71.276286,42.001339,27.863241,4.42184,-3.16727,-19.553869,-26.870273,11.515619,40.523304,16.545594,28.736893,87.52429,125.379924,47.215226,-171.336221,-164.87477,-90.170249,-28.101296,-63.151893,-177.992517,-223.358372,-234.916001,-200.353915,-96.832329,-31.395189,-12.61046,37.175417,47.218552,30.105601,19.810054,11.458653,77.393124,118.731264,160.016944,161.76819,105.580775,54.222448,-5.766272,13.97117,114.034222,193.007544,232.191567,303.9634,301.460067,206.099893,145.160747,73.622293,130.631318,193.725986,264.69277,238.014347,88.07417,11.27531,-56.030593,-50.30968,-14.250614,-8.667769,-12.308405,21.10153,36.765069,-28.140404,-88.074843,-131.987885,-70.007982,-48.282984,-116.142161,-185.515642,-245.390023,-231.144506,-216.339368,-211.381427:-26.815373,39.852251,71.223913,56.452091,1.33924,-91.846809,-83.515623,6.362654,108.919968,144.508771,139.471278,112.326916,41.650779,-4.746274,-99.209051,-127.93305,-105.224625,20.248149,88.826938,118.149777,52.27935,-123.861144,-172.880057,-162.320929,-16.875697,72.290267,172.175426,174.138355,84.922195,4.633458,-135.45317,-166.057205,-107.390749,44.897036,101.508445,138.23831,120.460735,44.865502,12.450218,1.856531,25.487804,32.471488,31.17728,16.180864,-42.307788,-71.800455,-125.977972,-164.144262,-183.290204,-28.764256,53.118347,130.596082,128.976692,50.185268,-8.475423,-60.800297,28.806642,107.931939,267.213676,301.618218,187.990776,77.236897,-64.445595,-65.654114,50.940279,190.246223,210.853298,190.324238,153.233021,-45.646104,-179.014963,-288.064145,-98.591059,-3.710015,50.381584,40.974672,-25.647245,-89.364321,-225.383358,-263.328603,-211.46645,-60.685417,1.416831,86.35182,99.952923,28.680529,-51.470792,-233.443864,-294.914599,-257.41554,-132.47682,-83.611477,-58.27549,-65.972517,-86.914861,-95.043886,-40.414284,70.659618,98.869395,64.058436,-6.309089,-225.926287,-323.39534,-352.517832,-197.311067,-127.452168,-69.31095,-55.314982,-19.990075,-10.627131,-70.817446,-125.005362,-114.617694,32.305897,73.906049,78.293009,56.375634,-61.051846,-147.164915,-241.854735,-128.807797,-40.688398,125.969749,184.450115,137.166816,48.022318,-89.737712,-112.654794,-69.621583,48.642275,118.906642,224.250359,205.439208,20.556815,-73.644924,-122.797466,-17.721821,28.174435,80.97046,128.259531,205.204806,172.497444,18.139592,-35.060909,-30.728243,30.54406,45.787063,25.095018,-24.478652,-180.333823,-236.709962,-233.372472,-144.609144,-70.99028,159.88337,254.837038,292.760051,284.711015,249.437006,187.146175,62.003758,104.346743,145.198485,128.36332,76.767774,-5.366592,-17.648314,-33.539554,-24.840139,-0.122471,66.765885,95.903913,75.498754,10.552013,-131.617984,-156.697991,-92.681256,24.092264,53.918351,54.765599,29.376282,-112.613116,-195.463108,-267.116541,-221.820678,-180.695394,-88.601741,-50.385622,-62.10424,-121.852301,-288.832661,-354.372308,-338.369932,-153.643878,-69.379228,-9.242275,-31.395208,-88.189157,-103.752778,-146.799638,-140.177168,-99.320901,6.523602,76.555486,209.420494,208.624943,79.907553,35.141564,83.393446,206.786831,260.032037,310.14107,290.243128,166.423017,79.225437,-99.285404,-176.054737,-162.710678,-61.110347,2.276688,27.118275,-16.171775,-62.710038,-34.478078,59.544078,77.662407,52.167514,2.856443,-26.7623,-137.419779,-206.864575,-294.141105,-175.112118,-44.958562,169.580505,202.233923,148.650787,87.681301,-78.12662,-154.630443,-195.51617,-117.051264,-70.328126,-10.374135,-7.278772,-52.71752,-105.42357,-232.672911,-240.362717,-186.586151,-86.288932,-66.863807,-75.951067,-100.305074,-190.275715,-245.662713,-273.674074,-162.748294,-108.041042,-90.23497,-130.902913,-250.361771,-286.363857,-278.34716,-228.451484,-187.795577,-85.559429,-55.244271,-111.25571,-187.886465,-338.156522,-371.909692,-265.322423,-5.227252,94.369738,143.569752,113.338019,57.155229,56.05379,106.156689,155.785671,172.42941,270.240992,337.1157,311.0569,190.097882,-48.844762,-77.130641,21.237084,129.790837,169.256943,242.609937,260.788222,247.653633,220.841528,154.618969,175.795256,215.060332,242.274306,221.436781,136.880093,86.364939,19.087213,29.991979,176.123933,318.556897,342.924081,341.575204,310.542617,171.62394,85.722882,-35.824591,19.97211,107.228189,267.236677,287.295277,142.129807,30.029738,-51.440234,-18.538328,62.336374,103.036754,112.532276,122.057826,126.196818,151.997955,157.764849,111.523406,113.269601,139.152667,160.585941,162.650632,147.993261,117.987394,48.688338,41.637372,103.124538,126.262499,105.809729,99.168847,103.205181,32.77467,-26.444739,-95.162765,-60.36458,-15.100552,72.480784,81.579933,-28.673209,-115.926049,-203.994963,-193.29114,-93.382185,85.440907,158.659459,176.551371,128.91698,19.77463,-19.741104,-60.285414,39.657462,132.132312,235.528047,221.184718,141.12263,109.616702,72.454882,66.096558,108.510193,183.831553,221.955153,307.389245,322.011011,222.364537,127.32607,-23.779359,48.103603,152.175868,279.65466,241.770363,13.955898,-91.457184,-151.326638,-134.267991,-85.876316,-6.160818,30.866803,22.217425,-23.20699,-103.612274,-118.354043,-117.011609,-81.653952,-67.976271,-58.07216,-62.090847,-121.414407,-162.961461,-212.726603,-210.9301:98.611894,1.83752,-30.821975,-1.456068,23.496612,24.482324,29.605515,60.186832,97.802444,131.92559,160.31078,116.301465,-23.649761,-64.318644,-65.841792,-64.296984,-108.383352,-123.800004,-112.206722,-118.704566,-148.649867,-209.029468,-212.004052,-189.551051,-156.82873,-110.877539,25.755524,87.768391,136.264481,115.470294,10.974391,-53.718205,-136.396718,-67.27714,2.82621,89.63901,73.623193,-30.020607,-59.901636,-43.510332,-56.907924,-107.517976,-193.307868,-181.697412,-113.134562,-103.382679,-167.48589,-216.737009,-207.385319,-62.75849,-51.475562,-162.160013,-194.355611,-186.02861,-195.71854,-239.128493,-178.712206,-125.073544,-99.020344,-108.509296,-91.996713,-83.298141,-82.781241,-61.38658,83.658566,245.307175,247.760738,127.662315,92.664568,131.701403,140.531787,64.087472,31.391112,62.062665,143.874926,182.989706,215.054771,181.557845,58.511626,4.798891,-51.222622,-76.070312,-112.953723,-212.982537,-240.970096,-274.727183,-323.192199,-482.789839,-543.619177,-523.769747,-422.98344,-326.42989,-124.060441,-86.912775,-126.291001,-143.171981,-121.786228,-111.639693,-140.757055,-231.868997,-246.13795,-190.95497,-184.008497,-266.219726,-258.732822,-204.469823,-124.359271,-86.408929,8.742837,7.830567,-103.811592,-139.262255,-76.661218,17.802158,35.308373,16.78372,-17.169421,-76.214788,-75.418976,-50.436027,-11.460731,14.275764,48.723552,85.419996,224.772782,274.943896,255.16271,212.430862,171.057394,227.387484,252.056013,244.027088,217.319216,160.061887,160.002893,200.426191,218.884481,214.96893,171.037972,144.239503,125.968448,142.154018,193.735463,209.490452,221.954509,143.384084,58.066806,-57.548225,-69.893742,-96.257338,-117.095831,-146.708519,-147.581541,-153.891411,-145.178593,-81.005433,104.342325,162.580214,190.223292,166.107421,113.828336,89.766933,47.58215,-28.631889,-35.907516,-59.501178,-87.780646,-121.637335,-41.124357,24.499767,90.049655,93.110177,82.001094,61.48221,-39.526612,-112.285487,-175.018842,-119.482397,-107.87758,-111.539181,-113.254598,-118.037651,-104.723864,-70.658445,-25.336876,29.325615,130.288279,169.509488,254.249113,276.739867,239.203552,202.354785,177.700582,203.627699,216.836164,272.176624,285.39023,200.602947,138.244524,86.718547,182.947,241.955724,260.789093,255.510223,264.700881,244.346071,202.914156,218.381646,262.596769,248.867015,255.506693,376.23686,438.329024,417.187771,349.074893,189.942886,123.09168,147.899437,186.049867,176.00468,208.623663,266.041658,354.434436,345.980158,241.863895,142.308162,128.28238,150.232103,148.18108,84.912689,57.247838,95.002999,201.858404,253.184609,351.737125,377.604177,346.835939,326.089622,357.659597,363.145888,231.356185,96.396453,112.78265,310.977766,405.641193,389.454641,314.469685,230.052047,285.064564,322.449256,368.060817,378.842475,355.251982,322.312577,233.110544,170.695895,55.533688,15.106071,5.428745,16.49925,29.344082,-17.940648,-61.107002,-122.825867,-216.826341,-245.79107,-139.498858,-56.461319,-76.204567,-154.16089,-258.304498,-278.648553,-236.652213,-96.155888,-56.412531,-30.019369,-0.701778,62.869815,89.719143,159.044095,177.672215,156.003153,140.074325,154.049515,128.923185,75.468388,-22.515998,-39.50675,-41.823332,-13.469416,9.782418,8.978575,-30.841796,-120.359108,-135.609634,-135.656979,-88.716099,-30.508982,52.366311,46.125481,-2.801542,-11.476071,28.223116,60.303568,154.121456,296.598446,344.623702,355.283774,328.513812,212.098212,131.603984,-2.088084,40.283007,126.652458,266.077425,273.502405,153.883629,73.225554,26.989649,56.689639,132.383012,196.872001,218.434574,226.539776,209.789529,171.907256,167.993177,156.729944,99.219706,62.539472,32.277982,55.818156,143.92078,182.94572,188.567061,147.137392,83.593586,98.97301,94.015276,117.572894,139.78672,83.546947,24.158243,-28.456149,18.879329,21.969332,-70.625522,-112.97213,-133.658517,-144.193062,-184.36505,-203.822419,-185.644883,-60.049725,-13.155501,-20.814605,-51.351303,-55.774941,-34.176452,-32.763684,10.740164,56.72428,34.504338,-52.716235,-207.753181,-204.457599,-104.264488,-70.697557,-5.945726,131.147169,178.492063,180.644352,155.720633,99.472193,85.894668,70.25291,31.023959,16.352138,5.438819,-2.343489,-58.520672,-99.247266,-156.380066,-164.034934,-122.831717,-26.305772,6.345217,-23.821552,-66.974456,-84.013253,-47.844168,31.892797,60.459756,47.196346,-26.575671,-68.710229,-152.226267,-196.698475,-237.968983,-228.527085:2.552385,78.518929,85.417128,66.438464,83.566563,154.452251,173.250886,130.773392,62.345605,70.715316,111.57287,93.204646,-16.059618,-50.007386,24.05415,70.949877,40.018119,-13.429295,-17.979301,-45.65465,-84.53289,-118.083064,-79.545919,-15.250207,-38.877655,-24.50691,85.491025,140.769387,158.849551,130.432649,93.239125,86.705844,22.802858,-45.1695,-20.866255,77.123933,73.544984,-13.403689,-16.067268,92.152307,135.130296,67.831818,-147.808072,-205.936277,-155.600926,-109.521612,-123.867821,-167.488077,-171.228378,-58.826189,-7.746674,70.617893,85.841135,35.833392,-0.548429,0.235975,54.542117,44.705222,-54.703147,-82.907167,-37.966691,-11.318852,-29.811342,-52.722721,-5.600347,94.109076,91.426561,53.528903,69.174017,135.013272,143.681792,88.303097,28.011569,15.914612,9.133985,24.76892,101.375039,130.725144,104.71168,63.895985,46.84669,93.333486,73.917331,-16.449216,-51.376283,-109.130844,-136.212605,-199.791743,-269.718966,-286.599805,-281.340946,-256.522758,-172.382091,-126.564253,-43.589956,-5.699902,96.333122,170.490593,151.353924,52.760945,-4.987734,-179.378117,-264.399921,-266.708543,-95.280755,-31.534593,-10.332124,-1.530086,48.596128,43.351302,-46.872667,-79.798082,-42.479951,20.188917,36.438475,69.773314,78.014899,19.59468,-42.895489,-102.582604,-32.919488,1.605092,78.308947,148.842618,228.498545,193.880995,107.327,104.083031,157.547243,174.919451,165.936973,190.479119,204.388221,143.466701,86.378208,-5.104898,-10.182926,23.225984,69.262515,82.517785,138.247445,170.573286,203.486653,192.909187,122.083339,-13.135019,-82.938636,-119.618181,-94.3679,-105.178544,-165.155818,-273.937623,-245.234431,-209.330122,-138.104945,-84.766429,4.601068,15.198603,24.664983,20.700019,-3.568092,-8.453537,-52.904585,-214.290438,-264.400065,-212.660079,-126.183228,-6.191701,-18.01294,12.037011,171.882161,234.439659,192.272613,98.954491,-91.128747,-156.055138,-222.128608,-189.113254,-138.520747,-57.374529,-53.767312,-70.137688,-65.803041,-71.414073,-100.928613,-84.669893,21.365829,80.834859,162.469005,178.259073,120.296664,75.248681,107.77593,206.281784,205.29674,202.519104,230.715793,252.910681,222.852364,114.834053,106.516095,157.457207,267.249799,318.31209,414.884012,443.333843,428.750711,385.064288,285.150032,249.537051,262.874442,338.42804,363.680008,330.478107,274.762958,77.746513,-50.137353,-22.203106,116.159836,179.241752,238.3055,231.091375,179.86634,147.081806,125.273503,147.391728,125.12567,29.31731,-16.38625,-67.75037,-74.82341,-81.458975,-72.188453,-39.974787,97.40187,172.506201,214.523288,172.88516,84.548957,72.216374,69.60559,51.48514,33.959846,9.949333,6.311296,8.962407,20.566574,37.216857,69.776907,102.56965,158.396724,179.086685,229.627855,259.318897,271.271109,227.436341,91.981198,18.742721,7.890607,-0.696165,-14.262462,-100.409288,-162.003305,-262.286818,-272.64081,-226.769417,-89.548693,-65.872531,-156.561998,-199.689774,-190.277399,-170.571335,-148.938478,-155.328136,-147.077854,-73.741519,-30.988518,31.146878,56.755176,63.955443,6.677439,-2.627666,38.100796,59.698115,42.164923,0.441059,-93.155096,-124.425162,-112.337041,-103.044367,-147.49267,-192.00064,-165.435757,-175.896419,-231.285537,-283.392151,-174.616113,-109.682277,-57.098466,-59.840781,-65.954304,-64.216108,-40.503298,-16.883136,74.079371,216.66301,255.128326,230.074272,195.664296,109.579096,51.414276,-19.047039,94.22999,150.546936,150.062484,143.821089,148.307607,134.577364,109.130598,117.161047,137.743912,87.365738,66.264481,91.794712,97.204654,41.175639,6.666078,-42.273924,-65.799563,-61.746377,-20.275156,16.230827,102.904594,133.671995,127.679961,93.109694,34.623042,71.26257,109.491483,152.556022,146.851795,112.845577,85.700647,6.334753,1.784645,37.255906,96.84092,87.095875,-39.022477,-105.487484,-147.952118,-154.256687,-143.339634,-44.367792,-6.127808,4.097208,4.409591,22.903739,31.601205,53.635818,157.343867,229.316019,260.998253,197.112557,40.749752,0.982616,-11.532734,-11.631721,-17.893497,30.45909,89.122472,209.151476,230.093974,165.947304,120.201188,112.877565,235.301699,286.242274,240.698512,185.661792,128.494856,112.968768,38.845151,-21.257448,-126.204302,-154.320701,-133.005965,-71.011331,-84.100387,-196.839391,-209.520223,-65.764917,36.910407,9.440295,-98.361804,-128.713378,-133.685264,-129.722789,-151.505703,-180.64473:-14.806424,-35.906456,-7.294818,34.565611,6.47197,-93.932601,-97.826278,10.378183,78.529284,71.88174,22.436563,-11.376638,-59.228716,-63.871029,-56.061858,-64.769873,-105.110689,-97.654022,-97.793756,-126.099649,-124.638121,-112.477639,-129.754364,-209.201466,-165.32108,-67.823416,72.196753,74.454707,-3.954667,-68.743657,-173.636556,-182.394193,-109.969473,-0.87192,43.832726,127.680814,135.336732,-7.88136,-110.372104,-151.955124,-16.445672,12.444343,-34.847644,-47.420785,-11.873441,-13.554583,-121.859966,-186.307968,-144.768585,50.48035,85.352178,21.181353,-32.851643,-119.769741,-114.100089,-19.984131,1.784772,-0.236863,47.731543,60.678601,20.285609,4.709993,12.223834,28.053648,147.608893,296.379495,277.273617,108.333731,46.88761,14.041451,16.358577,34.07106,58.996644,68.762752,59.390455,35.922635,3.266578,4.621664,-22.132165,-69.552794,-146.54752,-126.929993,-123.317501,-106.826166,-86.296182,-135.089945,-200.070835,-293.418397,-305.448306,-307.601387,-270.855615,-208.545959,-93.402261,-83.522496,-82.416132,-55.062479,-17.357053,-17.364146,-11.191127,-11.294375,-18.878892,-55.31973,-97.985747,-211.618124,-185.43242,-101.132798,-9.753072,-49.991651,-117.080752,-89.704873,-20.405416,-10.954128,21.155779,61.399106,59.966787,57.257878,45.173308,-55.257957,-107.449323,-106.158866,-10.142022,36.64139,98.119992,139.955645,242.752307,244.996362,129.080182,78.064757,121.271625,262.797054,295.636398,234.843817,168.175255,43.003507,6.250115,-2.571502,57.085371,96.721099,146.911262,169.972538,166.103875,121.977699,64.678808,94.744613,214.508226,196.120808,125.578982,28.876336,22.511413,-17.343307,-65.37156,-129.988457,-80.135435,-20.826675,86.70855,110.082631,159.868783,220.805805,317.583732,290.283903,168.024114,136.450554,132.299693,102.785951,77.775039,35.085301,42.96432,48.315005,-1.888654,12.343266,128.826673,167.204958,84.745905,6.773887,-73.908343,-94.825618,-116.410392,-37.367881,0.049447,1.689317,-22.212158,-103.086207,-143.222726,-159.912336,-88.426907,-52.066644,-8.625255,24.257644,69.214293,46.70477,-26.564043,-52.565033,-58.626179,25.789807,74.806107,114.717584,95.964851,37.941753,31.007189,38.274625,17.212224,13.01713,58.769331,105.392484,165.36322,163.031179,145.964204,130.155112,82.487251,75.831703,104.385984,200.596632,202.01916,76.062593,33.141333,32.479121,32.685372,34.669288,45.998445,64.988792,124.591578,138.337352,119.98324,108.903186,120.49747,138.099883,120.634285,25.385968,-36.022544,-105.274442,-84.645667,4.581738,76.922303,123.84849,248.204903,304.057886,300.873066,238.981496,107.093802,58.605172,13.333013,28.373976,44.773306,121.302086,160.69172,174.904054,166.393752,120.316584,45.562927,49.532296,112.437068,131.42116,118.51106,92.789859,34.74079,-6.143827,-113.970041,-169.637697,-167.002327,-133.970088,-119.870005,-139.62975,-174.595357,-246.448686,-288.638427,-285.228155,-219.155296,-199.784832,-267.11079,-301.920435,-307.421946,-328.047144,-351.239925,-160.671866,-41.114341,91.22229,106.13871,77.89969,62.266247,60.937715,35.869385,29.838009,104.591943,156.904324,129.654925,52.338316,-57.142088,-73.382429,-92.622105,-30.543624,27.26635,77.861006,61.539458,13.068899,-8.769135,-62.447378,-28.503617,23.188214,49.107168,20.265563,-24.648945,-30.790353,-24.987768,-1.837545,137.071957,274.018064,296.782291,333.497407,352.369944,297.43959,201.298396,-46.650366,-73.088151,37.349771,250.365444,253.249176,88.902101,12.545761,-26.443019,-25.942751,16.193214,174.331824,212.179512,127.488049,80.9431,85.612768,106.660347,123.753344,103.136365,87.861212,79.883497,95.670047,143.965108,151.551863,95.025428,44.822068,46.623098,189.63347,209.793238,152.67011,140.690744,120.869208,80.820749,-27.769806,-93.336313,-79.683132,-10.027729,-16.016058,-152.929883,-219.932091,-208.501592,-145.893505,-31.093795,-36.54359,-59.868097,-62.772294,-67.471783,-92.647551,-83.446745,-34.480061,45.930438,80.620637,63.480413,24.7075,-52.458089,-75.206903,-80.537173,-82.726475,-93.504161,27.388358,152.458724,345.449486,342.505879,166.768504,74.564546,16.733312,66.420484,88.989488,106.584258,104.164516,57.458969,27.017932,-4.76094,-22.408904,-43.633917,31.547472,71.249107,68.952408,47.039171,29.494691,32.782042,18.19393,4.683489,24.155956,68.532524,67.121355,-33.779301,-122.764912,-243.927355,-244.707868:left
-187.36512,-140.410241,-123.94823,-176.969552,-233.357086,-339.202297,-365.081754,-360.053266,-298.321839,-242.207952,-112.116226,-66.38985,-85.36549,-131.400698,-125.736717,-65.046443,0.403353,-75.761621,-113.487063,-125.351993,-134.687922,-172.781242,-139.020147,-4.203313,-56.464056,-121.108546,-136.23865,-98.686092,-76.814715,-98.97413,-111.528461,-107.334674,-112.370823,-42.697294,-5.488416,-13.666998,-53.725561,-166.042262,-206.844476,-164.82775,29.698978,117.408117,167.16628,159.941472,164.898711,164.853514,185.748287,223.449498,283.713731,274.022737,251.999872,218.689118,211.801656,177.443071,147.614701,75.119529,-0.238067,9.531091,150.786942,219.424398,205.384051,122.629343,-77.896653,-146.040564,-96.860591,105.831704,141.440304,91.217874,83.535676,90.157244,55.221318,-43.423658,-30.923681,14.418886,40.703114,7.777366,-31.244141,-15.606995,14.445309,19.069697,73.513691,181.726556,208.806137,166.253414,105.696877,-48.748815,-93.513637,-45.276052,35.540552,32.14317,-30.042807,-49.031416,-30.134916,-3.712634,69.108081,100.987701,134.433829,206.156763,242.665758,274.213733,281.737453,263.580695,254.899508,289.410912,325.837939,327.240457,308.797772,289.128119,218.386638,171.410078,126.896561,160.875075,323.361105,437.760121,418.704383,280.275345,220.069588,221.306183,273.951961,354.179867,313.926827,260.910165,155.580348,133.033818,116.045683,100.239349,85.439792,66.470433,-37.106923,-103.580798,-99.113291,-80.171543,-114.521216,-220.361984,-203.915254,-52.75644,22.99031,37.12564,63.043394,63.726325,37.439288,11.673505,-14.140649,14.005124,130.359636,214.189782,213.081512,91.916732,-23.598433,-207.979658,-211.600449,-83.926529,53.247471,89.054645,92.177458,56.361844,-79.937647,-147.707454,-197.845985,-180.411583,-128.374289,-96.387229,-103.35659,-177.912425,-232.445153,-313.300548,-304.006023,-213.74686,-208.464018,-249.424489,-289.370541,-248.359021,-90.433229,-21.46239,74.758728,109.963021,145.081062,155.138163,156.962904,133.965537,94.28553,-7.757312,-26.450058,-0.676793,-82.173987,-154.365481,-185.390812,-128.420464,-18.486697,-17.002666,-30.888829,-15.252037,31.855308,138.598934,179.893515,159.513804,108.880988,6.881291,5.656657,71.939648,135.950549,178.049988,244.262313,262.514393,297.189596,312.20337,338.40786,342.010732,288.028309,220.878718,203.335959,175.32844,153.046431,85.936006,63.253573,77.118183,111.647067,110.143573,114.147559,148.652101,221.5067,220.28941,186.36406,182.479001,165.291055,111.239084,95.8116,103.079282,108.143714,110.624187,104.806709,45.849295,-18.330092,-21.348992,44.30321,86.14093,52.89762,-29.577702,-162.455526,-164.406402,-78.733641,5.341738,4.078429,-82.849165,-147.336946,-263.924328,-277.13798,-193.542537,-82.498639,-50.434032,-62.237457,-78.634404,-25.910347,25.446685,32.568388,-20.518164,-99.008559,-46.038307,-9.931299,-10.173565,-47.014074,-122.806346,-142.500597,-114.764453,25.216518,84.838813,96.884755,71.975784,18.813326,-2.321247,-21.819308,-28.052198,-6.782098,104.792082,136.184083,54.837763,-39.690159,-212.010748,-235.610549,-188.038399,-145.647758,-131.761721,-158.3578,-199.902362,-227.96396,-188.671782,-92.909222,-98.92568,-161.523483,0.546587,129.339243,219.313944,169.424811,50.341027,37.508943,57.003945,30.51593,-4.569416,-83.064028,-73.616514,33.030117,48.796183,-22.806715,-38.307265,52.977887,169.957141,173.732354,63.754893,-8.870397,-60.922811,-27.588333,60.147374,163.565844,228.426848,268.758483,218.579629,79.205526,35.49706,-17.485264,-41.143471,-46.385902,7.668639,18.65648,-20.367424,-67.186223,-195.347802,-224.361055,-151.156919,-87.018923,-87.267307,-93.049606,-91.202129,-126.49459,-174.185864,-234.275577,-204.130452,-39.724311,119.152731,139.34756,56.083962,-4.588536,-87.589815,-94.640966,-7.199647,43.690104,-4.793472,-125.599606,-156.305076,-230.9314,-289.594312,-292.808194,-191.519971,58.23616,106.50698,57.920764,-84.21703,-168.713846,-302.340151,-301.634413,-164.288513,-36.361179,-18.847324,-19.625175,-15.303682,-52.928498,-111.994733,-197.763192,-173.371678,-36.965198,25.858158,12.773356,-34.688408,-63.128566,-92.352332,-57.454723,62.19242,70.509351,41.609526,37.187,66.416336,51.846835,-19.677132,-152.768503,-150.866364,-47.205158,-60.45456,-115.258037,-158.934186,-165.424444,-204.425083,-183.982199,-28.822842,126.394863,175.58569,218.379232,212.798693,159.864567,136.396414,148.476116,164.12889:-110.249842,-81.528908,-83.703686,-112.99398,-126.367341,-191.69369,-228.509263,-230.783121,-190.714524,-177.741194,-143.871853,-129.330124,-187.820272,-242.856994,-256.16619,-214.841589,-146.132276,-153.880016,-167.437514,-192.695878,-217.708738,-243.289596,-200.441366,-63.416708,-38.09864,-64.765602,-110.89121,-117.437606,-151.685713,-173.384173,-117.657939,-44.014537,68.358406,52.771319,21.739613,-3.781465,-13.711392,-89.910713,-123.121088,-95.790745,-15.462063,16.738227,59.504194,57.185331,-15.911426,-40.81044,53.644286,142.411532,245.459424,210.911777,166.832383,102.560684,110.295079,154.46195,145.159811,87.56007,113.613084,158.205367,230.438971,233.428098,133.340128,40.590901,-83.237,-77.091208,8.25654,104.14978,143.869026,198.152013,205.424522,179.066044,151.079581,122.388077,172.923234,163.613729,43.575902,12.009253,56.786505,75.10781,63.813177,59.106535,99.671864,217.911576,267.495689,220.742092,125.528584,-47.708162,-75.587122,-27.753288,77.724505,99.856879,41.561763,11.416357,31.003329,48.688761,59.497921,86.395478,193.630152,241.955461,231.801069,204.52174,189.506974,158.918104,165.301978,182.220468,166.830391,181.545179,189.278007,139.207816,32.445516,45.456401,189.53082,257.299083,317.667101,287.796883,238.212371,123.248019,69.471173,18.912944,51.004668,146.755115,163.188717,161.728091,130.940644,77.985267,-52.701954,-82.96366,-47.099094,-21.816077,-22.933727,-68.135234,-105.129965,-182.956697,-210.570258,-252.106917,-275.392396,-283.1438,-171.041896,-93.226283,18.634219,34.627263,-21.561343,-59.093701,-26.287967,36.696847,116.088819,88.921916,84.879828,108.67052,88.44986,15.447283,20.32911,99.742241,161.270491,177.968004,165.908206,99.385972,-131.438507,-207.854924,-187.3005,-141.279242,-59.868013,-30.031941,-71.501465,-232.502828,-307.187475,-362.68044,-332.992099,-222.187293,-99.085102,-61.687518,-85.024093,-94.21295,-19.790174,40.563606,129.305845,148.473563,178.339819,225.442303,234.220319,162.516224,88.089875,-32.78314,-45.411066,-2.801484,11.039067,3.826072,-15.033453,-23.885547,-15.358987,5.458917,63.649512,91.205223,137.978442,196.772781,233.195524,257.622785,212.327934,95.53516,84.375087,157.052838,278.454999,313.939094,295.132431,274.345013,230.051656,196.781373,168.417056,193.234059,298.756173,356.528208,332.00405,231.353517,168.491008,49.252651,25.478572,79.552286,203.518824,226.713006,167.657269,139.979413,123.533435,105.230644,79.345538,110.219277,197.198858,144.118036,95.660565,75.557491,73.11191,6.102902,-19.562265,24.28224,64.502764,39.903567,-10.568188,-16.018227,-34.760019,-51.456627,-103.276852,-134.71617,-121.741927,-3.048317,34.899587,-54.012156,-162.785523,-296.690914,-273.717256,-166.222022,-68.214004,-19.962556,-0.214941,-23.05002,-7.813252,27.091598,43.655797,38.663663,52.229933,43.192425,27.996919,13.210499,15.157455,18.954968,13.361105,16.557696,122.778576,187.278124,245.834884,233.30692,149.669112,114.342776,117.852417,148.558688,237.474944,254.313146,213.579719,81.520958,10.163766,-56.628014,-44.099331,-8.501249,-17.819681,-51.133798,-113.059659,-109.44845,-124.827331,-159.687694,-142.989485,-87.970437,17.018163,104.608371,123.318113,69.962554,24.412142,-14.199039,7.28816,56.664581,58.909803,54.209169,37.654195,32.772582,9.193557,-5.021433,29.650517,74.765021,180.096867,235.341854,215.003378,120.766518,70.48929,13.713188,20.690913,104.194527,247.754059,287.83143,234.21748,179.213842,105.772588,82.134708,21.753067,-13.376678,-34.665322,21.761581,48.106853,36.929691,-16.207494,-149.709477,-179.803892,-138.803255,-76.891229,-71.269695,-86.538771,-87.20773,-127.023874,-185.295682,-223.969871,-154.928807,40.209189,86.041045,44.421607,-61.148692,-102.425804,-147.259568,-134.290614,-18.756726,47.3448,15.007734,-51.155971,-63.161992,-167.42752,-255.492832,-286.255593,-188.539803,43.290291,40.611751,-32.502235,-158.252512,-208.883299,-273.42302,-244.015168,-105.098255,23.900005,57.836764,39.794285,28.056682,26.275334,13.51517,-24.196589,-29.918491,-8.781332,1.179437,-1.77847,-20.680183,-45.335741,-82.90913,-65.484347,7.154801,-17.24004,-76.60309,-146.104316,-113.963943,-32.515547,-32.046658,-58.931617,-71.29791,-120.169123,-155.121917,-154.907976,-155.206717,-189.695926,-298.118046,-301.939259,-162.776575,-8.252595,24.29822,50.128476,62.474957,65.432069,61.318948,40.785072,23.682243:-141.722381,-81.437611,-75.424302,-87.738309,-109.956585,-209.273154,-239.014683,-156.001231,-53.54082,-63.651272,-125.217066,-138.663965,-190.286246,-232.232075,-228.67249,-175.190298,-94.788275,-162.704679,-212.481456,-239.920676,-240.381972,-244.359837,-219.378131,-130.527193,-99.156146,-127.371641,-211.038058,-221.967722,-210.93284,-208.312031,-179.156387,-156.349934,-91.526636,21.762593,58.68019,7.623432,-71.094514,-201.64827,-194.789939,-44.47582,106.920889,132.579787,75.838944,15.318817,-60.68262,-39.486481,76.401834,135.609611,198.767677,179.543497,173.951144,165.953344,145.584406,115.263185,121.132132,136.344477,129.099747,122.250483,128.270799,140.781362,97.538041,34.907926,-44.786154,-26.904395,67.602613,113.565624,105.250163,59.97854,56.006181,142.165119,194.203675,210.789222,173.512733,147.657342,53.54286,1.227796,-44.757759,-41.915911,-7.464471,37.348256,176.01739,248.913562,234.172976,168.218549,128.014115,53.367714,31.79386,-0.476008,19.23213,70.606819,172.216878,170.176876,35.402154,-42.316306,-59.635273,5.390018,164.695415,209.584449,186.992203,172.557292,184.443035,180.028621,179.050372,176.986941,129.152791,111.231643,90.959124,76.497055,52.370228,62.776731,144.010679,189.541987,241.348756,262.725605,265.893414,180.811279,73.259989,-96.723653,-83.970843,52.971434,129.986401,124.559009,29.351412,-48.709458,-182.10647,-194.354018,-121.329895,-83.862426,-51.615139,-87.434468,-142.754785,-293.609401,-368.326461,-414.320653,-360.245807,-254.581416,-248.790356,-225.947223,-110.827469,-51.310302,-19.560654,-49.781609,-97.297543,-74.457047,32.625674,44.487422,3.449817,-44.256226,-41.326144,-6.084616,31.175855,91.251,99.964808,98.571604,69.92726,35.195323,-68.094322,-117.24017,-143.261337,-109.526702,-6.693633,6.54502,-19.922362,-85.460074,-139.485403,-252.919732,-257.76777,-149.095289,-15.582973,23.885715,19.422369,-11.903479,-53.175515,-24.074586,132.266927,197.063641,206.463679,177.110912,184.652098,156.641725,89.366811,-37.488083,-56.746245,-49.834819,-11.291439,2.589331,-9.280247,-13.564503,-5.122843,3.414558,74.392822,127.568453,188.706561,213.266778,217.448225,162.083768,104.381162,48.186996,94.108864,255.486469,350.690858,357.932348,341.478106,326.950359,250.240511,214.454622,253.147525,300.353011,326.378126,276.694415,247.905779,184.440809,157.743945,184.976462,231.545741,275.08559,218.471907,173.833746,120.710954,114.899829,63.73421,27.150517,42.477372,90.811482,182.619649,194.757807,189.423213,213.114195,210.449254,131.10272,88.21468,49.32056,53.830527,62.738915,64.303674,43.909853,-38.900643,-67.863067,-51.392363,-29.792767,-6.716773,-14.964703,-29.509587,-85.682983,-117.935814,-138.900631,-126.160964,-72.406742,-7.817665,12.461293,16.930061,5.806142,-10.773438,3.869722,95.191518,145.870605,163.992143,50.060844,-9.108435,-43.294113,-40.035099,0.196155,57.829853,192.856943,269.818319,284.867708,294.880312,280.533304,169.195928,116.192974,133.508342,164.705621,196.020022,187.218301,157.076703,108.33442,109.255451,125.223863,122.935384,88.840163,76.005889,77.643087,19.636566,-45.707505,-207.148478,-254.06092,-164.616983,-63.710119,92.746553,163.951297,177.638801,123.565777,60.558555,-15.864635,10.55711,126.546869,194.854162,188.648615,127.745106,110.187006,85.672065,56.795399,10.188133,24.490706,144.431169,232.79857,214.680937,103.645579,57.117102,45.33476,66.84569,125.708587,173.225973,173.09781,155.894671,153.921818,75.963085,-3.682008,-80.613195,-58.877029,-9.407647,-25.793509,-44.856169,-86.036031,-98.316424,-80.336459,-76.558,-125.689142,-108.664305,-64.554267,-13.277534,-29.351461,-155.256856,-222.014339,-199.318268,-114.296964,36.532248,33.467903,2.384472,-70.983055,-127.504133,-190.000155,-155.519881,-53.905149,-24.324849,-38.562346,-114.204614,-158.646413,-259.616506,-298.784663,-216.900421,-98.448623,91.953499,72.703616,29.497541,-49.117163,-102.195418,-189.29511,-175.903874,-27.241516,123.622396,146.695722,109.66295,80.243787,19.579362,0.373232,32.721835,74.248686,148.60028,178.68803,154.912688,-10.620576,-96.720903,-95.700605,-32.485132,29.416606,-46.301751,-84.77163,-91.600737,-65.662214,-41.925652,-53.35202,-24.153761,16.471764,24.513723,-77.157246,-128.178215,-177.803242,-181.603959,-200.191802,-213.466859,-171.952976,-26.809469,28.345027,43.931276,20.275546,-54.42268,-93.192316,-140.557725,-132.352077:-251.618998,-278.423459,-313.187675,-346.077093,-342.673242,-356.295774,-354.241368,-300.739982,-225.512807,-180.671128,-75.903196,-34.934565,-39.277458,-73.750242,-105.683192,-87.129706,-74.490894,-194.714885,-250.145856,-199.329225,-137.653869,-135.072255,-161.938301,-123.233122,-98.947889,-137.371302,-229.942244,-243.441758,-204.738816,-190.00399,-214.514758,-227.328491,-157.650135,-13.283008,4.653073,-91.810991,-142.338234,-149.552062,-126.177087,-73.758703,28.345068,81.532017,125.976574,133.4951,170.322781,181.223494,171.753169,197.02607,324.541316,354.2746,307.427826,198.771424,173.795502,190.391934,204.73755,174.292968,119.45337,130.759071,210.325917,226.140671,102.028694,-10.620004,-133.664033,-118.61384,-37.503815,26.492174,49.647471,88.284336,104.704726,114.240634,95.057497,14.690698,-26.352628,-17.557476,-16.179364,-29.48006,-57.865856,-76.14795,-68.992565,-9.802465,152.653837,231.884742,224.506726,139.322213,99.700684,95.684257,104.896746,77.149744,71.470016,80.050604,41.28215,13.298754,-0.444364,1.41718,58.934356,125.030319,212.931413,193.544637,191.294529,229.104367,234.362071,192.626632,178.298367,179.455748,197.035543,230.892552,312.042351,303.82237,140.332401,58.012658,67.896261,129.333867,220.909716,282.29135,317.1895,328.984808,289.181402,190.613952,175.695123,235.443501,282.802258,264.494063,178.815934,123.642869,3.678839,-29.520549,4.221742,29.191306,11.035738,-94.782508,-159.936137,-232.699026,-276.543139,-417.349451,-420.465106,-263.054093,-176.907727,-167.281207,-92.540908,-32.203825,9.478736,-10.788127,5.239863,39.191462,65.763895,106.157029,130.895464,104.709452,51.328216,-62.320468,-86.059649,-53.108172,52.88962,111.068946,108.110949,30.868537,-133.046885,-151.509926,-67.733592,-26.704908,-20.695157,-26.343229,-20.923612,-38.10378,-80.018948,-188.731068,-201.313063,-122.220621,-56.587078,-71.020497,-127.288889,-111.462648,-10.835678,35.023697,133.954832,183.074783,217.014956,238.351567,256.794993,217.29154,157.384633,59.715697,47.932514,77.329375,91.321511,55.938829,-52.191939,-59.14293,22.324305,62.438758,135.722121,173.069733,231.681466,260.144628,240.331904,144.840542,99.578622,78.721461,116.186971,256.689824,367.78163,389.506963,422.99917,452.919205,439.682679,382.21919,344.766873,387.954146,426.681612,343.613214,307.802895,275.33373,246.244074,136.494677,108.269882,183.841431,253.646033,222.286636,135.486249,136.822052,149.792051,131.109361,134.674411,163.704598,193.947505,180.213218,191.812513,250.53563,264.477056,231.727164,203.062153,170.627405,160.11372,152.093614,121.133232,93.198345,1.905648,-41.339673,-69.865854,-54.994101,28.96427,93.051169,79.005119,-3.078479,-56.668532,-146.982927,-136.065152,9.118715,94.78002,81.242767,30.932622,12.18703,8.169647,35.109011,136.485121,178.09204,162.060638,84.926017,60.661985,26.64184,3.477951,7.974093,56.378209,177.427127,231.777313,222.720332,172.394155,146.341499,85.295301,57.676768,91.782137,151.704526,215.566051,135.224844,87.934471,68.671848,69.193893,9.559489,-30.941586,-52.009077,17.460516,47.376328,1.932687,-57.383776,-164.502711,-209.403973,-272.705983,-263.08852,-115.99434,87.493634,150.70298,156.794295,108.627352,15.809044,5.379756,4.779997,6.57174,34.516501,99.354721,106.628365,53.430268,4.231755,-56.288368,-48.41623,-4.222391,40.166008,46.423907,-14.932835,-65.813409,-130.933066,-118.653977,-3.89388,141.722943,160.686655,33.560106,-46.623346,-88.722912,-68.193001,-102.621752,-159.981093,-169.573741,-73.31014,-69.858134,-113.297178,-140.349254,-235.630464,-262.701363,-187.721197,-105.545946,-109.639532,-155.225874,-174.510073,-233.20438,-280.841021,-321.669776,-283.132993,-156.399432,-120.313023,-135.168293,-159.201282,-173.308985,-209.075065,-207.262027,-143.629511,-48.171212,-34.131178,-134.670327,-211.399219,-333.368067,-365.626558,-288.094965,-174.537366,30.29768,-14.871784,-100.252893,-189.69866,-197.610098,-254.15305,-277.601881,-223.377376,-102.142293,-57.353864,-25.876643,-25.451841,-50.83912,-77.48333,-100.574623,-77.050331,14.355522,38.486112,1.46806,-107.573262,-153.436869,-162.118952,-126.535925,-83.988618,-104.349742,-104.18375,-89.199431,-78.364322,-43.182728,-30.441451,-32.441572,-42.543186,-31.47896,-4.457896,-39.000489,-128.511248,-139.029783,-158.442921,-165.806664,-67.817845,98.650609,136.303096,139.094205,136.97183,103.459867,75.898345,80.29222,99.168524:-202.400803,-266.606617,-307.838008,-310.884166,-289.198207,-280.601737,-280.321306,-219.502245,-99.507893,-47.858724,6.041998,6.712639,-44.25408,-83.270684,-107.786251,-74.891994,3.252638,-52.51329,-124.920833,-214.509317,-221.810529,-214.024241,-181.009438,-59.720577,-51.079067,-105.332646,-182.623977,-185.584187,-224.881658,-270.290839,-292.998563,-241.467085,-68.351881,46.056421,32.009283,-97.751174,-172.000703,-250.493591,-226.434701,-85.093705,72.239547,98.512887,44.972214,35.693354,77.780099,95.534392,145.118567,179.781493,248.909565,279.467409,247.257988,148.711588,133.484839,170.834486,177.253644,123.595254,114.526298,139.138999,160.180535,142.645298,18.933442,-64.405338,-147.474095,-142.892112,-57.292335,48.65574,55.403374,24.301556,21.314168,60.719081,82.946528,76.428628,71.159694,81.64478,79.074384,55.615972,-14.552389,-55.248346,-116.188034,-96.879016,62.550524,194.377505,196.80504,127.323841,87.67586,52.344271,50.694391,49.33396,109.638848,154.982258,186.95659,159.943072,28.221326,-37.739587,-40.371897,27.486437,184.731946,234.579467,227.97029,214.392637,195.413018,111.146993,80.007797,104.647839,184.140694,209.265349,220.297453,215.18114,150.279972,100.966979,100.222803,149.635167,231.054285,267.600456,269.235718,213.307019,164.695839,105.497634,118.183525,186.340452,204.682218,175.146665,54.95515,-9.28916,-81.518145,-75.87435,1.734736,34.224659,1.426599,-95.650187,-147.055773,-298.632533,-394.807423,-475.407008,-432.576534,-322.254108,-203.734512,-123.924482,-20.507576,-14.243206,-62.335865,-95.982718,-108.557352,-72.463941,18.165776,40.826302,30.028475,-34.777516,-90.723322,-160.875565,-136.489082,-32.382608,68.484326,117.364437,105.368587,33.828867,-118.091688,-138.509467,-42.838946,20.15078,89.820571,96.942961,70.062678,-45.798193,-115.336624,-195.148137,-188.730297,-109.648941,-16.315857,-9.261689,-52.622891,-55.207017,-16.355862,-2.232587,26.540762,70.153715,218.366712,265.246374,226.316991,111.366807,42.374452,-65.858071,-62.846329,7.171111,-2.104966,-38.821137,-115.022692,-128.074509,-104.571881,-88.250957,10.789446,107.541897,272.354022,249.554215,176.20055,57.570559,40.560784,88.657898,162.073445,353.164288,483.04249,494.898184,445.468615,419.083848,365.651488,348.607621,390.026316,408.990748,376.110905,350.013643,333.697448,235.97657,161.782731,53.929017,53.042785,135.291837,208.873642,191.328085,91.897248,51.940289,-20.580594,-39.669308,53.58479,142.514897,269.873605,254.698773,215.368555,166.423321,154.553151,104.885147,77.318555,96.295749,202.430808,217.649287,109.930048,29.194681,-78.806137,-93.631437,-84.491249,-71.285857,-14.315085,-4.951716,-25.696086,-36.068252,-59.380915,-190.776164,-221.923318,-112.057994,19.448056,34.271852,-8.340884,-44.473545,-51.260071,-2.159667,123.318071,175.53427,246.929631,209.240159,163.544055,100.596224,73.514483,21.594584,30.21639,164.822561,314.709733,308.904092,157.02697,73.210118,-16.613244,-4.529429,81.040527,110.586704,138.275938,134.812642,112.492926,53.085679,21.739142,-29.164636,-47.641631,-40.450707,87.221782,131.677884,1.135222,-136.528599,-302.751651,-302.169325,-241.535417,-186.247377,2.833502,158.431026,166.058464,71.51308,25.362224,28.030165,51.997707,65.508636,104.772743,145.076602,182.262068,162.385853,88.026888,59.898691,54.163221,73.133272,127.297442,129.685794,92.236814,-14.073123,-54.876042,-38.856101,21.904572,163.708021,222.962757,192.117166,53.429478,-8.579359,-84.386675,-102.596885,-100.281099,-87.737752,-57.59561,-70.09681,-95.209212,-114.539489,-116.065782,-140.197709,-131.988679,-55.092307,-30.285175,-52.450076,-94.886884,-114.232973,-217.743244,-272.517406,-267.683175,-221.032061,-84.556961,-36.420174,-89.284825,-221.350574,-269.741801,-284.733171,-215.604765,-14.209659,67.192218,49.92824,-54.082517,-118.192346,-235.540515,-265.971496,-215.600774,-147.116716,-14.679305,6.69117,-18.368606,-92.08464,-150.250497,-212.419785,-166.028936,-31.463715,-22.652498,-39.248294,-19.385954,0.824632,-37.487354,-67.844024,-24.524474,33.91727,140.214947,138.080672,84.653557,-40.47471,-81.28162,-106.411584,-91.267157,-19.190641,2.169827,-28.788891,-115.663621,-127.965563,-87.192293,-72.179305,-59.491653,-47.332386,-14.655201,-26.124134,-63.429713,-153.418331,-186.250765,-212.402029,-209.842606,-142.265716,50.842356,128.524059,116.013008,57.988913,-32.124585,-48.47666,-50.189582,-38.291048:-297.493767,-236.003426,-213.614578,-236.24618,-268.389648,-341.188091,-376.588694,-384.390143,-257.468361,-188.295471,-108.94262,-60.837213,44.542136,50.159671,19.059041,27.853528,27.228171,-72.4329,-99.296873,-60.735524,-59.361289,-142.92048,-167.325496,-132.408111,-133.359747,-151.064761,-172.827963,-187.016208,-189.754666,-170.064564,-168.689248,-202.568577,-223.069336,-75.136835,-13.006365,-51.23548,-105.011062,-143.601472,-134.091983,-87.008233,42.87349,114.486352,188.373905,200.136422,231.12532,266.087175,350.999728,373.296117,409.260147,460.366852,443.714432,331.724056,267.83168,198.596141,199.495608,162.18119,77.069826,74.413796,128.780743,150.096137,124.606704,71.888867,-60.762026,-109.885241,-109.797649,-21.349581,8.312121,28.695866,25.174505,-17.919234,-40.917821,-61.289083,-81.379663,-80.390868,-20.600856,21.193246,-1.224849,-66.398658,-137.271863,-115.269979,12.912492,176.738072,212.629887,156.535378,98.236005,27.425423,43.432601,93.267812,60.448598,41.009212,-10.412409,-44.003178,-63.769337,-46.015564,-5.452635,-3.916073,-12.508874,43.770813,69.086796,88.66184,107.005765,164.517254,177.669325,152.459557,193.40128,246.035767,274.74579,257.222685,243.532995,229.711151,202.197921,219.677605,300.350177,389.716072,421.575221,446.416294,441.92605,405.456779,399.485838,423.88238,358.685245,279.738498,125.604339,73.421821,26.407769,32.36385,70.828641,83.401341,86.044517,26.518146,-44.665455,-197.866426,-240.338351,-230.291856,-180.560822,-61.230062,-46.699488,-65.842455,-11.389362,40.958306,36.112718,-6.484811,-41.290524,-20.813524,43.367947,72.207053,83.642111,79.205736,5.121213,-226.640394,-287.711915,-254.821887,-143.602385,-87.926797,-43.697287,-81.391454,-230.489245,-269.340651,-205.388566,-154.929023,-112.089036,-58.684653,-16.550506,14.16564,-18.240513,-141.158465,-177.827536,-174.415156,-180.386437,-183.11289,-164.749442,-150.420521,-122.499195,-113.024719,-65.382546,-10.905262,115.157179,177.824807,176.060144,106.556465,43.201744,-49.084202,-41.638344,16.694514,-14.127608,-92.562206,-267.442135,-266.270017,-135.752839,-105.553773,-63.751446,-4.573425,79.511861,51.595946,30.956476,17.409993,12.161794,2.106961,40.142531,203.415622,241.522808,224.580506,297.038242,353.769012,352.977952,326.640513,362.700174,396.648284,360.59824,240.849458,180.441173,85.417532,71.425108,105.048378,124.785921,120.339247,96.327651,98.562592,144.02793,176.251878,168.937005,135.333086,141.992017,181.134281,216.687068,141.128823,90.320421,102.874959,163.203103,243.42738,247.01102,237.320927,190.752367,141.408393,89.668612,121.591389,179.063918,143.00791,12.16424,-14.655201,52.530382,174.266053,192.853004,89.578099,-7.115104,-143.227834,-133.676181,-10.400329,22.970418,-27.524349,-97.433465,-59.82114,57.308809,76.198563,52.67102,23.006772,-79.169781,-134.153676,-111.480886,-49.890639,-62.634492,-154.643698,-167.741359,-59.392712,62.350108,62.231879,-12.882567,-22.162214,-10.59835,-39.891732,-87.484884,-63.591529,27.950991,91.579582,68.681924,-64.027521,-119.809371,-173.314118,-189.237723,-220.103233,-177.608482,-133.485432,-119.496123,-159.816804,-254.982419,-276.81909,-243.958153,-195.592252,-65.593,25.391656,44.433551,94.538093,130.227452,148.475736,102.341559,-57.488466,-75.281894,-17.83915,52.0499,25.778908,-99.427814,-154.615785,-140.241388,-80.054301,-15.912018,-35.598218,-33.202217,13.361287,40.250374,51.265288,44.228986,68.534345,142.800095,160.972099,110.105697,58.937097,-36.037491,-45.570249,13.871429,13.285898,-102.344938,-141.88003,-96.986167,-19.759167,-45.933548,-161.690474,-162.380697,-63.256941,-116.660112,-181.305251,-191.728328,-140.062611,-63.717347,-70.362805,-134.037123,-170.386224,-161.541251,22.400642,80.822614,4.320486,-64.142689,-143.895992,-150.149963,-113.755031,-74.974803,-66.333329,-91.843683,-125.511159,-218.21755,-250.176579,-193.380223,-119.440948,11.007719,52.147463,21.653205,-95.773478,-155.021483,-246.133257,-249.124522,-142.557807,-52.484182,-50.528839,-47.120226,-49.534656,-139.042618,-202.126301,-234.12701,-192.788023,-71.400241,0.607888,-24.595984,-162.118024,-214.344557,-220.559551,-177.91369,-71.439356,-57.226098,-77.448139,-81.554406,-67.649575,-75.261444,-83.076084,-44.540629,-2.863157,83.499846,63.154187,1.723946,-105.577775,-119.806545,-76.583612,-24.737414,111.930664,190.874288,188.964154,227.320485,308.961464,425.231686,388.288541,259.382592,232.343099:-280.722456,-212.113307,-208.75993,-238.891269,-251.220552,-265.953426,-261.405912,-206.514128,-114.974031,-71.910788,11.615907,42.984333,42.212554,26.695079,58.622812,98.881544,85.931388,-62.980601,-106.290201,-50.608848,-13.939199,-57.425701,-95.611144,-52.006355,38.446552,19.227827,-129.806908,-202.97737,-291.715203,-320.268096,-302.522803,-234.627171,-63.854089,9.999213,-8.278564,-100.590743,-144.481294,-162.167078,-113.968043,45.694991,152.866961,177.583473,191.721802,173.862561,92.424432,62.784219,117.415326,192.334599,347.918955,404.739702,378.828663,278.391463,224.755457,162.41507,171.04508,221.936253,234.609129,226.735423,204.51902,194.25356,110.123067,24.939557,-95.227717,-95.863172,-18.090622,89.643367,117.793834,92.344418,61.823358,50.151984,66.605441,63.558174,43.505576,48.561337,58.588968,47.851003,-48.393629,-127.084406,-194.501984,-132.202649,104.116601,251.301727,254.857051,192.463573,149.385037,55.15829,26.91211,42.362645,116.034956,140.545579,83.031337,11.191162,-129.798543,-151.537924,-42.728561,35.145535,128.229299,156.372983,124.810678,20.254625,-1.260477,10.075416,22.441227,56.047894,146.153691,200.566853,230.774126,207.977472,123.081202,88.099998,143.888797,221.33048,337.826567,369.464309,371.654075,318.294973,266.959665,216.368129,252.373882,362.514216,313.51649,244.840327,129.497875,78.428244,-33.06024,-63.712126,-5.311803,51.456666,94.617847,20.153717,-45.890228,-203.036093,-290.369018,-396.15562,-365.438506,-202.403053,-58.884836,-9.826704,34.680878,27.062948,-78.195361,-148.978953,-141.603563,-70.040835,61.233703,142.303412,128.988679,-53.644445,-174.211917,-288.903628,-269.348845,-193.796635,-105.002882,-55.97883,-75.362587,-143.430296,-231.071431,-213.775218,-114.567647,-66.665505,-0.980571,18.818753,-6.996772,-118.122345,-173.94289,-248.909512,-248.236356,-132.534641,-10.236066,-23.015011,-142.429145,-181.687277,-182.351082,-154.22508,-30.573135,38.54244,162.422246,248.062311,220.585133,76.393011,21.43555,-11.07081,2.395053,38.408548,28.2318,-3.416797,-97.300668,-139.686006,-200.554399,-200.697596,-64.058567,52.057258,226.514046,215.752994,160.053933,26.243822,-28.306712,-2.27985,93.610313,296.536757,400.271488,430.481308,434.407608,415.452072,373.949771,360.707294,383.217795,400.909178,363.943769,277.462628,244.688988,164.478037,91.706145,-50.807459,-58.793893,45.421521,132.495902,136.681758,126.08357,124.907458,45.356912,-17.565559,-4.53302,63.915066,176.014441,210.407425,185.986742,96.192578,74.413675,84.25219,93.839805,132.470922,167.884331,152.784351,78.484691,35.349888,-60.797268,-89.054843,-18.552074,51.84041,101.172462,35.139385,-3.797569,-85.817565,-143.46016,-241.889283,-216.861403,-35.348403,10.563642,-40.104369,-149.536163,-182.684915,-175.411027,-129.012406,3.606212,46.750034,39.980387,20.852578,21.082819,-21.390478,-63.130482,-84.196389,-43.45459,78.903138,167.786029,151.527148,-35.29,-134.586163,-193.992183,-169.020465,-93.843034,-52.959715,38.717166,50.857797,-4.13111,-133.541535,-166.207293,-173.742968,-153.672269,-82.19401,-30.544896,-30.645469,-121.32467,-213.720881,-389.33069,-413.94572,-319.313919,-242.627103,-96.127384,4.19446,22.549311,29.925932,31.251759,19.556759,2.565188,-26.791529,25.277982,67.264645,82.250598,52.80358,-39.812324,-84.474681,-97.878871,-61.285177,46.333495,103.709143,71.495778,-48.592405,-74.373461,-13.477561,49.856622,157.166032,210.232161,214.849924,122.848832,37.174057,-81.927971,-85.144226,-27.145303,9.733685,84.378189,63.707133,18.367433,-6.120012,-10.390187,-113.379386,-153.984624,-78.403214,70.189173,87.988366,-2.780795,-49.507656,-71.778571,-65.279813,-31.782805,-0.84345,100.215085,189.512009,165.658179,13.753951,-44.359783,-41.027141,5.338019,107.969729,158.6628,138.748813,17.833614,-36.656471,-121.70187,-171.680874,-168.783428,-70.479672,154.188295,124.139222,29.929759,-99.178583,-118.921204,-155.981103,-151.527617,-42.092424,51.499998,54.038198,25.919514,11.459264,-47.206133,-85.287002,-78.242899,-20.706892,106.936618,111.028673,66.813073,-40.713855,-83.8857,-79.991183,-36.67694,-13.77849,-86.313173,-80.164649,1.648473,8.669828,-73.283469,-105.985055,-61.731575,-6.114849,111.658843,130.416502,51.005569,-154.55619,-200.693841,-174.025595,-137.000525,-23.348013,155.555404,204.170585,138.13557,76.929477,4.233538,-7.023151,26.03673,56.800103:8.09057,129.716453,124.038807,62.525351,53.810894,36.325712,0.83068,-94.556481,-149.799424,-137.912121,-52.447968,-2.711305,60.214395,59.804012,25.786124,7.889713,-61.91649,-161.035187,-170.547563,-136.893011,-150.36574,-227.040581,-232.682818,-160.420093,-112.63218,-107.960148,-121.41399,-131.03643,-149.862417,-192.184669,-285.621268,-264.432297,-97.99483,47.999447,65.671762,8.517753,-15.92695,-12.121711,-13.242247,-74.671778,-79.795118,1.872371,203.264454,234.538127,182.287905,174.46629,243.324879,287.950957,357.564802,362.328283,316.176456,220.800252,203.551625,184.330094,183.867829,211.500284,200.569039,192.538346,244.506508,289.256276,304.356387,244.082604,65.338917,-0.503359,-71.751561,-61.307928,-30.464485,33.23476,35.933277,-39.793945,-84.15735,-134.667774,-90.805479,-33.917689,-0.868724,-37.887707,-105.16579,-111.563369,-103.278774,-95.269468,-8.159357,146.09648,182.557267,104.455675,26.297574,-63.390183,-49.695283,16.374791,18.958828,-22.991258,-186.685003,-256.675834,-258.141883,-223.04983,-197.333197,-199.24842,-173.437909,-81.478205,-41.345772,-14.029205,-5.584349,44.811615,82.613651,137.669757,172.039121,189.36927,219.209085,239.907692,241.57053,204.607294,160.623633,168.006086,182.879893,250.919341,305.829766,401.946445,419.563007,401.989411,402.385199,378.449665,202.84183,104.385846,-1.319689,-1.721773,69.515387,111.258211,177.662224,218.378192,288.892976,222.493266,135.640525,4.34973,17.956498,129.844705,162.52339,167.669427,177.855598,195.979648,231.654862,214.809816,73.101483,-9.122728,-84.496491,-99.715126,-197.193852,-220.732343,-134.802904,-11.096867,-86.177398,-371.501273,-445.781929,-396.512208,-303.265841,-293.791129,-351.845431,-390.783368,-428.467835,-427.495682,-346.900214,-276.643266,-198.698274,-173.456466,-157.177375,-145.064118,-143.048047,-126.127597,-119.81601,-139.694233,-196.717596,-245.703745,-363.033014,-385.577322,-332.245806,-308.437499,-317.748642,-309.32425,-221.088609,-122.29804,-98.350616,-107.273152,-147.559936,-251.650025,-262.356302,-219.157174,-248.033324,-284.873355,-336.055383,-353.947362,-371.120474,-335.462807,-152.883481,-70.52914,-45.00629,-66.0839,-59.266076,-28.698943,-9.887319,21.97361,46.645872,113.410265,109.830544,107.10455,174.230284,210.70256,212.984878,204.35232,249.282252,272.388753,196.943949,43.096276,7.217591,23.611316,36.085526,3.191294,-33.27476,-80.924148,-74.69364,-75.116689,-97.511274,-96.035283,-57.352837,-47.688205,-39.333782,-15.997499,14.631847,-43.297457,-71.976217,-38.830379,14.914315,49.474311,17.675921,-9.70528,28.255754,25.874469,3.216399,18.760132,46.408477,20.676411,-27.97209,-13.835357,29.021544,24.567488,8.813747,-35.602526,-55.704772,-101.1345,-132.833148,-161.073364,-92.054322,-74.762065,-159.94045,-192.07304,-117.840887,-71.141543,-37.216901,-43.997173,-121.514406,-185.390967,-195.954965,-203.25968,-191.385425,-192.054732,-216.297705,-237.047415,-199.839937,-188.369408,-210.482991,-219.553973,-218.195682,-240.622078,-334.312348,-364.242556,-345.061546,-273.212183,-273.034887,-367.541418,-419.773039,-457.150815,-436.582181,-382.316718,-335.897352,-302.936801,-261.635809,-271.437063,-315.853299,-322.997667,-248.0477,-184.17454,-112.738766,-53.449003,12.387259,144.854157,167.281991,87.785799,28.754325,-13.474711,28.43663,52.202359,1.895654,-64.885385,-128.074816,-105.238367,-33.910495,-7.597404,47.701691,74.432303,51.05098,-13.42598,-29.983581,-12.233072,22.655164,70.896043,54.429009,56.852135,109.498848,130.216382,63.619274,0.929988,-12.987384,32.433709,95.553485,84.261858,57.589867,-0.896452,-27.410996,-92.252704,-108.843558,-78.079514,-17.744603,3.215175,25.413223,43.789291,90.204681,99.185401,105.728597,121.076098,161.125991,167.13104,168.097846,194.991105,196.545508,109.462087,39.797273,-62.462366,-61.973843,-39.995644,-39.093463,-72.691471,-180.946432,-219.17328,-144.297621,-44.378414,83.128821,-5.494376,-76.054233,-135.691104,-128.32697,-86.375543,-61.258896,-39.673685,-48.464157,-47.739676,-31.595595,-33.100936,-104.086114,-149.20634,-158.928396,-127.084256,-55.447139,-26.454475,-62.285658,-216.71581,-255.231489,-177.772344,-104.062036,25.065978,59.992951,37.252594,-25.721634,-29.222384,0.325278,1.343099,37.694787,96.118481,189.170621,159.759862,130.040939,112.241727,121.965964,175.119641,216.549004,295.482733,339.251969,339.846929,365.953047,424.668359,537.928117,527.177688,369.064707,274.718324:101.181165,68.815894,33.649977,-42.371446,-63.20439,-52.645216,-46.678031,-100.545739,-188.60661,-201.339815,-167.206829,-120.432249,20.112869,73.62954,94.945109,67.627974,-49.742878,-156.153944,-148.580437,-34.940274,3.625924,-2.722716,-2.618087,12.33598,-76.673013,-138.621923,-166.662442,-134.093323,-98.493499,-106.750263,-94.444297,-83.240592,-95.729992,-57.227966,-10.077989,28.283593,-6.727581,-117.34164,-147.210057,-125.813252,-26.912331,38.918396,137.837486,164.996184,193.552354,191.60128,196.546666,220.281625,279.307322,278.101804,254.155069,225.213311,212.164643,171.787155,163.168229,122.549215,81.865675,120.281108,241.077432,273.1912,213.060346,116.598254,-64.70399,-106.552458,-109.394268,-26.029536,-0.234601,-11.489842,-15.854975,-45.358849,-95.879961,-200.846613,-180.758757,-141.129396,-118.570366,-129.227445,-125.544024,-124.12186,-134.243828,-108.965215,49.682394,192.829003,189.482917,67.063419,-14.224788,-152.03404,-169.221235,-95.623225,-32.385308,-31.428344,-74.742173,-105.690396,-138.063922,-119.932724,-27.843595,0.055856,2.522359,97.493044,161.184589,206.826985,199.874828,190.159559,200.488905,238.855411,259.503948,255.198422,228.662319,222.173164,234.155043,229.334425,178.828194,157.282963,204.409527,317.071117,322.136731,278.516821,283.225454,326.860116,339.962666,312.969338,246.033481,227.968903,178.387921,139.434865,113.87546,126.145434,124.436771,98.908998,20.776547,-60.92957,-102.491177,-144.96506,-130.587815,-100.3836,-97.24574,-42.490234,73.849269,115.958944,132.659312,109.444592,-6.283234,-92.645366,-224.675522,-233.695299,-137.782834,-19.778805,-13.570285,-135.33076,-242.416261,-428.038936,-447.415229,-335.595094,-222.832758,-201.075701,-216.046485,-251.728195,-349.337505,-379.695443,-315.27364,-247.509453,-176.391008,-146.844941,-136.112516,-188.263069,-250.509862,-359.272596,-371.278394,-329.470739,-371.082516,-431.070278,-454.564962,-392.878992,-251.69899,-215.525284,-190.844378,-180.302534,-101.967968,-1.556602,-9.388812,-93.089555,-125.507656,-165.623695,-179.613892,-224.219998,-285.271049,-300.94348,-265.163888,-216.013733,-123.0654,-104.634782,-94.454907,-92.609976,-96.102575,-71.619121,-49.63286,3.114311,10.974576,-23.881674,-20.948163,14.074639,-17.406131,-6.432162,139.055745,219.683914,219.809968,144.945853,57.573329,89.523874,163.946422,127.794455,96.16364,55.084246,41.991898,7.268567,1.661792,65.245836,129.012582,126.479579,128.959857,155.506673,197.151973,191.173527,183.109759,205.242585,252.979692,187.958163,119.073826,71.397891,93.399811,52.63509,-8.678947,-90.332,-101.089637,-73.81837,38.424644,73.670963,31.742526,-27.122853,-144.676967,-186.692989,-179.404337,-43.353638,-6.430666,-50.402477,-83.467298,-116.042873,-123.48686,-104.521234,-58.273388,-52.858074,-69.620137,-65.192292,-10.549195,4.451056,-40.328802,-81.740092,-176.882608,-208.142117,-160.462925,-22.502715,-4.850877,-107.683724,-160.615784,-176.347316,-132.676346,-94.328958,-49.139044,-74.814184,-201.172261,-256.942078,-240.457775,-174.836542,-73.455491,-77.926825,-90.619035,-125.991825,-167.693091,-292.830479,-332.793085,-319.590325,-239.442751,-198.633517,-221.851544,-277.085788,-309.978614,-273.793778,-191.855486,-170.924914,-137.242783,-24.392931,60.454128,161.076636,136.621454,26.743073,9.211914,24.621242,-23.572743,-49.908507,-64.051863,-67.293627,-88.427211,-87.314138,-7.818025,53.036424,139.404199,154.174592,115.116143,-15.625579,-62.055128,-68.357556,-38.031477,14.181822,70.681267,120.784395,193.861417,191.933991,132.603108,95.649295,52.957782,34.484209,-25.501794,-15.320488,21.779317,59.762276,29.102221,-99.250292,-130.176771,-89.787475,-93.318938,-99.267084,-38.869511,13.888908,75.113007,61.466052,13.69858,4.521904,10.450826,71.293614,99.497982,109.839867,105.167188,57.085688,15.59996,-24.121526,-41.926118,-65.110747,-104.840602,-116.539055,-156.145308,-187.458721,-156.320092,-60.417054,106.664383,63.884618,22.832923,-20.799047,-64.851912,-208.655202,-247.126235,-185.31559,-26.967524,27.302261,57.39407,56.653988,25.669305,-5.643064,-50.737712,-44.706498,52.679218,161.401568,151.910427,30.331235,-26.860761,-16.841686,58.972207,237.440396,294.501669,263.337967,161.592286,125.936288,53.737652,10.279153,-0.359408,42.730072,149.27732,147.638057,88.906516,-7.731284,-1.329258,65.319317,92.656561,140.607391,176.592773,182.760787,255.987642,341.374561,457.306446,426.545666,294.066665,276.359618:-185.912055,-69.849075,-33.39702,-71.464949,-104.314192,-147.682915,-151.056603,-122.632421,-133.332297,-139.681396,-66.33723,4.163996,61.611166,17.856546,-76.241096,-61.974768,-2.403107,-86.558415,-145.212128,-162.911277,-133.241396,-121.419821,-140.180481,-144.671378,-116.358467,-118.618539,-147.485133,-145.717628,-131.945623,-167.99572,-273.032289,-269.515177,-150.461175,-59.43375,-49.199733,-57.320974,-60.800676,-35.999082,-16.166252,10.381272,42.452366,67.407232,124.710186,157.065142,212.826684,205.419284,130.83464,126.840796,249.132928,357.05784,335.792943,225.700803,186.872829,166.288267,183.355479,218.635672,216.473903,220.440416,238.054386,240.352928,182.593569,105.702481,-39.067736,-53.537003,-10.377311,48.442548,77.661507,45.971427,-20.000061,-79.447321,-38.58162,58.288329,100.571634,105.464686,64.706911,34.117698,-19.130197,-35.960319,-20.29627,1.806821,75.161765,227.053161,289.461184,236.133836,133.975495,-5.467242,2.864347,47.210716,17.220523,-11.92348,-132.10053,-196.352471,-244.038947,-242.745346,-165.507356,-89.290677,-1.119894,-7.581382,-20.483377,-79.938239,-102.576294,-79.413418,-28.203616,102.316157,131.977264,134.738954,216.916829,266.913407,276.137811,245.263224,240.71253,280.773782,351.365606,366.693424,366.398062,358.121316,338.356563,328.61467,364.938901,382.675365,172.689213,51.11218,-29.752542,-1.089353,25.722183,16.122768,98.284919,169.937782,189.551109,117.686658,83.547621,-29.739135,-93.094825,-104.963039,-48.997353,17.448119,1.667244,35.70294,155.167751,178.394909,142.539363,107.059174,52.807137,57.805059,108.332278,126.510941,117.854061,28.222573,-73.710318,-297.464743,-356.570014,-359.764007,-289.588513,-259.847529,-266.146055,-293.702377,-355.164412,-365.829432,-285.787653,-204.797376,-51.406373,39.584359,51.171267,1.520255,-46.090437,-154.452976,-186.535777,-148.956459,-84.065594,-79.632243,-98.275005,-121.475688,-214.330598,-262.362972,-223.722912,-111.274238,93.893017,61.672097,23.881956,1.04494,-21.601154,-92.77263,-100.590992,-90.746004,-134.579284,-168.802604,-242.570338,-264.627544,-254.25407,-241.6753,-185.970414,-113.801949,81.476808,162.314012,126.566447,7.088545,-41.761464,-54.250782,19.443832,250.478072,357.413213,351.488018,273.263697,241.245939,293.938118,367.925115,485.669036,458.282425,243.296595,166.550832,182.743096,128.520724,56.265851,-65.845513,-71.524945,-13.995712,28.837368,52.246501,45.370081,-2.457636,-77.333924,-67.237867,29.232521,83.560645,125.457881,88.257994,64.618872,73.939099,111.370724,129.73158,96.402734,53.289713,45.518852,40.034901,69.71174,108.388245,130.679574,86.38221,6.825417,14.313562,67.388374,91.043125,82.027557,27.290827,-21.982171,-164.674372,-215.738178,-155.7452,-49.61413,-62.633286,-146.664645,-163.455906,-137.445032,-116.292839,-42.764627,-1.928444,-18.486021,-116.263749,-137.581239,-114.98673,-128.039298,-234.498938,-230.849059,-38.528148,18.808747,-49.827723,-169.715075,-179.554193,-162.185585,-164.249559,-196.574734,-198.957439,-152.356538,-164.593958,-209.509865,-276.52238,-281.454027,-278.60323,-276.111731,-260.252784,-213.449581,-182.515621,-183.6448,-228.175352,-340.149885,-370.228599,-320.173902,-255.701492,-114.339462,-0.627487,28.493593,33.118683,24.378513,12.268517,14.131082,9.781807,-15.079094,-5.664707,17.094429,-12.115456,-124.453858,-157.37921,-90.723635,-12.450035,78.818558,20.816067,-19.88421,-9.781615,29.425184,61.395039,52.321433,41.211836,65.246768,81.547373,91.609972,92.676836,101.642345,114.730456,165.001986,171.610697,75.475028,-71.656517,-107.413535,-98.168372,-104.031426,-134.058388,-105.487546,2.692096,35.85816,19.582225,-5.01441,0.597585,9.335767,7.746079,14.371166,22.975108,70.955382,163.054004,175.362242,80.248838,6.996772,-101.958321,-117.225315,-91.215171,-17.059661,18.526307,26.638058,0.656925,-88.547629,-123.126914,-139.572247,-134.5319,-89.152493,-53.379366,-74.057159,-134.795584,-149.107165,-148.403751,-125.16047,-63.949416,-64.632727,-56.814541,-38.184179,-61.788479,-121.935584,-119.594961,-47.262445,-1.148383,56.655359,-0.910321,-75.034118,-191.172208,-206.43137,-175.698477,-129.318306,-41.304901,-66.373391,-83.856178,-65.071126,-36.042401,-3.384803,-19.315046,-38.326079,-13.034683,67.257743,99.420568,85.67791,54.136516,47.428459,-3.336951,-23.923745,104.86846,352.110673,391.818555,283.750111,227.988787,208.248707,197.394628,112.919451,76.532411:left
-57.955449,-162.24772,-179.615366,-159.95312,-119.94074,7.262472,50.449995,13.057236,-49.200838,-53.537638,-103.668837,-155.191094,-199.387479,-185.627853,-148.569387,-118.862595,-23.463989,-21.24217,-100.025879,-257.673105,-275.648779,-261.260611,-258.974888,-226.084154,-142.232049,-114.581746,-126.979537,-129.658866,-63.333739,-19.120959,32.186536,27.247129,-45.906294,-106.295886,-117.133385,-166.624259,-198.304965,-125.433477,-17.474124,81.092047,-110.721767,-215.284248,-294.379189,-305.526364,-414.882569,-485.991384,-465.548548,-377.245382,-254.300106,-316.232101,-356.943964,-300.177401,-216.639189,-70.411083,-24.610133,-12.164614,-90.686527,-141.092729,-253.316169,-286.730133,-217.86506,-129.840625,-15.298627,-29.949335,-143.552378,-258.971286,-298.357233,-281.499507,-230.632535,-137.89672,-94.23034,-31.680258,-114.992466,-177.397078,-237.894634,-245.61123,-264.746086,-273.31689,-273.722123,-268.446911,-241.916222,-213.427554,-217.385566,-169.564717,-81.268602,104.489399,141.94335,43.981619,-153.031569,-193.265603,-186.58167,-209.480632,-337.035654,-365.929486,-240.655881,-161.006508,-144.841612,-249.593793,-300.803189,-290.644917,-232.171207,-146.738439,-146.125799,-197.643167,-281.12059,-317.498413,-348.054107,-346.900185,-345.894564,-343.432422,-323.429203,-306.292542,-169.93422,80.599028,143.090372,98.152102,61.201481,130.965994,242.121603,389.931865,299.838842,243.117296,183.992141,161.377874,143.647728,167.311346,222.157161,205.586898,108.331886,64.719197,41.767672,-45.313371,-86.148778,-149.932222,-170.765816,-202.589621,-241.216084,-261.369197,-332.863309,-366.347152,-349.084036,-302.090078,-191.543933,-162.705974,-193.608655,-194.922329,-181.655868,-215.493655,-241.010493,-204.473015,-139.913527,0.963055,102.583682,144.277545,196.850941,206.635614,205.664268,184.098465,123.502977,112.402713,108.430679,62.637742,21.856036,-28.755332,-2.582251,126.752265,187.347417,212.248149,131.841825,94.091912,52.875443,59.283205,125.97473,161.777663,202.515788,213.527766,259.370535,339.456422,325.816932,154.598592,75.742808,88.270457,161.394106,294.109721,318.151549,306.886659,282.965253,267.093189,217.84934,210.459766,274.721111,326.622398,412.22523,387.927073,314.496824,236.418903,292.609424,409.748747,412.403929,350.755086,206.308562,134.422306,81.594441,102.537983,185.207265,213.102068,213.601313,197.513253,165.609017,142.343206,124.614098,66.611502,27.047355,-41.289638,-44.505798,-0.200877,8.767041,-0.087451,-36.178866,-56.092181,-36.352732,9.969596,118.267076,137.179685,65.151022,-21.478133,-28.757621,34.440075,86.358339,143.642992,145.061475,135.273999,131.693781,140.520428,142.432704,121.742056,42.677191,-9.44498,-93.858935,-117.920913,-153.293913,-189.145183,-209.357733,-210.973158,-188.81849,-131.543649,-92.963853,-53.6801,-148.19399,-206.152654,-253.536054,-233.618966,-148.165721,-98.240161,31.470282,87.338376,86.304029,-47.321514,-135.523516,-257.172142,-256.012918,-146.529371,-81.875809,-21.964389,-32.470028,-44.98254,-31.130914,16.269077,131.766001,165.24797,212.100182,237.735478,260.689656,234.953213,209.042573,193.59696,207.388186,210.466036,192.76484,128.558487,-3.551562,-69.759657,-122.79147,-114.01124,-102.323843,-114.876615,-130.350615,-100.880723,32.597824,67.587218,8.276567,-160.496238,-219.18569,-190.25132,-112.015509,0.092284,-60.101404,-123.836968,-203.755362,-191.168866,-85.150008,-22.301836,75.288801,88.257692,12.352993,-129.30352,-183.875541,-155.483041,-92.967982,-20.149871,-1.52685,66.084939,147.400148,178.476334,172.85839,157.120811,142.45865,101.527958,-11.479348,-22.382145,3.2877,-64.60179,-119.094728,-105.643936,-26.447825,129.245985,174.406746,192.678391,69.768671,-22.865401,-145.309639,-150.03062,-72.560291,-24.519079,35.403408,36.997001,5.521934,-5.661857,-17.031909,-17.010675,24.652798,137.020197,175.015683,242.865434,332.828636,355.849449,315.559932,276.631191,262.763766,287.100129,318.118284,305.680804,252.828337,189.891427,132.448565,58.290586,66.583254,45.732092,9.874917,38.644012,212.361833,264.192462,200.815769,147.637288,150.893778,186.783012,185.177297,131.616694,20.484584,22.907968,41.613506,39.61061,21.678968,58.337018,145.336332,288.90997,250.782295,236.498079,253.223227,249.864121,215.227922,202.36061,192.81815,175.622293,115.204274,109.785999,124.979936,135.298259,131.055096,108.194542,92.62753,97.01827,210.421822,280.656581,286.240544,232.642438,178.704814,190.851115,210.78066,180.431531:1.649037,-135.210987,-160.581034,-107.566505,-82.553046,-89.410468,-81.727146,-26.876607,3.167927,-6.203642,-83.646807,-104.022232,-27.408066,20.85433,8.039074,-34.55001,-55.976546,-46.31543,-96.155148,-254.688652,-296.076833,-234.84497,-177.540719,-119.226701,-72.330965,-61.348759,-118.057027,-137.491936,-51.778307,13.32741,62.103186,48.63343,-27.766362,-131.586831,-172.70559,-244.686452,-248.946101,-98.334939,9.788394,42.755894,-171.844194,-255.249228,-279.549346,-265.342009,-268.161952,-282.165588,-315.074057,-320.467529,-270.434997,-222.636704,-223.218042,-196.275123,-156.386265,-66.833037,-35.536397,-58.01765,-167.873269,-215.105648,-276.021559,-273.55101,-147.748311,-52.048991,52.944131,27.430715,-159.931819,-364.885287,-403.084793,-320.953059,-246.938103,-155.380523,-150.391302,-200.880814,-233.809594,-240.044437,-302.378696,-331.851847,-314.160059,-288.704625,-257.82983,-248.44748,-229.930197,-272.404506,-320.819847,-295.731848,-190.230193,22.220377,68.310575,20.673992,-113.481383,-167.285605,-264.435539,-311.598049,-342.548388,-302.845366,-153.986772,-93.469945,-67.018066,-181.697457,-273.261177,-324.726712,-263.496258,-196.984785,-236.544178,-323.338049,-375.686138,-427.304022,-501.825118,-477.537299,-390.431409,-365.160995,-305.680914,-272.06669,-207.056662,-62.985662,13.395395,93.00263,106.37684,162.081641,239.805144,417.129059,372.476125,293.623683,239.68007,271.070015,313.324791,293.518453,238.084441,222.570113,183.131362,95.023596,42.257625,20.26882,43.564301,63.119547,75.372143,131.182952,81.159089,-4.602112,-155.027285,-165.45719,-138.097182,-138.335775,-113.535489,-91.873194,-79.794762,-158.516504,-223.23376,-245.9673,-174.407427,22.167232,86.009482,90.434025,63.510526,83.966041,124.907779,115.456806,54.508415,34.976679,56.508257,69.373453,44.395438,-24.986419,-71.630046,-118.387879,-101.857697,-43.561143,-19.893475,4.55664,7.850988,1.577695,-52.093779,-82.664463,-73.347497,-26.951349,91.559646,122.610022,125.520944,89.585775,55.947505,64.323736,111.676443,168.973744,177.891048,248.52494,358.234463,378.304972,327.348556,282.466519,243.031315,261.179166,310.883374,322.950997,322.749515,236.387717,164.69064,138.004801,207.166293,325.572126,301.150045,133.971951,57.792532,73.05699,77.342553,65.385302,89.523596,125.94715,216.641247,240.582978,171.266449,55.977403,60.803232,132.082517,120.639186,20.588202,-2.481051,0.092052,-3.346875,0.732472,-23.876667,-36.528225,34.180863,114.625254,286.770572,327.06422,223.504678,36.884599,12.524783,128.848967,217.895704,337.792042,352.425512,302.932094,192.879028,141.931364,98.786294,96.866726,7.264267,-66.66164,-117.1853,-104.57794,-142.442933,-260.902347,-287.124487,-240.566387,-201.062668,-135.275383,-114.64395,-101.860442,-151.948262,-215.339114,-359.378338,-387.752241,-291.92934,-180.525456,24.36916,56.629893,5.291706,-63.555224,-85.258406,-112.101068,-119.978363,-88.207889,-32.6624,87.482541,84.211939,35.584805,-41.300921,-17.154097,144.913584,231.498976,304.675437,282.384066,232.213964,256.726466,254.483337,203.212167,184.087091,203.980873,228.521157,223.271742,100.13523,30.936243,29.515317,79.125019,58.934683,-16.360931,-99.053028,-70.414958,34.992184,40.912358,-0.583144,-122.065795,-167.387484,-132.816089,-83.503296,-76.599522,-151.211874,-165.782056,-118.144455,-71.321417,-1.102173,27.208305,112.986319,130.677529,16.712575,-144.525172,-181.539354,-175.208791,-159.371128,-119.760771,-63.961646,82.629323,134.463021,138.823252,131.6832,130.742349,114.389267,77.848269,-14.27498,-42.105055,-44.846198,-82.613856,-123.509716,-55.066831,80.084311,312.693835,323.203159,177.465252,25.57692,-21.384386,-59.080091,-27.23265,98.694579,131.440001,142.977866,148.566491,83.014015,-23.634272,-12.928702,137.576104,218.61735,290.717021,285.656773,269.450445,332.034654,377.276777,424.972066,409.297548,329.606525,313.633731,352.152533,348.418818,236.329806,175.931957,170.081091,145.370441,144.631974,129.373546,105.674099,142.602852,271.577512,290.555231,215.34003,167.72703,123.653902,127.382516,131.150409,96.772094,-13.591354,-38.291215,-34.905798,-42.533183,-21.653322,118.176469,188.922159,182.571283,107.238571,104.198831,121.66873,134.592894,155.776922,137.205963,59.75231,35.555654,9.055232,-68.946016,-101.02123,-56.925291,-0.537234,86.378468,101.762759,55.078275,-49.641446,-68.514269,20.224486,93.228858,166.561444,157.333922,140.230879,137.021423:-202.241807,-220.950024,-216.53089,-180.358117,-163.034577,-137.443252,-115.763403,-38.241365,45.826797,43.224367,-59.598176,-97.317747,-72.938255,-48.403622,-57.902829,-91.26676,-158.407928,-191.722514,-213.643854,-265.933763,-257.493993,-135.012258,-77.45761,-59.019704,-45.486348,-43.173839,-84.588283,-81.301453,11.340286,73.759081,155.753501,129.970511,-41.083004,-171.159409,-182.766502,-156.875346,-138.30255,-43.299605,17.112402,-15.101216,-276.749287,-373.421854,-337.464092,-266.99037,-227.63437,-265.862885,-314.440707,-275.34146,-160.811079,-202.693786,-249.791347,-246.730879,-212.615109,-181.45598,-177.354458,-180.373468,-238.778529,-274.918757,-291.164192,-254.295101,-161.716597,-127.711109,-67.541941,-66.849436,-181.962587,-305.395299,-307.821943,-224.09933,-186.540818,-145.233938,-120.738132,-114.698034,-201.050537,-240.875046,-279.199773,-287.540095,-260.218899,-211.693118,-130.529181,-139.446496,-216.672535,-298.852142,-315.352225,-231.695646,-154.554561,-20.687654,19.704678,-5.629879,-135.04358,-195.918675,-268.348977,-273.855138,-246.16839,-214.908237,-113.867871,-67.827759,-62.508264,-190.831511,-262.281927,-288.88204,-255.773092,-217.501375,-232.215936,-326.802931,-389.066462,-382.63121,-374.197925,-373.571341,-338.000667,-305.514633,-251.928187,-245.855085,-234.742775,-149.02511,-81.628977,27.22496,54.830697,139.214685,215.227116,327.33517,277.800191,226.322581,173.779884,193.96534,274.141404,265.963047,123.905711,63.23011,59.087617,44.0211,1.921686,-22.568763,19.861492,154.317081,202.968478,135.973527,-44.780902,-100.155831,-161.544058,-162.447697,-55.857483,12.593923,50.95111,22.200439,-67.10076,-189.680016,-248.439298,-248.715585,-179.745537,2.798226,71.58527,118.504789,84.50386,57.98439,4.169664,-18.438662,-35.347067,-16.383566,21.339761,5.762747,-43.048832,-77.481423,-115.642174,-181.929818,-172.57823,-87.614572,-68.566925,-148.231414,-208.827905,-184.031684,-114.709548,-104.221787,-69.815946,-20.176032,65.376743,65.597969,3.599935,-82.308469,-101.860748,-5.147477,83.379678,226.30688,272.117754,317.53838,330.95868,328.563229,314.634702,321.400219,350.624497,366.716656,401.746596,400.009215,361.359718,299.51736,242.225283,155.949201,181.008905,296.56599,301.421588,188.941181,136.099277,140.455263,110.140094,86.586241,148.61654,231.150809,317.111656,288.980993,167.532518,80.989849,92.627013,158.77705,150.964054,44.638289,-16.46047,-92.405141,-59.163489,-23.544528,-16.675659,-24.920313,48.351612,122.393103,236.888599,256.778139,227.476535,119.398192,94.947252,214.68976,304.696268,390.05049,384.531029,325.521589,244.628444,209.108881,176.322113,161.889096,67.529499,18.347086,12.775568,24.430434,-37.320099,-164.244243,-192.482678,-146.867773,-112.071136,-75.36519,-73.194766,-137.432828,-292.218765,-355.006231,-354.039553,-288.493806,-110.889285,-32.839836,82.834597,110.373366,69.828631,3.130906,17.545151,82.191672,84.311666,89.670677,121.176679,127.18744,-26.410255,-97.338614,-71.159507,17.336463,206.778768,279.578072,340.569774,308.542933,170.468295,106.147364,132.663532,233.64295,269.605551,264.117932,221.659104,89.356186,13.568056,25.595192,75.951515,61.867129,4.355029,16.977536,66.409419,71.813613,77.499733,8.103122,-56.913606,-157.890404,-183.354318,-160.664257,-116.055304,-69.185006,-110.728941,-126.789546,-136.885522,-143.944329,-136.608075,-90.164567,54.51878,73.626482,-57.664697,-188.17508,-209.519674,-218.216845,-218.725915,-160.989231,-86.105621,84.038477,123.214367,71.682209,-57.926147,-57.824676,35.895882,37.447634,-46.397946,-72.522417,-107.029398,-203.846275,-246.615983,-180.065729,-59.077015,171.318338,187.325317,20.045343,-156.233855,-195.376513,-170.823528,-101.72822,70.182924,129.352382,158.218885,111.493907,-51.382336,-101.869621,-63.211988,58.500069,107.790235,216.309998,278.944457,324.257942,318.865205,321.269116,297.727066,284.356118,283.801622,277.798367,252.049272,268.601156,331.524512,229.346072,136.029367,92.242279,142.513053,184.970363,140.025674,43.171136,86.099024,107.786528,74.670503,58.448313,51.715859,52.087038,63.983864,55.477052,2.134709,-55.23015,-94.662898,-131.025424,-83.184998,101.923176,170.455002,148.212603,77.683314,62.139965,-0.357935,-19.761198,26.99079,34.679981,-71.45944,-129.353487,-136.378864,-117.872951,-136.057249,-150.23962,-125.564027,-47.733092,-13.490077,4.679663,-36.713192,-51.150061,-11.72351,43.386872,139.223337,152.313453,124.52971,97.753659:-242.714205,-280.674392,-268.62475,-220.723038,-199.847756,-161.919193,-132.980973,-54.380891,8.595363,1.170695,-103.474001,-157.835886,-166.124839,-128.836767,-79.767723,-79.184088,-75.773625,-96.530987,-118.291232,-138.338262,-136.060819,-123.050999,-102.422555,-38.377089,-38.467302,-74.155213,-127.087848,-106.888141,-7.039985,40.250365,104.012229,100.229171,1.968553,-101.686742,-142.670037,-221.333907,-226.692992,-59.680303,57.281961,75.001631,-104.304523,-174.028163,-285.482288,-319.641336,-315.981015,-304.548337,-266.559425,-232.623496,-194.123825,-255.072625,-301.816864,-275.960058,-190.505578,-28.481346,-4.579712,-84.009299,-206.838083,-248.715821,-323.141197,-346.570823,-269.905927,-165.04578,19.79234,29.958639,-109.853077,-279.151398,-317.826229,-249.285238,-167.7435,-17.718167,17.983211,-21.024121,-112.923501,-143.795589,-180.046768,-189.924805,-151.650747,-105.034188,-36.79252,-39.002144,-94.298905,-117.624739,-99.796889,-52.693372,-43.490114,-19.96555,13.791622,43.18332,-55.271196,-108.76815,-162.49299,-159.633908,-125.170248,-111.171919,-86.872671,-79.67654,-99.461069,-221.878333,-299.567325,-282.676201,-202.461763,-127.948616,-142.732126,-182.658214,-249.035492,-303.43853,-428.055997,-455.187519,-377.920781,-312.086768,-214.875082,-178.672686,-83.447311,32.858584,68.621772,83.812259,86.636083,168.683499,255.893571,406.565,374.09858,309.609514,181.111854,137.832319,123.854054,149.650697,199.545582,187.655715,85.277755,-28.008379,-62.208929,-83.708741,-91.262213,-121.789579,-132.849389,-195.319065,-310.104753,-347.938742,-393.04447,-372.403509,-218.943635,-147.125254,-83.069905,-83.440787,-125.150266,-121.889622,-108.686838,-94.800265,-65.822152,85.062778,156.759449,143.249151,85.675358,121.03201,221.291549,237.750998,219.513129,207.208175,193.09163,185.806814,160.621526,60.434127,-31.571296,-139.189507,-99.205134,94.281803,171.582929,164.022859,11.534687,-56.536891,-87.861506,-49.235448,57.714065,101.898572,164.539271,173.979653,159.570001,104.569481,65.815504,96.067122,168.587076,280.67516,300.305887,326.596311,359.626341,360.426729,327.689738,309.749771,298.80418,325.059292,434.045613,488.415173,562.962535,476.84683,359.699482,223.531889,274.3832,424.426757,428.407842,340.581771,233.481385,171.263223,89.648607,97.973132,209.764968,272.073934,312.81969,304.925307,306.478994,287.465856,249.830819,155.542313,100.205093,10.765606,10.596414,61.741005,44.381232,5.574881,-43.792249,-24.032991,63.849926,104.678526,174.610845,185.293432,95.319353,-35.540712,-48.223682,64.374945,150.275591,263.191535,266.934407,177.61952,95.44516,99.931982,145.911528,140.970851,56.907612,11.72221,-24.126832,-24.146118,-66.612451,-213.295266,-286.788001,-291.09994,-222.76464,-128.770579,-147.684246,-213.172119,-226.348196,-242.125568,-304.811835,-308.369882,-233.349112,-174.254461,-9.577372,68.970408,124.605678,13.979602,-74.739582,-147.746751,-103.800306,38.967449,89.025485,74.690568,-20.890566,-35.786833,-21.686823,-2.717874,84.573857,138.700915,211.794226,209.805039,178.709926,238.108293,263.146747,239.064131,215.86325,196.596849,205.945931,184.008355,3.773562,-100.280622,-187.70745,-162.079724,-73.732725,-42.1381,-16.329564,-28.079709,-77.940114,-88.968413,-103.216332,-224.593375,-285.108063,-227.103278,-139.384274,-75.643451,-182.307691,-241.611035,-289.643802,-261.356417,-141.121693,-97.681424,-99.140802,-116.827266,-115.30142,-137.661313,-187.581424,-264.781634,-267.265393,-198.374291,-123.157152,19.010564,70.59449,72.825441,-3.505547,-42.729534,-23.352931,-15.507372,-46.792989,-47.478869,-70.143677,-163.079,-178.300876,-88.526862,-15.930858,72.807561,76.880524,21.283191,-57.083209,-75.678799,-94.233302,-106.74534,-98.467149,-67.76776,2.049552,15.816397,-24.113846,-140.56905,-197.190829,-175.618937,-78.777811,170.878008,254.73407,267.691428,219.602206,219.025407,248.207718,265.77089,264.554196,257.522904,318.802093,365.22914,380.343917,307.234657,239.894313,124.087281,114.896529,134.204891,126.649528,77.49645,57.281253,53.496744,6.932916,-4.053711,73.537112,126.262756,112.689316,42.162081,-89.314577,-98.300638,-78.147045,0.616491,61.377417,165.962453,192.883673,186.338387,164.27035,171.192008,153.171787,125.338783,98.222551,103.270749,94.920758,53.494088,-65.163572,-101.818484,-77.724368,34.157328,82.707035,94.702405,89.712679,88.420607,90.7203,99.969825,86.168045,85.568526,166.122145,219.884452,257.952904,226.456618:-192.387183,-311.392285,-355.51489,-341.988188,-306.414849,-192.887154,-106.376555,-19.204574,-100.030053,-148.555125,-196.238508,-180.113567,-89.114406,-34.060389,11.055393,-29.028244,-171.506861,-229.714699,-204.505831,-119.310211,-75.424176,24.904422,46.893995,-17.152044,-99.420094,-147.284317,-240.604106,-224.934804,-57.9222,37.084124,154.065813,141.148644,-40.53934,-220.575328,-237.276791,-159.313531,-106.684904,27.0674,93.375798,74.345276,-128.921461,-224.317966,-300.102011,-270.447846,-169.958016,-136.740244,-109.487013,-123.720769,-194.38456,-294.928755,-334.340175,-251.44022,-153.803448,-44.67187,-41.699022,-67.14875,-121.057947,-165.156677,-238.04435,-232.757005,-120.602142,-29.112281,82.839449,46.24602,-112.332473,-178.830773,-179.227564,-141.417955,-107.735752,-25.407724,9.710663,-20.612632,-162.167605,-232.892205,-315.214414,-297.627879,-141.276893,-51.85282,32.064424,32.008463,4.169512,-88.789707,-131.713449,-77.61577,0.534762,119.311423,136.180518,77.778305,-26.899987,-76.556479,-150.463785,-153.066565,-95.660066,-42.453974,50.958006,29.116084,-130.876897,-269.465205,-319.330153,-322.879213,-261.186639,-131.868034,-119.791506,-164.339336,-194.528693,-240.466508,-407.932034,-448.483613,-331.841229,-231.895129,-90.699844,-57.251953,-30.702199,-26.849197,-37.2455,-27.42634,19.261257,183.531861,256.615002,305.991953,252.673905,206.178672,119.633856,105.851192,179.96447,220.613649,168.929006,92.271717,-27.938904,-68.848982,-92.099266,-132.678902,-126.56154,-50.866313,-14.217138,-111.491305,-375.469748,-448.070055,-394.091319,-295.215987,-56.08798,25.778621,47.749301,13.131777,-71.132278,-134.528913,-151.811497,-104.70776,-36.915678,100.223295,143.59353,135.151481,50.331727,45.103424,145.265266,205.332698,215.74045,182.780282,141.845859,109.966859,8.326502,0.593959,-13.186537,-139.775336,-173.482347,-47.725394,51.40536,109.765254,-38.292835,-136.529262,-206.782211,-155.277734,-16.863512,30.550417,65.704457,44.710012,-36.185261,-89.092752,-86.61665,-1.525696,76.500183,267.478046,336.757764,332.537031,280.367731,277.364037,264.162202,249.841635,262.986081,315.246738,438.689612,467.131733,476.89736,377.052734,279.638749,166.797488,190.385959,312.824196,357.26927,379.119212,331.001066,248.173695,44.410323,15.240607,153.503044,258.86241,366.032002,345.295404,235.326333,164.661957,150.702986,127.617638,113.474303,66.391406,36.486982,2.031875,18.782114,1.509251,-91.448287,-100.309955,21.021799,120.84501,275.279099,284.986412,165.509982,-1.257937,-10.879135,178.840394,292.426992,398.683972,397.89041,308.91752,171.230609,116.294485,102.146506,134.680624,155.395274,134.647859,106.600146,107.545243,48.225692,-113.08461,-160.375099,-141.114311,-111.174286,-27.394662,13.842274,-29.051817,-193.980034,-241.490899,-198.321496,-130.320756,-19.940501,6.812483,54.598325,81.550375,113.240351,90.459833,67.973751,52.023427,66.442373,155.562981,213.885363,194.154479,4.035253,-64.626354,-72.316513,-20.779335,138.215443,207.465698,214.203803,152.780683,47.890296,70.959904,109.662294,191.227826,216.375589,234.880927,236.099451,165.618072,5.418454,-69.92492,-148.317967,-131.237833,-28.539988,19.190232,45.325209,28.613019,8.229718,-51.56139,-116.398591,-204.98652,-202.100676,-104.30336,-30.000889,13.134204,-158.040306,-258.453279,-326.985126,-278.495243,-119.274494,-55.00883,12.566554,4.545296,-136.719011,-353.141289,-402.760998,-322.511722,-245.247839,-109.745668,-52.715611,25.736668,46.710812,24.148482,-86.85273,-136.049775,-150.988261,-113.914968,-27.298725,-37.201313,-189.141547,-350.522571,-366.813432,-228.146778,-122.168471,-7.586157,-10.829853,-65.585284,-151.624192,-211.212661,-287.569202,-255.71887,-101.152074,-39.710651,-7.34328,-15.273046,-31.794768,-112.826146,-168.796377,-160.211384,-71.749552,161.392846,234.359281,230.126023,189.319596,170.28722,119.878417,128.568481,221.970926,259.927272,278.30403,275.973593,257.046681,172.329958,119.765036,103.992179,132.206801,181.53884,199.82825,215.071286,139.722898,45.500555,-111.220681,-90.739736,58.419537,101.646867,74.128966,22.146257,-88.586618,-204.481545,-249.036165,-174.651969,-56.187166,196.883763,265.900701,203.857757,45.037859,-3.191817,-7.741428,38.959927,132.815656,135.868582,71.597939,25.386944,-88.86386,-108.129285,-50.845535,69.305002,90.877812,119.674252,146.244698,125.252905,30.822044,8.53216,27.734203,59.837199,137.760504,180.830928,230.059288,186.574431:-174.891433,-151.849763,-142.181567,-207.423846,-244.082446,-166.04469,-64.841181,83.018284,27.356073,-51.849107,-193.949978,-234.256089,-225.528373,-188.958128,-104.343963,-50.29468,39.097991,5.045603,-45.069601,-112.063253,-120.436388,-143.804408,-167.168912,-202.45651,-177.821963,-164.912254,-177.962753,-172.139541,-75.047011,-6.464453,69.014739,53.744485,-26.116501,-62.909785,-83.594638,-150.373543,-143.288525,-1.712222,64.04108,48.391474,-95.837102,-156.118257,-209.298661,-233.916753,-328.445776,-370.070349,-330.759874,-261.169812,-214.449546,-345.841673,-389.173713,-263.061857,-140.044087,-5.863327,1.608179,-32.878019,-128.794555,-187.159653,-274.825945,-266.393063,-152.128781,-94.38807,-25.425719,-8.097889,-8.006311,-81.657719,-125.024597,-138.181327,-111.008672,-45.137154,-3.107537,83.643184,53.553613,-7.868743,-124.036974,-157.097377,-142.25138,-88.1978,24.438544,37.187194,15.395551,21.595652,10.726169,-22.105809,-3.117033,120.065455,169.110292,136.332836,78.083459,65.009854,-27.622114,-94.180423,-162.563728,-143.710503,-29.37468,17.786735,12.387298,-116.41451,-185.348918,-159.391648,-83.029104,-13.692965,-17.185613,0.338571,-37.158682,-98.211871,-207.113975,-204.196001,-98.21709,-49.519443,-28.55199,-37.544149,-22.652378,110.441983,189.909439,200.603547,139.89309,126.795755,207.690736,329.041045,240.233821,160.888813,36.013751,2.727444,-35.665648,-55.327341,-93.255993,-101.450094,-89.982107,-115.888931,-165.786206,-253.145444,-266.981121,-302.700507,-339.069677,-430.108153,-479.811017,-484.368517,-513.691907,-517.230945,-430.430757,-357.76193,-233.593269,-193.939376,-133.314142,-77.073559,-85.897886,-146.102006,-133.083092,-55.779233,-46.195287,-69.939015,3.201025,88.294785,179.851651,156.173674,98.953059,98.505877,110.83348,98.947813,43.985958,30.714396,22.948682,-39.414884,-42.095954,104.083581,200.788384,266.477827,134.427398,42.312178,-14.058074,61.39571,262.436111,307.686607,279.781723,243.382699,227.595442,278.735329,267.032516,177.546738,155.57333,226.470963,298.921415,398.523916,380.26836,349.985178,283.083959,248.912847,223.324489,266.170955,418.961223,474.263309,511.14966,470.940442,414.685831,336.613599,375.883021,518.867174,546.232445,474.448749,285.394491,192.579145,123.208651,146.149489,228.18967,270.402439,348.639176,359.25334,289.262299,202.711437,186.261453,193.494339,162.219171,-16.121721,-88.296718,-78.95758,5.577969,21.627654,-20.191689,-55.263235,-89.156091,-64.940487,69.826056,104.67456,-22.701002,-111.310802,-55.296122,136.967651,202.059629,175.545986,112.510715,7.468847,-2.637092,37.243525,103.84308,96.810093,66.338879,62.36424,52.094672,34.176265,-31.066829,-74.760394,-106.334463,-196.221856,-197.430392,-77.795422,-11.031927,5.027426,-97.112367,-138.478441,-157.259187,-139.863474,-108.464834,-100.191578,-42.295277,2.918166,32.149877,-60.29842,-130.893852,-207.782278,-183.098982,-67.982351,-15.80631,23.634432,-23.696047,-34.785375,25.213022,73.02167,93.83962,65.222646,75.969667,134.407427,228.70687,225.729449,205.181599,150.099778,125.933734,95.821785,85.112768,51.264725,-69.071451,-138.820275,-185.623268,-172.70653,-169.535954,-189.104003,-184.865837,-138.113745,-0.954046,76.838482,66.492352,-16.9619,-61.472608,-113.915234,-108.083668,-67.370266,-121.837075,-176.559357,-253.974613,-245.231476,-115.523401,-44.708317,13.476263,9.743306,-30.301836,-36.022515,-23.769165,-51.884226,-76.376107,-14.368436,58.721964,131.294671,119.348052,122.800595,96.334375,58.22848,-27.928662,-68.863149,-69.134594,-27.982949,18.973414,-35.33301,-97.913171,-210.866973,-203.635185,-57.674608,19.302049,66.036071,6.366688,-41.472079,-127.284636,-129.659973,-60.326253,-31.956752,2.15612,14.333887,-19.817315,-116.378962,-170.857237,-212.374495,-178.011183,-67.085998,-18.910375,52.755631,116.487679,139.635536,125.41796,95.809978,83.287162,118.355754,209.410498,228.56009,234.862953,270.607915,248.505582,93.339762,5.607834,-88.16527,-76.577234,25.089632,114.950093,98.704314,-25.157323,-41.398605,79.311999,142.439944,160.297307,134.275404,73.7411,24.573543,8.703797,30.477649,69.70196,190.186709,261.799698,352.071822,351.911025,319.429767,197.552352,166.985407,198.055132,203.351395,145.072047,86.64589,-51.397006,-37.613294,35.87998,137.777039,136.14192,112.319994,128.149746,198.829286,233.760749,244.674678,238.44056,218.127187,232.112782,262.10953,244.073197,181.130606:-215.156073,-271.211407,-279.433751,-243.832148,-190.819968,-51.376638,15.788962,49.034157,-97.783463,-199.962627,-324.689259,-312.816254,-192.502531,-127.989747,-40.646497,-20.826495,-73.592535,-183.535071,-178.122283,-56.850332,-14.422653,0.274016,14.834067,27.850345,-50.387699,-97.046319,-146.559091,-129.833893,-32.630615,22.128223,128.751129,139.628122,-0.497219,-180.569167,-215.454376,-157.18015,-92.728363,51.910908,106.237177,87.425309,-52.263002,-132.248124,-270.60017,-282.604907,-197.20961,-166.930878,-169.336763,-168.132001,-189.765289,-307.521059,-359.98068,-302.107918,-192.383387,40.485472,97.338541,19.995065,-150.926655,-199.499314,-238.401763,-231.172151,-115.688065,-21.599845,103.210017,96.08068,-7.46035,-143.276226,-190.678887,-174.812335,-126.166781,31.885273,125.653136,158.182972,-42.935778,-139.743567,-204.833999,-171.050841,-33.756527,35.575933,138.511632,154.696776,76.475211,-28.947262,-39.47179,42.423177,94.950033,144.303236,178.41023,280.475518,205.365739,85.742289,-112.798027,-120.303442,-0.754666,45.888775,57.213509,51.004571,-0.493339,-156.069301,-231.123689,-198.805047,-102.398627,40.526106,50.121695,5.78781,-97.695063,-193.17583,-366.255979,-372.488741,-231.145106,-139.355376,-12.411061,13.572265,27.238631,22.992177,9.948059,-6.618768,15.839548,157.076095,263.217175,382.632428,229.568034,109.694341,-19.975999,0.795116,127.938258,164.541077,129.363293,88.32085,-12.402927,-119.838783,-141.053384,-114.44714,-99.400018,-123.095561,-176.243721,-368.171146,-505.913506,-508.992746,-478.063639,-460.576627,-330.634623,-218.583275,-65.432564,-72.212334,-153.591796,-134.368658,-118.780756,-134.590255,-109.657694,48.800629,110.080084,74.938794,-2.001473,7.015696,69.406048,115.658256,235.393665,270.303446,249.39793,219.683295,146.307362,29.375804,-28.083644,-64.508541,-19.191954,159.307676,230.588876,237.936946,63.786021,-56.919597,-149.967194,-68.453275,159.175633,213.258254,236.593268,237.038215,182.617514,67.177364,25.491672,34.855109,96.217745,291.5269,379.200348,435.606439,336.739497,270.818621,195.033025,191.115915,225.150902,267.164586,391.579454,439.923555,460.396718,337.150047,241.771624,196.59893,270.168977,427.015338,449.291685,411.264771,296.373459,170.882367,-88.726928,-104.009759,91.988081,205.725405,345.786361,355.618279,236.147896,79.797326,40.947674,18.614783,-3.966591,-59.025359,-44.246137,42.04941,10.917089,-50.214607,-102.579376,-81.48354,-38.24509,13.593073,210.816188,254.838225,106.620128,-78.636631,-88.003586,63.172511,168.632916,306.068434,321.587973,232.487728,88.739112,59.443153,38.899536,20.283345,30.345144,75.546882,166.421719,170.817531,65.821664,-127.006707,-201.927336,-171.5865,-85.936326,55.20476,79.481248,29.643028,-127.052817,-206.916898,-231.666742,-161.58086,-28.314908,-3.091606,57.252263,85.476017,59.781638,-28.046666,-64.526213,-61.602699,-20.828357,75.808122,93.023325,24.559585,-27.610276,-31.489528,-80.948449,-92.029662,0.761877,85.210476,227.984166,229.53568,111.742917,58.436435,67.639523,107.856427,131.025712,184.050329,209.076236,137.290041,-113.402576,-233.866676,-356.891318,-337.698822,-192.639089,-117.5818,-6.494415,20.930208,-24.05636,-125.474462,-149.580664,-147.126277,-146.742064,-127.633546,-82.584276,-21.031202,-140.925556,-237.835832,-374.686662,-374.981342,-235.501207,-141.531608,-20.02082,-8.845947,-67.431503,-202.535488,-264.931487,-288.833967,-262.55382,-166.602488,-104.832207,-51.729661,-129.034625,-164.906999,-160.514175,-132.179069,-63.291315,-20.961745,47.27459,15.105455,-205.783949,-356.650702,-349.297144,-251.336137,-188.691245,-43.878819,26.364149,61.396596,-66.899081,-132.171244,-176.348051,-150.686161,-74.55425,-50.94571,-5.810794,13.658732,-25.521309,-149.837283,-188.11653,-132.930371,-68.173151,42.254557,88.982071,152.393345,137.941669,96.956499,-1.000081,-19.16745,41.500884,109.807053,219.098424,214.105963,169.704726,189.428743,166.312285,49.142017,5.232684,31.405205,95.139603,167.804552,54.662783,-35.364511,-132.448112,-102.764783,32.719854,89.534121,144.398163,131.106889,52.25492,-10.762366,-31.731939,-1.64294,64.184723,252.333038,333.643867,342.595856,211.895897,175.134262,161.353859,149.453617,106.228314,95.470163,127.39192,145.185888,103.593465,3.883204,-21.387122,45.491414,104.409934,162.170223,166.640794,142.058948,92.498451,80.695464,97.839504,136.090565,244.197258,278.778134,252.8487,195.096958:-34.855674,-63.088209,-53.22202,-9.492418,-10.013271,-66.222162,-75.578178,-6.656618,33.10448,-2.755484,-135.517695,-180.677321,-150.673502,-88.30776,52.810076,116.958336,196.033971,164.979418,112.973572,-18.534713,-63.171157,-98.650148,-118.203909,-171.91574,-209.863201,-220.595387,-216.159107,-204.008276,-170.07835,-140.449627,-57.081015,-26.13824,-2.896497,-20.129003,-56.550718,-119.556711,-114.89223,-70.589653,-45.390446,-4.933049,-23.079131,-57.583713,-162.309009,-227.06851,-308.977168,-288.622736,-166.321523,-131.338158,-159.869451,-198.676192,-212.418197,-190.012455,-129.423512,9.008274,36.017005,-13.077035,-95.967213,-123.317443,-163.260195,-151.701002,-27.621069,42.704093,135.814729,152.615809,93.651064,-27.186395,-75.914227,-110.115183,-106.98467,-85.269466,-40.477261,76.772423,47.416561,-13.139131,-108.875095,-109.626052,-22.169076,29.862715,122.160014,159.147479,184.251843,183.101688,176.274974,143.847939,118.418166,57.5834,32.445852,-6.304748,31.108415,88.483767,125.539524,75.406249,-57.873969,-79.549476,44.824844,151.751816,295.954847,223.259599,137.244099,115.379749,202.188254,359.6308,364.208434,304.402332,314.56559,320.670164,244.051353,190.563104,145.617266,145.047445,145.24616,146.003369,164.736012,214.233952,219.016951,130.254915,82.716106,102.854192,149.59265,173.95674,85.021342,47.448376,-43.948083,-99.141701,-153.940509,-169.712257,-220.1364,-234.651785,-206.914652,-160.683529,-160.364567,-212.809011,-240.125434,-273.471056,-292.265113,-355.820932,-349.73249,-292.661143,-231.272231,-250.612848,-234.961109,-184.683982,-110.22812,-94.569128,-46.43653,14.547214,-0.923349,-154.780538,-234.119982,-272.669319,-234.455904,-145.788602,-121.115274,-111.753315,-102.440523,-106.763198,-97.622045,-87.295412,-58.177703,-40.282502,-3.786905,51.405598,66.12429,83.242825,136.768328,330.81519,399.465508,361.518488,171.326866,97.093218,97.117632,162.752231,327.374906,381.852869,384.381482,360.599718,370.005514,422.42269,411.541168,318.083204,277.789677,282.675511,330.551394,393.89549,312.769399,277.098638,294.651007,298.586321,202.105277,158.519355,203.495814,253.595225,293.516086,253.4347,240.06625,274.862186,298.594141,324.706868,346.47153,389.418773,279.962066,168.528712,52.030442,97.826848,235.216215,243.76613,172.752769,155.367399,162.230437,126.375382,97.477916,78.115851,81.196544,26.938193,-28.89255,-105.2379,-60.615833,-13.92426,-30.107265,-102.3484,-210.794663,-207.598734,-159.96168,-159.554228,-203.085882,-206.127525,-196.465514,-161.185509,-123.650498,-58.321358,-45.841658,-52.159561,-106.200374,-119.712642,-90.698305,-73.857782,-44.672057,-16.170438,50.20984,62.519993,54.528613,58.344327,24.37557,-116.801356,-149.89875,-56.706074,24.288588,102.366282,15.279087,-43.39837,-117.356976,-141.346674,-199.388043,-234.903379,-263.736137,-235.219283,-130.918785,-92.834622,-108.725407,-101.475381,-57.453601,28.318629,29.769739,-31.174988,-26.430623,11.897273,52.149101,39.634887,-0.86953,-12.899087,7.032005,25.136376,14.973958,-20.374013,-37.163388,-66.967439,-81.686155,-142.137785,-163.249346,-97.429125,-23.518552,-45.47713,-178.719957,-243.736641,-239.832372,-187.645712,-143.88238,-154.559067,-110.80661,11.304903,18.522237,-77.0854,-99.385894,-48.061891,-12.838009,10.667717,-105.814442,-179.232336,-187.538072,-136.393529,-66.874175,-55.183477,-11.823639,27.990027,104.723032,116.019048,89.432396,20.818462,10.189464,6.303505,-17.997623,-69.32347,9.913561,49.813783,-2.789895,-28.806254,-10.254197,-19.356312,-35.528893,-4.017937,54.245609,19.490254,-13.952614,-87.905452,-106.728163,-32.418333,38.244885,135.14711,131.188365,102.519118,3.435905,-46.364056,-54.678293,-16.080863,92.896769,145.799049,165.092558,68.643675,20.491416,-45.495493,-57.160057,-33.658933,-16.236077,-11.609985,-8.177565,12.054609,48.137201,61.803668,111.285012,130.927308,147.269593,166.262396,233.503705,247.629424,197.386839,70.084175,25.811105,-88.481352,-144.373655,-104.645548,70.258307,96.739844,-42.637518,-114.299074,-76.215504,-8.491893,54.003821,37.226142,-8.999907,28.108107,62.028245,87.456866,76.296613,79.450553,112.473659,123.795769,24.442041,2.639346,1.874374,-3.802293,-16.523256,-19.746424,-29.927265,-54.842829,-118.747876,-69.777464,-23.701227,5.005424,7.740479,44.620677,54.869709,40.641544,54.308128,67.887456,91.738426,114.506676,159.333066,148.217118,73.643535,36.271823:-27.727998,-25.878579,-82.917227,-182.682065,-179.495473,-115.435416,-83.765484,-23.030227,31.540331,19.135383,-92.718096,-139.714455,-136.42724,-95.870497,39.268379,91.800356,67.351029,-26.91547,-78.646449,-160.443955,-175.405207,-219.098753,-258.206534,-294.898616,-283.070037,-300.586036,-348.994757,-323.675021,-187.781389,-128.88569,-62.452447,-46.755538,-45.272078,-70.84285,-93.502048,-124.178093,-113.536718,-54.970119,-13.143595,52.736165,-39.454799,-130.783697,-251.827991,-273.783786,-313.242408,-338.248459,-341.961402,-314.046502,-276.584012,-269.088169,-238.214252,-94.31541,-12.447461,87.293544,99.053627,72.621774,15.201982,-27.00663,-139.578467,-174.412311,-122.893463,-43.854922,115.835164,136.664555,49.639747,-57.565343,-100.976037,-158.680686,-144.533196,-34.831533,8.46384,-3.332478,-43.93422,-59.308977,-142.11583,-180.860816,-137.217422,-83.477362,-27.034202,-15.793049,27.052465,67.670149,52.436055,18.768348,37.147085,68.276167,51.707789,-45.180571,-100.51849,-53.329542,61.688842,46.944074,-117.702163,-192.019954,-144.926195,-36.084072,152.237719,118.252329,49.37147,38.489843,101.937696,191.046822,193.262072,152.433472,131.150347,151.314434,171.051107,148.170543,81.759996,60.967615,45.095269,37.763756,99.121653,227.229413,226.114255,106.63651,50.194515,68.091011,140.411274,217.243188,134.276547,99.123516,26.418637,-35.209022,-158.662439,-181.333602,-115.976103,-73.93621,-58.166174,-97.133229,-142.284714,-262.41411,-297.385716,-301.976928,-293.989532,-271.943446,-208.388177,-185.28644,-241.52053,-285.968467,-278.002922,-244.854295,-211.305091,-210.352592,-184.108481,-57.173218,-25.705144,-163.865857,-263.620512,-287.05931,-209.953878,-76.284188,-77.909454,-88.45188,-86.903581,-75.753772,-50.002385,-54.966875,-77.783033,-72.494137,-51.69474,-55.482542,-47.916219,35.769704,103.294043,226.354301,259.901894,242.964845,124.214433,62.464506,55.112418,138.069816,358.25691,398.39584,328.906991,299.132085,342.955378,453.58129,454.306282,271.871568,162.615079,110.3053,169.645382,260.532813,223.285219,214.970402,202.73895,169.042031,74.627272,61.693293,176.257641,264.471691,316.849442,190.968304,127.81933,134.310363,208.357362,365.018427,400.235478,337.780465,144.454688,63.722807,30.923792,69.187596,155.283084,169.49832,156.912234,143.19873,74.141464,-43.907623,-74.869466,-46.954927,-58.533307,-229.331003,-304.377138,-270.553567,-163.37587,-135.280927,-145.233384,-176.00835,-202.932689,-185.381047,-119.273459,-91.941506,-117.553855,-173.084179,-149.458544,-6.37828,63.169724,104.66336,79.736659,-4.373542,-15.555217,24.15892,59.500569,47.240991,79.909656,103.811887,86.206708,77.782438,99.303425,59.730724,-24.34299,-189.808225,-184.945746,-42.766113,18.768207,18.33061,-96.243931,-134.727081,-148.39272,-146.961618,-128.602261,-99.754931,-23.263615,-3.51941,-24.949217,-113.466125,-176.627784,-250.01899,-243.242945,-160.450981,-90.572564,18.965541,29.49083,34.933595,79.384264,102.778061,114.583073,100.187397,105.181145,148.890455,222.575406,169.13042,115.961022,31.019118,-2.720219,-62.490238,-59.910917,-12.517865,-79.035115,-145.61376,-221.729244,-204.28136,-94.702436,-63.29965,-103.414853,-111.131432,-3.605369,24.943671,-37.438929,-125.92773,-123.487855,-98.10566,-70.255322,4.737524,-2.457349,-33.367401,-94.936853,-94.055787,-15.588944,22.081097,93.63688,137.809364,163.191503,83.591459,37.781951,0.622976,13.024555,78.483014,111.016373,122.285048,162.558369,223.858915,279.302253,233.029781,68.074222,7.607011,46.250245,120.05313,219.597974,188.390381,148.03817,103.614863,101.817782,117.15043,145.774625,216.613888,179.845707,123.742541,28.940902,6.632453,8.914673,15.264467,11.409323,27.138499,106.650719,85.841542,21.398595,-64.395619,-41.511161,76.131749,113.400171,122.499558,167.950396,205.192804,181.65884,137.266934,157.58539,214.552094,264.221675,222.485263,86.796032,10.409583,-15.926618,-37.573521,-32.695209,-69.199628,-100.183015,-64.667914,78.552303,120.472271,63.299336,-2.4125,-83.107286,-85.950771,-44.312247,-22.677484,-0.731531,35.735583,41.162038,11.385944,-5.013865,-17.753913,-0.29293,64.427751,95.517425,114.690256,171.297156,187.558375,127.482838,64.408659,27.427173,47.916354,-5.851296,-79.638414,-41.929496,79.60087,90.282115,11.858731,-14.43788,62.528655,239.007071,288.131098,210.548917,135.833569,79.306623,81.780174,51.576067,8.587943:-106.047472,-168.643418,-187.124868,-181.540063,-167.340125,-140.040831,-112.508087,-30.517749,-6.535582,-47.318064,-201.929541,-270.467201,-265.32584,-185.470452,-26.959461,-1.988727,-14.241101,-11.140659,-1.813801,24.158593,33.871709,35.557516,22.092195,-51.751854,-106.251776,-95.346491,-48.378709,-40.280443,-60.797698,-53.500351,72.765945,131.040794,62.16709,-68.533974,-65.651796,50.631347,112.389933,154.875483,135.196948,15.504009,-126.423805,-145.223095,-139.149528,-151.352814,-201.126317,-227.474162,-196.048514,-147.363602,-164.90051,-301.373261,-334.652662,-255.458662,-164.591559,-6.582563,25.761141,0.341371,-39.907556,-49.095078,-79.84464,-92.123152,-56.551795,-11.522631,106.506774,151.033963,127.659352,33.648177,-19.965623,-126.228327,-147.443847,-82.538852,-24.44389,14.84234,-49.147663,-69.699175,-42.184764,-22.369723,-33.909036,-26.953815,113.779801,190.821458,156.614589,9.546274,-20.302754,5.105829,30.883029,55.539135,65.744035,107.962984,122.624308,108.235013,15.60025,-31.763976,-41.819434,-37.355543,-49.117214,-39.469859,4.449451,-45.290412,-106.964315,-99.222049,-5.813256,164.985942,179.38574,116.607828,53.478066,18.845518,-68.134502,-88.92221,-46.255872,-20.054153,-25.444462,-45.510389,-2.770363,182.982368,248.236897,199.289264,124.61494,69.147065,124.323612,250.732392,142.708066,30.786474,-108.014676,-112.106051,-69.254747,-68.200772,-117.202377,-132.890256,-127.706392,-149.620306,-187.721763,-237.022608,-215.334338,-176.19249,-206.048184,-329.027137,-400.616907,-401.309322,-393.681211,-373.985853,-246.942251,-174.541911,-122.168818,-149.433584,-212.84112,-120.472329,-63.953816,-68.186278,-91.10285,-83.071871,-74.563614,-78.862601,-29.005798,-3.901704,-32.630006,-49.908489,8.771555,59.319326,123.474408,130.619253,79.175464,21.740604,33.877426,92.633655,108.311092,123.323709,139.376879,180.323346,104.280172,26.160424,-13.971239,52.771157,196.467482,219.30533,226.837608,240.208811,258.201335,234.575938,201.632032,147.908432,169.772541,289.320636,348.826933,397.766646,338.207708,301.800597,219.985944,157.5127,105.653685,177.644405,379.421173,413.739657,388.080184,322.112509,273.892723,239.773778,265.607924,318.436462,332.3718,381.123569,375.116229,292.89336,69.954818,32.116246,128.960104,169.032245,143.743059,123.971923,126.089026,141.013081,128.755735,64.000735,28.352854,-4.30707,13.784399,59.192324,50.318094,54.204354,42.261519,-16.440116,-151.722992,-144.182146,-31.63238,-29.158581,-183.867429,-261.245265,-212.440738,-58.324085,10.657289,103.623589,108.258627,14.855916,-112.406631,-135.849464,-88.108606,-46.203828,14.014252,32.698742,83.495498,109.633761,103.9581,42.553325,-1.620922,-59.196845,-46.013003,16.587287,35.085747,49.488435,2.464524,-70.834927,-193.851871,-192.212169,-127.481008,-111.991476,-149.414749,-175.621038,-139.339512,-76.103606,-103.529169,-123.022571,-60.562688,40.269529,36.320336,10.03976,3.604435,3.374766,5.227695,-7.384147,-57.034447,-61.876716,25.29838,90.589824,115.227608,2.728406,-22.535191,11.996479,31.421954,91.055668,129.111163,84.941406,-121.829357,-197.38906,-227.301431,-215.720649,-219.926049,-223.047358,-157.063814,-115.096089,-104.451,-117.394905,-118.88957,-111.698616,-100.793105,-114.906504,-126.599793,-97.498513,-143.91019,-203.061086,-234.881537,-200.237097,-161.333619,-170.13297,-82.456477,31.123604,127.289201,-22.955571,-78.568487,-87.135983,-79.155628,-109.839227,-137.283941,-107.152524,50.306202,98.465387,32.589649,-33.788561,-103.488683,-90.697308,-4.214715,3.792175,-81.060845,-119.800025,-136.20785,-216.427167,-226.63565,-105.101514,-5.941652,112.129029,80.8981,58.088565,-20.848992,-77.543682,-111.487132,-62.888582,59.834627,64.531927,-22.469564,-111.635542,-157.378703,-234.537339,-238.02643,-153.781614,-80.82595,37.206416,62.072198,45.572238,-14.283978,-24.10647,20.699434,63.509936,175.435885,220.035282,220.134422,185.359291,182.392486,113.50627,30.280989,-87.02325,-73.17683,15.674461,17.32287,-19.105777,-66.586823,-47.298913,32.556743,65.754292,126.59644,155.070754,154.899791,77.866885,31.147386,0.703085,39.824641,194.812218,261.407592,249.136432,150.028111,133.269384,107.17985,87.822891,122.583837,145.828312,75.096104,14.06965,-31.926836,8.258061,22.089445,32.970838,48.831079,101.250171,119.849279,85.707501,30.565917,44.027156,82.351388,85.260624,105.848136,115.845269,126.487994,137.429168:backward
-147.855702,11.385169,27.893969,-58.471667,-134.568749,-275.804277,-311.259883,-319.413965,-255.311454,-214.264035,-225.382318,-259.445777,-262.989148,-221.210374,-105.446306,-64.617919,-35.156975,-10.031955,21.630291,42.488865,-21.273602,-188.53973,-195.198424,-37.455003,150.153362,196.947795,199.30737,170.832272,32.181358,-47.844153,-92.802607,-62.067035,2.815623,-4.716392,-37.605504,-151.028906,-229.795985,-322.287365,-292.983793,-178.252378,-83.30053,-52.901466,-68.602887,-86.12184,-88.468799,-87.116807,-91.7263,-87.564263,-34.706568,-7.912762,-40.160869,-145.824237,-180.884975,-108.828929,-15.597448,88.62133,47.883288,5.674468,-145.562934,-231.773103,-289.92877,-246.14311,-127.405595,-112.166008,-141.387325,-133.672901,-131.630399,-178.649248,-219.526743,-296.501296,-329.691274,-313.136691,-116.237121,-36.533991,-49.352428,-100.649433,-162.250408,-156.347535,-136.879311,-149.499055,-146.72651,-52.721987,-14.106212,-65.920247,-156.53678,-294.253625,-276.353969,-150.523106,-39.511535,20.480909,51.239782,0.118719,-148.686758,-222.133665,-301.089943,-290.49371,-230.232491,-225.673695,-240.837842,-249.704565,-256.46685,-269.563784,-238.158559,-81.771405,101.357828,164.379464,189.434326,152.094321,6.075442,-75.603177,-156.656939,-129.917459,17.667012,56.059277,-19.43552,-182.738691,-210.732729,-176.6488,-119.93389,-10.809227,-28.948965,-66.534501,-164.999306,-217.197698,-304.601029,-341.396435,-401.915491,-434.726246,-465.261758,-316.67749,-230.165648,-211.622717,-256.22364,-334.117046,-351.59154,-262.37061,-12.349012,76.725628,59.249776,-2.620679,-105.425893,-146.731995,-201.723192,-192.27888,-88.376895,22.423388,38.42549,-10.287053,-53.206406,-96.316774,-68.838564,18.532684,22.749729,1.721346,-56.961274,-80.731098,-109.596125,-127.267921,-153.024296,-136.767606,-9.468795,126.414004,130.406769,30.962415,-38.622169,-136.922084,-128.319745,-37.427997,60.866008,103.452052,87.103772,19.740873,-137.443997,-174.511767,-131.371522,-98.938249,-87.439642,-98.836512,-119.372508,-171.23833,-171.092632,-128.478647,-105.488533,-51.456215,81.504545,152.801874,150.366185,95.142494,12.820857,-5.967006,-24.876022,-37.944866,-46.214364,14.143846,60.946978,93.405592,49.401604,-41.791981,-26.206162,85.861667,165.66604,170.512682,126.503607,101.032308,66.717547,69.591405,134.646208,167.271356,198.349905,158.689634,77.240562,-137.327182,-219.010616,-293.310843,-305.625974,-354.694491,-358.003856,-315.633871,-281.899302,-295.543697,-235.300785,-176.267567,-183.963119,-248.962598,-289.338262,-157.494436,-106.832498,-136.162625,-196.106396,-252.059247,-220.33815,-120.25674,-6.324763,68.927908,166.088466,146.66032,31.215973,4.63928,60.328193,98.627424,125.185004,125.143292,127.123733,126.730666,97.065093,-68.659579,-171.472756,-252.223661,-20.825249,137.062626,250.173978,191.579682,-8.371082,-70.980061,11.796811,125.078324,315.074045,327.455489,257.203163,53.547312,-24.887525,-82.492325,-74.310098,-40.658653,-33.24629,-37.218976,-44.37268,-48.787017,-103.253135,-134.039665,-115.923789,-89.261288,-35.972567,83.294939,136.022587,158.644363,132.219813,60.177558,55.411274,105.008305,140.328184,147.792556,161.111321,170.619854,178.841569,181.238634,268.642107,357.60962,511.57762,478.053055,383.140909,203.521346,164.749111,158.081575,162.772006,149.457741,185.093792,218.359977,190.439742,130.715791,-10.290898,-84.316078,-205.900727,-223.457138,-118.491473,37.162918,42.237253,-113.311291,-212.382675,-280.34224,-236.232507,-118.135695,-86.44859,-79.756102,-15.957401,17.153816,21.494061,20.681689,110.747196,163.177263,133.852002,55.328974,63.440279,61.867525,-11.100112,-192.171904,-209.582772,-154.658522,-166.252021,-157.077966,-38.885918,19.640303,-19.681146,-82.606349,-110.490917,-81.390603,-32.301435,-25.188532,-44.799805,-119.043377,-159.806699,-201.994316,-185.350726,-106.697493,-96.921202,-117.761792,-119.762644,-116.296014,-176.990772,-209.409458,-160.926605,-92.055517,3.676943,-9.725642,-24.652727,-1.552479,23.169148,60.275495,91.814452,175.438644,201.370422,221.553844,293.508772,294.856941,175.54528,111.681808,144.845544,213.091848,254.209227,210.232889,215.466668,198.935217,126.218645,-58.410533,-95.98386,-3.724464,188.609811,252.328693,228.829688,155.532049,7.972593,-11.864447,67.56285,100.010308,54.987241,4.036986,-18.459926,-158.257466,-277.427444,-479.445622,-491.020549,-325.669715,-120.455385,-80.096488,-107.588633,-135.858869,-144.163065,-85.564549,96.462165,130.128684:-24.863918,11.550699,-31.732623,-206.863414,-278.031132,-286.700885,-258.211322,-281.454789,-379.4515,-390.31986,-359.563183,-348.74127,-314.539139,-276.657775,-186.248477,-148.704456,-82.070245,-78.632104,-107.674586,-216.744293,-278.568289,-260.199426,-172.560624,-27.479619,47.894591,89.944044,128.042956,100.818301,-20.310071,-65.766,-33.984347,15.207512,60.329001,25.036006,-10.981691,-125.141948,-199.443785,-274.073536,-229.703531,-57.343899,-1.334348,-25.161581,-49.344705,-38.209944,-11.510617,12.963848,64.109931,60.267517,13.814494,-35.93045,-88.743887,-207.488055,-225.562538,-181.85163,-144.964758,-25.398804,94.284876,78.375454,-98.613994,-176.861583,-206.350046,-187.926206,-163.160002,-155.740499,-144.423978,-186.572894,-224.49786,-284.187606,-294.557194,-276.741727,-254.803777,-146.439386,6.369797,16.724725,-110.57522,-195.508364,-314.114904,-305.300689,-148.733705,-88.380762,-99.227896,-86.403922,-76.34509,-189.10888,-274.106225,-275.31446,-192.057196,-53.392435,-46.068292,-81.725493,-206.339674,-257.506797,-300.321095,-313.93803,-319.688691,-291.677117,-193.688761,-172.995822,-200.870776,-262.415701,-280.211072,-239.18775,-178.400626,-45.114639,88.774101,127.912809,55.549014,-29.599682,-190.702619,-262.036654,-324.226604,-265.506355,-66.723971,-89.878031,-177.630561,-306.559848,-334.366122,-356.001965,-326.260022,-123.97974,91.415485,78.266261,-163.188441,-271.44507,-339.253529,-339.610803,-345.553504,-359.232129,-370.387825,-319.992789,-310.970951,-358.651474,-381.548684,-362.239767,-336.76383,-243.964458,-73.898658,-29.352136,-84.539223,-142.692912,-212.423994,-199.880544,-132.919478,-106.733775,-58.373367,-39.906712,-81.549233,-234.121764,-274.878634,-214.42147,-162.143727,-85.329031,5.419767,28.453662,-36.756087,-98.883592,-205.825321,-241.258391,-229.518165,-162.163077,23.829447,62.332976,8.255722,-117.323032,-147.581062,-99.973791,-29.744394,117.619895,168.200738,157.255305,95.440026,42.283379,-72.248295,-94.586525,-22.199867,35.863437,100.258612,32.716644,-43.318493,-166.044044,-192.261516,-149.957858,-85.075846,38.745972,97.995026,109.17924,63.140281,14.401788,-29.822232,-10.303021,42.269637,59.260876,97.925423,94.949144,74.387465,51.634828,30.261335,-53.278365,-87.176116,-82.028159,51.28904,119.979116,112.593702,58.954592,5.62989,22.445919,78.800521,90.930042,61.187587,-42.918405,-112.107037,-230.790719,-274.284294,-333.423469,-344.460338,-364.81439,-415.076063,-425.299051,-400.329543,-367.083913,-285.593858,-274.010852,-307.352843,-316.383931,-248.766819,-107.222854,-78.193688,-113.525457,-136.985118,-143.816756,-110.621367,-6.254257,57.178034,66.699114,-1.626595,-60.869153,-99.883284,-59.844988,49.581306,76.979776,105.251109,162.785195,183.032812,188.132912,175.728108,68.563375,-12.712848,-72.738985,85.591993,180.734069,250.767135,221.198912,91.407793,58.971964,174.288344,273.001912,384.725305,310.12422,243.622459,137.786571,73.110331,-81.65583,-122.589747,-86.491979,28.892312,81.525504,124.738187,111.927604,41.10404,9.566705,14.363001,49.842458,153.995894,192.553836,161.940365,62.321354,16.44708,-15.890169,15.02636,129.033032,252.294541,308.717134,299.401615,224.735618,153.639634,212.199302,350.359163,377.347589,425.423754,416.668687,346.024797,135.998495,46.395206,29.037156,91.421047,183.860297,196.856085,206.030016,249.178336,261.194618,190.736452,111.102177,-51.876125,-84.709938,20.756461,130.627826,99.407688,-38.676059,-92.57178,-151.283213,-160.740752,-93.294101,45.079034,74.472301,74.034358,64.428598,-11.73601,-60.949831,-64.118922,-18.331172,13.526335,-86.288992,-107.351796,-52.04146,-35.274214,-96.681657,-153.845493,-205.852729,-134.816472,-114.845695,-122.517924,-128.163048,-218.596201,-291.452684,-346.349039,-330.45371,-273.958272,-209.876957,-215.422584,-274.741411,-275.525118,-201.009308,-148.857995,-61.416521,-56.200232,-77.972806,-94.909363,-91.079599,-114.913586,-145.957395,-169.44479,-132.949475,-31.097968,-45.352373,-66.175636,-44.320432,-34.271586,4.43366,77.872887,262.867518,371.26488,395.741887,394.305284,387.547373,349.303691,295.892555,190.845306,179.454298,236.574684,276.339409,252.741572,147.779331,72.79314,-81.764465,-106.048578,-3.656233,173.017343,238.638768,233.52514,170.744967,39.925421,6.329492,-3.272915,4.443099,32.70087,9.987258,-46.329404,-214.1288,-288.668492,-372.301456,-378.010312,-258.762328,-24.808397,45.941935,28.345394,-19.590613,-79.674641,-57.970764,54.827867,88.270913:-54.443549,-49.899634,-79.122535,-145.651609,-188.975506,-256.751452,-249.27215,-205.335162,-214.606064,-235.579457,-298.259168,-323.52525,-293.214578,-233.834085,-84.761414,0.686725,119.741958,0.870772,-97.932464,-228.639591,-258.783214,-230.497743,-167.759843,3.061425,125.879365,131.846493,47.884501,-23.85483,-139.444405,-131.366444,-11.346803,38.103534,75.411817,4.345163,-78.364725,-233.757398,-269.737668,-221.215509,-156.614202,-46.135021,24.984576,49.409483,26.03824,-26.972241,-119.381386,-106.823452,-0.982958,24.510651,25.883346,47.837892,17.44732,-95.209784,-116.002954,-93.83764,-68.56094,41.228134,97.353849,46.732534,-83.248864,-87.562968,-15.084427,-10.653463,-74.519986,-74.778695,32.360836,61.920667,16.51175,-78.054646,-104.390304,-105.300115,-78.117892,-13.292311,-28.880959,-79.945188,-242.410634,-329.261016,-379.045698,-312.880495,-148.499355,-128.63778,-179.426506,-203.268124,-231.859979,-370.96098,-422.199103,-370.398439,-304.687589,-191.729234,-93.821614,-84.13324,-181.769284,-241.436537,-301.402549,-308.575006,-287.530058,-259.680896,-167.338928,-103.05124,-142.017104,-312.197361,-379.96992,-396.918845,-340.01728,-150.160866,-4.765515,13.910951,-40.269037,-106.94586,-286.304664,-346.454434,-335.182494,-302.827009,-282.746483,-322.84225,-350.464443,-393.459843,-402.33346,-359.307706,-295.304982,-103.138212,63.065331,65.342195,-91.249482,-187.146886,-331.696171,-357.503839,-274.708872,-206.393909,-145.278011,-203.268202,-248.764374,-348.755047,-395.378932,-400.456852,-351.931502,-217.288462,-137.68603,-153.472128,-240.207306,-296.30884,-410.283312,-415.226745,-296.487951,-229.012268,-147.414601,-147.349724,-194.023448,-344.199814,-398.182901,-350.507824,-260.459849,-74.048837,10.133495,5.590528,-43.872877,-77.564337,-165.494636,-196.535506,-146.075255,-63.721023,97.520607,54.074605,-34.91915,-151.58413,-147.733002,-100.0196,-84.992424,-26.057046,118.140744,177.854692,160.424973,85.006739,-61.969209,-78.607825,-1.049952,57.890176,147.435524,134.268398,68.231141,-130.130688,-198.534809,-158.604307,-89.589136,-18.20357,52.695574,107.776917,81.235261,-0.549171,-82.631899,-49.105167,42.238291,61.06705,74.036958,35.19949,4.04979,-5.160553,-13.045385,-107.767439,-157.379929,-158.997248,-6.273205,61.56037,22.951218,-44.123315,-56.895392,10.931338,101.539408,79.204359,19.592901,25.832249,5.885617,-131.132406,-221.792072,-311.34388,-283.595236,-219.265542,-248.499985,-247.195021,-205.755231,-221.271078,-306.721873,-307.05628,-199.431309,-141.205224,-65.653955,-39.892649,-41.677014,-26.996247,-15.660944,22.387825,68.551085,183.663258,247.754498,245.516617,182.256018,131.644532,47.044447,35.201341,62.385522,105.228414,279.811482,426.822421,419.620306,303.111062,258.966669,201.557289,153.08526,77.600422,166.925518,220.780671,245.360788,247.263838,223.658292,186.116574,204.304336,280.999874,386.367733,303.431438,259.393719,247.202336,221.310855,53.201285,-33.041136,-56.944481,58.437033,95.145955,71.162183,35.041674,-32.645349,-62.136714,-88.074213,-56.556843,85.630912,122.150197,76.300231,-32.4583,-83.677625,-149.45621,-122.209231,59.238766,237.941266,275.150241,218.942569,142.64906,13.245592,3.606868,128.378318,234.853758,350.905859,229.280057,143.283783,-24.576807,-94.168366,-64.123271,29.316895,199.230399,283.155516,289.812556,205.364683,152.028764,139.591432,163.135824,130.637537,80.698492,74.958906,166.912562,169.721848,43.882555,-39.608649,-125.740207,-134.993665,-120.577395,-41.197294,-18.963901,-43.261384,-50.556622,-25.914549,-6.73166,5.850156,-7.459562,-25.387283,-17.865955,-20.360296,-65.822567,-123.457539,-269.570154,-312.601484,-270.042755,-124.626143,-88.876489,-156.004249,-229.542426,-388.383815,-441.427659,-439.027949,-407.066804,-364.664122,-394.387435,-416.701213,-406.276604,-376.40542,-297.172995,-263.238055,-226.218271,-174.671673,-155.567303,-143.3541,-135.760295,-163.073404,-202.919342,-221.476306,-166.570234,-53.261081,-108.232564,-148.124772,-155.849662,-153.973606,-135.858402,-68.786215,166.910174,302.706333,301.415753,279.55288,284.776591,278.563827,254.53777,205.814588,211.792681,303.762061,374.002126,355.986703,196.881567,86.941684,-40.170574,-36.243596,51.959775,170.959286,182.808035,74.861162,10.701455,-51.778359,-58.605187,-36.035048,-23.489748,-61.17785,-121.861523,-132.800439,-217.718628,-310.511652,-429.190817,-397.994329,-231.122569,-86.888281,-38.156107,-18.776521,-59.945111,-153.864832,-150.601166,-45.345184,8.907642:-177.340952,-44.492407,-49.188633,-147.143147,-203.086418,-289.559124,-305.77088,-273.476188,-204.922456,-184.443961,-219.966895,-248.401905,-238.040169,-195.285657,-60.357521,6.015606,73.290401,12.270607,-40.619843,-121.780822,-165.067948,-193.398641,-129.336588,82.91099,223.130961,233.263444,146.395182,80.010705,-16.346972,-17.61674,52.335673,82.182246,111.250041,89.303382,22.803432,-155.794638,-214.02838,-218.851339,-186.321905,-148.407391,-130.893717,-117.948824,-117.644622,-115.298267,-93.654319,-92.317927,-111.042602,-122.487308,-118.837161,-115.395753,-142.242451,-199.415729,-193.717931,-100.189268,-45.134288,9.001052,49.100787,57.192051,-15.315797,-70.685514,-144.784898,-135.67108,-8.114926,48.47698,61.155799,53.265951,43.049147,-50.472846,-110.43457,-169.174955,-166.949089,-91.299877,44.103189,61.21289,-86.118858,-189.178117,-293.959566,-287.715123,-201.371655,-169.45879,-178.319071,-140.24963,-116.593966,-211.134324,-300.952627,-343.943807,-279.787709,-154.443654,-103.898776,-84.542479,-90.23191,-117.15211,-196.04241,-246.176251,-285.696649,-241.173969,-102.596783,-103.199886,-163.784036,-299.283214,-348.748092,-359.141922,-321.266179,-216.316241,-93.756948,-50.173216,-46.824246,-85.144367,-239.613493,-337.701677,-419.935707,-367.449439,-199.96353,-198.805917,-274.932156,-392.507416,-397.589529,-325.862245,-236.483632,-0.404945,130.255293,111.8193,-91.06434,-219.808612,-356.820394,-342.358161,-239.491547,-204.730535,-194.585357,-189.318502,-205.313911,-296.131982,-338.93564,-334.113295,-281.638067,-162.386316,-77.026797,-47.918301,-78.278647,-145.32902,-296.511425,-338.153421,-311.685974,-265.017892,-178.325624,-119.163153,-120.677814,-200.769358,-240.753444,-215.740639,-150.846074,-13.221439,87.297579,116.268092,65.725856,-4.728248,-138.101117,-152.499264,-37.962585,43.735719,155.791421,155.312413,95.447397,-75.376336,-153.690704,-259.200032,-268.076242,-160.912281,77.85216,175.572964,164.632217,64.043486,-114.727595,-119.279087,-31.545739,-1.127256,31.159327,24.906274,-34.350212,-200.097788,-220.128252,-69.781969,21.265599,62.79036,83.063418,125.671561,95.060991,15.65512,-42.724043,13.766896,128.572129,133.328107,132.806143,186.295098,179.822586,91.791515,34.624837,-56.284029,-58.083266,51.622166,179.576805,189.524174,139.193803,117.594679,72.74461,51.601309,87.4005,127.115394,162.93031,166.72378,150.213762,33.57987,-61.630695,-216.411869,-231.771766,-182.228205,-153.87462,-149.817353,-180.703289,-223.221772,-285.830319,-270.810624,-169.156972,-123.150968,-51.600544,-16.426864,-36.587339,-84.004773,-106.458364,-130.293144,-87.311515,77.482512,169.877045,161.404208,80.64681,40.185631,1.041,11.482634,83.551433,125.913367,182.4412,174.283638,152.005933,113.259543,93.657055,25.265389,-8.292542,11.819333,202.375126,302.857439,354.082474,314.48556,193.913117,144.279004,136.51228,179.570445,339.54638,473.694541,454.671953,311.420514,240.975368,96.902116,37.495665,30.022808,102.459052,138.564938,175.717509,141.265561,-27.939664,-104.093891,-152.948445,-137.986363,-63.473272,-25.791946,-36.873079,-39.751583,-28.589619,-38.064761,-45.713323,5.591753,109.666123,140.830923,116.015658,67.886953,-36.152799,-38.422007,135.080588,252.46579,387.67849,320.901336,212.950155,0.490806,-54.968348,-73.987927,-52.812492,21.550103,152.198364,220.749253,245.064009,203.373784,93.963779,24.139615,-109.680559,-116.684762,5.963086,91.334119,78.620389,-39.775604,-141.232707,-285.456795,-258.747042,-76.399996,34.442279,33.300253,6.323516,11.507883,51.746473,82.402488,170.407833,216.40872,261.348011,237.127948,224.20336,187.404543,117.683967,-75.243774,-127.529171,-140.955958,-123.247019,-113.190273,-127.870861,-161.887294,-281.628443,-339.626253,-339.766429,-293.774305,-245.857161,-289.479189,-334.922813,-420.060051,-425.475473,-366.018782,-328.265599,-285.599067,-286.516694,-305.780193,-345.347408,-339.957487,-314.799965,-319.072154,-304.102815,-260.876117,-169.342593,-174.918302,-202.552802,-252.108494,-270.471432,-239.275516,-173.401585,-11.095947,115.049963,149.639623,182.068412,207.305662,220.770338,180.569046,105.088908,117.920729,212.326692,253.028254,226.012068,108.131316,35.871109,-89.863231,-124.572432,-66.018991,181.455433,273.444342,205.164937,103.563173,-38.612434,-58.442235,-17.901034,10.696832,37.327214,32.236345,6.444966,-118.84024,-211.318864,-372.952341,-400.952464,-286.252163,-91.241485,-58.955802,-106.192513,-137.732929,-156.203082,-123.270364,-22.201159,-6.3535:-94.495012,-54.202865,-85.72813,-197.162554,-239.616275,-254.955644,-227.651516,-122.027088,-65.023913,-100.61554,-229.195644,-269.122919,-237.667575,-158.808608,31.589992,75.90518,57.154628,-3.437397,-56.33266,-244.534454,-336.103295,-300.959598,-183.97974,33.153736,152.661813,176.356821,93.832183,-17.018537,-233.607928,-261.85427,-150.080935,-67.008961,61.023125,19.677381,-68.312983,-222.807429,-267.349997,-264.841074,-206.523084,-75.25633,-27.116553,-25.118408,-45.029715,-72.982988,-144.257871,-151.171403,-111.167806,-101.994139,-108.630903,-137.655524,-158.442668,-161.58578,-136.963336,-59.513138,-4.51952,133.517476,173.87732,132.237835,16.498041,-34.473453,-93.683197,-74.434283,57.337773,137.822801,263.599071,283.575065,249.129949,103.575804,5.073336,-96.939935,-60.333743,81.69206,99.70423,43.526695,-105.045595,-188.59021,-338.17339,-343.60285,-225.464888,-166.049014,-88.977031,-154.952592,-266.287148,-498.234985,-547.843457,-434.549069,-309.10156,-88.749448,-16.466128,-53.798661,-173.765206,-204.670201,-243.039357,-266.594237,-249.651003,-192.083139,-49.614935,-49.726837,-114.642252,-285.872265,-367.476505,-419.077885,-365.411767,-182.138709,-37.443134,-13.731644,-87.985899,-179.137898,-372.352239,-416.499014,-382.024199,-332.019167,-231.052543,-259.289718,-331.323352,-437.414837,-417.839028,-284.049578,-206.862557,7.457187,225.453254,229.314095,21.826451,-99.835106,-223.013285,-214.574686,-91.450263,-5.546497,108.957723,27.413113,-67.133156,-262.17929,-337.238789,-357.180997,-307.294359,-204.916459,-139.042595,-123.198525,-173.799978,-239.826657,-377.126026,-403.549793,-327.584164,-268.232846,-216.867804,-242.644639,-283.448701,-388.313254,-409.736844,-326.772255,-233.105488,13.118449,159.07865,120.224472,-65.310488,-130.47248,-181.929082,-178.71005,-91.694299,-4.793771,187.154448,195.038652,113.433364,-81.79026,-159.207606,-233.719488,-209.423203,-17.036123,169.265999,176.116209,57.793043,-20.111529,-114.425565,-99.282204,2.288209,46.378058,114.658608,103.459782,31.62933,-170.499534,-217.177777,-116.333021,-36.769596,44.461293,122.098627,161.943958,135.29201,57.217689,-89.416188,-82.829164,73.402224,156.404633,274.610717,271.893953,197.559292,17.514101,-48.289003,-131.491426,-127.74181,2.074705,163.87747,190.633105,107.84124,39.921021,5.948117,60.537139,215.336733,262.717692,276.869198,277.759141,269.747618,151.714904,49.707607,-54.2299,-8.462932,126.98492,108.610652,52.626556,-65.301001,-111.769253,-148.677119,-118.971265,16.469113,94.075514,230.529958,220.174507,160.635824,63.912679,35.103288,48.977314,115.404983,285.853097,362.51873,355.696403,280.984329,216.020821,72.790344,43.663406,108.347854,162.688918,239.716011,259.598726,243.153439,169.476615,131.591342,95.933721,93.348719,125.430782,246.16237,299.872373,285.840741,235.859778,170.36756,175.277317,198.527145,217.564281,360.306495,476.232442,454.815881,339.712482,261.69992,92.986491,61.067862,168.851692,298.960045,299.134004,200.07118,136.622726,25.174004,-12.77374,-27.90424,-16.662476,-10.276042,-37.752015,-57.702831,-106.013749,-120.08933,-77.351091,-27.341353,61.66838,105.696782,114.177604,130.558407,139.847248,93.043229,52.385658,92.469624,182.690138,370.056224,306.433378,164.608384,-86.080919,-129.173236,-96.022604,-45.852411,100.018373,297.213095,367.723923,329.700235,245.489783,77.057991,20.309169,-16.392094,-0.390942,50.847193,52.780208,25.274162,-99.94573,-198.297102,-380.350953,-402.326613,-266.438814,-74.398735,-29.129909,-21.850856,-36.15506,-77.091603,-67.548577,70.04426,153.653544,232.449524,190.52792,138.094349,-2.377879,-71.32464,-130.81374,-121.953734,-82.540857,-15.665942,-1.409122,-108.09274,-212.015533,-406.014375,-458.207391,-423.729991,-354.039996,-252.764014,-302.028659,-363.8052,-497.412814,-528.19233,-428.500282,-338.034971,-259.999802,-262.602857,-262.379363,-301.893253,-340.814465,-432.695689,-473.946581,-490.207594,-437.477078,-245.719158,-191.418676,-256.939817,-408.523504,-434.627584,-359.293449,-278.948339,-92.485403,72.424415,103.92522,87.54392,75.450938,48.446644,38.727019,50.49845,74.320217,167.633473,237.68763,239.044867,160.109269,66.138981,-142.12768,-175.104051,-15.613091,192.437035,193.408908,46.756632,-25.699526,-102.753025,-94.562637,6.033471,57.511386,81.384494,-17.090138,-92.4033,-238.641069,-292.342636,-303.788262,-260.035069,-125.308947,-14.259895,1.881608,-62.942163,-121.825853,-195.483725,-193.575978,-120.965966,-60.083083:-204.510431,-59.971096,-72.816184,-234.794545,-297.902244,-305.264568,-284.376909,-233.009365,-163.884796,-150.210343,-203.300395,-224.706127,-157.726858,-104.071946,-63.969789,-48.831682,98.544618,230.86895,198.472709,31.381714,-39.697041,-85.691346,-44.623424,123.645307,257.402348,260.268191,160.669586,110.648642,30.91239,-17.626677,-48.313539,-10.412495,44.554621,-25.260663,-85.641069,-220.918029,-296.231724,-373.033311,-334.435848,-198.19947,-134.114462,-150.181968,-242.38903,-268.038265,-268.496672,-264.721329,-221.275588,-179.138512,-114.199784,-97.09173,-95.957698,-103.5123,-101.066042,16.845457,124.948144,228.027716,118.841739,44.542559,-73.137531,-104.8046,-140.746877,-143.271442,-81.526818,-48.116306,-39.548932,-13.191986,11.333757,-53.947438,-160.087279,-318.561149,-292.248329,-79.134639,132.90931,166.074137,65.894063,-9.001347,-96.302641,-106.356342,-87.377616,-66.224707,8.247897,51.388536,36.032606,-32.664422,-72.504666,-117.201517,-92.417268,32.472009,129.528063,145.008178,84.736839,23.16775,-86.194228,-129.336156,-213.012399,-248.314691,-270.42641,-254.821443,-265.054602,-309.28816,-317.049907,-290.447159,-270.340478,-176.796951,-4.898029,49.170487,48.836797,8.580136,-126.944738,-193.910559,-220.444251,-170.403981,-17.638896,32.140293,-18.289949,-129.842403,-134.453798,-69.817279,-23.964589,85.570043,181.214164,186.846193,42.787063,-55.655304,-154.403961,-164.451026,-177.06674,-182.03721,-143.51041,-67.53141,-57.821871,-122.51919,-168.974522,-192.352026,-149.460577,26.131855,202.974968,240.55192,164.177983,68.448035,-142.875506,-220.938067,-239.885161,-187.743078,-63.146697,42.311778,76.38539,50.776481,-6.334645,-63.724603,-3.860215,185.327954,239.260509,216.830854,146.713298,100.911635,-10.116963,-61.437421,-109.674124,-74.176546,126.042862,286.730961,287.367382,150.205386,37.412233,-200.524825,-273.770091,-187.524527,115.472651,213.398775,157.638135,49.807727,-150.328201,-189.369669,-108.42226,-26.181521,103.083474,73.591211,2.969676,-85.815348,-77.727125,-34.397182,-10.0524,25.223444,83.363593,136.271164,143.011238,77.955503,-50.88702,-60.29682,-7.024475,-0.614087,35.538041,170.01763,196.595462,105.059692,28.611202,-25.526109,17.755398,112.576111,126.338645,127.853715,158.490566,189.213436,220.542577,193.951337,143.234596,167.74924,274.711687,268.632083,175.686786,-77.798511,-164.929573,-191.739217,-149.484139,-92.648369,-124.730274,-127.10334,-129.279091,-150.876122,-177.757454,-152.203426,-58.701465,-36.659531,-38.998786,-44.924017,-63.09521,-129.318336,-156.67625,-141.627875,-96.148205,9.34962,95.89423,138.561634,183.798218,166.357155,88.705906,59.295093,67.679023,112.588227,188.57532,146.604684,116.268455,48.695669,-19.482557,-141.685789,-134.201115,-15.909859,166.80109,250.719555,235.253417,127.775898,-119.674982,-163.094374,42.287958,216.25422,420.848982,391.293213,335.488733,202.27984,124.441089,7.463026,13.232394,72.535913,49.814168,39.634059,44.174679,23.839887,-93.459045,-142.891536,-132.263285,-109.725641,-59.528462,46.629559,72.194212,64.457946,60.514754,42.752986,40.431811,114.605863,209.346148,214.344598,162.321048,132.413195,67.710061,46.856398,121.797773,193.112526,274.621211,293.9425,279.449263,152.383683,86.005544,46.841436,48.324536,84.025378,212.830565,254.516004,200.071206,137.348506,-20.945633,-115.118004,-248.701493,-262.885796,-177.041326,-53.359885,-65.609756,-234.804781,-320.255398,-340.079055,-270.864798,-138.668716,-137.566808,-139.055999,-84.717313,-65.637306,-64.396254,-32.451847,138.284315,213.338526,207.936345,139.365187,141.284676,143.787313,87.092337,-95.287759,-146.538726,-188.899163,-242.996981,-235.083376,-163.284846,-145.773297,-152.437118,-149.21952,-120.66547,-93.984512,-29.945682,-21.489915,-54.943995,-210.127554,-306.459664,-375.306085,-312.981831,-159.644202,-182.527026,-216.332685,-192.507859,-165.661601,-252.30882,-327.740805,-280.256371,-166.99481,0.997221,-29.373551,-75.695362,-116.543808,-96.428212,-16.999048,11.284315,42.826272,64.183106,83.009112,169.434469,191.527139,108.040457,54.31245,81.291168,145.958359,229.130414,232.326137,222.81596,183.380908,139.519352,3.39426,-32.771006,56.019552,204.459189,238.068685,184.182062,107.193741,-44.106511,-77.052177,-73.843363,-69.921706,-42.458785,8.296024,-17.984788,-195.891735,-304.479916,-469.246903,-485.572054,-333.598564,-97.870669,-36.452691,-45.328932,-72.505307,-81.338996,-49.608839,39.079039,79.112195:-96.184634,-36.391609,-106.274213,-294.526079,-332.587372,-284.274198,-233.122923,-94.511477,41.887886,43.546907,-151.487681,-271.940667,-292.131786,-202.87783,-40.46055,28.067451,198.036539,216.864814,133.890019,-78.502208,-173.630639,-233.10165,-159.236697,92.591879,250.584738,240.857382,86.349652,-9.328677,-170.015353,-199.816605,-86.671209,8.575055,106.965125,53.186561,-7.35125,-166.884605,-259.936215,-334.787619,-262.856373,-39.65176,13.380345,-45.601846,-210.875246,-252.905268,-235.942126,-222.080028,-220.642236,-200.564069,-80.429579,-10.586948,-55.484136,-172.241091,-170.972115,-59.311582,22.916647,193.906319,291.89028,281.911443,157.314305,72.798917,-60.962707,-67.890877,83.737925,195.532127,334.4907,314.310107,245.447939,34.853986,-66.251166,-137.879262,-81.480243,115.947408,228.953096,205.539275,-7.544213,-145.154036,-338.456798,-354.703162,-225.874438,-137.468157,-18.167455,-17.380033,-76.173747,-269.294256,-342.283727,-305.252525,-203.753148,19.624535,111.923555,96.907491,-24.577607,-104.193991,-243.766599,-288.375257,-284.280163,-243.048967,-135.145011,-89.955325,-139.87505,-339.098158,-426.596728,-483.40606,-432.897132,-188.215865,27.625675,43.391942,-92.45771,-217.693155,-453.3629,-473.495751,-275.224133,-147.20983,-32.623773,-120.559431,-201.147349,-302.6894,-305.016127,-205.91646,-87.324175,208.501635,362.411526,349.910866,170.737415,36.432227,-178.062932,-204.941418,-110.815752,-29.361271,126.062678,132.734773,52.409153,-175.930253,-271.084286,-288.747376,-199.861534,-5.776575,83.063831,99.834173,7.289851,-110.346626,-332.261407,-377.558795,-342.705506,-287.30132,-141.392137,-68.495073,-105.057237,-280.530227,-361.023813,-336.589405,-212.798167,87.108396,252.980567,243.047887,58.178594,-50.178389,-192.199559,-208.73297,-76.279831,56.188569,295.035572,317.10022,235.823104,-16.732442,-137.053264,-263.26415,-248.605228,-85.627082,145.735813,216.384013,130.438783,14.104363,-141.167815,-147.405744,-38.144993,69.431933,240.884936,126.313455,5.029273,-152.96515,-170.341648,-120.338682,-60.861623,96.421345,263.397376,298.905987,182.530183,76.480494,-61.74535,-57.639448,50.0146,106.432221,228.846353,329.484512,297.409342,26.150841,-133.524084,-215.134395,-111.867168,172.222792,306.90336,292.672562,205.055895,188.601958,200.333482,203.758705,236.617326,282.869464,427.595844,447.129989,344.063159,57.369081,-52.130262,-118.663963,-62.633336,114.755902,163.887278,122.917229,-23.946572,-101.527801,-191.390992,-173.825676,-34.690238,49.589106,171.674509,134.018994,44.139609,-148.991072,-192.508203,-111.960983,1.504802,228.244479,329.067768,336.244183,264.778603,183.413938,-4.694875,-53.066046,36.770492,133.352404,250.735403,240.741418,204.987959,81.11877,4.941003,-65.384574,-19.601132,180.208247,363.023233,401.5709,334.92583,238.735218,7.267467,-54.688736,37.994416,152.154686,386.579023,478.572924,442.350768,277.217865,165.356396,-10.065088,7.154663,232.790791,389.631014,366.970957,164.764376,39.74859,-142.536087,-163.252191,-71.256139,-4.04614,70.756553,-9.823183,-77.201566,-158.164898,-173.865293,-135.869192,-60.796754,142.151349,248.193393,228.710988,84.62425,1.008309,-124.97133,-131.488642,56.262831,206.438573,402.419395,337.390775,230.399191,-22.554538,-138.123378,-227.416494,-160.879997,83.799843,229.260186,233.623369,157.342999,99.09989,-52.377619,-122.13201,-139.105907,-83.810597,20.858268,-56.413529,-145.492187,-314.421782,-402.748752,-538.788182,-508.59513,-249.811409,-21.630965,13.438499,-51.83403,-122.013909,-206.400518,-155.534555,123.2314,257.418215,351.09485,315.506026,296.174549,160.747774,21.083793,-162.307102,-136.800766,-34.174569,-1.374072,5.357176,-96.60008,-220.051429,-432.9165,-450.378233,-338.877354,-260.198165,-109.507195,-89.037938,-162.864839,-359.042942,-437.7896,-495.891013,-447.384739,-264.924655,-195.906248,-230.299626,-341.718342,-392.970385,-511.373772,-559.855048,-472.433177,-327.221108,-44.538162,-35.570198,-124.198302,-335.789397,-409.868003,-374.756364,-262.221987,-3.893234,107.95132,102.599069,92.026349,105.89671,82.526976,32.819687,-49.279184,-32.077165,127.416433,218.929288,192.662934,70.966827,-19.929264,-188.166561,-187.597992,16.583221,215.516768,223.547674,85.349324,-13.418218,-153.81845,-157.773125,-78.047201,-35.482277,60.392269,108.616536,54.111731,-190.642914,-323.317866,-448.135109,-403.400872,-154.229804,86.025395,120.134612,11.302529,-67.474494,-147.394326,-142.645428,-62.865114,17.106939:-206.977464,-141.868748,-177.180707,-255.779463,-245.327658,-186.386233,-172.822798,-127.317621,-24.619702,-3.448884,-19.217607,-2.74036,59.07438,64.953327,69.377278,100.808956,245.426559,394.438719,395.730866,257.92011,174.477194,80.205411,84.392315,158.338781,260.200198,293.5885,269.964926,226.60522,93.495669,14.372594,-106.436883,-160.308375,-230.513112,-163.351997,-145.835514,-240.370212,-309.190728,-345.436144,-295.026284,-180.37244,-173.586174,-185.069651,-179.02118,-152.429251,-53.974186,1.215807,46.991151,25.658615,-17.347939,19.065695,50.989756,80.099552,72.062671,122.754888,201.852372,337.392607,325.563061,260.159608,72.722848,-7.154717,-103.3548,-123.825773,-122.091159,-120.132623,-150.739532,-167.812139,-134.991688,-74.900838,-114.396954,-240.550013,-228.514429,-38.541745,161.826901,214.101411,204.482197,180.404229,183.795702,195.747214,181.925934,171.702991,201.365464,194.320572,157.220244,107.832275,109.223825,139.488069,167.19164,253.776555,300.228149,274.186391,185.742446,160.470187,117.15166,62.352718,-112.100714,-183.546935,-228.866313,-251.830865,-258.92276,-226.845115,-219.825291,-272.584246,-276.103842,-96.631647,145.155503,189.546741,157.921551,135.231316,99.815411,82.205821,113.433984,177.32879,305.357286,313.038155,275.714528,200.568105,202.142259,267.973555,287.139084,278.591414,288.468442,291.490632,207.842944,122.792167,-44.320688,-93.926142,-141.438669,-164.845584,-182.302804,-117.10459,-98.26153,-107.809212,-121.315279,-174.559117,-176.746885,-12.558333,233.259455,272.921357,167.497634,95.823335,-12.480374,-64.826532,-101.46704,-72.881148,5.698281,132.304167,182.588607,153.088113,94.00557,47.294677,110.386139,311.026723,365.460615,333.857598,238.9134,178.171011,1.726957,-81.824084,-77.402696,1.506388,139.462505,196.293923,208.400439,175.943591,107.860091,-87.811158,-133.374702,-40.766703,81.482462,82.395848,-24.685784,-103.435078,-208.375153,-178.243244,22.572024,80.978034,-7.47494,-66.044684,-38.105373,23.18007,50.945173,88.948372,73.22189,7.083712,21.310654,50.72183,51.243019,9.670848,-83.910187,-98.897977,-99.404191,-119.176989,-122.062813,7.634805,61.912928,47.002515,8.478454,-3.346409,21.374906,64.233063,157.179709,200.704229,186.335712,159.412812,138.285525,136.502195,175.121315,238.592679,336.566462,175.343124,35.112823,-178.21767,-214.493662,-157.501167,-117.968458,-121.985308,-146.577171,-136.780054,-165.894582,-195.88726,-170.842628,-142.915729,-136.086123,-130.011771,-75.825252,-47.861762,-65.01145,-141.695615,-177.463693,-153.858645,-84.876455,64.503259,146.084546,168.525647,144.730454,104.602961,35.845878,22.232957,52.358779,76.12847,84.223351,57.602575,30.307673,-67.940576,-140.162229,-268.552028,-278.537777,-208.041124,-139.878001,-99.758,-17.287528,-14.216795,-147.981913,-235.07559,-214.34247,-105.228288,73.394052,97.604549,86.064114,25.85874,-27.539257,-108.323611,-110.710891,-93.041698,-96.807445,-88.5982,-38.67019,-36.957724,-161.910124,-243.565791,-260.831345,-196.598752,-63.049649,38.365351,67.907462,35.072858,7.149288,15.534338,49.75842,115.596038,115.371104,108.256654,126.6805,144.042845,123.615957,77.525246,-4.666959,-4.463523,93.595957,152.980591,111.422388,-12.427131,-33.286983,-18.640094,-28.156674,-86.026836,-48.32616,5.092486,39.202027,4.908204,-138.299394,-211.40641,-246.702921,-219.495316,-138.977326,-77.761857,-98.896516,-223.043495,-261.194615,-184.697005,-107.305705,-28.687463,6.976663,38.272042,22.628687,-36.141119,-126.159088,-105.706211,58.507227,132.923041,130.080034,62.174261,68.334054,93.917877,51.641997,-144.048449,-216.567057,-238.451028,-235.411545,-236.386204,-216.394345,-194.850689,-136.107799,-109.805165,-81.59319,-73.990103,-51.782022,-65.817541,-101.63972,-177.106508,-208.111599,-268.05696,-259.977305,-151.403302,-151.371749,-188.785997,-178.427844,-142.802741,-168.868572,-218.767544,-178.250067,-72.988167,123.137398,195.985997,197.219131,95.926672,22.541736,9.272193,67.678665,124.803458,98.429415,113.577049,155.391334,130.9159,33.49791,28.349233,146.695224,204.471062,178.673927,69.524517,44.604006,43.141372,12.762903,-87.636648,-83.475225,27.830453,140.626934,155.096221,20.868349,-81.387781,-195.336002,-198.167627,-108.101319,-37.419437,34.112273,1.186549,-44.980612,-171.128833,-217.754285,-240.650494,-236.596703,-239.383929,-225.063327,-194.316735,-106.408419,-69.336276,-20.703772,20.10354,176.207578,247.21853:-366.448303,-233.032007,-204.462783,-207.690205,-214.238225,-204.287731,-188.149519,-177.838663,-124.957173,-73.890584,-23.342731,-29.23164,-89.961185,-108.398074,-15.725761,65.469878,224.094824,334.520195,340.661941,282.654769,219.991769,48.035059,-8.690372,16.430877,150.276765,199.18996,228.96185,225.394125,158.379093,88.336978,-81.227089,-150.355959,-150.906607,-39.054269,-53.669224,-237.561505,-338.45882,-418.641041,-367.693536,-194.525046,-124.750715,-131.37874,-134.207041,-102.053022,-20.546016,5.760512,16.399996,-2.313364,-18.461662,65.326297,113.251821,151.688866,143.480713,167.404004,221.909719,266.841094,123.810344,45.17123,-59.330553,-109.830494,-241.55683,-273.842847,-192.383026,-139.855744,-137.119387,-165.369943,-161.667175,-166.588022,-193.264039,-241.370524,-227.89593,-128.076018,45.51121,138.654473,227.017633,210.613681,137.848232,127.999688,141.660284,121.385398,86.95504,143.205256,152.145191,60.676179,-11.022901,-76.212304,-47.003483,37.622065,93.630901,118.806812,77.858852,21.486196,-42.380767,-81.194415,-278.480447,-377.245353,-388.744368,-260.972638,-226.909491,-234.380708,-262.025027,-300.272542,-266.648809,-74.137905,146.162945,201.336132,203.823611,190.884414,165.2056,135.486794,52.691208,39.139122,106.766927,169.017747,175.842059,172.503849,151.351626,101.712129,111.826355,177.489221,192.534178,166.95802,79.197309,48.383162,-49.10359,-148.11456,-278.30809,-262.705862,-185.505668,-119.288845,-84.253209,-61.05937,-103.769067,-233.91931,-227.817093,-7.225806,211.518182,235.01665,188.828361,179.024567,130.8413,55.238264,-63.452773,-43.877703,122.041415,273.09363,272.620035,135.274273,64.815692,38.185481,85.995845,174.147301,92.680117,52.19485,49.726712,35.184426,-47.520152,-73.526964,-56.187831,-15.521054,132.375959,198.394724,155.647682,36.271499,-13.325002,-109.382151,-131.744243,-57.222376,71.859804,100.470866,51.186255,0.564307,-64.789438,-64.301405,-31.751098,-43.227365,-84.995982,-30.52979,-26.21774,-97.608212,-115.468018,-66.584705,-35.238338,-26.147292,-3.295665,33.527928,70.131083,52.394934,-6.533776,-16.26772,-13.775303,-45.097699,-124.357347,-70.711349,-31.700515,-37.021077,-65.169534,-58.207757,-5.988391,108.402338,194.612757,224.336614,219.916176,213.059731,245.735043,272.082376,263.153265,224.070885,216.892678,222.841786,128.628048,-136.383959,-209.895335,-229.561806,-232.662761,-283.718554,-303.475968,-277.405751,-204.70697,-173.812683,-140.651383,-146.347418,-172.951341,-185.60228,-166.878596,-58.259926,-17.734993,-36.894715,-71.270092,-110.555037,-107.409286,-25.415036,143.250535,205.863527,225.492455,201.310485,119.447895,72.722006,25.769028,41.520557,103.960596,83.4858,60.862871,64.388654,35.169589,-163.834699,-256.77133,-289.918595,-141.739786,-42.994326,27.776953,-17.490053,-166.418974,-221.170366,-143.900162,-8.403131,218.007917,145.05953,21.449584,-223.100284,-297.443966,-327.786153,-299.406769,-247.238892,-253.54191,-250.104671,-173.300212,-126.786264,-135.75869,-176.715998,-215.596804,-192.981857,-32.574949,150.392001,161.882379,71.039838,16.075828,-74.813142,-84.817732,-36.498772,-5.399644,3.714039,63.399281,96.088112,84.060034,62.199498,103.152131,166.039825,305.582179,360.229487,328.994599,206.881033,155.850176,107.636539,93.964819,57.233862,98.680691,139.194109,130.598249,74.063281,-86.778907,-158.966274,-225.267306,-232.791767,-199.543943,-99.140373,-83.651585,-176.326466,-231.799112,-179.294793,-70.998649,98.880573,98.603355,78.257696,29.463516,7.116531,17.036653,54.952299,172.873986,208.453466,129.462943,10.408374,6.160851,29.914146,-7.170604,-150.154975,-191.506229,-195.587087,-179.730665,-178.750831,-142.724674,-85.785183,0.90046,2.278321,36.131046,82.789154,106.825713,12.908294,-27.148249,-73.01194,-108.27947,-186.256575,-192.873075,-201.675791,-290.135112,-314.012125,-253.056144,-225.88094,-284.492948,-314.475739,-247.432327,-177.385654,-92.017782,-89.796354,-78.627818,-54.758912,-70.859178,-116.766642,-108.264621,-39.152585,40.784656,70.716922,85.688609,79.985525,70.604578,68.554258,116.92818,176.679003,237.249141,133.565487,100.375983,132.032024,118.76239,-6.729898,-31.695037,69.687177,166.013534,152.172286,48.84655,18.800931,35.923393,56.09126,71.081128,51.944349,-7.330503,-33.559566,-72.52959,-205.345863,-247.276795,-248.701599,-231.01859,-181.305882,-111.061473,-85.35717,-46.284295,-19.875313,6.195748,7.167691,62.688839,105.513135:-172.778867,-151.550717,-180.621279,-249.650586,-245.541935,-193.130426,-154.383537,-37.051129,55.782204,57.708928,-25.709083,-66.092076,-86.323354,-74.023733,10.275228,78.486349,219.785179,271.932949,239.282787,101.91702,35.905645,4.704942,59.413807,222.933261,233.804517,163.036023,54.105111,46.87537,2.271078,-64.496639,-167.768615,-146.471965,-8.021747,50.401649,3.382983,-143.895365,-192.62581,-206.288945,-172.83288,-81.006818,-46.817348,-52.602606,-92.602121,-118.797177,-174.894178,-189.656727,-159.053571,-134.113891,-90.032619,-44.315644,-42.647747,-41.451605,-13.443027,76.127001,129.029843,246.181812,305.683495,280.090918,126.900265,52.202088,-4.939391,4.139986,56.926064,80.452222,119.639263,178.561148,189.033935,98.494129,-8.117922,-184.724375,-164.648118,39.178271,179.402155,195.122935,142.754344,90.569112,8.970465,-9.528671,9.864262,48.090313,110.459075,77.92378,33.390734,-66.900712,-96.70005,-61.990778,-18.276249,32.783937,97.401736,142.096091,145.213846,94.987472,14.460777,-3.10074,-107.797797,-187.257009,-235.224144,-203.169874,-242.588431,-343.326177,-341.667748,-264.608296,-201.693503,-26.597981,85.178246,77.424165,-6.169324,-49.344047,-137.637243,-169.268553,-98.987676,1.806841,181.816654,169.805828,104.910759,31.526401,35.824882,43.044591,65.148347,191.880768,338.419116,358.250571,213.432252,105.849754,-27.930651,-60.158402,-83.59342,-64.978185,24.505626,63.7015,20.711479,-115.342132,-158.217127,-171.722825,-124.346305,84.722513,242.43761,240.602715,115.969472,48.901557,-79.899271,-158.372257,-217.550451,-183.762153,-93.977007,-44.108414,-60.728567,-111.853787,-118.335248,-76.979937,-10.324419,185.864965,264.81915,204.330235,42.35476,18.199626,-19.125528,-78.510661,-137.961667,-72.863177,199.447285,341.112481,290.865789,83.960516,-13.01269,-131.764184,-127.325961,13.227885,159.989428,162.747676,21.836777,-78.970579,-202.380679,-181.887885,-15.7427,57.967738,99.373423,71.414621,34.849401,-46.020405,-60.681916,-16.964854,22.40066,42.22777,64.709046,102.793767,104.78605,56.906512,-55.359159,-102.180932,-165.178285,-164.494025,-52.087217,75.732331,69.972565,-52.959454,-104.407808,-70.156186,-3.574155,90.248922,114.770179,124.714611,118.531214,90.60862,-6.720946,-36.140663,29.137952,93.90406,183.75268,136.827948,56.703556,-102.064292,-151.912309,-162.725757,-114.35024,-20.026889,-24.255613,-43.283044,-84.616623,-114.379781,-206.334846,-234.928768,-176.645412,-120.285938,-101.195706,-172.598627,-197.290377,-272.618086,-331.791079,-354.554924,-272.826621,-29.769699,139.834442,179.061256,151.23068,96.384963,-36.549004,-88.181805,-85.062512,-33.815457,101.088038,124.75639,67.660472,-36.807379,-53.463793,-74.917707,-93.571807,-98.007613,-4.030224,43.253209,76.755654,56.062299,-96.984355,-185.199569,-128.347526,18.054275,219.341331,178.160914,160.89882,156.843251,110.064515,-39.209865,-51.281126,117.167977,302.912181,312.605317,136.216756,6.030052,-172.351757,-193.366532,-151.636746,-123.720262,-83.47682,-72.161252,-80.384275,-106.98034,-119.670854,-99.636575,-50.159205,52.03314,54.537864,20.317817,-58.826748,-64.102649,-18.262458,-8.724973,3.006591,44.9124,176.47354,182.223144,110.022778,-32.730514,-62.574807,-91.686807,-90.716715,-20.489102,67.737507,82.118235,22.593884,-35.72085,-107.26521,-104.446599,-99.141589,-110.608543,-99.368563,-82.243749,-117.261205,-239.223947,-295.655783,-328.100551,-276.672702,-126.101601,-37.470973,-2.506959,-2.233462,-54.510404,-127.536815,-89.921847,125.326034,250.19678,359.319354,234.048793,157.772617,81.011445,64.512712,20.694905,-19.148089,-115.20119,-123.369957,-95.616981,-78.612729,-110.066739,-208.046662,-228.860071,-146.549812,-76.083909,-13.980344,-59.877358,-98.68982,-190.917126,-236.980848,-304.851632,-290.112954,-147.096798,-53.108439,-52.379342,-95.969063,-123.624491,-163.226161,-163.105762,-65.984702,19.125221,154.014232,151.696351,103.816056,-12.273722,-55.565016,-55.186264,-9.63443,94.126515,137.651621,140.780983,154.218704,168.232703,156.713666,119.310391,83.876562,125.404193,238.450704,234.221847,192.108547,65.631275,-17.435141,-142.273677,-137.455437,0.877487,188.457651,260.54203,258.632825,159.589015,-96.070234,-151.768045,-59.005055,6.097993,36.043477,48.313634,37.085189,-93.060804,-168.849474,-239.837455,-240.090565,-192.500839,-71.623551,-16.321562,1.441904,-22.087286,-62.810147,-50.571229,72.305623,158.016727:backward
133.86145,142.080392,129.656059,78.464757,21.741377,-101.488352,-120.919419,-49.004622,58.901057,88.941832,111.303061,106.916352,70.187937,49.367913,-0.907114,-19.082001,-12.181324,37.484407,63.535714,92.162192,96.940703,60.062527,18.165118,-34.05504,-30.026011,-14.673902,81.087735,130.820006,95.606783,7.163875,-156.515755,-172.536831,-121.255556,-64.51395,-43.362372,-67.61351,-90.035834,-101.165899,-114.794358,-144.160141,-69.951692,16.344993,201.562285,242.431033,238.099049,242.129101,220.721711,154.440226,-32.8332,-63.538941,-17.890995,-20.935194,-78.598766,-153.780149,-143.444592,-62.601193,3.571559,22.981303,102.181437,158.72936,201.651422,157.971466,11.21472,-15.565802,53.14099,79.018075,37.616246,-110.661813,-176.61339,-261.9933,-298.578877,-337.26294,-337.380094,-361.362308,-399.246641,-382.873465,-388.373382,-449.643966,-567.336325,-561.03369,-467.098603,-431.980508,-433.943491,-381.140795,-316.238536,-261.186782,-331.81697,-515.853926,-450.938058,-351.239347,-279.714862,-349.3285,-529.318005,-559.273756,-470.118254,-370.570326,-123.18291,67.339536,104.594422,103.870135,98.272891,50.31678,-19.725537,-228.003591,-392.380677,-381.195162,-189.209802,-101.201488,-87.160636,-152.349166,-294.039369,-307.037772,-238.435471,-190.491188,-167.39545,-82.180649,-40.191867,-30.559789,-50.595274,-57.249674,-41.735396,-61.908435,-170.990672,-234.935398,-313.569653,-339.317272,-418.745898,-441.813157,-419.095962,-356.630541,-307.593408,-242.950211,-236.071316,-214.218464,-188.484482,-124.91539,-52.714467,-4.445532,51.98877,28.442147,-52.8159,-91.037721,-191.374797,-216.523976,-154.863088,-76.963783,-57.174293,-42.556788,-45.690057,-80.259144,-97.562952,-44.577007,32.166315,11.213489,-111.485243,-166.351128,-221.261792,-219.581609,-127.873344,-49.755931,50.714032,87.246384,124.374257,176.63728,160.941259,62.498788,18.673954,55.153735,141.244389,155.627483,240.39435,304.861297,308.364463,231.573173,78.075133,56.986231,88.73122,76.647359,47.153828,38.111693,60.993754,-19.098062,-145.506315,-352.534624,-339.33181,-299.05177,-240.347528,-210.043468,-135.858779,-114.660376,-83.15585,-38.386853,78.391377,152.745053,172.712775,161.211979,114.101912,-55.061031,-134.375132,-164.84128,-74.540167,-32.665889,-3.250277,-12.401645,-16.949302,-0.012288,76.76261,133.081719,222.884501,311.269431,372.321518,434.011634,420.713999,325.485321,263.445602,238.536986,322.343782,362.536476,402.473601,382.287178,287.169024,233.37072,143.792469,131.043823,156.137129,187.47456,179.7975,37.77543,-41.452209,-71.027854,-65.406053,-64.983634,7.056844,40.339956,-19.483756,-113.391559,-262.43792,-280.198846,-265.151294,-226.442639,-59.540084,79.21232,85.536831,-8.701905,-62.854373,-103.737265,-84.575201,44.400646,196.44552,226.424483,181.107752,142.509234,159.618393,189.829463,118.702799,35.095462,-53.821104,-24.336172,-4.9893,18.774772,24.31551,-10.89274,-51.073779,-49.446053,89.90203,148.391284,160.696,121.37416,66.172446,70.887611,64.6508,36.859788,-56.223932,-85.786122,-34.998741,64.790699,76.023997,99.903241,127.939949,190.282036,267.562263,329.085554,478.381741,521.693482,488.769346,424.807448,263.901528,222.090035,297.907054,467.837589,515.721833,459.300058,400.622227,311.503235,267.510888,209.230055,211.246542,234.616323,308.156175,313.898851,211.231756,136.179343,68.012178,109.295281,273.488944,339.688141,313.158154,171.341371,85.014569,-54.070479,-89.659884,-51.220438,66.766999,124.905209,203.189747,198.256225,78.484165,-6.891828,-94.610936,-82.265937,-52.905261,-66.044681,-67.427546,-84.524546,-100.214564,-96.779686,-72.325367,31.27396,124.868462,142.925965,187.704894,201.36269,119.842698,33.423919,-124.413442,-154.398855,-125.05467,-82.385444,-64.037399,-80.157497,-128.322912,-213.921388,-214.813668,-104.93099,52.864362,93.272739,65.493188,11.683499,-47.020353,-27.400066,14.970099,24.210224,43.799363,87.451565,135.323812,203.475396,175.768839,17.696225,-60.409514,-114.917603,-66.539107,-41.516124,12.848202,52.143753,99.607006,77.222566,-40.164123,-71.484595,-1.354187,125.059968,170.318651,185.041552,169.924172,130.822688,103.462278,100.74122,152.63479,151.901792,62.737093,-20.164891,-159.032701,-177.555066,-156.811834,-138.554631,-48.091334,64.836824,59.176197,-73.402279,-114.89723,9.066947,137.147373,299.515071,252.764423,209.686666,206.950729,232.439807,258.652725,265.109415,311.201395,339.001725:238.310098,266.738261,253.890175,102.946663,-8.525916,-116.704607,-89.985313,24.501461,66.866,55.527122,77.152957,103.80961,67.585725,26.63864,29.731965,53.02713,56.293866,71.265562,99.12248,128.39146,107.907108,2.725296,-54.449542,-93.469769,-31.364371,18.885923,116.068592,120.331903,19.437506,-47.110302,-126.502766,-129.339484,-76.582445,59.768754,116.058813,120.270688,92.783484,15.997103,-31.193229,-77.352982,-5.470748,63.083871,159.153326,150.701924,106.182864,100.393611,64.489532,46.219829,94.053795,184.649677,175.474896,3.701449,-103.413026,-184.974747,-137.254311,0.832311,44.139187,61.532047,114.06598,114.297281,64.407517,33.385455,-16.415142,-10.254244,73.86001,96.088534,45.403264,-163.328464,-297.942837,-473.779607,-466.542777,-344.367549,-325.372327,-378.362462,-490.450715,-508.154306,-505.032409,-533.096504,-620.910526,-605.606252,-488.149825,-476.108979,-494.224944,-488.309298,-466.867128,-414.684161,-395.44783,-415.285247,-434.557154,-378.179355,-211.587065,-189.662274,-297.610599,-354.603289,-305.938091,-193.857741,101.971412,348.173063,408.054073,412.889442,387.095059,242.348745,121.082836,-99.626916,-182.759387,-158.010315,-89.876839,-98.50518,-180.124248,-219.28089,-228.222671,-190.266359,-112.374101,-90.037689,-86.080023,-104.045324,-117.230994,-126.855426,-110.873809,-20.650674,19.172032,-9.467894,-95.053261,-141.669742,-287.060075,-376.43419,-476.687882,-458.12557,-363.08489,-304.415638,-284.368506,-265.370938,-283.578469,-330.078935,-317.441994,-235.8179,-162.67072,-121.244289,-66.78888,-78.773429,-144.210723,-184.943481,-242.889056,-212.013187,-66.716838,-13.287732,-1.987157,34.728604,36.930331,2.979173,-7.6748,35.315263,78.911389,66.639749,12.539247,-6.697195,-65.408559,-111.629369,-118.889183,-58.468111,77.446923,175.215237,202.714922,152.912596,96.281062,-8.816186,-50.180849,-54.595717,30.953029,85.527263,178.35826,180.177305,118.879663,87.800621,69.271941,86.809665,92.910468,22.317374,6.386205,52.036944,74.596702,-34.053232,-155.460544,-300.721608,-256.864985,-223.645812,-193.56701,-197.682743,-197.792188,-175.434402,-84.602602,-25.008093,36.821717,36.663588,54.179854,94.540426,84.494387,-35.294039,-112.842843,-150.415034,-62.521766,-47.653747,-131.626326,-191.089079,-228.285023,-197.887983,-58.416932,27.720444,155.348453,250.403647,308.346825,413.054807,417.715112,248.261428,137.552546,69.333887,100.075833,128.49126,213.444199,230.279113,218.806295,216.240064,199.471891,193.462611,207.853674,208.295302,192.727398,92.536048,14.898477,-81.291875,-91.021385,-98.872058,-106.589739,-108.526394,-133.80094,-171.336766,-253.644001,-284.770228,-312.143139,-279.974079,-139.676404,-44.967735,-34.532424,-36.298941,-48.973681,-130.707218,-168.077469,-112.244182,61.648449,135.245649,170.732673,145.239746,130.87012,136.762622,96.386557,73.691134,98.493897,170.659652,183.290307,159.638825,149.014909,124.102537,92.423792,49.338008,138.451389,208.887376,235.832847,180.329444,108.121608,127.853418,160.091863,147.524101,119.573987,112.290806,122.572391,130.188814,120.829104,147.173707,182.809268,231.623748,277.664035,331.204332,420.217967,411.503471,378.580862,385.017998,366.130856,351.571127,419.368935,566.288263,602.134351,533.275942,449.324615,286.026444,248.556206,251.928447,237.097759,235.313792,272.836097,289.194792,248.73386,183.180931,79.322241,93.778095,219.760288,356.056472,397.511384,338.365777,233.199703,-29.4564,-134.663936,-208.499659,-119.149906,-35.74453,130.762265,159.345155,71.150279,-3.205503,-90.598761,-78.003317,34.995794,141.137502,125.334199,-41.978835,-117.103967,-144.225546,-105.656173,18.988976,92.596673,105.764223,102.164146,61.856725,-61.816652,-96.151139,-95.353039,-87.342217,-101.827199,-85.340838,-49.099332,-60.189697,-119.430558,-148.017975,-71.548786,108.551033,152.490544,154.705845,182.205926,188.971035,179.618873,178.831977,178.509778,179.064557,191.122693,275.586397,330.512444,295.086266,207.315871,54.830498,24.489692,42.450236,76.765537,101.983346,171.25639,176.007829,88.933939,26.570437,-10.90544,47.894077,240.111537,325.251248,311.829936,276.01253,276.070757,261.357158,240.901832,220.510012,171.497983,127.234107,32.396496,-20.133875,-119.737725,-146.191283,-123.262336,-92.150926,-0.318915,133.600984,145.534642,17.496456,-44.083285,-16.563756,60.113321,213.366804,276.600668,304.005488,378.586346,382.349515,296.628163,245.267266,188.1442,191.66519:227.308738,242.186708,194.791381,48.439158,-23.699183,-139.951591,-154.01365,-62.221362,13.341994,15.766126,16.751142,17.334056,-22.300661,-65.754809,-91.309973,-36.234038,94.616003,82.924357,35.4596,-7.591536,17.361903,45.55487,28.89203,13.506577,39.922443,58.608977,92.642751,79.549635,-24.448452,-71.326903,-88.191312,-82.556545,-18.596374,200.475029,282.18717,220.738739,131.097374,-1.97248,-35.303725,-75.23722,-52.525514,8.265228,105.535958,93.205299,28.069429,13.442925,7.765556,19.216106,101.851058,164.223324,140.999475,23.59814,-31.072802,-80.976819,-79.140995,-49.959916,21.233823,51.75435,7.353208,-39.480186,-45.49921,-34.797798,-78.171606,-74.984561,25.362798,41.532121,-11.427305,-210.653508,-334.384123,-512.497493,-520.022811,-415.071257,-343.244249,-349.170088,-434.257801,-486.647943,-547.746805,-564.436692,-568.859236,-535.913171,-438.111501,-389.333958,-380.121888,-368.795601,-380.830147,-469.403059,-508.123381,-469.467876,-309.769151,-211.705207,-77.620867,-86.296771,-204.11631,-231.722267,-97.064894,28.068825,244.843745,393.105507,434.869662,434.472824,401.60762,265.497422,180.150576,63.765705,29.178623,39.463074,63.050158,29.578972,-146.022491,-233.152354,-257.342449,-186.178318,13.489139,104.674117,69.107481,-93.150956,-143.065156,-103.388803,-53.789115,-11.270268,-66.751775,-99.482589,-166.481614,-205.022122,-277.239122,-322.588886,-396.693141,-395.56203,-335.060482,-247.362474,-225.406522,-237.399837,-238.804748,-234.854346,-241.99688,-233.72934,-164.735355,-139.566133,-191.878515,-243.669179,-293.064527,-295.321241,-284.839894,-266.02682,-174.126252,5.246493,60.303136,7.891589,-28.616663,3.357792,45.534693,128.293492,209.631554,225.299733,158.455296,96.642504,-19.192424,-50.287264,-5.436932,51.390629,185.522525,321.843457,336.20129,244.331606,183.330383,72.24751,30.056831,4.979287,80.358953,158.087233,251.067106,215.760952,80.517894,43.632096,76.771183,118.03729,128.465063,69.233007,57.715735,60.787003,36.118072,-130.682849,-216.817982,-224.932548,-122.471273,-86.75569,-92.21313,-127.661659,-169.873959,-164.451697,-119.296037,-72.699236,28.662488,90.025216,105.959218,98.693566,66.90813,-49.370396,-97.853971,-66.826367,48.521663,56.104365,-40.127231,-93.921414,-148.342461,-163.771476,-116.917981,-33.195088,105.438969,172.185708,252.92846,434.914666,424.776804,151.81039,32.383881,43.158819,143.89549,193.416597,314.210286,344.111368,285.139806,228.349228,182.969869,199.318268,190.975137,120.776243,87.535353,-31.75739,-110.194433,-175.789271,-145.587645,-62.963809,-46.681917,-50.175468,-90.736521,-132.075314,-233.996216,-300.192683,-372.789183,-332.089844,-162.35255,-50.163556,-40.55659,-99.534341,-151.717154,-238.19121,-238.741456,-129.844704,1.906704,47.880169,106.935977,120.121065,136.772702,130.243953,54.711276,19.294242,58.522174,173.218699,194.720098,158.321456,127.937949,68.918822,66.452209,156.555211,183.172824,147.820396,86.853789,62.324326,13.378657,6.014137,32.467212,51.581453,73.306083,58.534284,49.830426,52.282051,66.376708,134.919738,178.203081,209.837722,223.271396,255.454621,274.46535,250.056512,210.894001,191.842518,193.450637,253.934347,419.788484,478.235372,471.091504,431.761297,379.12373,170.509756,76.005503,73.786147,152.95602,171.03484,241.092492,256.448293,148.219147,79.488054,87.012467,141.464419,232.026764,320.002381,347.032096,296.752107,234.438913,91.52311,28.774687,-37.46496,7.530467,79.798802,203.02476,188.170789,26.344643,-68.144417,-127.414608,-43.52771,218.853618,319.089448,298.050891,167.064528,77.177165,-24.347795,-7.660054,51.979965,68.108765,79.679745,44.15615,-8.302193,-92.956832,-117.708846,-133.892759,-112.79684,-28.673746,52.994809,91.260106,119.882174,83.4638,-17.343867,-21.607941,52.427803,80.792955,91.215496,148.797793,169.878388,141.544697,91.215299,6.879493,13.172705,95.614332,254.839416,344.927573,343.350408,221.434428,-49.289929,-103.033259,-5.234746,170.931952,218.607797,224.502496,190.516308,109.693398,99.605033,177.787819,249.222656,354.830072,338.369402,326.554888,396.594408,441.675374,376.706958,293.736846,231.231916,264.70006,257.965466,132.224947,23.146052,-136.314257,-133.933234,-39.440388,-0.698613,88.404659,166.67704,136.578495,-5.581319,-36.077243,15.863613,53.351769,109.938131,186.471728,227.271591,261.74283,255.92258,191.356109,138.969712,90.831931,107.003939:103.34677,144.918702,130.461248,-25.336847,-107.551681,-156.039392,-142.375642,-112.582707,-61.379175,-12.529767,73.344611,68.423643,-24.598317,-71.785607,-89.005644,-60.850642,-5.924163,39.843444,87.013001,195.919868,204.874886,85.42952,5.295235,-51.523389,3.720228,46.753605,153.490813,182.932321,88.790672,-22.880656,-199.781473,-209.227992,-106.729558,33.799916,66.550624,-20.694899,-109.562793,-215.073208,-196.235008,-127.038084,-154.855621,-126.37854,75.0278,170.956095,219.277,173.353543,35.26054,-4.249234,43.457437,172.863162,177.121816,19.894462,-56.864984,-85.335743,-77.610731,-87.400579,-0.792237,97.893376,198.024911,136.201763,-56.406555,-103.608942,-96.406297,-54.530751,48.779046,16.897051,-60.314592,-245.87495,-314.713983,-364.356207,-352.640876,-301.960829,-298.501751,-326.799373,-398.901364,-425.05919,-447.492251,-461.82805,-549.758063,-596.363848,-585.278482,-453.474983,-396.031337,-403.756264,-446.326561,-494.472492,-522.164769,-599.634513,-484.837989,-366.723989,-241.472738,-261.656505,-342.336125,-347.98904,-232.898533,-117.449032,113.134678,226.684208,259.54418,330.944375,350.010077,216.922182,86.314897,-85.445509,-101.675792,-72.768296,16.201366,35.041892,-26.977651,-83.192186,-137.148453,-114.033332,-29.249339,24.559963,21.869855,-47.043085,-79.002287,-86.120218,-81.733122,-79.390768,-87.644975,-119.02434,-204.618405,-224.657036,-246.124407,-285.275489,-401.24143,-435.591153,-410.158297,-255.478105,-171.62164,-122.510572,-145.744995,-216.717456,-244.5019,-214.837691,-137.558565,-119.062114,-110.496638,-127.995107,-213.141084,-258.34058,-290.215925,-263.383239,-162.902662,-44.40217,19.192788,97.02578,88.045879,-5.29923,-35.396249,68.395063,226.471359,219.15344,70.215917,5.532565,-16.827595,12.182134,120.858794,187.346451,311.3656,391.277166,391.233335,317.739874,267.405097,162.175271,115.315474,123.456611,258.84719,324.030302,374.569309,344.03201,219.743603,159.276875,122.589,156.137856,193.14954,105.263722,78.910274,117.452655,120.721429,-57.995839,-194.722644,-323.334526,-259.680841,-220.825371,-171.277811,-130.970408,-19.001564,0.153981,-8.70402,20.79001,97.011139,111.112039,122.970338,143.188348,124.801278,33.935354,-2.287193,5.477634,42.838146,57.325644,70.261698,48.392992,-27.302981,-50.42972,-9.150554,52.870386,159.885777,215.703756,277.504243,432.506558,437.160247,241.684419,148.42121,174.652819,279.279266,303.319004,357.360411,378.057454,326.297495,254.312472,130.50368,131.865063,206.303347,223.975478,196.212196,72.573502,14.112999,-40.9511,-42.591125,-0.343796,32.603904,31.799009,-10.652644,-67.427058,-208.585139,-267.632393,-320.05462,-288.759996,-152.413892,-65.298726,-68.735753,-162.077682,-207.250051,-190.247936,-142.490015,-34.157082,91.350086,158.33325,199.675204,160.203231,101.762637,95.352116,46.615949,16.741588,-4.550479,-11.791039,-9.21993,23.172242,36.387076,12.908014,-20.840321,-66.950352,-37.341903,0.184094,52.403756,31.055416,-49.34863,-65.174796,-68.678786,-73.800656,-89.64018,-98.651173,-87.903822,-66.062222,-66.400172,-21.796339,42.899606,172.822022,213.506271,236.96763,319.329518,336.097981,249.195332,173.718892,118.662298,154.750854,243.321855,329.658215,376.209166,380.90611,335.995339,227.569821,182.542206,155.570006,173.888312,186.809743,241.197084,256.381575,182.083936,109.876843,52.58402,110.289998,314.235626,462.965919,487.684369,415.866741,354.933014,232.276311,156.901924,58.77381,133.38207,210.911243,303.828684,264.769899,55.328223,-44.554974,-93.931613,-39.222705,91.911885,145.750722,163.481477,133.424397,74.787499,-5.781702,4.169768,76.793732,110.006026,96.145134,42.149679,24.232852,19.896812,-12.733613,-203.313284,-293.167661,-290.498302,-138.16745,-87.567338,-108.993546,-162.336178,-263.807922,-281.264004,-225.210737,-117.502595,-70.703666,-22.360356,-42.514782,-140.066782,-174.729373,-137.712573,-73.572921,11.436233,31.902785,65.643529,130.104931,114.223679,-23.776157,-104.094121,-119.954423,54.068472,127.137709,186.011587,209.711344,275.940931,273.234268,149.593617,98.445781,189.243614,393.081183,437.34342,401.111377,371.283027,328.248849,313.72374,323.808902,269.701765,201.955791,74.591854,29.384823,-10.084036,-3.915137,19.756369,20.910082,38.780513,85.259381,51.327454,-99.193243,-121.920405,-24.670042,39.350966,128.774466,164.875009,179.293765,236.228873,254.528535,212.08829,172.351143,141.379126,168.92666:149.268409,197.730285,169.197977,-18.825476,-117.583264,-216.029891,-222.966548,-180.510128,-43.71408,55.88859,164.879443,128.332075,-18.811372,-77.340317,-116.465382,-97.025594,-50.483103,26.83351,89.604114,159.02996,123.806985,-31.701618,-59.936397,57.152933,166.300366,176.748871,121.600964,54.666201,-101.401431,-164.364785,-205.624048,-170.605682,-33.651309,97.796514,114.356947,-12.613062,-107.177543,-211.606908,-228.836497,-257.101389,-181.843636,-82.43328,61.489745,59.779052,19.088175,21.572129,54.135537,65.856236,81.643711,134.148051,131.928528,17.596415,-46.397052,-131.671031,-150.76583,-91.319886,54.111329,112.553765,107.616175,42.218548,-92.918594,-126.992958,-135.185528,-119.565254,-54.231305,-0.769934,-34.8991,-225.489792,-327.429102,-423.059836,-406.757966,-311.748408,-252.451994,-263.08199,-360.171455,-409.787876,-427.211127,-413.893473,-425.094806,-431.904816,-375.195844,-336.485536,-352.037638,-396.698858,-414.236225,-434.103114,-436.217682,-417.086984,-302.708325,-212.529279,-119.856625,-135.613838,-182.425226,-193.558755,-166.122486,-96.236436,131.599308,274.912148,287.781773,289.181816,270.263415,71.705655,-69.356902,-164.827376,11.248701,102.744919,119.443658,42.193359,-122.237375,-148.84171,-87.538214,-35.489736,50.106186,107.346001,96.388863,-10.538145,-60.671773,-127.216797,-157.415024,-175.259886,-105.195858,-75.220076,-121.299807,-185.835936,-326.003154,-389.801171,-426.996803,-384.564818,-271.77835,-215.973722,-201.010709,-176.745395,-179.582684,-232.638254,-239.564966,-162.067371,-170.792247,-214.828192,-239.903558,-234.490602,-300.562304,-356.604621,-365.628777,-313.331354,-181.947076,6.975465,95.459341,86.854748,9.508683,-70.288203,-29.925441,122.255132,202.899582,207.838871,139.433796,69.359295,-56.602241,-68.058752,83.641978,212.386992,425.79911,547.564934,553.27894,409.999947,300.910687,157.062232,158.58129,259.636845,318.443353,327.783179,379.544755,387.336666,248.482293,144.370463,80.008087,117.545981,168.598961,202.860564,235.76389,223.200757,137.380575,-116.022197,-192.754614,-155.772833,-61.239707,-42.084581,-48.695808,-51.981997,-47.559239,-61.72633,-63.501154,-18.365325,77.229065,166.260629,231.647002,280.044592,230.806003,84.027074,37.78107,52.961695,153.405673,190.926987,167.740479,114.689243,-16.922307,-75.125108,-70.346951,10.948476,185.307408,256.393754,291.527407,377.673928,377.158853,220.192041,138.528694,147.82449,295.080349,366.087356,396.579547,335.893041,170.317672,123.060562,136.473644,176.556266,238.722259,234.557447,195.458069,46.898178,-18.392764,-64.349646,-51.166287,4.97395,71.610264,95.854059,7.035345,-98.562313,-273.216432,-322.709679,-303.454042,-229.413446,-93.089668,-50.417917,-58.282583,-146.161143,-206.829676,-267.636558,-228.130829,-26.77484,127.204124,165.260798,185.971544,153.638617,60.743686,31.154475,-2.61723,-13.865145,12.308825,126.065738,161.163746,142.614771,125.10083,83.383675,59.575161,85.160775,188.865495,241.0227,257.287215,208.566687,102.305111,71.698632,62.617679,88.716388,156.917055,156.400559,125.818249,47.247923,23.516899,62.496504,130.049456,289.974256,372.965667,379.118755,339.900146,301.062499,217.60695,181.053626,151.85183,174.478989,293.139119,430.329957,446.276237,361.50611,309.228302,224.382807,198.935618,228.5668,264.703895,273.034875,306.470129,306.543079,224.83394,169.263779,134.264933,171.653758,336.214046,498.039168,498.266878,365.082843,315.618043,296.895401,273.018922,149.958584,125.88128,189.569033,310.836606,303.147889,146.222095,50.372818,-21.092232,26.475013,189.732029,263.907241,253.670195,161.824189,82.253225,-69.367483,-92.647737,-55.209244,-3.695834,25.007037,19.677345,-25.463333,-138.199587,-204.149353,-311.911237,-313.902963,-221.664755,-67.545491,-31.494727,-130.55223,-201.978907,-234.521105,-207.841413,-153.936316,-89.845755,-48.33696,-16.153818,-39.863685,-131.543156,-173.026629,-149.387699,-86.089943,18.453369,110.507811,150.825909,90.894788,-7.337108,-176.044375,-178.918534,-11.018457,163.399181,206.956898,225.265352,192.650719,67.468599,18.008998,46.150193,119.427062,303.526693,465.918482,491.205864,419.245982,367.599624,266.444367,219.059053,201.273165,237.941046,222.575078,99.875211,26.790952,-56.317488,-72.608594,-61.418569,-21.751351,93.40205,154.723177,129.40959,29.361981,9.879216,18.771807,33.414609,125.292821,283.332196,364.325709,415.326968,356.089177,148.008405,57.043849,14.424523,62.039856:34.757009,70.633646,59.151918,-60.788772,-150.75922,-209.186715,-148.681563,-32.958999,-67.451322,-85.081984,-27.754683,1.28476,-32.366065,-72.060288,-156.193711,-176.493448,-137.707094,-32.746474,45.425621,166.246555,160.95952,67.325604,39.858464,42.088321,55.73496,67.891866,78.920548,47.802674,-52.37806,-75.701105,-80.036252,-92.152763,-105.805074,-16.308856,25.289014,-42.172235,-114.558535,-154.332495,-138.411931,-164.151063,-180.265416,-108.529185,168.456055,268.465891,259.649867,209.767513,127.674002,81.208506,4.044235,40.368336,60.5031,-7.913818,-74.94958,-149.262622,-134.857824,-49.236144,53.250905,107.535413,181.039328,179.622854,105.132851,48.22681,-39.614607,-35.148174,40.776875,43.742777,-7.812691,-160.291528,-209.057238,-243.863535,-264.542511,-254.948726,-140.938769,-112.513006,-184.146497,-254.48468,-372.920603,-415.818435,-446.152768,-408.1192,-307.528646,-318.184211,-337.217641,-325.5005,-293.482554,-308.009086,-404.308721,-584.039753,-502.937815,-426.52043,-376.961369,-406.595631,-428.941592,-392.337179,-309.260044,-262.017172,-146.081503,-104.318847,-84.193687,39.546791,108.518564,89.571882,-16.080893,-236.643481,-224.88104,-136.854407,34.562564,68.773809,43.114205,2.443221,-95.697656,-127.834658,-95.369275,7.072803,25.723718,10.755673,16.296815,-20.963866,-93.904501,-188.141725,-93.672375,-64.372474,-128.041211,-163.918896,-211.744574,-258.050704,-318.61649,-277.960581,-155.240177,-138.161623,-156.980798,-239.79511,-289.400006,-307.661714,-263.107385,-133.383318,-90.286349,-92.286601,-62.018877,-77.166058,-189.237887,-219.085864,-202.247431,-190.190139,-166.421982,-79.188189,-26.811101,-5.881864,-37.165793,-89.386928,-84.80308,12.383271,99.011485,66.616048,-87.117664,-149.93222,-194.104628,-166.211859,-30.429891,29.226885,25.200097,-1.533897,56.580637,220.502689,255.458559,190.285623,126.815603,104.110397,239.646568,293.082541,342.762319,356.99347,338.867038,295.740721,180.3218,134.682447,74.571005,38.597402,47.313901,96.496813,93.278566,-59.783298,-184.596298,-350.898926,-324.212056,-284.090479,-197.028746,-129.323041,-4.512233,-10.514766,-108.627914,-107.944165,4.822286,30.267684,16.098067,3.315561,-24.689242,-138.774392,-169.548317,-82.739476,45.87088,70.588842,69.854574,57.753017,56.451117,68.892312,77.320953,83.877931,122.046874,187.940321,232.149457,287.377513,289.225473,246.069125,207.319817,179.619334,229.875482,257.558263,306.707374,318.082652,274.541435,213.326828,62.945737,11.652525,1.380242,95.780964,143.65313,85.321577,-12.099293,-170.144066,-190.38724,-112.004606,6.446062,42.369096,40.653992,-16.114878,-216.093807,-314.785132,-385.707427,-316.455651,-62.431614,37.823974,27.355996,17.895187,20.988378,19.904601,32.742105,141.136484,244.527085,251.173151,200.255858,151.661193,64.226034,32.439873,-36.919994,-71.708842,-113.90006,-37.306133,20.799547,32.269948,-21.725712,-150.930657,-176.226706,-95.297497,26.755444,51.63786,79.663752,96.465167,62.598002,-5.928162,-142.084639,-157.752325,-125.065567,-97.598956,-66.369549,27.305238,57.773466,53.01256,41.580383,94.800162,259.211406,357.994,484.342125,475.111599,379.074647,323.994109,218.077394,198.299487,239.885263,290.658628,310.195187,319.628413,309.216229,258.568834,223.454423,207.118216,257.344216,286.332773,295.915219,254.412481,133.829204,76.073197,19.477462,69.346449,282.863634,407.182739,414.017334,369.160209,331.758624,249.128184,225.602641,275.62511,393.218084,436.229192,433.995357,383.365897,245.051898,179.109191,87.22181,79.585462,130.864702,210.323946,231.563057,149.939989,76.20039,47.670059,101.52205,237.543245,272.867472,232.546873,148.749652,138.611253,127.443273,94.134507,-26.26297,-88.780876,-168.345287,-208.809186,-242.234006,-309.249192,-304.068303,-226.817566,-193.908885,-180.079355,-177.393789,-163.555831,-160.172549,-180.209232,-181.13575,-162.879946,-145.777475,-133.453353,-113.901393,-67.202248,-10.329356,55.696996,29.651674,-51.206606,-66.533114,-29.486331,73.741595,108.940609,133.095001,161.137376,237.509883,243.050599,174.359118,145.149681,170.409927,286.260235,349.454791,369.978265,331.339266,263.192993,246.31781,220.157144,154.071384,125.279128,133.485328,139.971763,80.592621,23.683528,-50.060061,-32.452171,86.15993,121.164979,41.350232,-207.872245,-270.396097,-151.492678,-27.41974,144.394804,182.723919,175.849875,116.893461,68.056093,-15.767109,-27.175883,14.441026,68.024839:21.717892,102.983676,89.839628,-48.035409,-123.202177,-194.323166,-206.346383,-188.757139,-48.379524,38.082072,95.617774,48.621846,-90.458354,-140.908585,-175.602799,-156.067868,-70.905987,19.900701,66.128438,143.782609,136.904743,24.97589,-5.975889,80.054439,161.143753,161.966234,129.008826,92.093159,-8.455416,-61.084909,-147.553289,-158.198816,-85.21236,54.109406,88.787885,2.280425,-87.918382,-241.132485,-273.108107,-252.053999,-163.072039,-67.701191,162.435975,216.011887,188.018646,151.726151,38.951683,-25.603196,-48.896438,92.958832,141.645464,49.818396,-46.119356,-152.937807,-128.9814,13.026486,155.17714,214.246592,218.56153,143.895905,-31.347196,-90.157607,-147.221195,-126.867606,-4.570455,62.722079,45.387182,-83.559722,-169.397235,-322.919831,-371.623258,-320.970707,-136.556993,-84.773041,-165.091681,-269.497636,-444.367004,-490.416579,-515.652697,-486.590752,-381.971735,-286.513798,-257.652955,-275.03389,-303.97951,-393.08175,-465.965094,-535.303451,-349.626449,-229.456851,-135.660119,-165.320201,-225.821891,-223.450737,-185.123795,-153.189227,-43.428985,126.216174,168.050405,121.941062,105.647992,52.017312,-35.785311,-157.82987,-47.864493,22.071959,30.935002,-11.126031,-53.913004,-47.700713,-10.183937,14.896172,51.530979,136.620685,193.286204,194.687254,128.788124,-42.439697,-112.382316,-143.160297,-30.993175,7.528555,-68.450412,-148.78451,-250.675484,-263.106296,-234.51101,-202.399195,-167.300669,-110.008347,-50.990198,-24.179567,-93.426413,-288.891328,-340.986956,-286.422051,-168.836867,-123.076259,-90.314135,-123.293667,-230.350128,-266.927363,-297.264965,-283.667714,-150.060152,74.34427,154.690398,135.912003,46.434912,-152.644288,-179.82177,3.145125,187.552808,174.975073,45.860514,-9.312463,-76.579509,-72.333489,90.178274,208.845202,330.336683,349.969945,348.400801,290.059272,267.638971,233.399952,191.807417,163.927215,309.940853,404.026986,492.717385,469.04556,362.846359,305.105055,224.492495,208.664847,175.976279,132.935809,120.45708,115.79301,107.592787,-17.535095,-125.363069,-238.454519,-145.004194,-82.082703,-48.69128,-74.885891,-98.113613,-76.600467,11.72616,61.696289,92.119307,118.468485,163.988889,186.600509,115.402539,-92.252387,-147.748758,-105.484073,12.569887,59.629535,110.198443,100.757182,27.137985,-1.245556,48.614128,132.761024,275.172006,259.656405,247.90668,268.636079,252.617444,114.188091,48.545501,55.305952,182.873991,253.454116,338.805428,325.340711,213.161715,141.057268,32.070401,35.564302,133.396751,193.043573,163.891056,14.709385,-46.76043,-98.509866,-103.081812,-50.031159,51.121617,79.872293,51.330478,-6.999417,-193.868901,-301.285599,-389.58856,-323.749796,-115.444374,-13.306827,4.767481,-7.866157,-38.559563,-103.009875,-97.443716,26.129653,183.279876,243.353756,259.191301,200.887109,79.344763,55.432964,23.53091,4.001855,24.466213,124.117543,152.102617,137.853724,111.477265,4.010112,-57.602848,-64.571628,61.788017,132.433314,233.116341,227.871842,105.468861,25.81273,-79.665979,-77.564084,27.043463,140.311032,145.21841,57.890062,30.405726,82.123747,127.658072,209.406914,268.903006,294.432885,356.072983,367.256161,257.516532,148.135665,7.762483,28.584894,179.552172,348.006648,380.982796,292.504941,212.709341,33.199264,-23.216989,73.946838,264.769197,312.616278,285.197007,211.643077,50.719279,4.579591,29.311614,113.771885,319.671183,420.897717,423.753765,365.103961,339.691118,308.887817,267.711755,151.801558,151.41294,219.993,366.151816,362.425763,181.662596,82.605224,27.560197,64.989678,165.812586,225.156604,211.07562,60.066471,-34.096978,-106.028999,-53.985801,134.236095,187.70383,160.456013,84.012715,25.918801,-146.296942,-238.333345,-345.732379,-334.533489,-221.127159,-152.868336,-189.342454,-357.706786,-416.871755,-432.466543,-420.40534,-338.242731,-203.968163,-172.672489,-209.250774,-250.78263,-317.663981,-338.916918,-307.274227,-238.863558,-99.098861,-32.905484,-13.53173,-33.780649,-86.137496,-206.689597,-224.925876,-133.871027,20.360835,89.499645,186.623303,211.592947,220.423829,196.642044,126.223119,131.998908,290.901182,494.926129,527.184259,432.039466,353.907133,221.921831,187.709044,202.576606,199.108593,179.88562,168.767853,148.309162,31.533562,-33.238827,-83.390217,-55.761935,62.844288,137.219994,106.811375,-33.323993,-77.706917,-64.299271,-17.534634,119.702929,227.496863,261.769718,262.918237,206.241186,54.190554,19.76034,64.588427,116.538138:66.367584,116.047723,103.983109,46.225041,22.616361,-27.63868,-66.890298,-137.620759,-166.942692,-163.934244,-104.587493,-62.987939,-1.981929,3.451184,-59.55659,-91.192154,-71.048023,-25.030942,3.490146,92.727262,121.451561,129.19563,140.935621,210.527331,300.174085,326.483224,276.317209,215.192235,158.831309,178.473386,223.413094,224.319327,215.321774,239.310371,217.654568,26.628492,-73.964899,-84.04534,-34.539001,-38.083938,-62.852368,14.726589,292.178717,394.066994,402.950912,337.616361,181.291565,134.321893,107.204864,104.748168,121.336696,148.440391,124.024688,-19.564003,-99.623714,-137.339669,-43.074201,7.404806,138.528919,214.155971,243.566042,184.36779,77.979124,87.445117,171.012183,124.77757,54.516592,-46.294034,-53.974369,-19.006445,-6.760217,14.520976,113.170162,172.145446,201.578462,160.526426,57.762015,41.093346,108.385705,177.795654,259.879161,112.977495,-13.263946,-205.37142,-230.659709,-228.113076,-270.649112,-398.344556,-364.495258,-295.032494,-216.520992,-238.426255,-299.943662,-294.776722,-212.336346,-163.999036,-188.832166,-297.719763,-276.320988,-136.873337,-92.545224,-83.555545,-95.499636,-110.465706,-94.294825,-77.258029,-37.257366,-2.263256,91.667112,109.152995,49.11349,5.276049,-41.916596,51.495259,134.549197,226.033892,236.229512,215.081847,177.383126,108.694219,114.898138,116.137177,50.665035,6.987218,-27.122249,-14.855755,11.939424,5.210437,-85.122965,-226.63907,-256.005721,-269.13195,-289.966581,-310.995115,-283.683695,-187.7804,-110.373815,-51.78337,68.67716,60.679437,-20.588383,-15.133017,39.246095,33.962599,-32.561931,-63.320348,-49.152506,-5.764214,9.115827,-1.084142,-34.551402,-83.357966,-42.263831,-33.58828,-83.054592,-119.759684,-168.185749,-175.486066,-194.309826,-207.506698,-184.66844,-87.201014,-25.280159,103.065883,142.014561,81.138037,7.160432,-44.560929,69.067582,154.851543,319.075155,330.848954,175.796269,100.197335,79.237869,87.443923,47.356564,16.204796,33.035009,44.498036,11.542635,-107.690482,-174.242625,-274.028319,-317.487051,-315.081204,-267.046268,-230.409228,-170.120613,-172.977514,-233.629466,-247.370168,-201.193717,-111.691775,-75.573735,-61.19932,-84.080695,-192.203505,-243.751795,-188.747789,-16.96601,33.469739,69.599481,70.389649,75.450953,85.938365,104.613699,122.660871,154.127486,141.864944,137.107976,94.810645,50.691537,-22.662477,-29.098701,62.524234,198.144702,213.885757,154.092917,121.654268,52.476396,-18.542859,-187.116051,-224.326202,-187.34823,-165.139797,-198.6611,-288.495811,-289.466466,-234.549346,-252.737835,-344.434111,-311.225244,-270.70335,-245.77048,-272.658522,-364.066303,-403.019442,-429.919617,-385.786308,-225.000555,-229.48987,-282.279111,-290.710757,-245.383951,-145.648625,-89.305859,35.916442,62.74721,23.298727,-68.939022,-93.840678,-48.926845,-3.61794,-48.39156,-134.432314,-265.356599,-242.926465,-198.177572,-122.930393,-97.707007,-110.4508,-174.184596,-266.102064,-133.767158,-42.971519,53.633948,57.851446,5.713028,-63.313631,-246.284216,-288.519258,-196.191241,-28.631327,23.240534,1.931588,-48.304166,-73.06374,-28.668232,110.143363,184.780745,193.355515,214.100707,226.241799,229.620187,201.327451,66.973391,0.180759,-19.477609,59.852443,76.367803,35.243738,4.358307,-43.144567,-41.398639,51.707323,139.556698,144.329436,94.00021,44.513018,-69.81789,-116.255315,-142.907305,-88.597448,109.990641,176.12448,153.230778,95.814812,79.591204,84.922173,112.896518,230.340356,340.646385,378.642988,413.896234,389.55999,282.631913,228.087599,148.947159,147.879152,178.572078,145.049582,138.224071,121.011721,79.462872,-18.530007,-31.547828,75.672597,194.715161,190.025546,139.923929,140.190216,120.037151,60.804275,-94.694214,-149.94857,-218.121528,-287.49189,-303.070585,-308.560052,-323.09666,-345.509653,-332.258306,-260.284416,-203.669325,-202.304712,-206.994014,-187.402729,-109.090357,-66.648057,17.820249,53.226477,50.784397,43.95122,88.45374,148.840948,130.425695,65.787897,31.573201,-29.581626,-36.240026,-10.881344,58.754188,74.223882,74.517916,55.144738,-51.666936,-89.340599,-5.945169,176.989116,224.596009,228.889581,225.004554,207.800967,173.804453,92.444637,85.522219,118.216803,163.482266,146.675307,83.83265,50.170901,-24.627828,-36.53415,31.206957,98.273135,62.374609,-155.245523,-234.989498,-176.656482,-107.616775,-49.375095,-61.645324,-91.700279,-158.297768,-151.980271,-106.53322,-111.391591,-134.931875,-102.189008:40.458089,106.936767,125.487743,51.898655,-13.337513,-89.503586,-107.161096,-140.473273,-105.925325,-60.58587,10.473208,17.659968,26.123514,25.104593,-81.326356,-144.290461,-153.454996,-87.658805,-29.269454,135.058973,193.535416,170.779885,121.88424,124.980963,193.420303,205.59185,212.176201,197.514101,128.216314,84.729648,21.464737,22.496865,52.832665,61.841629,48.840588,-26.825178,-68.09223,-101.988029,-94.186228,-59.630595,-35.531345,-0.961871,144.699616,211.928626,266.815496,274.383409,258.681226,200.13015,-4.10916,-89.929327,-56.887825,24.025791,22.639664,-67.633553,-120.425855,-138.972168,-41.176782,12.031484,95.577214,139.958054,225.478447,239.365208,200.940659,181.805562,188.201116,178.385898,137.304698,12.401425,-24.59687,-16.371496,-7.197516,-12.717607,-5.451194,-4.396271,-3.108436,7.807718,6.411663,-36.278206,-168.105565,-189.761848,-104.633993,-71.071423,-111.574749,-166.475707,-158.8513,-183.303524,-251.446536,-423.302435,-483.897396,-474.276278,-428.483303,-418.910274,-441.750474,-450.836865,-420.023828,-366.55895,-220.424839,-177.413856,-193.307274,-202.747666,-166.41394,-59.849153,-64.492655,-230.170074,-377.835205,-363.604494,-221.804329,-162.180563,-122.381524,-132.961943,-193.971547,-234.370667,-280.307139,-228.424697,-167.586238,-22.857824,49.64025,135.972275,127.594389,73.174221,36.870959,0.926906,-102.145184,-153.948461,-236.477743,-256.237686,-270.330437,-281.663469,-322.188541,-284.335567,-228.051685,-199.34662,-221.132931,-137.721945,-26.236563,135.074639,116.567448,110.37506,132.538838,114.916018,78.507816,88.532338,71.407978,20.35209,-105.321951,-101.40313,-36.18965,12.746954,-53.726498,-213.196184,-221.951186,-96.754761,-36.283102,-84.29582,-239.921345,-303.08093,-354.617367,-327.133869,-200.537125,-155.165335,-189.709545,-218.936143,-157.522584,16.312813,67.316464,37.835074,-23.402632,-76.150285,2.815642,52.787958,157.722292,179.727606,128.928739,89.34769,41.483823,27.433566,-5.33999,-47.37827,-71.774607,-77.426844,-62.580564,-120.828377,-198.694517,-303.747533,-293.357552,-278.150294,-244.159276,-210.91884,-150.150153,-169.309406,-247.385477,-237.191394,-139.580765,-65.216896,-23.205697,42.454959,12.50837,-149.383272,-201.56468,-144.091995,-33.612618,-14.187125,-0.905736,11.687273,49.956017,76.723252,147.220851,177.108753,151.179976,86.978801,88.623172,109.016192,107.714646,52.78367,1.356264,-29.573342,73.744643,122.010685,142.910111,109.005956,18.169368,-20.64515,-136.070687,-187.163539,-181.307696,-116.376075,-119.492778,-224.316206,-257.343575,-199.973631,-172.297785,-176.820323,-184.211604,-196.795732,-233.538225,-245.614983,-297.3609,-353.4004,-411.329513,-345.589285,-158.117862,-149.244977,-161.963596,-122.830248,-88.991101,-67.981388,-76.959336,-30.152025,86.052238,107.844164,23.143554,-36.771757,-43.872051,-9.811152,-4.515494,-32.706274,-92.949858,-122.047735,-105.698927,-30.925146,-10.351632,-87.39859,-155.785361,-159.902673,17.064049,84.470352,113.32572,108.511543,110.229329,99.968093,10.286051,-51.577581,-114.917859,-54.241548,-6.626774,2.891571,-18.575118,-4.076207,17.636952,48.333079,104.355088,160.823581,317.080912,374.007116,379.377688,345.233849,263.247361,225.133581,156.746398,172.297935,202.00806,144.252673,76.284528,22.369059,27.074181,70.541192,203.78505,264.146273,264.530533,207.057265,39.819043,-36.640776,-62.822435,4.467384,162.486604,189.740289,176.438198,113.750969,67.1108,34.540346,71.981514,194.089743,217.327898,207.332333,231.371767,233.853577,150.186358,83.239167,22.907616,48.858005,92.876041,130.331439,161.712423,72.416139,-49.099695,-190.782314,-155.628753,44.011166,217.565897,235.164952,201.010814,196.826996,151.22583,66.39894,-159.986533,-225.905331,-216.168396,-174.8968,-189.589285,-264.6827,-276.948722,-257.417921,-268.216498,-259.923884,-160.59578,-136.834701,-189.347557,-223.974173,-164.564976,-92.662245,-20.214889,-16.844768,-44.444365,-33.325073,36.188572,169.770355,160.535355,31.060547,-29.01829,-54.840561,-34.567089,-34.383892,13.213836,58.402248,74.322601,13.3465,-138.151928,-139.328091,15.426826,155.128556,188.281936,216.668535,232.306178,202.906415,131.831272,24.738769,75.891056,127.73658,164.180528,111.343746,-51.448338,-100.221385,-103.045056,-83.858592,-45.843348,30.530074,31.509536,-113.448275,-163.189898,-29.841087,92.653649,225.816167,177.898179,118.623927,19.405959,4.642351,17.27567,22.72458,31.351096,46.402234:29.085878,44.835349,72.946385,53.901579,-8.726198,-135.378849,-169.686767,-140.702802,-27.132056,3.181854,16.180176,15.840624,17.694157,2.317896,-133.940035,-197.847353,-125.432181,39.007128,69.802139,60.418399,57.478656,39.126591,3.011114,-6.087692,107.560716,130.131069,91.814041,79.325069,102.349621,99.840819,35.894399,21.543651,60.723725,90.303152,80.424167,-36.193866,-118.764708,-210.258343,-218.190221,-159.021518,-4.175652,84.895495,272.558036,349.584483,380.201985,330.559487,218.843735,187.633265,138.945987,110.238289,110.050688,57.27066,4.064247,-80.923817,-99.773098,-48.8003,102.099686,164.914458,186.925518,158.94154,106.962763,88.363616,42.280173,41.243076,92.122183,65.749924,5.099405,-123.287773,-153.064136,-178.518712,-192.206031,-146.347495,-15.15625,9.830412,-52.716289,-106.395848,-194.725999,-216.099183,-210.71723,-194.394364,-179.669121,-185.771102,-190.279363,-213.559491,-225.209592,-270.891793,-328.181704,-436.099623,-356.318909,-268.059887,-158.913502,-146.72687,-161.25766,-184.03803,-205.894127,-186.144421,-130.94117,-75.646951,-45.475145,-33.125992,-49.265151,-77.368446,-96.44449,-135.539507,-110.398702,-88.268845,-46.6805,-28.504428,1.166156,31.55248,97.595822,100.787786,76.662286,127.864922,161.219391,137.55334,97.453285,-1.274927,-63.472091,-107.876563,-13.88115,8.575265,-51.893985,-82.109821,-75.77134,-73.664465,-102.481596,-115.69141,-141.988297,-141.657821,-118.890948,-129.355463,-179.726368,-285.890029,-311.764731,-281.145232,-225.881317,-198.819008,-85.061382,-40.608631,-71.663123,-112.530568,-149.521669,-138.444727,-105.516708,-41.242033,18.430916,15.695034,-80.605152,-250.460963,-255.985906,-121.154884,41.559264,55.493201,-29.74303,-74.947287,-96.421385,-71.051334,-3.808271,22.558109,81.887478,137.470975,158.833886,204.860419,227.342201,220.800462,185.289662,128.06144,152.174532,176.312254,267.981102,322.859797,296.894725,213.318127,102.731828,113.663949,157.022759,114.774444,81.796373,37.071448,16.314789,-74.351975,-141.688037,-211.571205,-175.708099,-165.732216,-157.131616,-140.828869,-134.074917,-160.392629,-206.430996,-181.893625,-58.302074,58.814307,93.780685,21.496512,-75.316253,-208.604647,-206.488704,-131.360036,-105.27654,-94.810798,-31.350229,-16.125594,-20.104006,-2.84627,78.712658,126.985449,182.902322,143.424313,120.252167,109.982368,105.402835,55.938397,35.792084,100.694723,232.523663,271.83543,236.042959,166.246045,82.095756,84.366379,39.839215,-4.270768,-63.309468,-59.128467,-37.780148,-54.965317,-80.697162,-71.694336,-77.227639,-175.423701,-197.246458,-143.333623,-67.270193,-119.646653,-323.86033,-390.707639,-402.146652,-337.225378,-114.957502,-40.03572,-64.792825,-83.764034,-45.353449,90.909094,137.467974,139.235135,126.801238,130.651317,102.23773,56.835289,9.879405,21.076345,-41.183458,-123.231385,-246.662329,-176.561989,-88.928509,-1.103757,-36.758924,-197.114263,-256.104149,-190.656292,-38.952078,-3.417263,68.054643,96.949035,21.442431,-59.56876,-149.959903,-139.868385,-62.33402,26.179292,56.940946,76.80366,83.339706,77.856454,57.751707,81.726087,181.352792,199.588049,167.302842,153.554343,175.438303,167.534732,16.520636,-62.13436,-41.263477,148.791933,212.353751,136.209613,59.065195,-10.531599,-20.613122,21.091767,125.147679,147.901876,161.290315,162.170683,83.33409,-3.030352,-113.646891,-68.686372,133.239256,249.881921,257.370553,184.246194,134.244081,73.446146,67.290715,112.058536,210.505104,272.653941,362.580238,339.807458,176.98901,90.822382,9.661391,47.588641,206.562207,295.676038,301.825983,248.618658,208.677648,117.199589,79.685873,106.063394,160.811925,137.546306,88.167534,126.417095,248.655981,219.911867,-46.771046,-138.856012,-70.677593,-72.635814,-161.297161,-297.497459,-316.693253,-353.417319,-390.155933,-392.272553,-214.917014,-147.791522,-177.763421,-220.483678,-209.832759,-175.155021,-113.409202,-68.828541,24.340794,62.827016,66.843437,37.604819,19.663577,-23.197915,-67.667431,-124.372092,-33.414493,26.562239,97.480019,117.768567,177.637892,193.943402,139.855867,115.452555,179.446227,272.117508,275.887321,246.309947,259.41206,288.943486,235.455119,72.555636,99.012544,185.404578,328.024651,307.905915,113.920015,10.095747,-88.481621,-51.107713,127.039665,194.021208,139.582724,-62.05129,-144.409648,-177.635522,-134.589792,-13.251128,58.142707,64.885921,6.793249,-54.020742,-147.234915,-140.743394,-42.929544,18.937373:backward
94.564612,41.969706,31.035047,32.429272,20.395359,-48.033909,-51.144582,75.455974,114.716708,63.063023,-47.176392,-87.997272,-116.78208,-79.346865,59.634721,98.556311,45.132892,-41.590183,-68.212526,-106.727461,-118.446402,-120.993209,-90.78831,19.094067,57.413255,58.921112,54.401758,55.105822,121.536675,145.446258,80.428706,39.254617,32.814594,64.990583,54.822471,-83.31152,-184.031455,-265.648603,-222.41981,-135.760167,-206.302358,-265.760521,-376.30419,-435.617628,-512.940309,-500.799898,-404.036471,-371.686392,-417.524379,-462.689917,-441.318335,-352.723305,-306.719142,-236.862292,-187.392063,-52.78702,-16.885253,-47.715905,-131.803482,-145.815318,-49.841014,48.359948,225.762074,254.509304,209.962157,168.331258,139.091127,5.996392,-52.926687,-63.985836,-24.943832,74.539663,41.5195,-24.828915,-116.341058,-124.839657,-107.880298,-91.213518,-18.643601,37.54652,121.529541,56.531473,-28.585422,-129.285526,-85.284316,95.393207,146.082065,127.705515,63.446678,24.55195,-92.571867,-139.441272,-114.328844,-70.509193,-18.083503,-5.806708,-26.675127,-140.450428,-206.558729,-316.129132,-334.190346,-276.623805,-228.161788,-107.083397,-3.361798,-17.956814,-183.272294,-247.029808,-181.6632,-92.476473,49.564721,69.702917,22.776886,-31.090174,-64.216262,-125.083732,-106.883336,28.804695,97.92914,143.505626,44.776722,-3.084976,-19.84366,-27.583818,-119.021572,-179.702824,-160.550702,-49.467577,130.356175,21.073223,-47.679933,-30.254045,3.779691,-82.190819,-158.643967,-155.830115,-138.503564,-203.62454,-371.72137,-397.522245,-259.146514,-149.643194,9.665074,58.220089,96.475801,-4.820375,-96.448538,-211.401168,-189.301961,-58.788478,-0.078732,75.134395,55.072125,-0.743914,-141.100898,-168.169813,-83.315247,-21.948387,86.083196,149.168491,232.201236,205.535026,162.509561,57.914469,19.044396,5.204889,40.652962,117.208696,65.935641,27.036237,-3.767655,-13.668218,-96.596269,-177.587595,-265.59884,-193.06317,61.656225,56.52655,-29.339513,-100.014035,-73.660553,-19.82364,13.654756,123.778541,120.389499,47.542187,-110.976269,-140.599624,-87.259632,-48.780583,0.296631,39.365508,157.569827,214.225951,192.770766,73.055009,28.140929,82.029116,153.144139,229.748525,85.72262,-43.441934,-247.941796,-300.052916,-292.056096,-218.473835,-21.220202,25.554693,-3.178834,-37.443107,-60.475356,-133.694033,-147.478788,-95.672556,-49.477271,28.256249,16.589735,-49.745487,-208.632797,-211.376537,-69.073794,-19.827637,-46.924319,-87.194127,-111.687338,-21.64144,-6.010023,-94.786592,-124.544541,-26.846643,58.033592,128.772127,80.362927,59.199788,-8.725469,-63.132739,-87.85787,-42.436078,55.752797,96.978762,176.379364,142.423744,70.038784,-83.128597,-124.70389,-65.720302,34.865361,196.91739,101.48711,22.128998,-2.553203,33.154382,79.913774,96.135349,211.719945,290.095889,286.121026,47.198305,-71.675139,-162.020286,-119.414563,53.338941,102.162337,45.306389,-17.351247,-17.263974,-32.130109,-30.904375,85.878704,144.577171,101.896374,52.958789,73.154741,179.919069,181.912799,37.393685,-48.651449,-108.182114,-72.486598,40.336495,98.684008,149.296142,235.904708,206.23343,81.04178,58.068899,68.423473,55.669594,27.101253,56.31108,60.021279,30.894935,22.721579,33.444815,66.540309,190.242882,231.638241,191.156745,18.790798,-65.273541,-69.144816,11.969969,173.189857,185.573789,75.87328,2.751756,14.69094,79.766372,109.50575,116.700213,93.292576,52.583966,14.436782,-27.871766,-139.648023,-188.014724,-187.262248,-125.803191,45.535946,111.880871,137.156491,84.658837,65.333226,83.409739,137.429359,284.170897,335.238695,350.156965,278.584653,242.323164,176.627379,137.934893,112.622909,148.756019,222.076333,192.560409,5.10375,-110.654925,-116.775368,-69.710824,-12.266352,75.895345,57.732161,-38.349524,-50.944512,-53.53361,-148.647432,-174.991462,-31.035474,92.838408,266.161077,263.942098,97.771888,-9.67068,8.395058,123.181343,169.267991,93.54634,9.912983,2.606743,157.420364,192.00841,76.471262,-19.637446,-48.289501,23.9343,202.031253,262.833557,181.728957,-84.983532,-156.936237,-70.84698,29.983148,158.181671,182.325066,224.97912,199.398871,154.279531,34.583874,-26.59784,-60.294827,-16.790424,102.049066,137.86807,108.833887,-39.663321,-115.352556,-156.704518,-109.397881,8.413661,51.175983,144.08089,199.099611,169.49533,-35.691638,-148.751242,-215.711377,-191.200613,-123.320506,-70.992008:99.012982,16.992926,-18.5704,36.292094,73.977115,50.067546,58.544118,186.911472,154.299851,62.26792,-77.015252,-86.853872,8.236379,83.142867,169.614793,156.385897,61.682178,-13.561405,-38.645998,-121.499413,-162.528635,-103.952306,-10.170876,128.687874,127.194829,108.882197,55.16716,41.485967,124.671632,178.327519,151.036446,102.614001,89.663164,144.237681,135.236091,34.910227,-12.476666,-65.481515,-79.233999,-110.292398,-171.896337,-195.032496,-247.70817,-306.118226,-445.252937,-466.531255,-378.909453,-333.103444,-358.12608,-387.759822,-372.624784,-349.251383,-317.314198,-159.568156,-76.078636,-47.899127,-132.89396,-150.425704,-171.548775,-178.070413,-62.560443,46.346226,169.736808,168.256313,167.856534,157.487226,125.500331,111.703096,136.084856,107.986895,73.032848,114.507302,166.44564,129.01791,38.042577,46.369838,115.930462,121.745119,96.355419,105.224737,170.405532,178.750731,136.723733,59.085758,49.967387,60.155597,88.418539,188.555803,155.770448,64.774515,-106.330023,-122.885716,-1.824416,78.059757,107.844747,38.618774,-143.888697,-200.381542,-193.428019,-216.313726,-241.743986,-208.594556,-131.15614,12.56351,-0.711325,-26.321759,-97.999241,-155.106925,-174.987503,-83.785711,141.774009,152.590039,2.265063,-41.26484,-22.124289,2.794389,32.215616,166.246547,230.174345,225.413128,82.840021,32.315213,29.440468,39.461655,34.332805,43.988829,135.574913,183.905327,127.492485,-74.565078,-123.044675,-52.181001,-1.144583,-17.94079,-47.678628,-11.803095,-68.825756,-163.238752,-292.210948,-288.605814,-152.891928,-41.290003,147.618092,178.991478,141.424588,97.57869,90.115388,97.943928,93.342517,55.985416,76.673764,191.426424,104.507441,-21.74346,-195.202322,-182.697031,-88.015046,-68.385357,12.346889,88.664011,138.696559,44.272239,6.118334,-20.716406,-20.532483,9.893654,26.862847,11.927746,-26.613523,-36.360936,-47.076618,-64.737814,-162.308501,-205.280863,-147.878478,-73.786609,2.099932,-70.497861,-115.547206,-115.157284,-96.411267,-68.246832,-16.989856,107.330068,-16.098004,-156.303765,-298.846525,-242.662822,-59.910099,-35.641407,-45.426325,-4.303068,117.548725,132.353244,76.475276,-101.44101,-153.31724,-85.6008,-14.228245,39.076874,-55.177481,-119.702095,-236.868557,-280.148594,-265.154158,-193.0043,4.908967,60.451505,-13.22842,-105.19527,-109.056229,-115.554666,-116.668342,-24.752878,40.664151,27.322833,-36.124163,-42.665592,-121.46963,-168.508253,-134.617013,-65.778999,38.815065,36.203873,-14.791414,-10.692905,-13.425388,-8.284801,44.962111,222.852179,283.00511,226.597981,118.61787,115.863119,43.752386,-39.571486,-105.339075,-60.231883,114.181016,216.477268,314.93375,189.988432,97.487844,-62.632245,-103.857577,-14.080834,105.145095,262.722527,150.887068,70.601463,30.965399,56.258048,126.56351,190.883622,372.424894,407.722256,262.709701,56.638766,-4.282209,-27.301922,17.02087,181.005414,235.519795,211.704388,192.152655,202.727871,159.348159,133.073901,203.589704,247.751648,207.269519,169.211659,188.490614,227.917269,197.498288,90.463836,55.822931,78.48489,130.801975,175.0727,120.879073,138.830601,167.723426,119.980413,37.483429,62.631096,145.500487,131.491883,42.932973,68.341236,120.588739,194.057194,177.902949,102.338491,113.733354,215.065589,169.611493,102.227166,11.299616,1.189484,64.700344,125.984793,205.469429,186.66727,39.5837,-92.033601,-103.519673,-13.113836,58.594469,124.596828,106.722366,53.895606,-10.670541,-52.364504,-114.019392,-134.045279,-160.218774,-140.611443,53.222017,173.097665,196.990121,36.048435,-4.805623,34.720986,86.014119,184.687879,214.765556,184.610725,132.336495,126.759304,106.090834,101.011559,145.393204,197.618834,252.388541,198.720878,7.832964,-95.726888,-90.759287,-3.201871,56.42796,109.686832,61.595949,-86.659791,-132.19346,-155.848164,-216.159858,-193.045535,-61.393198,-22.392777,-1.145464,8.839604,-42.891494,-162.030905,-165.416368,-53.364683,-16.224231,-81.58907,-125.367302,-77.348828,51.009774,71.917041,-28.370773,-105.502833,-120.992914,-40.559903,188.722639,253.931807,132.988246,-80.236978,-100.409327,-8.893077,39.223339,117.66849,162.908117,181.986347,62.734353,13.831936,-16.636809,-13.858381,62.247168,111.788195,94.257206,31.564054,-57.53506,-2.384059,28.705022,26.21699,25.539156,91.630229,157.377645,293.637916,267.011031,159.861718,-91.187059,-153.252519,-150.64579,-147.433371,-167.196306,-152.034888:180.977945,136.534617,108.036551,79.446785,91.624898,164.890372,236.143488,355.497942,228.299293,123.665733,26.835522,33.735361,126.037069,202.237225,324.804126,317.302269,114.303167,-105.799896,-123.811044,-42.998092,-17.875985,27.649564,93.810043,211.19396,147.279452,96.583487,82.109644,142.544811,344.130398,399.033857,316.190298,257.559562,259.516317,247.676088,202.751243,108.701856,70.978324,-3.690968,-33.884982,-96.872384,-215.084329,-253.20692,-257.774537,-285.015512,-436.13941,-469.475067,-323.421661,-236.248808,-270.947946,-398.793194,-389.686584,-235.954982,-144.402873,-25.620822,3.334737,-52.081163,-248.223312,-279.445273,-159.571408,-77.945098,89.136932,168.473178,194.508333,132.487034,40.025605,119.800038,168.582311,208.647486,224.063068,254.797299,266.657044,276.538569,172.26929,84.629989,-30.106008,-12.417136,130.345468,184.005285,184.615551,156.520896,111.766381,97.798189,90.930226,113.269457,134.626814,129.318818,109.473742,68.686458,85.009413,99.376356,48.220673,25.846481,92.096668,147.40486,222.093528,213.456762,54.977682,-105.126062,-122.483646,-121.543461,-145.482737,-233.44207,-241.607127,-139.060131,-62.8866,-55.473101,-109.837173,-170.345251,-213.989878,-155.057986,19.679432,65.528917,69.483401,23.850927,-13.945962,0.587366,63.134364,135.248498,127.131838,126.32956,122.100482,82.609766,-26.399317,-54.399742,-12.079087,32.045914,106.519754,131.203168,110.349379,-16.909919,-66.285342,-55.320981,-19.397636,4.939177,0.785682,49.662927,64.348957,25.45165,-68.420451,-78.513489,24.528367,119.245572,288.765297,319.392658,288.019264,226.692764,183.303466,111.998825,110.109046,167.629945,219.700746,258.565479,70.908254,-28.338677,-79.596907,-45.329318,40.417122,69.109575,147.961821,191.268951,178.934796,75.729965,32.428263,1.081093,22.255746,108.323446,124.777436,44.42744,-23.772445,-18.715932,-29.620603,-61.423168,-102.300418,-87.87404,-6.441491,20.281302,-14.693764,-68.60346,-81.276581,-95.41226,-93.845059,-51.749808,-13.699898,43.277108,36.963795,-7.478295,-156.093053,-192.481402,-109.893634,-48.118066,-19.769763,-25.476043,9.448833,7.358907,-29.600333,-112.045854,-112.336502,-10.666468,34.939227,56.088203,9.137197,-81.633729,-349.961957,-426.826287,-367.714079,-265.025615,-18.582561,61.25403,45.281335,-53.974104,-80.669311,-121.999544,-131.521635,-22.703351,66.008375,80.25501,-31.32018,-69.909834,-149.556312,-146.070719,-14.924709,42.505352,75.384468,78.499585,75.049493,9.067606,-41.957817,-30.104003,67.085059,278.032204,316.788151,240.388755,101.423658,64.155098,-11.699645,-64.267737,-130.996018,-121.867483,15.022466,110.451673,186.014935,88.289497,21.979768,-77.714901,-90.241227,-2.889541,78.859785,166.013214,71.66276,9.349085,-5.775316,30.483747,105.782786,160.752486,292.089606,323.580914,304.874882,195.686913,109.746042,33.048317,85.712631,248.864135,285.130177,242.479465,213.015134,193.372457,68.817556,26.991888,128.607032,226.119538,305.064016,262.490979,153.572721,111.93338,82.047704,35.098798,30.835853,52.367422,102.475021,244.061231,256.323968,222.625131,158.176439,131.262584,105.902614,136.837122,249.763789,241.583567,31.035592,-112.724626,-69.234625,114.368507,148.114347,113.212488,143.328193,293.981046,292.73765,205.066502,-17.767779,-66.897473,-2.693573,49.80264,143.52651,153.79255,-18.580526,-232.690903,-235.933346,-104.214378,-56.670322,7.600485,67.01126,107.542597,-1.41886,-21.518031,1.412522,-20.663165,-132.380168,-141.317219,61.04482,184.180801,182.591875,-59.260959,-137.671974,-37.878761,74.078016,168.505341,156.246925,64.413464,-57.339041,-71.599823,-17.446963,31.48138,123.114526,155.079369,207.86023,197.525413,84.633227,6.746198,-12.685768,-42.794455,-22.290505,98.24828,131.036254,5.294092,-245.554382,-335.077051,-354.895638,-297.802182,-160.181372,-111.57209,-72.652172,-83.020125,-180.375594,-278.088224,-273.549216,-243.431478,-257.713702,-264.614846,-212.168168,-37.463801,47.062392,28.610918,-41.91719,-48.487157,22.478067,83.087548,190.593221,199.934089,116.006006,-14.628147,-51.24498,9.472247,93.210017,254.586337,275.835096,179.321807,91.631931,73.492242,-25.860616,-75.788665,21.01086,113.969143,100.007117,19.117228,-56.58499,-19.528741,-3.082586,-5.688444,-22.059737,-29.304925,6.456327,114.63017,93.840552,5.797183,-194.829561,-239.450742,-228.752035,-215.803711,-153.940424,-79.740097:224.283022,183.739081,138.893324,55.839903,51.207346,75.871739,81.684276,119.909355,133.887162,94.189133,-25.977251,-69.945629,-60.127696,-0.011199,141.15503,154.232831,6.708843,-172.307085,-211.460804,-194.613267,-151.410208,-38.081451,19.844347,132.641183,229.999939,242.625121,153.5871,117.684388,217.419447,291.652933,256.675174,165.746632,85.512135,187.755473,211.325513,110.205179,25.329507,-70.892813,-67.341646,-75.703591,-191.461361,-251.311008,-383.721368,-473.857902,-591.323433,-581.313068,-499.212712,-460.259836,-415.523336,-364.953329,-327.315989,-272.607408,-250.762762,-197.588597,-168.433788,-134.734317,-135.444055,-129.889648,-127.934522,-129.625207,-27.667096,85.003692,270.556591,290.020237,228.023736,137.129017,90.579627,42.533726,57.029275,128.969877,177.128962,222.102403,60.609208,-45.541868,-141.206439,-123.670627,-24.726137,3.947426,-7.132214,-1.176369,54.748394,55.076681,15.0564,-69.024061,-66.146231,21.748259,65.035757,90.811982,68.719794,55.479285,9.199891,-14.376063,9.549025,59.163085,184.21511,224.74838,146.804943,-44.1871,-97.398007,-142.168717,-181.8214,-322.788402,-361.729562,-233.109317,-49.714471,-29.484803,-126.657326,-195.060967,-192.287761,-105.593897,83.826062,113.102916,27.692583,-65.23394,-70.245113,-0.407908,57.224166,168.20959,223.338344,313.059397,260.93436,183.17174,6.490871,-56.057183,-52.465047,4.467907,152.851649,212.87796,237.40347,159.051211,117.956034,110.002869,141.50618,141.501184,87.27731,-8.201699,-33.105389,-38.82711,-84.575494,-108.134889,-31.515871,61.258912,207.723802,229.498546,198.657199,112.363097,54.321101,-30.728296,-30.113468,78.520578,181.382209,340.464493,220.429042,102.209817,-38.699824,-28.252422,80.270076,128.079661,235.296064,312.214492,421.959487,431.098939,387.11644,248.269192,223.582697,294.471061,339.302764,329.185574,211.859766,174.509634,153.137209,131.881103,38.628897,-11.751471,-24.494873,19.114761,92.045501,86.517226,66.18288,5.762118,-24.160343,0.365077,75.411614,236.143527,232.783617,167.30873,7.708566,-33.114586,4.097969,36.812143,60.912592,81.920961,214.313632,313.30155,253.235633,23.916319,-10.753989,127.110635,196.863123,193.027821,42.13955,-58.182236,-247.945223,-294.976978,-248.374854,-187.079189,-41.380878,15.304962,25.195599,-14.344175,-24.86016,-66.716873,-86.845676,-30.546647,38.337426,134.537627,114.323542,55.827261,-99.734315,-127.18596,-54.911599,-16.90007,11.96181,18.699309,6.907803,-10.73382,-20.495619,-21.022177,25.047543,172.483241,211.949695,160.447252,79.558242,78.400505,29.929279,-45.645752,-125.353853,-86.658372,34.920162,67.488086,69.815474,32.085817,-15.77733,-184.051174,-254.390575,-166.134633,-19.988416,159.215025,13.818139,-77.759344,-123.933557,-99.072798,-5.114639,74.845852,278.027305,347.540888,313.7482,133.581222,40.961185,-71.703364,-65.720343,51.681483,117.727323,173.737516,141.697903,108.444961,21.486018,10.517091,148.757498,237.045573,256.212837,205.962269,142.035265,173.723677,176.15237,79.638717,-9.308761,-134.328888,-93.325441,120.258472,159.481443,133.430523,120.760751,119.831691,128.972228,146.671801,163.021054,138.768467,49.819343,-9.145768,-4.266686,57.625167,67.127096,1.418115,-9.89813,103.065702,176.172156,131.195356,-60.893793,-138.133978,-125.737511,-49.650052,109.254222,133.533651,14.871976,-149.700198,-176.185253,-102.520389,-50.683842,-6.240452,-6.871408,-35.634822,-43.387703,-35.393796,-89.328079,-153.802951,-247.701307,-232.785823,-56.203281,31.43514,11.186594,-119.454092,-149.951794,-112.099133,-50.078577,65.504622,85.781231,58.789424,-17.541782,-62.635493,-115.20305,-94.122457,8.618934,46.574311,59.876178,35.487631,-67.91301,-179.731692,-206.966964,-140.162927,-62.507942,46.475544,36.285593,-98.620483,-212.196119,-242.385276,-316.728032,-330.68066,-233.78918,-157.160289,-21.052854,23.600686,-10.445371,-106.597935,-124.001157,-147.8238,-166.612335,-168.831329,-142.979442,-70.771981,7.702909,42.246434,16.448352,-37.331483,-50.451207,17.30643,173.128727,195.439998,90.329722,-106.006029,-166.946788,-90.938517,18.112034,204.810308,239.519536,181.605876,46.518658,-7.728451,-103.87648,-149.167655,-170.407408,-147.813863,-88.593123,-68.197812,-80.521096,-135.491269,-164.481695,-190.496991,-173.228389,-94.503903,-41.013852,53.218077,22.480246,-41.519965,-231.418827,-323.257896,-345.55638,-292.204555,-223.377857,-209.621544:311.301387,204.969322,142.123633,62.104641,85.655234,270.846995,370.651414,423.471531,283.912699,195.742255,69.468463,49.382192,79.923565,115.0672,196.712623,199.73992,40.811806,-163.819498,-202.344192,-123.829526,-46.402136,75.307732,123.866,205.284415,208.217798,202.405098,203.163429,223.390166,343.70847,388.774475,294.829062,199.858287,139.738872,226.687919,237.160861,179.59228,154.815866,149.045798,147.311975,77.626668,-73.415679,-148.197337,-274.513853,-349.490894,-486.664715,-483.134119,-335.979531,-263.90868,-254.108358,-363.929893,-387.413812,-272.248345,-172.718707,-33.208706,10.294845,11.492389,-153.166735,-207.230289,-152.604777,-91.057371,22.797503,86.741107,236.365232,279.957335,217.69655,79.570894,52.355124,95.462497,129.811704,179.232298,222.597916,296.37029,168.761239,51.114333,-133.098369,-143.367881,6.952562,99.120103,160.940971,128.682166,33.601125,-39.122414,-67.642569,-62.677605,-40.651296,-2.957093,29.458604,94.178252,81.976001,47.175252,-13.770533,-0.218556,121.918625,201.835353,331.661911,336.529909,166.51466,-83.930791,-169.00557,-186.213707,-162.004748,-233.379754,-290.124888,-222.376923,-80.089963,-79.329683,-183.85794,-232.689404,-210.334383,-144.184177,4.114386,60.282736,125.749123,92.316146,54.176838,63.824427,116.864353,205.684005,229.445152,277.792172,250.556577,193.976568,52.421427,-10.418987,-53.805163,-23.224146,106.607854,166.094481,172.682083,65.283739,42.164203,121.668579,168.51887,179.827881,159.451707,95.08347,16.473359,-4.62363,-14.407812,-3.747537,53.083809,85.992904,151.095174,172.444139,157.727703,81.170984,28.311931,-6.746468,39.769965,166.43465,209.28104,225.706253,107.144695,30.554303,-40.662885,-32.460228,-7.086936,6.462472,158.832052,278.007651,356.337328,205.971256,121.52995,67.52139,108.802326,237.579144,280.802216,263.48479,188.927672,165.187029,83.481358,18.195547,-15.346723,46.571107,160.897169,148.769159,50.256971,-24.275462,-62.646853,-134.84673,-134.789295,-21.504818,51.325183,115.646269,92.936702,47.169294,-86.731237,-91.506842,41.323624,76.504168,50.961055,56.83073,117.247406,77.592012,-10.878371,-137.127561,-101.59534,73.093959,138.841275,163.943364,73.610549,-3.741331,-166.527963,-207.926495,-180.361866,-112.435362,115.432217,190.678199,102.596483,-36.006218,-41.996374,-40.10324,-55.276037,12.93847,107.979274,206.638555,104.125172,29.417387,-93.547306,-105.122394,-7.248693,55.408939,125.061196,126.155446,91.220795,48.802226,20.5841,31.898657,111.049769,339.25604,418.501461,363.233969,154.418541,105.010274,57.195461,22.479088,-8.2002,10.156243,103.446406,151.214172,171.768113,139.778193,124.606946,83.194672,57.5283,76.831484,145.440252,246.491794,133.727413,48.526888,-17.386372,25.78639,200.72083,284.267942,397.402,423.35584,357.617122,186.124052,120.666199,117.916622,175.307752,299.988143,317.692244,241.84232,221.027499,247.285278,233.178694,215.518938,268.96046,319.67045,344.105155,296.523317,185.272434,103.938645,39.949879,-48.149678,-36.714417,75.02121,166.299644,292.491138,241.793659,218.510335,214.030659,205.672541,211.357757,249.49874,344.961537,348.422102,230.097914,87.164019,78.600974,192.476202,232.817243,197.820793,182.880112,243.543415,265.550741,189.28849,-46.681495,-95.063901,22.001864,111.8415,215.439006,210.880799,75.605254,-129.247996,-206.447354,-215.297596,-152.345952,-8.541483,44.664299,78.606699,-12.221858,-91.923253,-231.176969,-255.10696,-243.948093,-216.741494,-55.34704,34.047832,23.692171,-200.137146,-287.601724,-256.270116,-178.474386,-96.139858,-100.160198,-147.808901,-240.017942,-279.342577,-269.318183,-200.283027,-38.678653,-0.928718,18.308168,22.148061,-7.775523,-140.363936,-235.34052,-276.54388,-188.709281,-7.415675,10.316905,-142.406904,-401.272064,-490.238147,-531.152442,-498.79928,-375.54439,-305.654231,-192.244249,-172.40565,-265.41628,-373.216903,-380.605595,-394.401855,-413.691893,-413.165831,-376.57242,-240.768537,-126.543093,-137.123605,-234.686025,-227.0304,-33.899877,79.405572,178.189429,160.023571,63.841568,-57.61699,-113.075823,-107.510444,-25.991075,167.408253,203.985742,141.301746,32.831022,-20.7508,-113.193824,-136.214807,-94.832669,-46.012253,33.981665,36.774856,-51.605779,-114.462439,-109.029123,-100.656497,-109.257889,-81.773978,-24.492191,75.533809,5.375358,-69.623859,-206.016907,-241.707517,-224.235123,-191.460668,-118.470643,-90.989779:127.111125,85.118443,38.196669,-46.805871,-43.388302,54.183328,112.52961,193.97235,197.582483,156.69078,16.850023,-47.446458,-58.236294,10.314773,142.626332,129.649265,1.69576,-14.769743,0.725762,-21.600366,-30.853848,-18.402576,14.864235,170.929517,266.081738,255.994793,189.191213,174.85288,242.279137,268.882667,184.250914,136.412238,198.379032,224.353329,130.185074,-87.020269,-123.277334,-105.622529,-104.939052,-127.525564,-187.400637,-255.383322,-447.40223,-533.718341,-610.799396,-590.556558,-473.477432,-435.57116,-458.900974,-396.994157,-332.86762,-279.382616,-259.242491,-148.588018,-69.380826,71.143058,23.239203,-68.157397,-177.861225,-134.660603,76.589844,150.614259,129.848484,89.63749,107.554284,184.830279,172.208541,85.808718,74.229073,105.493627,105.652612,53.30572,-3.571982,-19.026745,-68.429674,-98.701194,-88.21647,-51.621644,13.46636,44.259464,93.48726,33.568867,-20.158169,-54.966913,-16.527347,107.347653,154.998777,184.88752,171.458632,154.737276,46.304031,-22.802933,-63.433406,-26.511913,80.887992,113.196767,65.404945,-98.723994,-180.092077,-246.761684,-220.867682,-203.675389,-247.251489,-279.634791,-167.903956,-106.58571,-74.705917,-105.082911,-126.640037,-87.072695,21.073477,58.559775,101.165065,67.31525,1.005244,-111.704205,-98.538362,54.937624,143.843746,223.55473,148.547689,101.563018,-0.680661,-80.481994,-185.573696,-160.522596,-8.199233,77.751249,194.423372,219.244215,209.585374,155.109831,117.763514,36.106346,4.547795,-15.897476,-60.045058,-99.628916,-159.979551,-168.918559,-127.631363,-68.334175,72.265667,100.600432,27.337847,-88.407367,-116.000542,-72.349439,-14.570901,91.392073,154.48441,328.020108,318.889066,212.530938,2.077007,-9.06824,133.843344,199.500865,293.904777,354.130019,409.625132,331.883665,300.143139,284.66344,280.691374,248.240687,228.179117,231.092764,209.061299,167.903713,95.95139,69.020787,-13.111145,-66.539067,-103.516869,-47.020453,142.12329,126.942829,22.396045,-175.537631,-207.423864,-143.944763,-84.150869,46.738759,110.002168,88.898192,-21.223592,-56.503419,-16.824829,21.986352,100.076612,156.578635,297.406395,361.773238,308.502441,110.310959,70.586636,164.162244,229.953284,296.772913,220.165158,121.557695,-93.207792,-158.205053,-164.876602,-120.171802,-0.881323,27.953271,-18.086798,-39.630833,-28.196755,-66.720303,-92.10659,-65.339041,-19.351433,71.68688,15.810523,-55.806314,-138.771653,-131.121451,-76.103208,-65.238066,-96.79824,-105.434534,-31.144904,78.231223,65.703257,-82.025302,-133.131199,-84.776712,-13.207729,78.808262,38.888009,21.527329,36.000323,37.710698,-17.961817,-60.335628,-91.080424,-63.357135,33.28716,68.879525,36.265041,-92.088909,-148.143147,-125.945899,-24.093302,181.093456,46.184592,-89.26217,-157.704438,-78.512195,86.401745,115.740839,148.773363,200.580949,279.886367,146.792779,41.475129,-71.297284,-53.252986,89.967489,162.495435,171.032403,22.205111,-36.00575,-43.081754,-5.903488,112.326674,165.32948,185.722247,153.790982,98.414555,179.646086,232.793371,136.490492,6.354603,-145.361168,-127.074886,-2.647343,96.14179,128.155152,136.858134,122.042102,161.032973,216.20309,295.765936,298.178171,224.528084,98.691107,67.589842,117.839088,140.294031,74.414541,49.20748,125.830653,181.995013,140.213817,-12.561328,-57.443101,2.486241,84.951325,223.456763,245.351232,211.338492,124.855959,73.863352,14.438172,15.129671,41.279234,63.599335,128.761182,145.395726,97.46023,-76.229632,-148.757949,-160.747234,-110.095193,26.698347,77.135112,34.876736,-95.031696,-111.602416,-43.17856,-0.368187,21.250563,19.894111,22.417504,-93.007864,-178.97808,-263.252578,-259.960114,-234.061591,-207.03007,-76.227533,-11.162658,-49.564275,-280.98263,-371.786371,-328.558711,-225.587201,-94.774119,-107.818768,-208.420373,-257.404179,-269.235477,-310.853893,-299.86527,-149.216568,-50.071454,52.921375,30.931547,-85.999895,-126.790564,-118.480818,-119.09626,-131.82267,-153.885158,-146.976573,-76.354017,-2.1786,-4.799645,-105.526576,-153.434669,-79.722022,27.934225,205.091209,209.894078,12.598324,-266.522022,-329.763076,-196.884185,-61.34521,91.83324,92.057559,89.479207,124.97257,103.902547,-65.063806,-152.388052,-149.000177,-58.141136,113.769724,121.01615,-26.724278,-215.405428,-268.046952,-296.228127,-283.743725,-208.638806,-144.797476,-15.696665,-17.905872,-69.508039,-197.874548,-235.666576,-263.284336,-308.2145,-380.96941,-317.021304:344.594396,135.406213,69.18626,82.842037,128.10839,176.039646,194.456943,254.401501,207.847305,136.583005,-7.284714,-42.023117,10.798918,78.709405,173.585877,149.90045,-33.043408,-139.940681,-121.711575,-71.571204,-57.174392,40.254348,138.216394,314.499026,291.189063,218.267508,92.818052,90.689966,206.84758,263.198736,248.161458,199.133334,143.577668,153.449398,131.558533,20.079833,-18.092805,33.431841,107.636266,167.427857,-37.421019,-173.270721,-369.570361,-419.356363,-438.489516,-421.839302,-335.530718,-281.716399,-257.084121,-294.697297,-292.212906,-215.94181,-150.659051,-10.365649,58.148909,101.374633,-59.778715,-133.498953,-146.867713,-106.151032,46.146057,147.867621,313.208474,334.206331,233.233575,66.620632,0.785266,26.156335,119.58758,243.514311,242.154606,227.261086,150.129315,55.936465,-148.887578,-191.963161,-113.210004,-25.294042,157.357525,198.745391,113.958628,-44.845718,-96.329221,-93.485033,-48.472145,70.452681,138.567119,259.619868,264.43528,209.232132,48.764106,6.007888,71.800452,141.489995,290.356031,350.161555,279.538259,-17.41168,-130.968113,-144.134258,-96.855987,-106.904802,-147.449652,-139.364806,-65.907077,-48.165543,-112.300231,-174.629171,-154.773947,-45.593496,201.296633,262.472747,265.589452,208.453059,158.032018,87.046192,103.937692,239.278631,328.266298,435.621706,347.540979,254.773812,47.499603,-28.711658,-39.346772,2.250577,114.098123,173.130657,225.485366,167.5731,129.07026,144.612256,200.177216,264.445684,251.738895,177.427031,46.608183,1.014867,-5.696951,11.822865,44.393326,57.796978,91.066537,97.214445,28.401968,-80.894801,-106.277102,-75.216786,-29.190802,84.262785,162.345871,304.636093,210.374068,100.724389,-40.358495,-38.039677,53.359642,111.129438,271.104128,352.77992,389.040582,301.91304,262.031232,247.166562,282.40671,369.438675,376.557127,313.345839,218.967343,162.902286,18.990401,-34.038586,-20.871126,23.458475,111.927651,146.919766,173.532734,33.974923,-105.02877,-313.519698,-303.258891,-117.383875,-9.037893,149.956242,165.881916,115.420578,-55.477823,-104.660918,-4.119382,91.656528,219.988794,245.223345,284.288403,247.277875,135.469429,-81.316447,-66.698956,137.385347,228.398724,290.689589,144.505217,12.637438,-187.614163,-205.373574,-137.413861,-99.560442,3.833729,61.027434,44.411305,-114.505531,-166.889809,-195.292694,-193.735171,-112.125532,-17.2443,174.264213,160.66071,53.038439,-204.539368,-249.610385,-119.48862,-23.450647,131.207307,179.705647,140.972305,27.930183,4.550379,48.529093,105.916536,241.387239,300.618236,330.806362,219.699869,146.926039,29.009219,-2.937265,-3.348076,22.149819,101.066302,147.00201,225.745807,181.870329,93.64981,-58.600653,-60.0059,48.011892,108.322912,146.700223,67.21166,17.363413,-26.923725,4.12957,158.795761,241.795815,391.737743,462.832343,496.188351,299.852253,173.063315,65.312272,88.862119,173.200116,209.208501,248.162185,223.926246,172.11527,25.451636,11.798761,192.549867,300.379996,356.581392,316.216605,232.852009,223.78117,197.093534,54.47274,-13.116982,2.760248,104.965796,301.433094,230.890782,150.43161,91.414179,128.25238,268.262438,335.470282,407.242578,387.629135,236.127035,94.705524,65.747159,52.21584,50.26491,45.664332,62.672692,149.93228,140.132812,63.598303,-115.477106,-151.041366,-77.245383,-3.744772,165.211188,219.697702,138.333953,-145.160758,-269.95412,-313.506224,-251.850334,-92.731325,-25.524907,7.90586,-62.14645,-101.42822,-236.707386,-322.396055,-365.795346,-293.194885,-35.127421,53.430973,-53.314058,-314.279936,-381.396223,-334.639084,-262.658099,-155.007943,-127.728069,-134.077368,-284.040997,-388.490925,-521.348075,-524.704394,-451.195573,-387.604835,-225.570404,-176.935788,-231.053425,-367.098941,-425.186026,-447.4069,-391.844786,-255.248019,-222.415887,-237.828766,-331.933026,-399.981546,-540.107864,-568.965069,-473.989699,-386.823488,-223.218877,-172.176192,-224.909412,-353.98123,-378.158146,-409.815609,-423.511651,-358.241133,-271.096862,-106.98245,-119.730447,-193.30438,-368.536317,-396.020888,-230.533421,-94.361699,98.617826,126.101241,3.354021,-244.872724,-321.213626,-267.651943,-164.503599,21.570694,69.457711,105.521575,61.069195,-16.638535,-220.621203,-271.59877,-171.961637,-65.642267,62.882106,53.902194,-20.619311,-104.693262,-162.219452,-220.530209,-187.736179,-47.72853,29.202719,100.525344,16.303108,-48.317036,-202.10219,-264.77531,-253.58775,-199.41588,-99.265905,-72.266548:12.343058,-117.405312,-144.565801,-96.748078,-66.528736,-80.359544,-96.311181,-37.050034,40.418619,44.234984,7.196081,-27.914339,-53.828349,-18.814634,53.595861,45.92405,-37.400722,-40.639072,-1.912279,-31.953118,-119.946851,-246.980624,-190.198515,128.743134,244.790247,172.358524,38.382532,58.92109,218.721097,273.580645,230.137576,163.039421,48.217294,45.158454,61.308146,-15.254932,-94.734873,-154.398503,-110.437814,18.854631,49.533112,-1.801382,-219.077541,-347.312037,-528.343243,-557.602458,-479.09435,-392.561736,-265.10492,-269.291497,-304.035979,-365.289953,-339.549168,-192.945822,-119.843857,0.600015,40.068077,11.332969,-93.046006,-121.894321,-10.438241,101.214045,213.730584,187.709096,124.239706,178.273389,193.174028,120.939524,85.875137,102.842323,119.721803,83.923762,-16.674286,-65.963107,-163.929622,-196.354219,-109.774339,-15.95087,82.34344,72.187732,33.836072,3.635944,-20.748567,-22.534813,16.948599,106.067983,142.64538,192.947818,130.92869,83.328116,59.34689,72.428759,101.579786,110.515039,121.291813,122.228843,66.342066,-95.991436,-192.36075,-285.859101,-249.196151,-121.067806,-103.696262,-166.692999,-199.276117,-173.230792,-118.571549,-139.052798,-152.063219,-75.082948,96.441243,109.465207,24.840393,-66.382047,-91.896398,-76.228897,-38.075997,-0.749387,-30.389405,-96.740632,-77.148842,-64.519079,-111.058531,-169.591443,-265.034995,-285.834979,-276.717904,-224.469397,-45.085304,72.687656,62.47722,-45.665992,-83.143577,-82.677085,-61.291255,9.952102,22.945542,-16.761604,-99.970791,-125.019379,-162.911219,-162.731554,-90.780015,-30.979329,110.806096,229.280608,242.61771,206.91852,196.591807,199.329495,222.77141,325.219119,299.707946,209.593172,70.913054,95.329079,252.812427,307.402112,334.03531,333.776322,308.558016,258.433761,231.341727,121.831562,59.845282,26.15722,44.815613,56.171264,-10.041472,-30.550546,-19.458923,-30.129611,-100.293282,-123.398142,-107.771144,-69.62943,61.283227,130.133611,84.748478,-73.90283,-118.102375,-119.533153,-102.346784,-60.282325,-21.823082,10.462687,79.125967,90.369984,71.026409,54.362254,85.128716,156.374979,300.060126,256.687158,165.297573,-21.926996,-34.200809,110.399713,165.158116,161.632307,145.553213,113.215836,-74.694414,-175.693448,-228.627872,-184.625185,-46.215908,2.886428,-15.7735,-68.209881,-62.650349,-52.493581,-71.835398,-138.356438,-160.469647,-145.69344,-110.766297,-120.349226,-144.502516,-116.921099,-26.793522,-16.264264,-44.58774,-42.16959,-26.962111,-55.052552,-100.754465,-255.11603,-301.459187,-251.55154,-201.783475,-166.056608,-147.278437,-119.041291,-101.418523,-124.256247,-174.09438,-198.639175,-252.654723,-243.421809,-101.533002,25.959414,-16.892621,-244.52499,-294.493124,-156.836703,-66.171179,-56.200986,-220.409723,-275.447638,-232.379785,-165.536631,-49.451325,-18.671606,47.714635,110.161618,182.683217,68.091732,-16.038715,-146.57758,-172.013646,-88.241775,-10.203412,50.394561,-0.0369,-25.550535,-74.577089,-89.16795,-31.442263,30.196932,127.240227,144.150351,150.303381,230.466194,258.202589,106.058373,-49.488465,-270.410711,-277.03272,-215.121646,-239.871758,-239.897333,-175.987934,-145.531541,-57.430791,7.190064,50.623052,13.56342,-83.523693,-179.667613,-239.325762,-288.293939,-243.399225,-146.502664,-133.354999,-80.103715,-18.664281,-44.349532,-147.908239,-177.813305,-155.317448,-112.382265,-20.335728,12.756654,43.906047,105.014115,144.382066,132.053873,104.161018,150.700407,220.301473,304.626797,256.191283,229.078301,153.169511,82.369554,15.328345,69.279108,228.14891,253.994778,184.583713,139.864106,135.780472,113.854614,122.610057,191.034548,210.576222,159.774334,27.317968,-29.114851,-58.079506,-43.993907,-20.003258,4.27777,133.32751,177.32067,75.097646,-75.95254,-119.677527,-177.732272,-161.52736,-40.430848,10.69628,12.478924,-58.899438,-80.415669,-89.29653,-85.980773,-56.086636,-23.13293,60.884557,90.950619,69.623532,-60.095156,-132.929509,-213.557344,-209.377411,-168.406775,-146.824372,-90.81994,-28.780193,-5.604589,-48.140343,-104.334662,-106.118975,-42.102709,65.102347,83.631065,27.129099,-185.184089,-278.922211,-268.812652,-196.502128,-114.263691,-117.304988,-88.47035,-9.909039,-4.596641,-80.596161,-109.198654,-57.348849,-9.691789,40.820651,47.348474,63.804255,58.174951,9.030671,-150.828692,-191.280038,-98.971211,-13.327484,40.654156,-67.494339,-118.43297,-186.622146,-207.34467,-202.337373,-188.929806,-175.816362,-156.791951:42.71204,-74.396415,-79.325488,10.253706,40.109405,-20.805095,-66.91228,-52.801876,37.257216,56.594772,6.494633,-50.591054,-106.026518,-64.398596,67.836052,82.32351,-12.209407,-50.011798,-39.41061,-76.914312,-128.990729,-201.373717,-171.534459,-2.476643,116.188631,135.119916,125.698296,119.563209,164.017846,181.422431,111.817446,51.735236,-32.416755,-16.271777,-2.005936,-75.077386,-144.446892,-230.388704,-216.87434,-123.173269,-148.705241,-188.400683,-216.299513,-253.866768,-394.580623,-426.300665,-365.097522,-333.078155,-361.269924,-374.760154,-364.466864,-384.84955,-381.347479,-288.1405,-214.480687,-47.458544,53.323118,37.345297,-93.250561,-140.400341,-87.400872,-17.280401,78.43589,89.221647,112.371158,174.744768,157.096422,-12.809289,-90.080874,-116.434848,-92.307762,-52.774168,-73.912583,-111.935433,-199.796333,-222.987135,-185.456064,-135.069986,-25.312784,19.664419,68.145661,0.917813,-90.122789,-233.413032,-200.115326,39.072493,146.806677,197.662262,68.682536,-27.893361,-186.282466,-200.443576,-84.297152,-18.170048,-6.646113,-48.224823,-109.79606,-158.121484,-217.601111,-360.202121,-392.4721,-346.961041,-302.460321,-196.23323,-119.868982,-129.610234,-191.571711,-190.230735,-80.007676,-16.899157,44.739446,47.65261,3.486612,-47.167725,-82.048943,-192.073828,-218.415886,-145.724293,-87.578224,-42.346864,-101.684727,-133.20235,-188.493845,-232.356255,-322.223559,-352.302812,-320.412249,-229.984674,-48.117141,-50.834146,-78.474608,-139.639354,-190.524741,-276.790598,-260.243309,-147.842972,-210.239117,-306.857978,-419.074535,-416.047383,-413.871108,-415.495264,-285.955273,-166.088523,-7.280378,2.987865,-11.67786,-27.121955,-26.866794,-61.782305,-68.437829,57.252184,155.173136,90.073446,-125.895528,-152.081963,-12.227459,43.960921,48.281306,81.577556,248.309923,265.441268,171.730539,-82.182798,-164.22858,-174.526951,-131.740225,-50.496832,-65.401156,-86.952877,-100.661634,-117.191391,-217.893408,-270.909065,-254.134276,-171.693664,29.785955,55.207903,-29.152693,-226.076838,-255.176952,-167.293654,-97.047306,13.835294,41.732097,28.471356,-59.726282,-106.175361,-99.539187,-73.6875,-27.335628,31.367747,233.982931,322.667705,253.423605,28.863845,-9.667375,104.241821,176.627961,202.331935,84.10063,6.738792,-130.137393,-156.874479,-111.037763,-71.472995,-4.027266,19.318944,32.143626,-11.32065,-55.103732,-144.427669,-173.330538,-181.93102,-162.278864,-125.960084,-134.272187,-142.669152,-157.090045,-146.441089,-76.45967,-62.212175,-138.230888,-188.073844,-194.710736,-133.756632,-155.182437,-294.253061,-339.926635,-322.226448,-297.906129,-268.74346,-195.757809,-166.50503,-215.135127,-256.269256,-256.279009,-242.444946,-240.342638,-210.973832,-66.633891,15.377633,-36.419185,-251.273874,-311.318004,-253.941335,-202.693299,-185.482279,-223.160078,-219.143919,-190.567122,-183.561111,-125.062697,-61.52361,102.253069,169.447306,145.181329,-41.856456,-121.921252,-206.384449,-201.019859,-111.044868,-67.962507,-50.478874,-90.377072,-104.912911,-93.599172,-59.930043,78.87542,140.439417,129.328172,91.809426,95.229623,204.458045,239.951651,149.782102,30.8869,-206.648114,-263.933438,-243.336995,-144.271438,-99.158593,-103.531296,-140.731264,-172.297274,-166.094207,-165.813932,-171.423167,-148.934771,-98.892209,-108.029329,-159.218009,-150.908981,-109.683108,-104.675615,-57.272474,14.413302,5.003442,-94.24836,-152.922158,-218.942001,-200.971292,-99.300492,-68.098794,-54.422067,23.01166,66.791721,103.395316,109.354304,88.28877,65.449361,102.061787,220.128853,238.396398,134.618174,38.711165,-77.973182,-47.75727,133.4295,203.702076,187.014555,155.592899,208.802727,367.099418,409.708096,370.534966,338.385935,341.214712,335.268153,305.231962,235.550881,208.981946,188.068195,200.815284,262.403827,292.692691,250.157055,27.161816,-88.602049,-148.498692,-78.649151,69.831903,92.715377,101.404156,96.070422,61.015208,-40.720735,-63.06822,-18.913506,29.529078,143.816088,188.696202,161.378041,52.89056,43.693301,127.733101,173.788563,138.378776,77.398576,47.602818,174.422002,254.824054,263.052906,181.609189,106.838143,152.557596,259.60975,269.413445,150.990713,-54.834115,-113.212585,-93.243965,-45.652566,40.991122,74.157246,177.672125,235.982095,195.712884,75.813775,59.34064,120.961341,155.584819,192.45852,219.946341,294.936411,250.287212,169.100194,53.902538,63.128489,144.882109,202.058553,301.411704,231.725099,155.763411,46.069318,39.610633,84.422582,85.067851,61.396104,90.179806:122.354871,-4.974851,-41.683476,-72.110131,-94.504254,-118.147981,-99.037163,-30.116439,-27.821302,-59.980761,-142.706691,-183.481047,-176.568197,-117.913606,-29.138552,-57.645617,-197.981524,-208.414214,-175.311655,-175.620123,-203.259145,-208.332182,-157.66587,9.933994,65.798083,45.495936,16.991176,25.663915,77.892885,89.570428,25.932642,-10.808746,2.884777,19.327737,-11.078928,-67.580696,-66.682069,-48.692424,-40.993077,-7.580316,-53.639342,-137.276136,-353.405699,-441.949249,-489.689916,-463.302269,-415.716292,-406.066319,-426.492248,-426.175038,-386.032893,-257.559394,-177.378666,-28.445384,12.375678,7.821284,-76.6399,-119.200252,-172.926825,-174.598394,-73.630865,3.279246,110.547544,135.914946,114.657472,2.742657,-43.848005,-69.934185,-71.910447,-59.707924,-24.92687,31.869793,-79.179284,-168.678228,-266.721122,-258.50625,-150.012071,-78.116187,-7.980327,-7.312091,-22.188667,-46.640604,-62.435152,-92.123387,-87.014804,-67.115057,-61.038189,6.505392,124.272961,159.244383,118.245858,52.546173,-45.202171,-43.672543,33.11336,64.593225,51.238952,-46.099253,-123.483603,-243.759953,-251.073708,-235.758882,-234.940623,-199.806493,-136.543672,-113.5854,-113.798535,-120.612765,-67.368268,-16.455476,48.361093,50.422251,24.243614,17.537922,16.620158,-77.910503,-130.366164,-33.267713,73.192548,152.999212,88.874228,52.445389,-59.244407,-138.157267,-236.250979,-221.022339,-75.377478,13.076636,63.319636,-18.121675,-18.284215,58.486791,80.238183,50.988602,34.365631,20.781226,-59.901592,-76.184925,-22.519318,-16.547715,-45.556566,-33.80136,-13.73359,-44.039419,-142.339979,-129.121745,-74.955484,20.174584,54.148474,157.599102,238.990837,364.988588,299.122984,221.854545,89.430754,60.582911,112.153974,160.662616,237.650533,282.54512,372.180352,364.796131,307.547965,165.669062,137.436373,168.40205,189.82987,196.382659,98.826303,16.43039,-62.172178,-37.422149,4.818585,-12.860335,-25.753734,10.105315,49.718031,-31.374104,-74.604133,-128.712671,-137.592998,-123.975946,-113.380691,0.921288,220.3111,245.47548,99.801469,47.360752,101.073432,159.640579,264.331821,279.980232,221.272074,162.643581,126.108904,66.169242,98.905754,260.975996,308.569867,273.635811,164.41689,77.680006,-149.764638,-235.759916,-240.91404,-195.477802,-125.076442,-86.297945,-10.933652,-52.262525,-112.639579,-223.709236,-225.575022,-129.674056,-73.225525,27.869193,51.167791,8.250725,-112.796692,-124.597085,-8.793422,61.010178,108.760172,87.218808,46.542507,63.420447,45.767514,-33.977946,-47.568664,-7.654278,33.633781,140.359901,232.755814,257.771576,190.503871,105.844259,-18.573291,-32.976589,4.143631,28.860005,24.518572,25.367722,25.678406,-59.013132,-118.602823,-128.919251,-78.53084,-22.183233,-125.063589,-168.314162,-91.695791,-12.961522,72.775079,75.43899,121.062679,204.393827,350.454449,234.023573,88.09476,-150.879948,-166.637221,-65.186891,-8.164175,86.850554,58.137799,-32.38939,-224.880031,-247.071274,-111.486118,-19.939811,87.492003,111.097184,120.000238,101.739973,78.222797,-38.705107,-110.656195,-207.946448,-212.38426,-124.419711,-5.437944,28.617138,-32.138591,-101.520865,-100.055956,-15.451261,127.262272,132.344397,80.292813,78.113626,66.345664,-42.52486,-104.41476,-171.948213,-165.621017,-64.798472,13.349198,1.295641,-74.543864,-97.298883,-48.835017,11.20096,114.261698,123.525656,58.821502,25.410525,24.868945,-16.519946,-26.227957,37.919015,78.947838,105.746684,79.589205,70.74814,46.018127,13.298656,-6.145346,37.555651,168.457958,206.31321,129.966615,-66.896697,-154.629281,-183.709747,-92.322619,104.661787,113.870498,41.392049,-3.981741,-55.058036,-162.419963,-165.648886,-106.751936,-82.831785,-41.231036,-16.989216,-6.885491,-37.916424,-66.722335,-66.291673,-2.503616,92.962941,56.400477,-87.019705,-148.890908,-147.880027,-141.54993,-149.571153,-150.159307,-122.885885,33.937242,131.685236,147.439139,-27.145985,-88.987665,-128.666861,-129.878591,-136.932319,-125.923928,-23.598525,36.221781,20.316044,-54.331227,-93.008262,-47.027527,33.633743,148.823406,168.274744,118.653334,-80.306682,-159.134369,-181.184012,-150.014705,-46.370617,8.112459,63.865867,32.537127,3.67364,-39.871686,-31.458365,40.239206,63.423684,47.690076,42.585159,72.876611,22.633787,-60.306456,-179.933714,-154.34281,-9.268849,41.946243,47.281476,-41.178954,-96.725571,-205.269411,-240.282591,-188.876986,-130.791875,-65.617485,-51.932709:backward
174.401396,167.053511,135.594055,124.828932,160.097885,175.868616,140.001343,43.062349,-51.822874,-61.588545,-6.718257,10.327436,-31.100043,-83.058582,-195.701517,-228.310361,-214.476453,-104.933905,-52.209599,17.970839,56.731773,95.009026,63.138925,-56.963581,-147.866828,-180.261815,-233.414272,-216.454996,-102.79263,-83.156108,-137.00637,-153.307581,-156.353707,-175.189909,-168.149818,-73.024904,-17.291452,-13.841548,-52.79483,-127.081109,-209.360876,-229.213604,-168.081507,-109.901448,-20.838406,-19.95042,-111.766366,-169.681911,-235.273357,-222.671423,-189.80647,-72.127935,3.915698,94.409154,81.329683,30.433893,40.238267,54.152726,78.713725,97.789345,184.276128,220.883781,193.542496,157.942066,135.912676,159.985352,147.175631,61.324247,28.631413,17.094591,18.987379,11.924249,-32.422287,-54.618883,9.408977,89.811425,197.389214,200.253595,188.437564,201.590426,229.403913,222.257179,212.398272,167.202209,135.869496,93.524212,78.712113,29.722363,-51.240724,-100.620219,-178.011477,-181.408631,-144.428976,-138.288214,-142.638033,-133.040135,-138.788654,-145.848007,-107.680944,-60.058112,-90.92158,-127.905042,-70.546114,48.632319,-17.46363,-22.024932,84.55678,121.641425,155.891277,190.984423,225.869663,183.139175,74.650301,118.975483,176.504132,222.373923,183.573814,40.457343,-10.446526,-32.216891,-17.005795,19.190844,126.121827,162.582816,186.88314,163.126394,45.396153,-12.767747,-57.86556,-13.565836,28.009258,124.848206,162.11574,114.739485,30.712025,-110.905534,-124.859942,-81.61203,47.355894,98.635066,120.658687,94.631723,50.824044,45.912245,58.590385,147.601288,215.684545,329.497643,340.053958,263.166586,221.404012,156.976456,104.435915,117.665958,164.544157,148.112384,37.791689,-32.195176,-113.71016,-113.343209,-115.649913,-111.537425,-80.181188,1.274741,5.19325,-107.817008,-161.441961,-101.979189,-13.672256,-28.819114,-43.084198,-25.354761,-41.746534,-81.876969,-142.807419,-151.22645,-142.990436,-56.125406,7.096059,108.643172,147.090117,146.292136,100.073029,25.82433,-5.183093,-15.61661,-34.729938,-41.954176,-9.032498,20.934015,57.72594,61.740627,18.815307,-48.325265,-67.807733,-87.835986,-80.255147,-45.531938,-34.573152,-4.517994,51.237659,89.485998,118.47755,100.08004,89.630414,84.104894,6.351306,-18.954469,7.781886,17.675663,22.8322,70.371027,80.117748,9.029662,-38.681389,-117.030371,-194.30515,-195.425065,-125.55922,-102.920544,-103.287647,-88.265335,-9.374462,-4.170504,-126.565858,-101.063852,12.71747,183.740965,187.021573,93.965027,31.722179,-65.936507,-88.188005,-65.892152,18.454165,57.012127,81.879537,63.28138,31.36263,43.45524,58.477642,23.332724,22.884035,121.787921,224.144416,346.048395,289.029605,76.293498,-18.794887,-23.476839,-26.754229,-17.849615,49.525502,69.178494,28.912739,-3.273236,-46.739943,-79.426087,-88.058537,-86.30214,-100.855478,-184.52741,-212.421844,-216.117928,-249.780632,-247.828213,-176.59691,-152.878801,-173.809386,-196.660951,-205.427977,-179.688323,-82.896148,26.635359,45.987673,32.125574,50.995902,130.02255,143.181037,58.787005,-65.096403,-63.354767,32.864056,60.388214,52.803644,61.676725,136.29516,156.889043,114.418409,128.014146,166.460114,250.538277,295.075948,358.069085,371.325563,382.365926,405.617494,412.745647,338.43421,272.002985,198.403585,178.985376,101.961674,50.708236,-21.833144,46.956306,103.438889,125.094559,118.675741,158.650524,163.587945,76.206287,99.593833,199.255221,374.028781,398.439266,417.534042,431.84039,371.995163,298.824189,206.649277,230.242289,229.789938,142.151391,81.313436,27.98374,57.623143,122.989035,84.247448,79.790497,156.298123,194.302059,174.158602,107.735194,-51.180952,-89.02026,-62.250828,74.258939,158.597651,238.316925,215.019465,121.078147,88.908166,31.006728,-68.44163,-119.661393,-214.70848,-250.322533,-283.243766,-294.074355,-308.807605,-296.208973,-212.359022,-129.997865,-137.608599,-208.893674,-216.361954,-160.377372,-133.515446,-150.663615,-221.898716,-216.952114,-116.895962,-65.465174,5.671485,20.956234,-16.600555,-51.243291,-104.435733,-108.853177,-88.845733,-19.246474,29.474884,125.277993,143.421462,112.05226,105.452557,124.266537,153.731072,163.826137,178.994246,167.650085,96.612806,55.731319,-14.63108,-82.221372,-102.70741,-85.887093,-46.532698,23.363642,8.850261,-81.418353,-90.087642,-70.997914,-47.852093,-33.021943,3.002227,-20.660382,-194.407874,-295.27724:150.453008,212.016099,230.873842,201.828903,193.904605,228.52621,233.373013,152.170006,40.173419,36.274151,149.834142,208.539455,169.905956,53.631415,-198.225082,-241.958398,-190.622027,-84.722788,-9.577922,123.581634,135.7369,51.031273,0.231931,-69.575851,-185.772971,-249.552494,-235.988927,-151.079603,-20.878519,-31.28451,-107.677954,-126.057306,-120.797937,-74.365383,-29.809575,76.63063,99.557213,1.15307,-91.098963,-210.739448,-211.775393,-172.382388,-55.735841,-13.995032,6.466004,-15.217008,-85.574612,-123.362555,-211.754716,-165.93386,-59.356825,148.020027,187.008732,159.702001,126.549745,76.288898,118.429571,173.859598,238.184062,222.229079,187.077628,199.860656,217.19347,192.021776,110.110084,93.433814,104.9353,125.289096,124.984556,86.851011,60.213633,0.079222,-96.491451,-121.736379,-11.387271,94.473172,228.660849,243.052406,234.538467,201.220357,100.309203,140.234399,191.923496,196.744591,155.452133,110.498467,114.234723,73.015909,-16.0504,-13.428439,76.927544,118.330225,123.914368,71.67915,-103.617262,-164.056303,-166.247441,-120.039186,-77.780278,26.730771,32.452986,-36.461715,-48.780311,-33.318433,-24.171268,10.487416,120.334685,151.448606,147.246291,147.376866,189.02518,198.477234,166.428621,207.879186,265.357947,315.621527,281.918986,164.45803,105.566611,-6.275158,-29.521127,40.38551,239.255747,288.37309,257.81179,217.524051,144.463757,100.748148,47.041696,150.112427,206.741997,188.390141,132.806152,34.826371,1.649241,-70.547504,-150.655236,-170.294038,-108.677116,-37.12778,71.772625,91.879306,81.863398,46.449041,-28.270747,52.705723,149.724729,313.057403,332.230028,254.484996,196.403122,88.37985,23.051022,17.898464,-3.405234,-24.712623,-63.043648,-93.972557,-156.070955,-170.029972,-184.991586,-139.722175,-84.104024,-20.394991,-58.065203,-198.086365,-235.252153,-228.599852,-203.436231,-184.523093,-124.202374,-81.917463,-33.67105,-60.079327,-161.2932,-200.579497,-212.325653,-118.029815,-43.710022,139.972637,217.736234,198.559686,107.73227,-18.188081,53.964857,115.251805,178.826692,174.1333,134.995327,106.456393,65.637559,76.318733,127.559896,131.414332,105.045916,23.99277,-2.4914,-16.060387,-22.74326,-72.384702,-99.776284,-66.721703,9.572756,25.339832,39.42411,29.877837,-30.712746,-63.049394,-70.426439,24.629147,66.199912,98.947662,100.357861,51.264245,11.034983,-47.583479,-45.901948,-14.317249,41.468389,41.707695,45.207776,57.675899,19.986016,-44.450361,-114.73508,68.203948,184.30559,288.828722,284.372043,203.149517,138.061313,21.922761,-37.831554,-49.14679,-18.785885,8.139148,-25.626225,-81.870699,-116.333831,-84.652216,-66.900212,-103.631104,-85.953408,75.589952,180.468455,212.593904,145.772166,57.667574,26.768607,-0.514139,-29.381639,2.210587,91.468969,86.253248,-8.475004,-45.131908,-53.117386,-38.286709,-44.351493,-53.228538,-53.824135,-73.17684,-73.874406,-63.596824,-97.921311,-111.127463,-79.143008,-46.182019,-38.417819,-69.232934,-114.157292,-114.866235,-80.517306,49.236701,104.080303,89.629796,72.213251,95.480255,88.014167,-40.044726,-121.718116,-87.171597,7.538898,36.802445,107.838722,142.297213,117.957968,49.136131,-38.691834,107.783648,186.992527,211.49391,208.353602,253.43475,268.929727,236.94398,185.587416,174.240489,178.14256,204.735182,237.076422,198.090376,84.829809,50.989999,30.115942,112.569936,181.660999,251.649113,226.253986,130.736115,106.592739,61.469264,52.936686,131.190663,369.654659,452.522621,465.694575,411.017386,284.991259,235.109861,143.691132,91.571443,96.309009,111.929871,82.230168,-18.816495,-34.227909,-31.282874,-63.928868,-48.829188,52.166974,92.361653,62.896505,-8.412306,-170.046532,-211.293136,-154.758673,25.913004,112.349524,180.716418,139.604718,4.246521,-27.126162,-20.849967,-57.091553,-105.037629,-190.073158,-197.368752,-169.95016,-177.540689,-233.294983,-250.052758,-236.851083,-174.421631,-140.979547,-89.12138,-70.191654,-85.64652,-130.498021,-226.492092,-238.130719,-208.17662,-104.298171,-53.557826,-37.55614,-67.740177,-71.866401,-49.232088,-86.822513,-136.243976,-106.901827,1.520687,26.432623,-7.045516,-21.505061,-29.805875,-28.253795,-8.870157,10.965678,10.253736,36.771528,49.915021,18.904435,-29.220536,-146.381955,-185.734953,-186.049181,-163.24992,-125.611154,-110.779642,-162.68863,-245.032295,-239.516098,-250.122047,-266.601901,-240.841679,-191.513024,-206.999413,-277.401152,-311.189107:242.810422,234.120341,230.328817,244.858633,283.031783,352.536231,329.561783,166.315818,41.020535,45.959662,117.114913,142.190588,123.756179,75.85433,-17.616487,-42.096671,-70.621764,-26.663612,19.219353,79.804931,76.255963,28.196032,-3.291667,-91.444647,-162.437928,-163.281102,-130.805603,-99.394768,2.727294,34.027547,1.719768,-39.910787,-87.571462,-17.027622,32.159346,84.162409,87.111027,35.366171,-21.993259,-160.329721,-167.075332,-105.548659,-7.466374,19.881079,62.937005,43.359503,-87.256764,-147.826124,-175.290313,-75.309082,-4.660054,84.334607,92.424443,76.394091,74.552465,126.183653,222.575023,247.931422,212.053267,187.393501,216.427136,247.436009,218.510993,152.368257,47.602599,92.48744,126.7046,126.993916,94.441318,15.14995,-7.431694,-44.331172,-83.053946,-54.326062,108.951043,185.316441,214.801261,188.327788,160.331062,146.524569,93.358197,173.283373,265.257207,372.312155,348.259899,214.730408,145.962081,62.199915,54.667538,68.348079,128.032968,163.858195,165.118281,111.104509,-53.220754,-126.884851,-198.781968,-157.092817,-109.455881,-37.449507,-34.038427,-70.677999,-87.788193,-106.105187,-62.516756,-1.480882,129.958085,169.391439,180.676685,168.879886,150.8456,138.285496,115.646636,198.887494,267.275218,302.483291,261.908736,174.967241,132.683051,25.758757,6.768775,36.250563,97.620477,135.072371,187.313308,157.984714,10.140016,-60.950425,-102.223805,39.587473,137.819923,250.391135,235.918051,91.819494,6.700485,-118.782757,-181.509696,-176.982481,-86.192239,-25.857878,11.840186,-17.888422,-46.854023,-38.89897,-29.831522,61.52369,127.32511,197.103142,204.240987,195.986503,168.780309,57.827478,-30.443345,-47.377818,-56.931491,-54.881253,-64.127463,-100.651581,-213.413715,-246.693886,-214.164592,-154.489641,-141.335718,-86.164567,-50.866508,-26.861171,-41.129587,-108.011189,-159.747855,-163.142665,-108.425239,-34.808559,63.874985,10.320206,-182.62846,-220.983885,-155.599902,-24.068982,47.08987,168.283341,209.114799,223.207814,192.665815,103.655842,58.32227,76.3019,174.410465,227.856182,273.113604,254.290599,165.100605,121.886259,98.859274,95.336093,81.655768,124.049339,174.632215,178.375929,117.074439,-35.723014,-119.795495,-114.457744,-31.0796,31.911938,112.741705,96.226956,16.185725,0.219521,44.523994,145.903794,179.296271,188.661603,175.251888,85.510488,23.29706,-37.889124,22.039483,76.067426,170.423056,212.48353,269.88618,252.628503,113.57271,26.301861,-70.892567,4.473786,67.978003,165.812694,186.534171,143.065063,89.677613,-29.09165,-105.674831,-111.560014,-52.087435,-15.895622,-43.629521,-107.337611,-223.084406,-259.248835,-297.75522,-204.019642,-119.343001,18.049344,50.236574,34.126737,8.268781,-62.433154,-150.483342,-157.124573,-107.442523,-78.126581,8.420654,53.865014,22.264514,-59.844351,-157.49427,-38.978114,44.430652,140.675097,131.664404,49.436956,26.726889,45.529844,76.24152,74.166731,54.246665,55.932282,54.099746,45.395904,27.144305,-5.718175,-64.972565,47.600112,113.572044,136.863564,128.080027,115.748289,73.892276,-93.542795,-151.719795,-101.514864,31.46684,65.917986,69.447131,70.621676,80.929465,58.70294,-6.550562,45.039524,88.749574,111.492233,116.974236,152.562469,149.068077,81.009453,28.70304,33.598543,77.249776,120.991454,209.11347,184.956461,17.313197,-49.088752,-66.960333,0.592138,48.69557,141.749713,142.788961,77.26175,56.90127,8.253673,-26.693235,4.748507,141.320105,208.965419,266.933377,261.384805,231.200392,198.152409,90.932702,22.522514,19.677685,45.25818,47.885288,-21.987102,-84.747771,-183.295123,-169.721671,-115.8682,31.83962,79.211064,18.88368,-66.021664,-182.557865,-203.992082,-216.668043,-112.229986,-12.139691,134.214594,134.22822,42.122947,-10.126399,-88.67745,-131.975897,-146.033301,-131.832432,-105.158523,-89.343511,-112.827069,-173.962231,-194.255056,-183.003619,-98.813465,-50.580343,0.067008,-19.103417,-140.753435,-206.481752,-291.418116,-301.366061,-254.630568,-83.838672,-26.680994,-71.129908,-119.778657,-123.283655,-101.482315,-79.679401,-53.026793,-47.725702,-35.721708,-35.506759,-109.756104,-151.814908,-126.615565,-6.520075,33.871094,58.644101,85.865803,167.28694,155.543968,2.314888,-77.23546,-134.366585,-125.894866,-134.824759,-137.189195,-123.89637,-143.832581,-180.65644,-254.006714,-322.007285,-350.890078,-341.465788,-302.987107,-240.590694,-237.221425,-293.690292,-344.317002:173.464289,250.740142,254.120195,224.577264,216.959011,168.912221,125.47403,54.632983,18.724844,32.966053,104.135433,114.266487,20.614116,-68.766842,-188.847142,-181.044194,-98.239041,-35.596787,-17.426171,23.948565,35.824397,-35.645894,-98.169095,-133.885978,-87.104249,-82.880656,-83.569339,-63.253262,-38.966867,-69.492628,-148.267373,-152.322623,-126.276414,-103.811976,-63.906385,89.599996,153.228622,124.124977,44.96953,-109.519507,-123.706372,-77.695427,-12.198785,-6.772222,-3.036317,-17.462624,-122.856315,-194.718257,-253.513251,-132.402609,-53.99084,40.718678,55.796242,56.851395,78.207723,165.820992,176.694223,150.382877,149.29876,192.231534,264.521634,256.52815,188.735998,163.383268,164.179395,164.563848,141.268365,116.018941,109.853667,41.654341,16.259349,20.837859,-29.990725,-52.122131,11.023402,83.720017,212.273155,250.392088,291.258929,286.062628,218.124771,214.851333,251.090472,278.552661,248.657383,161.827428,130.897862,73.235262,1.108569,-11.300715,17.189375,41.908854,82.157137,76.404014,-34.89838,-129.396569,-276.742563,-266.592022,-222.12195,-130.577781,-104.867686,-97.101129,-82.255607,-37.221323,-69.042315,-72.070364,-10.878556,23.78279,92.483612,127.673185,161.138436,151.056686,117.943703,120.850703,130.347523,154.655547,155.832021,107.646926,69.733248,6.13908,4.431073,36.225455,109.513277,129.51483,116.666724,81.508694,17.714194,6.797686,-26.64994,-16.84391,35.841867,153.452193,160.937259,28.923793,-54.042639,-123.571846,-121.215284,-124.241002,-119.719614,-88.575842,9.736414,42.126738,37.245793,22.393647,53.090376,157.921893,201.14463,284.930886,331.925245,340.590465,279.699823,102.038048,1.943819,-0.726832,-0.984838,-9.796815,2.011331,-1.207372,-68.130899,-93.037148,-90.98466,-86.30166,-74.513656,-7.969051,17.00431,-35.63922,-92.499989,-153.613355,-129.290081,-98.97244,-44.119152,-22.707988,4.308305,-19.423989,-124.193952,-159.09312,-145.944118,-25.320067,57.80346,201.489177,233.708664,149.54869,52.076924,-73.852713,-6.643483,53.180186,120.911776,126.351791,110.876348,104.778684,140.78719,178.406575,214.546248,138.794376,83.03245,54.688382,86.026721,102.352926,55.163686,-59.568656,-69.150191,-25.985799,67.387123,80.46432,74.883405,71.089262,37.064644,6.889228,-7.039893,112.969052,177.046351,209.935203,194.222608,148.707139,122.030493,55.669977,-4.031914,10.54329,93.330686,103.94726,65.861939,42.368389,-23.547154,-65.086827,-137.697231,-139.150675,-99.714003,26.037613,83.196964,83.374562,30.323291,-46.370077,-25.967212,3.539953,68.671139,93.195755,90.110006,50.641697,-62.92364,-103.752264,-130.960692,-121.183637,-91.392441,59.852627,143.689935,157.873133,78.408111,-112.273272,-162.992909,-135.410793,-88.181437,-60.087218,51.174265,74.827583,-28.798374,-98.240555,-138.487885,-86.95952,-50.246639,47.330116,75.302881,15.875994,-42.077113,-117.357371,-96.860491,-63.288344,-18.145352,-16.102994,-41.426443,-66.416675,-118.902235,-128.936698,-112.371051,-51.263064,2.191765,111.284007,145.01785,139.867488,93.717492,-61.156104,-108.179357,-49.407168,88.373855,121.73924,150.909946,152.63984,101.077543,66.198526,66.26156,127.134153,129.04582,115.720852,138.892369,193.735951,211.34047,242.321754,234.846934,227.984129,233.518902,239.467373,201.998644,146.889456,54.471681,34.827943,-21.011379,-53.620692,-30.655959,58.417361,90.23045,83.921378,69.043884,48.07856,58.240944,102.224092,211.036418,246.628595,283.205037,295.383737,314.347503,290.565088,148.326051,96.646256,124.230125,133.419021,98.512032,11.29912,-26.469897,-116.961732,-153.418417,-92.80465,70.859536,89.226837,-3.622083,-66.273643,-131.30602,-136.202721,-133.017541,-19.768226,75.602632,172.847846,152.965162,83.032633,65.750229,12.07168,-104.260069,-161.644395,-231.438301,-239.16396,-232.148863,-246.683746,-302.221684,-304.877364,-211.135524,-88.744935,-88.603354,-149.527195,-148.183624,-134.96767,-159.691022,-201.769131,-206.132208,-202.382667,-129.307484,-78.406245,-57.195271,-73.046304,-59.556647,-49.601315,-100.545633,-133.114849,-98.421107,34.483198,76.597744,48.051139,30.131565,68.090383,99.43674,110.102418,189.953543,257.493591,324.843361,273.678743,83.957221,19.369517,-34.21473,-104.147042,-152.129454,-192.681281,-159.608256,-73.589583,-84.265785,-216.298038,-274.27384,-240.056655,-149.638341,-120.620224,-126.960519,-166.481994,-262.77569,-300.831363:163.702927,172.692872,189.333397,234.80345,231.391091,134.934521,82.404507,30.418031,50.714388,86.321711,151.951327,157.986319,95.598256,42.895476,-29.215691,-47.831851,-81.902825,-93.770441,-89.637376,-67.7574,-56.59782,-75.063557,-106.157105,-184.683478,-219.311214,-188.244809,-60.561948,-12.743389,-25.921374,-55.380151,-56.455793,-53.81124,-81.814093,-41.471912,5.773813,124.000451,155.347971,55.904711,-36.833352,-157.352519,-137.790697,-101.543942,-34.234425,17.948037,128.01738,121.45,-76.746953,-212.779861,-316.872445,-156.263507,-71.803676,39.713648,68.866679,44.791031,26.401324,49.218645,97.538495,126.800185,188.377352,223.460869,288.917671,282.582565,162.04075,90.681214,60.898762,166.700996,198.523148,177.734273,142.51864,43.262262,6.725811,-44.968762,-109.952437,-112.516727,15.179516,137.72421,328.372812,328.100549,184.755735,99.628017,17.288532,185.789536,304.622735,370.058216,316.990523,173.228736,107.473933,14.497211,20.031997,46.664716,77.391634,81.871146,78.653387,49.05142,-78.143145,-154.147209,-254.54879,-227.061417,-184.839761,-89.124683,-50.610247,-44.457603,-76.775094,-139.984812,-95.694905,-42.074169,56.231782,96.372518,143.957963,146.440241,135.178994,118.287516,72.156748,106.470193,155.416931,225.192688,224.572328,168.552886,129.388456,53.628169,-1.256963,-5.887212,39.606504,78.549523,126.448365,103.533001,-30.598316,-97.813703,-161.378012,-101.984937,-15.622197,182.13445,208.850548,44.456708,-69.569602,-198.579556,-241.725123,-241.9215,-150.446644,-60.104136,95.418436,111.163039,21.248724,-22.752915,16.706053,138.764781,186.069833,268.750053,301.887771,290.911425,238.318455,53.120188,-106.631615,-128.4503,-58.117856,22.487847,131.140668,93.53204,-84.701505,-153.789027,-177.152463,-110.506951,-82.357947,-0.334142,45.994264,5.434667,-65.67177,-137.769486,-102.170117,-82.999918,-67.489333,-38.368148,24.129577,-13.195947,-176.274836,-215.124318,-166.644155,-46.876401,31.672125,206.610121,257.295669,176.76449,78.603597,-44.840224,15.358408,70.055592,127.328069,142.148809,174.49907,179.933507,154.827326,138.108898,148.639235,148.704576,124.617637,153.864346,204.623892,191.918137,105.018923,-78.331856,-58.809655,5.335588,64.233101,55.814805,42.198904,38.781077,38.680875,41.523791,71.063474,200.988245,283.589922,342.73167,300.022557,196.781073,175.242443,113.475837,60.432306,91.221916,198.572023,224.887112,198.880204,168.976973,120.46075,83.956004,-33.425169,-88.729478,-65.813351,74.76966,150.975854,145.215535,57.815059,-130.579689,-160.084002,-114.634213,-16.600408,3.486203,-21.477589,-54.839659,-128.851878,-155.530935,-135.898981,-55.689834,-39.064718,-27.376149,-3.841501,53.893827,45.223382,-93.504856,-216.753179,-198.288315,-72.53416,-19.446423,70.588675,103.786372,81.655593,33.327037,-29.57624,53.28879,128.02026,242.303488,246.555705,187.066136,168.108164,116.752798,9.064514,-19.814079,5.543064,53.726758,146.399158,135.525373,14.46667,-39.531374,-41.942738,70.842747,115.902415,154.173688,162.068354,124.288436,63.393778,-91.62512,-113.809018,-51.360727,93.402338,133.552883,145.330919,136.04877,94.019617,54.105244,15.013723,103.541669,159.113442,229.073377,221.53895,116.416939,77.077149,85.656633,92.670284,86.852941,82.610386,113.378138,200.026505,186.096499,43.916623,-31.051404,-106.725599,-74.828269,-22.799656,113.881288,133.053855,35.241582,-8.624302,-28.549682,-49.450832,-47.767316,54.052572,136.815135,200.240777,167.181894,107.453239,94.037266,38.175869,19.549907,51.050803,132.37216,130.537583,-15.857453,-118.781491,-259.354439,-245.396583,-177.813666,-2.508851,48.705534,-24.030736,-124.514704,-261.336089,-253.265447,-177.51344,-132.038056,-90.166438,64.354658,128.207286,104.982607,27.897173,-116.761034,-146.084451,-138.683822,-122.103063,-111.808423,-150.744579,-211.419995,-314.639713,-315.303524,-226.453035,-122.868955,-86.390959,-61.283187,-61.643286,-93.227409,-147.709167,-260.666626,-218.957486,-158.194792,-33.986685,21.65649,57.331852,27.801331,-45.372004,-72.210771,-107.725819,-71.51373,-28.519753,75.595499,109.863346,72.60191,25.007222,-18.646721,4.979364,40.835133,154.817199,205.797999,249.042042,220.607344,87.546619,25.246292,-52.724546,-106.327072,-130.646336,-134.380409,-110.197772,-62.649653,-70.160516,-194.793253,-321.644654,-324.150021,-258.100427,-219.365822,-194.183407,-227.87681,-335.886637,-368.305956:192.772639,242.107035,264.427121,275.119524,250.917197,112.198027,34.153935,-9.528407,27.995954,26.853106,-12.435855,-34.650264,-76.032723,-96.705552,-83.652941,-43.797059,-23.776809,-104.890267,-121.342587,-32.497869,28.61571,24.951917,-30.454406,-118.887441,-105.195564,-48.300229,82.602723,107.692335,42.620742,-31.945784,-110.596701,-71.671933,-11.775878,-92.705231,-96.842554,28.634188,98.903551,102.884838,41.669055,-103.902345,-231.919533,-258.847315,-165.04155,-72.230471,0.8828,-48.043371,-171.531038,-217.418337,-280.955907,-178.296869,-87.114217,-17.177237,-39.200337,-79.681003,-65.054867,20.767698,41.687277,19.5354,9.216744,33.597325,59.531904,42.80178,32.78788,60.28248,161.25482,265.999454,278.301506,225.262435,188.694565,118.101496,93.487866,55.181785,-10.653318,-6.21864,110.406379,163.85198,179.041712,162.830815,173.368824,208.687001,227.410224,163.218696,175.156853,240.582332,234.400362,149.475482,102.958709,13.245772,-106.965853,-160.945414,-201.819796,-171.687203,-54.412866,-25.058623,-97.45249,-167.58734,-246.073266,-180.175982,-140.543995,-171.59531,-201.360985,-172.95303,-136.805467,-113.788271,-134.818506,-106.145032,14.474676,48.760454,55.678448,68.290041,106.263509,102.556482,47.485664,68.072063,122.480258,147.460982,89.468432,-25.334636,-33.736744,2.592722,-10.588911,-12.772823,1.752413,-10.871511,-67.327006,-93.338987,-121.76403,-126.104149,-132.018469,-114.537902,-100.025558,-81.182143,-54.130176,-17.025008,-55.884768,-187.237871,-185.498137,-122.520746,0.157641,37.009057,53.686338,12.403721,-62.057662,-30.504973,97.387654,173.993877,205.385111,259.441105,264.029147,204.802261,151.547077,26.651604,-45.574135,-17.041944,78.163669,73.973565,-0.84248,-23.927106,-48.60672,-70.586719,-139.58874,-149.915564,-99.32737,45.435612,68.283315,-54.704492,-121.300852,-45.743472,86.176103,77.726735,53.486037,88.564513,158.920249,137.131507,-23.890867,-116.423519,-176.098984,-43.698733,28.030725,96.651553,112.040576,148.696269,143.313491,25.663054,-67.341309,-44.072464,35.468074,43.799154,51.461042,74.473298,111.816332,112.786639,94.79146,54.753878,30.927072,55.380741,107.355154,139.558674,91.682865,1.186846,55.948848,119.782512,187.252739,175.133301,150.634771,144.786032,95.630996,64.812888,51.366942,61.762528,55.81204,63.182609,81.897243,77.793129,36.174996,-99.475813,-184.413049,-160.529825,-55.889566,-40.606336,-98.380932,-120.380128,-131.583398,-161.533948,-246.4322,-154.572064,-59.791552,20.127045,-9.4425,-89.937965,-95.698796,-65.975255,-103.448195,-121.66545,-30.219342,72.996777,196.255185,163.125827,85.090979,92.758865,42.427521,-70.121455,-52.023368,96.048827,147.207709,104.930542,48.386538,-26.530939,-82.434159,-98.931436,-109.153888,-117.664604,-142.412744,-144.477644,-84.458125,-49.736494,-82.262328,-152.587651,-139.73803,-20.410922,27.705279,-33.96353,-103.972961,-170.307611,-157.19423,-125.361619,-36.045247,-20.11263,-105.904004,-167.07193,-150.450443,-75.20325,35.077438,61.60228,85.312556,140.112533,148.885448,114.536559,82.653766,-5.025302,-42.78948,15.52969,170.825378,193.030701,146.151701,116.473535,82.075762,64.681835,17.095583,48.481144,64.101131,60.192056,94.556066,233.884395,295.851408,362.133967,364.428454,343.189428,239.444974,188.5083,133.932451,93.935749,-32.249586,-87.137396,-149.445006,-117.769561,-71.040319,-0.59909,18.005014,67.237992,86.433669,66.25472,67.016716,117.529801,239.101028,267.835823,262.53442,241.276474,227.94738,253.259021,281.13747,242.216533,230.098798,191.113747,131.268499,-17.754169,-62.703978,-107.728138,-108.608071,-59.784917,73.369547,100.756667,41.089455,-24.114101,-128.428082,-143.676319,-97.515275,35.896264,103.275878,154.448795,133.261424,88.576233,104.161069,121.639487,-9.129122,-87.358129,-187.912061,-223.199556,-275.345058,-278.837302,-251.569304,-235.61362,-187.37762,-73.198962,-20.835242,-34.8806,-73.593856,-108.443244,-121.498021,-173.074352,-239.973718,-247.399214,-107.041998,7.920894,97.227608,48.792865,-56.697529,-83.567292,-164.95633,-184.493781,-130.468474,18.523593,79.534794,133.547254,126.079336,117.04041,172.176046,205.542742,257.281097,294.066725,369.564676,339.580171,133.250125,47.40193,-17.143238,-72.376126,-92.487233,-49.229199,16.907396,135.37388,126.674592,-33.667982,-139.969528,-107.612904,1.88898,20.161034,-9.490688,-49.347359,-167.162489,-230.84019:136.885711,128.946647,150.747219,219.907764,238.863957,161.56245,90.987502,2.562262,-0.197859,18.877924,77.581191,105.661989,77.611254,3.298208,-156.894051,-204.322998,-246.405685,-184.357397,-123.412134,-53.722242,-63.56181,-162.640287,-221.34507,-293.267041,-281.011932,-225.746552,-64.995103,-7.987787,5.950478,-21.809165,-66.344265,-72.026605,-117.208459,-154.440682,-100.001607,91.258605,128.117323,-7.211227,-118.660864,-270.787388,-250.003931,-174.000562,-26.12677,8.184957,31.261798,9.886511,-165.15243,-276.352586,-324.948681,-117.574214,-32.120033,-7.644788,-24.875546,-24.052987,13.015482,84.681165,21.257418,8.941146,154.681572,235.410509,204.273039,127.170892,28.435868,16.564397,43.110754,135.250409,173.93707,187.961435,168.962956,90.251353,41.434022,-91.633028,-210.024015,-174.780851,63.352008,183.253559,297.268477,274.379603,128.576457,61.428751,12.945719,133.129043,245.4888,379.98908,354.122773,202.580736,128.61011,-3.068868,-84.11805,-82.334755,-52.258946,-29.734749,18.263062,-10.808838,-191.993963,-269.406256,-266.218405,-127.242221,-68.996271,-16.969945,-13.345322,-38.350197,-56.718285,-90.179312,-81.897463,-41.84707,73.575401,121.9248,162.718537,150.839141,94.849768,71.163914,22.11398,23.955185,74.525803,166.511836,165.60309,102.030604,61.223417,-15.660384,-27.739535,5.187999,63.413611,52.58432,9.378347,5.583837,-44.9553,-119.837321,-252.474978,-165.560912,-67.009694,96.919833,138.439423,80.962004,-21.361684,-226.378286,-262.512684,-235.198433,-130.170638,-48.051403,47.89334,8.032345,-114.497593,-124.007567,-42.121961,119.965984,201.467717,296.75445,308.337401,247.352073,170.739265,-45.43749,-191.15297,-175.380677,-32.431012,31.978683,50.28502,4.471474,-108.501659,-147.826145,-161.968585,-72.478931,-8.893209,116.865765,149.618434,42.852738,-59.65954,-150.219118,-78.760239,-45.1335,-26.374721,-4.773715,46.831178,18.717345,-135.394513,-199.693306,-196.075246,-22.34656,72.381177,180.83497,200.025278,171.033768,111.371853,-35.196018,-31.781861,32.312218,132.210856,141.844078,116.356045,83.118671,13.174977,9.933061,55.560338,66.904906,64.490221,139.170122,199.665489,204.388191,139.3326,-7.418055,-83.299478,-69.490291,51.782876,120.495104,178.086297,152.269481,62.31836,30.654237,54.223854,208.433938,274.837681,263.708417,198.812524,60.603071,24.093361,26.663223,42.909691,50.842915,62.830882,48.95695,7.686875,-8.002761,-63.766458,-97.034366,-158.7298,-179.394277,-129.577045,42.714041,95.087258,56.817836,6.413185,-50.758565,-42.799498,-1.514382,123.61902,165.013394,153.136545,108.73968,19.119593,-14.998211,-97.86962,-89.78048,-19.520643,163.042955,226.2884,196.856058,109.559298,-91.947861,-171.773982,-154.698845,-87.878306,-50.612678,14.169029,29.756605,31.52836,14.489053,-48.878023,-14.026007,60.519053,203.044765,223.660415,135.976297,55.2582,-73.194356,-84.679693,-33.919557,119.045791,169.214624,143.380776,82.9076,-32.55337,-54.239362,-4.118632,91.062465,128.025142,168.6725,162.245273,94.384054,52.983908,-26.41789,-14.121224,61.682831,188.977473,181.129065,108.767373,95.908931,111.209585,96.725373,20.833011,22.81197,57.829952,132.793481,148.38826,134.299348,138.407819,160.09962,108.857606,79.135192,93.200515,131.6132,153.967562,112.919471,15.972512,-17.305278,-77.073088,-40.468166,7.763946,46.840937,39.127099,36.501927,51.399631,47.037335,-1.758917,27.221806,207.923271,294.156368,303.691198,243.833353,191.515734,213.027828,216.638121,148.619211,116.364534,85.618589,80.096443,-3.785555,-96.346398,-261.632541,-217.987114,-120.157996,73.962257,108.203461,1.743606,-93.662767,-189.641898,-182.423716,-167.585127,-101.621422,-26.714024,82.707298,76.701125,10.363613,3.486298,-13.06055,-115.433985,-148.845501,-132.207961,-126.819243,-204.017352,-250.946091,-296.818801,-307.589155,-306.684911,-224.099253,-148.157142,-43.02256,-53.388049,-133.552942,-169.948926,-262.913801,-325.779929,-273.240135,-65.904161,10.087124,41.282132,3.933647,-110.074982,-154.119708,-179.007803,-92.943986,-23.777662,132.020603,193.719297,210.443638,186.026309,138.473694,101.698418,97.887228,146.38017,221.101123,378.436167,366.976975,156.588959,45.294246,-77.292362,-107.15283,-106.147149,-53.412607,-4.280708,-3.974604,-81.129995,-257.346469,-245.838154,-169.757739,-62.925293,-51.100078,-59.471306,-91.769362,-219.914073,-290.124881:199.013009,141.786968,142.345026,199.941387,203.380782,71.475442,-15.067941,-60.808307,0.837237,10.65668,-37.577676,-60.502753,-21.652548,11.685444,32.774424,36.299861,69.501892,123.153777,131.53746,119.451592,132.256759,170.827356,165.465205,122.059979,70.000819,45.515568,28.634801,43.638974,72.005015,42.510062,-37.162622,-31.812581,-43.699146,-194.689201,-247.019223,-212.500873,-158.808784,-121.765114,-170.528937,-353.643554,-472.915018,-464.87245,-374.755752,-328.440211,-267.705972,-264.453716,-298.120615,-323.969071,-368.646593,-311.147035,-253.30978,-172.406081,-163.936345,-201.917948,-208.411053,-127.683203,-99.438241,-108.941863,-33.322805,25.93046,46.94478,18.418554,23.728168,65.487823,129.823056,155.582853,151.690729,118.590202,114.30934,99.264144,64.525101,-23.547365,-66.50229,-45.126124,34.923567,56.705222,97.887886,122.928442,121.461505,102.677875,43.840743,-4.27664,23.697917,141.640709,186.353574,184.733973,136.680559,-23.166767,-241.583935,-321.839317,-321.966884,-278.11515,-221.736587,-213.294248,-229.470761,-262.139423,-317.267859,-233.059675,-169.078858,-175.582339,-222.709826,-202.395813,-140.1633,-90.565531,-153.040111,-162.303074,-95.034978,-53.499567,-6.905888,23.880823,111.73299,121.575919,58.309889,78.393597,122.842862,116.420258,59.024529,-36.772137,-40.554997,-1.537955,6.618437,-3.02132,-48.202174,-81.515354,-169.413371,-239.361788,-382.940237,-405.805937,-350.247233,-314.387313,-317.479854,-281.293014,-231.874634,-149.863101,-140.261655,-147.88155,-151.514141,-119.20104,27.552454,87.207416,100.42315,69.124245,-11.974087,-32.56077,-12.220647,75.002457,135.514839,206.53022,202.225625,154.246844,119.990397,16.640273,-52.197545,-31.639488,18.6081,-8.756477,-129.085321,-189.058463,-225.087383,-185.737901,-118.392992,-73.235209,-29.918222,48.19142,72.56508,57.209162,31.184898,87.872175,207.169434,206.546462,152.18055,153.599079,175.960703,152.375851,39.956728,-22.580991,-112.707949,-84.873,-39.553061,13.960182,17.19116,14.335239,7.023024,-35.74786,-86.559769,-89.079715,-47.883018,-29.879413,-20.910409,-25.444668,-17.893282,13.561536,85.306333,81.572252,66.652946,71.118749,78.072255,66.681407,62.711468,92.676227,185.747859,241.583598,259.487751,206.965128,100.063636,81.364514,76.000448,66.76363,41.729824,-23.255876,-89.374381,-171.733847,-136.404379,-37.976973,-60.275666,-231.754313,-355.375924,-371.794511,-305.137729,-228.28651,-119.621743,-126.010634,-161.079129,-158.830045,-182.299678,-212.025414,-186.740554,-90.217327,-62.420497,-87.144798,-115.819021,-147.309046,-110.696521,-66.936838,24.890906,62.583348,131.914599,143.29827,74.322402,20.320374,-49.943512,-0.001032,63.252327,150.332723,160.824044,175.098906,167.85854,28.220767,-157.931347,-193.984526,-218.553453,-230.80183,-224.39955,-221.090428,-234.313447,-215.902977,-122.120999,-78.7022,-76.368039,-21.231567,23.852852,-2.071471,-89.7057,-250.157501,-224.679912,-142.755624,41.116436,66.109698,-52.702599,-106.177417,-13.385323,90.668182,196.8964,154.663747,132.947878,117.380898,116.461389,124.717595,119.121381,44.681712,2.758253,52.055435,214.627588,248.071004,150.313814,72.849377,9.148186,14.37521,9.943041,-39.697864,-62.451675,-48.484853,-20.515033,36.192341,57.580462,32.246808,-70.520915,-87.166955,-17.792422,22.933626,19.00105,-21.575365,-81.449101,-90.334509,-147.969208,-207.223143,-197.197826,-116.035346,-58.305202,33.628051,43.32896,16.865308,-28.146099,-40.425786,15.833987,70.269988,128.361641,104.040195,28.031573,44.335068,146.980128,195.265754,201.704464,171.097778,137.830509,79.743966,67.517072,36.757886,-13.488155,2.916692,60.558366,37.646882,-48.990428,-56.590968,-56.037963,-80.332873,-107.635337,5.255064,73.719043,95.465863,64.447213,71.996067,136.191837,242.75797,150.826916,79.22205,-13.272508,-52.521339,-124.547034,-125.853968,-63.045809,-42.683901,-29.207976,95.481311,169.772081,197.072236,172.381524,130.35495,116.3335,104.760143,57.681818,39.60374,119.428223,192.924674,231.679899,184.325196,89.77266,67.804135,32.226497,-19.195513,-29.996681,64.97863,159.458484,283.58715,282.449433,229.907572,184.899228,170.865532,249.567527,356.222432,506.970248,480.852871,346.512594,295.096578,199.655651,112.431082,75.808718,72.068542,130.387268,232.963956,218.616048,89.992893,-4.849348,19.518518,101.859303,97.443397,25.878528,-16.228086,-97.952367,-122.334386:7.453409,-10.037191,14.934299,33.70999,15.629647,-34.265848,-49.222958,-44.901116,-49.76466,-56.586153,-83.040958,-116.147402,-161.790891,-146.051172,-81.245601,-74.260333,-90.805897,-2.513801,46.623242,31.656382,12.892232,78.345264,118.254663,73.567449,-43.513982,-70.725306,-84.783523,-77.869507,-30.542418,-29.784769,-105.157383,-147.698036,-227.818223,-313.188474,-335.236594,-263.493213,-175.078567,-36.921194,-36.564522,-165.37931,-322.032109,-331.971719,-220.465742,-161.380568,-108.261869,-116.45565,-197.449944,-256.51614,-340.273911,-318.309098,-277.484405,-169.15697,-130.360429,-106.759255,-93.126737,-73.122806,-142.042118,-174.272671,-139.957845,-88.669869,-11.060225,5.887389,87.609928,155.463971,225.617786,227.959234,221.794614,164.636414,119.374848,24.307954,-15.877923,-77.305579,-118.789471,-94.817842,55.169525,128.750922,194.996153,182.162093,91.020504,57.078416,60.961779,121.999305,153.492821,145.743069,107.095596,17.320425,-21.577019,-74.741949,-109.447841,-143.960603,-263.609621,-297.678177,-236.9991,-210.287288,-262.856322,-296.292085,-297.93132,-204.787544,-143.185579,-70.654697,-68.785823,-117.562081,-135.22646,-96.576401,-85.276967,-99.622766,-66.684833,-14.946876,95.597571,111.844986,55.168926,27.854011,18.740255,70.707023,115.604563,154.930838,123.88488,23.632351,-1.778249,-12.930235,-30.172864,-25.027032,16.759263,31.561044,-12.258823,-68.52758,-164.080782,-183.363,-207.144302,-211.110063,-187.665782,-139.942706,-136.477031,-172.054316,-185.917729,-153.640025,-116.582974,-87.30658,81.393542,188.18608,245.816284,188.847094,106.394635,107.048661,69.754361,49.357975,90.780099,148.541633,130.698231,55.444903,24.628848,-0.791436,11.180956,21.409629,3.47381,-30.865901,-94.598249,-87.309165,20.435585,67.134538,47.46789,16.536442,41.62978,117.521234,133.654396,60.006482,1.576389,16.443713,148.852028,173.173761,127.905545,98.40061,61.98241,43.074099,-3.75596,-25.298992,-61.184318,-31.930917,-4.621636,-7.861371,-14.138589,14.751158,26.101579,21.652811,18.373639,21.534244,2.271423,-18.989924,-26.839621,-21.797605,-16.52406,4.092575,53.632374,20.867067,-20.959744,-63.829601,-41.547382,28.6612,51.426336,69.228099,101.431108,152.186706,239.163829,232.341351,159.259038,123.433567,69.165814,46.640374,-3.766197,-21.418254,-3.978993,47.230026,65.145571,28.503069,-25.282515,-158.583711,-294.112096,-319.368224,-259.940289,-212.175683,-179.100108,-188.446986,-188.718883,-200.736118,-287.935302,-246.504757,-163.999845,-69.513775,-81.212951,-163.401194,-204.625955,-239.184923,-205.966883,-163.482318,-79.254932,-56.170985,-5.129001,21.223911,14.860172,-23.207084,-126.818338,-109.725561,-30.57994,164.980153,240.162231,265.317802,202.087763,10.768559,-104.259215,-127.372644,-198.301052,-228.066289,-171.791682,-127.890343,-153.094143,-199.642128,-256.156677,-241.100771,-223.668655,-187.262886,-170.941873,-201.479411,-251.640016,-345.680381,-359.832937,-318.492111,-188.684979,-134.478988,-100.130647,-130.196816,-171.123012,-118.730634,56.721446,131.914895,117.761543,61.643168,74.634867,167.654193,183.467936,100.304463,32.93473,71.203658,212.516995,249.883241,178.916765,91.45762,-14.776535,7.204845,94.159331,103.486541,83.412207,77.43028,128.222702,283.354661,345.03137,381.763472,285.438573,247.025162,285.228269,312.67842,264.593412,195.10941,14.461077,-71.430743,-164.603934,-148.699182,-128.373959,-47.113273,34.03195,154.328594,142.525368,32.442877,-38.252715,-13.43153,105.855079,146.452477,135.173401,110.85509,153.868693,202.730401,171.97562,87.682798,103.566176,133.361393,91.629989,-14.152257,1.93117,135.206559,199.940884,204.871345,181.45639,164.058268,142.092296,110.809235,-18.195133,-51.848015,25.821664,141.035916,178.131232,238.947429,246.774531,192.225684,179.576045,195.862845,111.530024,53.360864,-33.237164,-66.224304,-84.051938,-67.597938,-32.705661,-35.990469,-49.551325,25.026907,54.59933,17.856669,2.525389,58.368058,85.934051,56.568127,14.453231,42.370601,159.639346,204.00815,224.882701,218.745934,221.81864,210.889024,82.634993,2.548479,30.228872,120.654755,189.049913,357.328832,386.417386,282.512002,177.839998,182.528355,247.442463,281.761789,315.404267,295.360765,191.400859,130.850494,62.823234,87.294468,87.935077,82.22913,122.931538,205.179039,188.609127,101.710714,92.782756,119.548924,155.524139,154.679437,120.888879,68.763739,-88.529348,-154.65817:188.633659,161.225038,176.754815,238.232117,248.32675,156.746155,76.709575,-14.561826,-7.111319,6.323201,11.302109,-8.2439,-42.819616,-36.424969,-15.202466,-14.801919,-29.052885,-53.887696,-60.139012,-46.392513,-34.597599,-31.559712,-38.76638,-39.987545,-59.441234,-57.488302,4.319797,29.739637,41.351259,38.379892,33.306591,19.07492,-60.381111,-89.819545,-58.083461,4.483336,2.915222,-57.935411,-91.228436,-169.583099,-296.596547,-329.490286,-279.299606,-207.135256,-70.017264,-59.907726,-145.962255,-200.196521,-252.773711,-182.258869,-135.185585,-77.363732,-69.729904,-86.622438,-75.053941,13.870701,89.257895,112.326994,116.797036,87.027577,32.202464,35.867826,65.762856,72.643124,87.015968,104.569775,109.324051,91.304022,76.35511,96.222495,118.50418,82.236955,-66.023803,-93.894916,-28.967932,6.362016,100.492252,165.655522,209.927147,168.336994,65.334152,89.618827,140.275306,215.437593,227.611598,227.818211,205.091925,48.442062,-152.74824,-196.379858,-202.067019,-203.809616,-186.913091,-160.308188,-132.013464,-135.948933,-139.247183,-145.043846,-157.205896,-181.711297,-186.16555,-162.684659,-133.655381,-101.172202,-108.746069,-74.431549,53.770376,79.661702,47.320252,34.503604,34.704765,29.021407,-40.45494,-90.918256,-57.44115,45.895079,53.231347,-6.708196,-10.396037,72.199478,89.535073,49.996573,-32.847301,-68.803441,-141.672707,-167.523413,-216.111091,-246.161234,-302.330612,-366.066688,-361.217993,-202.047245,-99.555119,-11.27252,-39.458029,-162.394974,-225.591592,-195.149372,-23.009982,68.60728,104.841446,37.122563,-96.772857,-91.305786,5.944567,57.188324,87.83363,196.094375,235.886124,205.949812,140.160415,-26.591774,-141.774936,-153.664503,-136.806294,-134.307816,-128.758529,-128.427937,-152.997232,-169.167428,-196.651126,-147.361608,-77.044309,39.472967,59.135442,34.796608,4.858367,5.693626,88.390303,93.486501,37.048891,58.636726,196.249098,200.531017,33.798189,-32.609664,-51.93019,-60.206191,-58.265094,-7.118913,33.933839,100.91741,114.309024,73.861878,14.147777,22.950602,52.848953,51.953378,44.17156,22.628426,-33.952861,-24.722163,60.665966,114.384317,119.081991,80.316327,48.911389,44.762585,61.834276,61.023378,85.373859,98.567597,39.982603,5.978553,18.665988,26.045071,0.258531,7.528923,90.288116,108.636022,65.235314,-11.454834,-15.177596,-29.834345,-69.828618,-147.447534,-151.100532,-142.762023,-149.166844,-144.20689,-61.007964,-34.968681,-131.036479,-204.071513,-271.29319,-192.452475,-115.748457,1.963743,25.811332,31.409978,33.08117,29.115518,-3.373794,12.840353,116.886724,160.117726,191.27425,182.170647,111.219418,47.523205,-67.946945,-12.102781,61.929147,177.004555,197.729141,133.639888,72.131701,-8.241261,-32.172972,-21.558972,-6.028667,-33.575719,-134.337252,-169.172969,-139.937022,-109.070726,-122.262232,-91.612878,-12.891708,157.04262,200.126118,152.165218,54.339864,-157.221821,-151.054666,-93.721702,-28.770351,-19.774418,8.277635,19.86501,42.58725,84.414104,201.158827,183.902346,132.484208,72.489803,69.164485,51.902771,44.64251,64.815306,43.348145,21.519988,64.126804,107.582309,96.158491,44.650669,10.882744,40.494919,50.966103,32.9438,51.760345,88.927299,100.959786,121.703472,114.063548,34.882732,-53.766028,-58.346277,-15.087172,6.054248,31.337618,17.493464,-71.793398,-110.587859,-127.573331,-74.204302,-48.202743,-63.276926,-65.582495,-4.812443,19.604648,32.596265,-10.233718,-40.615924,-16.484198,39.09245,153.282273,183.646827,192.649454,190.319214,159.639155,147.68377,169.034531,209.637164,205.217186,69.993277,-17.739092,-80.134614,-99.102955,-92.696352,-21.191255,-6.787629,-52.732116,-74.051299,-87.944714,-106.09381,-134.48618,-41.244742,20.136545,72.065325,75.867814,89.366986,102.331236,141.656209,93.663182,13.413122,-144.145506,-183.705374,-204.03151,-193.689596,-160.946255,-164.2605,-166.725925,-97.128633,-67.925912,-14.386264,24.337601,36.108891,-7.510553,-101.205159,-146.602106,-140.909941,-90.262957,-68.824699,-51.49846,-59.781607,-93.367674,-112.004863,-128.648363,-56.490502,-21.387686,6.270304,29.1217,114.115884,143.708129,137.027605,124.881508,139.905031,253.143657,335.034265,386.62678,311.479377,66.661942,-14.441035,-23.741593,4.574133,-7.104677,1.354211,50.64432,142.69532,134.827693,24.622212,-51.249609,-23.964936,38.09071,25.935801,-12.973789,-27.538618,-82.969507,-125.235267:backward
-227.81572,-186.284992,-202.025746,-248.435598,-231.919065,-164.344433,-155.265068,-157.4202,-143.563409,-118.740361,-27.714151,10.716052,29.905849,17.854319,23.05865,65.786176,193.428393,325.32408,361.324021,296.636627,221.209282,34.93401,-53.136652,-56.55942,179.735615,279.966021,260.567387,180.183222,53.938589,13.20438,-34.909721,-30.626997,-2.816186,-42.969883,-98.930867,-241.382643,-300.617128,-336.151,-312.708976,-285.659809,-402.549429,-479.843996,-557.766628,-565.239634,-633.066656,-725.705644,-878.144923,-840.40044,-612.60918,-470.020992,-428.793747,-333.014167,-283.488748,-235.468512,-221.348583,-132.327296,-23.460906,0.723509,-47.480277,-113.828776,-252.641914,-314.178136,-350.316054,-294.518978,-203.42843,-251.133129,-238.188393,-101.702824,-62.299265,-142.536292,-197.561411,-187.400056,-150.699173,-161.576502,-175.176383,-155.442617,-45.577151,4.014014,-7.455483,-40.356053,-84.011912,-95.650932,-86.126739,-64.779537,-67.279571,-98.549228,-120.032417,-133.841007,-77.392423,-43.074287,-47.152602,-76.358791,-103.814693,-122.461691,-259.719491,-348.591547,-406.392128,-315.835123,-297.355974,-346.376655,-371.481912,-385.009946,-364.796813,-280.86004,-217.297498,-178.852995,-126.137236,-148.101479,-202.219787,-200.615156,-229.419804,-268.223841,-275.12675,-196.440858,-188.82254,-226.889668,-217.738232,-150.465818,-126.90029,-89.295659,-39.433741,-13.092464,-0.692522,-8.665799,16.02043,31.322899,-9.62815,-44.291564,-98.787321,-180.271795,-188.2145,-108.953206,-89.303625,-107.800547,-76.978738,69.552553,148.070319,171.462988,233.075127,237.59324,181.296655,158.761372,192.354421,256.16049,395.901955,362.505179,271.914189,97.385789,60.323381,70.648396,87.9002,92.719386,83.007762,96.323571,143.32298,136.939582,28.138116,-38.335081,-98.227754,-88.294033,-44.234351,29.028958,76.247204,119.170874,109.823671,85.073624,85.382203,77.810708,40.337313,33.363674,-9.844483,-56.23385,-109.890966,-102.969659,-46.771803,3.139691,138.251396,250.019857,268.379508,220.948226,166.647985,60.492313,40.45422,59.276529,75.10182,82.604452,99.093109,84.487949,-61.431603,-161.642112,-218.147532,-171.31091,-86.003644,-8.796079,30.336191,18.963593,-20.003887,-47.43285,-18.074043,55.777157,59.105956,63.774976,102.503326,91.218527,-45.470589,-136.423803,-232.129753,-200.984049,-36.415436,36.6684,9.143789,-72.343847,-93.585915,-132.732047,-157.242,-181.381017,-168.806256,-146.586673,-73.021388,-31.809057,-9.050976,-53.245945,-172.339524,-185.752252,-91.250363,38.562907,64.179185,71.658128,85.974388,52.790149,-9.381704,-102.198217,-92.944457,-43.259048,89.402031,103.543447,-42.351308,-153.015601,-271.258869,-252.751884,-160.578692,-112.967447,-118.630816,-164.994087,-168.132103,-150.163257,-161.012333,-173.334074,-142.96145,-140.120436,-188.430653,-241.430121,-370.416827,-422.582636,-437.731309,-394.285708,-291.22677,-232.826756,-218.352322,-214.487557,-214.147652,-213.507836,-210.236165,-176.361609,-143.619093,-123.148881,-114.51031,-148.887557,-208.91908,-197.822998,-116.897974,-93.032172,-142.225613,-126.016085,-65.043054,-23.93542,-69.972512,-192.90863,-226.409483,-195.266624,-113.074747,-74.471508,-48.839582,-71.129248,-108.621218,-128.183213,-196.739846,-209.562836,-151.75718,-5.969615,82.640989,200.484832,214.114601,167.762568,149.487519,197.599636,221.332875,213.351195,225.124494,234.97808,196.501199,156.973297,172.790241,249.780007,409.16997,460.632944,461.808284,446.091645,425.5508,334.453697,282.685422,242.776736,255.314564,258.983513,241.214999,218.5664,124.287093,40.035429,-134.145834,-181.781977,-152.34382,-32.290682,-14.718898,-82.689943,-104.263895,-107.770795,-123.753672,-116.326482,-2.23988,61.138188,151.998154,179.816067,170.688311,99.358956,-123.663028,-189.954468,-184.416939,-154.329735,-141.430411,-104.403417,-86.519894,-26.677059,32.776535,191.151018,243.492618,205.597305,131.975584,143.966882,192.913775,159.897609,22.332928,-4.521056,38.328859,93.013606,129.211984,249.109622,291.306774,195.575747,82.073006,-88.619295,-146.196329,-131.923838,-27.079074,21.360585,53.891816,51.020382,62.430297,91.308142,159.46286,199.341954,207.192398,190.967535,176.778961,156.100621,157.175856,143.151747,67.25246,62.878561,157.699988,184.566947,88.263814,33.088438,89.449885,169.239825,250.119066,238.392523,241.560236,310.415011,365.228094,358.094496,283.329004,149.325983,130.468432,171.979104,288.785039,297.355055,185.972625,111.074745,23.120426,18.725408:-117.295631,-185.660908,-232.846951,-246.116526,-219.024842,-194.177247,-195.360975,-150.5545,-25.930634,41.574064,70.473086,28.107062,-31.022097,-19.085599,35.474961,61.997329,117.640538,163.123924,159.472564,82.681356,28.715373,-43.809417,-48.241711,1.789408,109.627304,134.634157,17.432942,-66.635304,-98.517869,-67.234792,-38.449201,-43.260049,-0.531715,55.8143,19.301624,-95.840378,-113.059848,-152.394897,-198.178555,-248.930555,-261.17731,-267.622037,-281.802678,-307.207875,-427.539999,-500.293241,-571.248737,-550.94137,-400.722482,-206.912017,-163.656964,-195.601685,-218.578611,-211.393291,-187.926938,-125.84442,-52.423043,-29.356089,-63.816144,-93.950435,-135.061961,-182.579107,-314.507334,-342.372815,-313.478105,-270.210895,-259.718664,-239.355738,-209.180141,-171.965413,-182.870346,-160.296786,-72.812774,-49.231428,-42.487826,-28.880241,18.195588,3.447655,-81.47239,-97.58669,-104.645061,-90.979989,-58.067546,-24.494112,-52.727112,-153.739847,-199.547766,-238.589967,-93.658097,20.492505,60.363782,-35.541918,-224.288119,-246.60858,-188.856615,-169.997703,-205.37508,-229.117569,-231.95197,-252.869342,-261.769873,-241.360949,-196.97584,-97.302335,-112.20922,-120.219584,-68.951886,-45.106498,-55.83452,-102.147403,-260.371445,-316.553071,-269.536848,-127.235748,-117.234302,-210.498366,-231.173684,-175.989214,-134.799568,-69.153555,-47.678066,-52.581851,-48.844318,-25.460292,4.208449,-11.069217,-38.069831,-31.316446,-2.929266,23.784832,20.516772,-14.572917,-10.043121,67.698931,126.225747,223.626954,225.896407,220.31812,230.865562,242.824435,294.831335,320.855395,323.090827,309.107326,287.207284,227.473194,164.738114,70.374024,78.178081,122.93229,117.673456,83.258782,76.837703,77.477852,44.282629,17.824813,-31.426193,-61.246439,-98.352476,-91.786985,-34.90057,10.442502,-13.940486,-142.005761,-178.834916,-88.702716,5.451009,139.015713,96.552635,49.862448,-9.019618,-48.923972,-159.005301,-174.706477,-48.077375,39.269086,122.003076,139.910457,132.784528,87.71926,59.632286,-13.381759,-41.161626,-46.822782,-3.509982,18.844697,-10.465808,-54.536669,-129.654488,-152.361355,-179.719518,-182.919418,-164.488602,-77.553172,-5.741331,91.357868,84.787209,23.370678,27.389562,132.562332,188.924139,194.304026,227.471703,220.464332,99.927826,27.786425,-26.961951,7.491587,152.276819,214.619642,178.691387,65.125887,25.507789,-24.283599,-37.524065,-40.378647,-35.197009,-9.788823,79.985134,115.904163,120.231881,82.056662,-49.623689,-104.794059,-73.081916,59.121235,66.74218,-6.325732,-33.752331,-92.053929,-113.060315,-35.700145,59.118362,39.026578,-101.603627,-150.518163,-145.605121,-166.895636,-320.877639,-367.128778,-262.841346,-83.202449,-76.586145,-181.673801,-194.415463,-148.151011,-164.714052,-284.594354,-281.432655,-198.216588,-70.57069,-104.848726,-284.674254,-336.113372,-319.338456,-305.347131,-280.428689,-183.320488,-143.567765,-125.923721,-136.214118,-148.325141,-125.208543,-42.810507,-17.403825,-34.657211,-101.413022,-128.496749,-125.547681,-115.73714,-104.54086,-96.154166,-92.911026,-60.842864,-35.580339,-73.443847,-133.962453,-229.238942,-234.017676,-170.010572,-103.532396,-86.147599,-84.551227,-116.608801,-243.755469,-301.849344,-296.13847,-236.438816,-123.614416,-30.632177,16.351881,65.920306,54.242104,-11.416385,-24.8346,10.168108,27.407896,31.454164,96.5684,149.203947,166.406705,104.915917,24.057848,82.457586,273.655982,302.923725,263.110642,207.133308,211.010597,213.603527,193.018073,146.246869,170.720489,217.471377,283.798372,250.625838,38.704473,-68.833878,-161.079076,-168.69175,-157.903782,-127.322361,-122.58553,-126.368922,-126.778457,-153.643258,-158.072487,-52.6261,42.51698,23.361864,-72.069719,-97.535276,-98.564717,-114.077769,-204.970971,-249.038967,-269.471683,-190.579349,-144.041773,-108.626617,-109.354928,-111.010671,-95.378318,7.262681,144.892505,177.089605,120.393294,75.61078,32.1229,12.492235,-14.871662,4.244831,110.311167,236.956782,258.296166,215.78223,194.092464,151.088251,103.218429,-4.05418,-20.233761,2.545367,15.901142,-14.444928,-69.335806,-53.945127,39.275687,78.631576,136.087832,210.111829,232.688903,216.09823,166.84237,42.072204,16.681622,39.201717,95.664,134.330555,143.502545,100.655696,65.74904,88.454754,101.173206,88.570036,110.111845,151.756169,147.32377,142.820512,162.848269,199.327138,195.005433,145.924274,95.206789,93.863107,152.677926,190.184233,175.889811,111.737488,-24.269748,-53.83918:-185.111209,-138.484894,-170.294494,-236.791859,-241.403614,-215.015675,-175.912851,-35.025524,70.669093,84.166056,79.382875,81.865114,33.652323,-20.026702,-18.24244,46.012067,121.905122,93.254705,89.305189,87.021687,54.23486,-29.650079,-28.997356,41.282149,103.395952,123.191489,104.370747,66.007651,-23.854333,-58.728553,-53.076063,-11.886108,49.366976,36.918086,17.155914,-76.806474,-142.895672,-233.555682,-237.879433,-148.755527,-49.71669,-67.410056,-189.695695,-221.311763,-243.117867,-296.063475,-426.193346,-430.896294,-287.939362,-98.562116,-61.118339,-108.1068,-134.233512,-97.847598,-55.713921,-14.487514,-6.436048,-0.777655,-37.1358,-66.2726,-116.698984,-164.571998,-272.167017,-283.708233,-226.502104,-177.716953,-175.595128,-191.3447,-196.620069,-206.10221,-202.25272,-150.973922,-64.942103,-18.968463,47.628639,55.298737,-2.206621,-54.662072,-90.0328,-60.157451,-8.941215,-15.677985,-31.88637,-90.385861,-142.379897,-254.975338,-276.190237,-207.702631,-64.088273,-2.36583,45.635505,26.402598,-69.024883,-106.818893,-89.917805,-57.036383,-17.022878,-44.004689,-91.785878,-193.598748,-211.202157,-177.286255,-141.194965,-86.10775,-69.079977,-51.705037,-13.988606,3.438972,-15.288567,-83.503639,-219.70974,-218.713539,-118.551164,-100.45527,-154.45352,-248.114406,-231.449042,-127.415546,-93.782801,-71.21903,-31.503933,-10.51133,4.485956,12.165563,32.041608,25.450183,-2.344262,-3.412945,16.21936,-0.847484,-19.607996,0.06896,29.47734,63.450795,81.80939,131.403614,146.308359,168.221064,257.924443,282.203221,240.766609,205.513369,190.344607,216.063223,262.799274,213.050851,151.244103,28.568182,-3.364569,-10.542048,5.27197,58.239587,108.016611,115.507599,25.798884,-57.837941,-171.875268,-187.763683,-208.805594,-227.549631,-224.916787,-134.887414,-111.504088,-186.593294,-240.362149,-241.550431,-170.84548,37.38504,128.332885,102.084137,16.66515,-7.205849,-43.908476,-63.774955,-46.529665,2.157252,112.836067,183.700706,184.07081,103.622424,59.484451,20.830339,34.104481,61.710355,15.576418,9.123513,30.671464,8.817558,-102.52457,-138.710122,-103.175741,-40.657634,69.748921,48.284737,32.430399,54.509638,60.371461,46.262703,63.316903,173.633975,264.724383,289.158037,315.357581,295.541564,166.895987,95.431646,64.41057,106.218234,201.388218,238.517108,223.091708,137.518717,89.387643,26.067488,25.263051,73.215085,112.716947,132.309938,170.280195,170.217655,71.999657,-13.343678,-100.795879,-87.714179,-38.239646,-21.826714,-45.942237,-152.351795,-191.827946,-162.606671,-115.017584,-78.122699,-107.898422,-126.915904,-219.52163,-267.825753,-291.725839,-297.763537,-311.732516,-286.331838,-226.347406,-227.917931,-220.304774,-200.403413,-221.64625,-300.079201,-316.541528,-282.881413,-207.302866,-171.671425,-134.968133,-144.314924,-200.721397,-220.546673,-238.740049,-251.865087,-237.031116,-162.402413,-138.187399,-125.970742,-125.62475,-102.804255,-77.538383,-40.664338,-10.283256,7.904279,-16.817656,-65.41356,-137.701407,-115.242242,-21.692374,-26.915097,-114.421083,-136.387319,-124.859173,-120.309851,-149.335734,-200.039625,-174.604968,-85.350514,-70.23549,-90.49018,-201.069765,-280.28343,-392.095731,-404.145099,-353.320303,-301.533789,-192.692919,-128.842101,-128.805914,-157.173171,-154.827958,-122.09905,-109.411575,-102.577983,-66.253768,-33.42674,-30.583293,-46.532971,-37.964302,-38.093299,-61.40432,-44.278341,60.656465,114.014409,102.125676,68.91767,56.33226,28.889382,29.082791,53.816159,81.216211,115.269929,137.692121,94.28414,-52.272118,-139.019494,-272.057825,-294.457758,-285.95403,-263.052985,-274.252498,-364.297444,-395.024252,-339.457436,-286.073807,-176.858619,-54.995137,-39.634717,-126.49904,-159.167577,-116.871207,-99.783935,-199.521193,-281.093231,-324.728554,-196.674919,-138.76576,-126.311413,-147.591603,-108.303775,-40.6664,82.013622,152.258425,160.95728,95.005778,46.232979,-17.544868,-28.967986,12.318331,69.619336,199.872958,254.477237,241.980932,171.349033,130.249677,21.957028,-37.97274,-86.015424,-31.958595,1.692444,-8.347977,-41.846275,-40.000694,1.304231,85.610582,115.149764,172.107393,209.35504,190.861071,106.74333,74.249019,72.684955,103.372908,139.029774,81.720158,70.672923,108.987553,122.30455,113.267549,95.072932,66.725977,81.291352,137.051904,147.11869,141.210488,164.382912,184.946819,165.63427,124.222535,60.554474,68.48704,94.533901,145.304127,143.094945,57.639453,-11.616678,-121.823247,-133.043237:-177.588248,-147.003397,-156.119489,-167.73747,-162.136614,-172.057749,-185.880535,-145.36817,-41.887253,-12.507397,0.306242,21.770094,102.350987,109.698219,72.87079,83.412717,151.077713,215.418282,229.606439,182.271149,135.099923,49.894226,38.706924,89.512303,179.739646,221.74238,171.680453,81.303552,-55.831563,-84.889017,-101.604745,-91.458799,-73.652338,-82.470116,-93.94912,-149.101169,-188.791448,-272.733959,-305.518615,-312.362197,-279.518387,-283.366866,-300.779522,-310.650095,-442.835076,-561.163926,-671.358627,-613.74055,-424.757779,-306.387602,-277.417645,-240.504497,-216.457026,-151.234437,-116.360828,-54.688856,65.956902,141.386575,139.036043,62.551881,-82.44052,-157.092419,-308.754737,-329.687727,-257.38893,-176.146005,-167.233958,-207.732767,-226.610828,-223.797748,-203.976694,-146.269703,-123.202549,-121.546739,-86.275014,-59.673228,-57.038626,-92.352498,-144.502752,-124.753396,-55.944789,-23.61155,-19.426195,-11.761394,0.887513,-14.852972,-48.232572,-87.692568,-25.21148,41.677657,130.238085,117.927764,31.596077,-25.777845,-123.386267,-132.653534,-111.454558,-140.674647,-178.692782,-243.627625,-259.052734,-323.578491,-361.945866,-326.479647,-195.894232,-151.764254,-146.491866,-176.687136,-262.802429,-300.528892,-312.121322,-294.174709,-290.858257,-310.575678,-299.731324,-245.911026,-222.148289,-207.109077,-195.540981,-142.01703,-90.537732,-60.915363,-1.021342,24.722933,66.637111,57.308754,-46.263402,-98.308053,-120.036427,-118.372526,-138.70009,-156.250151,-140.091135,-85.071754,-29.257036,126.860634,192.950746,189.37367,180.828602,168.997434,108.572715,92.861563,163.425769,231.291107,330.937151,311.332527,260.594056,115.247296,53.858716,78.31665,161.947863,297.65098,264.395199,217.791781,134.800313,92.389754,7.40625,-36.356967,-103.335486,-104.360855,-74.154644,-34.897129,-7.886707,-9.337059,-41.283485,-71.251631,-42.202832,60.327011,109.769436,88.470009,-29.610068,-82.332752,-105.380236,-87.513883,0.086476,81.811604,278.085339,369.001625,334.839078,171.758482,92.69246,-19.565152,-35.489408,42.152784,160.994285,200.834147,162.123213,74.379546,-108.172622,-148.15667,-130.179962,-97.565681,-12.471128,83.755433,118.554462,115.447136,82.633578,38.698478,57.601492,129.316091,119.247086,105.335975,97.754418,70.305635,-26.187421,-56.423414,-42.906531,-9.453431,55.537863,124.365449,138.738441,44.674498,-31.01754,-140.272617,-173.216324,-185.375867,-98.432446,-49.65208,-10.943067,0.766381,23.883078,2.061298,-103.079237,-140.972935,-106.434302,0.635173,19.248157,-11.417632,-33.455016,-106.277154,-145.89841,-126.709026,-33.835969,-26.033697,-106.111265,-153.243444,-219.382546,-269.149063,-364.690392,-345.529453,-186.904243,-97.175446,-122.020209,-235.150382,-278.154116,-299.675783,-284.230267,-234.86068,-180.903527,-156.696415,-174.253677,-224.828657,-328.808865,-361.385046,-414.661439,-435.024361,-404.185081,-293.475259,-260.148154,-243.740108,-230.364666,-211.263266,-211.88782,-168.582325,-112.816199,-107.838544,-78.905748,-52.575781,-71.602402,-119.285175,-177.705719,-180.729837,-190.868911,-132.614086,-87.41756,-77.640941,-107.440653,-183.89851,-206.192214,-178.698958,-141.642492,-118.678906,-85.437984,-118.072147,-243.393846,-291.107927,-320.856194,-308.1998,-235.241501,-118.556836,-76.098121,-23.578954,3.858514,59.522026,91.926603,123.787752,50.895512,29.190601,108.66356,160.946123,120.061652,35.322938,-45.882129,3.415137,147.581242,201.805218,207.574852,199.514723,170.101602,50.770153,-3.497279,-15.775467,56.433917,92.464082,76.049978,26.329467,-86.831794,-159.833975,-311.300498,-343.442279,-293.221426,-224.805266,-229.680641,-281.181709,-297.490882,-292.015299,-262.05082,-168.072489,-145.610596,-144.49822,-75.756812,-21.44868,25.720482,-1.644849,-86.498237,-118.468688,-184.140298,-188.676409,-160.679359,-124.550049,-105.263574,-18.352308,40.374921,168.518318,258.303304,256.009755,182.881387,162.550738,165.164186,136.026599,40.096017,32.265733,88.219935,104.832374,100.972051,138.430643,163.117014,131.629524,78.97543,-18.629895,-42.874244,-13.503554,42.81191,37.282637,33.652534,50.359607,67.249045,70.297245,122.948569,195.358158,193.338728,108.522408,56.972684,-6.129058,8.083091,111.699725,140.046315,135.641914,145.577448,129.175583,62.967723,38.309993,9.090981,16.594926,98.88194,175.889164,179.227148,199.103539,243.405927,263.943515,213.494564,144.083193,150.668862,143.915895,150.109251,171.040018,172.957239,128.907397,-1.319905,-40.91681:-48.847022,-11.252694,-42.731488,-146.930163,-172.62944,-136.020068,-102.348309,-54.960803,39.672389,100.679017,122.216837,89.557942,49.158122,52.204583,104.545718,141.455608,186.220424,231.038433,230.206667,127.056489,56.32225,-28.093177,-8.978913,137.238404,254.332777,254.317393,140.406836,68.639308,-52.290171,-107.602773,-137.95617,-98.777403,-15.384427,23.728192,17.470809,-76.996282,-135.55986,-228.064543,-261.819566,-257.053609,-163.004514,-137.651669,-193.133715,-245.814828,-383.563489,-479.465906,-611.6353,-585.824854,-365.931902,-181.708699,-184.316412,-260.788743,-262.923616,-226.372124,-197.386659,-77.239821,40.161605,63.828329,62.007087,45.365913,-77.269166,-185.009092,-330.618424,-315.006155,-198.591617,-170.851215,-204.947596,-266.566586,-253.413293,-183.809001,-164.859098,-137.669198,-81.7166,-63.948079,-64.271906,-65.487308,-97.677489,-134.05511,-154.271815,-122.465593,-32.11539,27.999529,22.824622,-43.87294,-83.41589,-163.434145,-186.274745,-147.61958,-15.052343,41.985756,46.820043,29.746721,30.356817,14.291267,-80.729352,-120.311308,-99.885903,-42.328279,-76.975599,-261.874491,-350.92237,-440.793725,-440.193691,-348.952356,-200.034332,-155.146714,-197.332012,-251.191302,-316.874835,-334.589181,-364.471345,-363.398003,-287.125084,-187.546943,-187.233982,-269.752867,-302.989443,-310.724057,-306.044852,-257.52778,-96.294353,-10.014409,52.850446,37.918366,2.349941,-19.71573,-69.217599,-72.417684,-40.124953,-53.685718,-93.86365,-161.40301,-166.588781,-112.891368,-61.85352,19.310236,94.843058,135.203961,139.352353,111.904828,53.987497,30.250665,55.967568,114.677468,246.607758,279.600599,242.674808,126.92754,73.496216,9.590311,27.34253,167.125515,232.264574,200.017949,78.649162,14.719448,-58.233871,-70.698593,-122.552934,-148.412787,-124.990138,-79.374984,-81.189593,-132.169752,-165.041929,-124.584028,-31.296877,127.280319,135.212947,115.839701,32.802399,-24.923463,-118.485219,-132.471048,-26.959236,88.763888,339.944145,453.691588,407.136927,217.084867,148.812118,47.098741,14.3497,70.250658,177.680883,205.424105,162.790276,87.085472,-76.290346,-119.969667,-76.418003,8.304735,175.558782,203.941977,187.345744,146.787988,104.830921,9.769239,27.539544,226.249002,372.503436,378.534439,283.183388,195.462987,12.882466,-44.653821,-5.796563,74.835045,219.311432,306.614792,300.612982,166.680154,90.877709,-1.756093,-12.823654,23.304299,92.720497,137.003497,131.017735,54.765164,-116.660102,-172.991191,-204.816236,-187.283309,-105.919224,11.877742,40.888389,16.7384,-19.490343,-123.613435,-158.421763,-101.879705,5.019613,12.757091,-75.428924,-128.683844,-223.663747,-279.320676,-318.756466,-277.787022,-129.467312,28.036974,45.674584,-103.898758,-199.766596,-264.907033,-244.298586,-184.979986,-82.752231,-41.247216,-104.951666,-167.816224,-248.258855,-288.452564,-313.553304,-269.324132,-152.81325,-72.044757,-61.771003,-126.568077,-169.027979,-184.740459,-161.075078,-70.843907,38.600121,66.640608,37.870685,-3.056256,-74.194993,-84.281114,-68.010598,-74.819521,-112.73199,-89.846736,-81.289614,-113.149268,-146.7919,-223.574165,-228.524728,-113.20249,43.326955,82.085895,50.040253,-5.873141,-172.25953,-254.262964,-266.65287,-204.327424,-90.51826,-12.998358,3.49269,-26.933897,-48.785036,-101.470228,-128.8264,-79.504572,56.198757,73.513701,20.043414,0.583091,-54.832694,-115.289117,-172.739793,-131.256053,-5.251548,55.301887,49.435151,1.287713,-19.188195,-69.994097,-105.424336,-141.579932,-54.481961,3.761451,4.766154,-41.905412,-175.773415,-272.503148,-434.487138,-448.365626,-384.035872,-333.911611,-343.304061,-392.664911,-391.270343,-297.420421,-230.305388,-145.766094,-128.404683,-147.916404,-216.512252,-234.275632,-240.481395,-242.254556,-221.576438,-205.466238,-180.125031,-139.645895,-145.993941,-203.573902,-208.14157,-134.967523,-62.887681,114.458164,242.634756,266.903239,207.318652,145.716137,66.865915,48.381756,16.827867,22.362711,93.74881,145.561557,127.60666,22.702438,-30.55408,-92.059795,-107.262555,-122.425527,-35.818918,33.533887,56.048884,10.362714,-43.403896,-32.697987,36.534852,87.006127,156.092126,135.644206,108.667145,50.645633,17.897076,-11.772259,23.930612,128.103381,150.659109,157.468528,167.532637,143.089424,71.738558,57.435322,95.128508,137.537559,217.899917,226.253695,201.007066,164.39394,152.459177,77.150926,46.236227,132.211426,292.82169,308.965329,204.100723,139.637941,57.769491,23.87369,-54.643857,-82.392479:-248.039488,-213.7238,-216.473803,-192.721353,-149.938804,-63.174699,-56.80665,-117.66981,-126.153683,-72.265727,16.846314,7.686473,-55.655136,-72.292699,-22.20772,43.906634,170.207253,202.776872,188.811171,147.839223,142.734824,104.558237,47.835999,-39.870078,17.655023,73.227674,103.021662,50.392192,-113.920294,-180.828776,-227.342531,-204.646231,-149.217426,-128.734824,-137.509704,-200.440277,-228.737712,-268.735771,-298.198726,-362.881389,-421.196834,-460.56316,-548.550928,-583.630091,-675.284841,-744.224475,-772.517719,-683.36418,-474.959202,-424.98379,-407.710585,-302.613304,-264.467093,-277.371031,-253.754281,-62.344118,87.896082,102.487398,58.566876,3.942117,-154.085412,-223.096331,-250.046682,-213.088102,-149.420826,-168.203001,-219.050294,-355.956026,-373.542617,-302.836216,-279.715767,-287.573665,-308.281754,-293.372807,-186.002072,-136.623173,-105.91271,-112.33907,-146.995264,-152.057286,-80.043476,-13.612642,-36.199191,-102.651973,-98.21254,-93.833692,-129.108067,-150.305369,-13.455548,50.123606,43.60033,-4.279886,-58.169974,-83.876666,-231.994302,-308.298765,-345.470736,-344.388989,-382.618807,-467.216356,-470.981911,-453.787988,-452.777477,-407.136369,-295.826806,-220.384891,-138.563997,-178.269014,-294.831761,-309.927243,-263.451822,-234.35016,-258.050752,-312.774337,-291.283283,-192.14481,-141.789959,-81.596541,-69.093191,-74.251344,-103.413899,-73.485212,33.441234,54.816266,43.519241,25.034221,-71.216884,-126.966014,-190.548311,-285.445307,-335.234292,-353.598394,-334.386532,-260.398363,-192.057153,-34.112386,79.123252,112.313389,117.632683,102.03887,77.322451,65.358394,76.90257,122.152221,253.754627,295.934985,256.333208,169.199474,149.027711,113.771907,115.812972,192.436741,228.177109,215.343957,149.751116,84.811956,-49.502112,-72.93418,-36.192131,-24.790493,-53.638024,-7.844413,52.134179,84.818123,35.499747,-37.604751,-21.156676,57.850687,107.834849,120.652773,95.934421,51.41658,4.025546,13.354328,27.239875,42.69914,170.344293,335.554474,340.677131,260.529641,256.770668,256.884507,221.874237,194.112799,240.873494,252.099119,247.24265,212.100767,14.201644,-101.376169,-120.743484,-15.765572,142.478437,111.811997,97.337687,104.234486,93.079299,19.788308,2.320009,80.298231,109.624769,76.635766,5.651645,-32.239319,-122.847982,-161.748138,-183.964838,-170.234205,-119.423159,-37.033992,-11.328719,-30.443663,-58.763852,-140.598813,-180.640507,-170.128394,-95.508371,-94.333103,-140.308371,-146.514197,-151.870117,-188.557819,-248.932008,-221.507342,-115.916868,-0.540445,77.486052,194.783635,194.157061,47.959042,-49.004766,-97.844261,53.664447,146.582984,192.594262,120.002914,-22.702612,-47.269708,-91.165481,-103.569642,-32.069923,44.379205,31.640223,-24.694141,-27.713353,-31.600903,-47.228255,-53.908676,-27.924058,-27.748149,-102.006879,-153.329868,-231.265574,-286.887718,-381.333069,-365.065136,-245.277552,-141.247705,-134.438392,-212.890823,-250.849261,-274.799457,-251.158806,-107.25276,0.781727,7.34797,-2.09838,-21.573785,-78.415051,-65.371673,34.516218,44.755692,-80.517248,-107.777975,-21.395024,98.444039,40.450985,-151.090156,-159.774338,-34.546038,-40.958199,-67.522987,-27.053944,5.76201,22.047861,5.504781,-59.172349,-90.346338,-69.045504,95.89977,180.307994,238.544515,211.514937,131.920151,124.153505,209.064216,303.214783,301.822386,236.754146,216.193823,184.888155,152.106267,135.915491,169.205442,232.832381,304.867485,348.256485,378.735637,346.730874,175.040727,92.285558,95.762091,132.519313,89.630701,-14.153488,-29.410602,-21.682878,-55.491916,-200.84674,-257.391994,-311.861202,-287.745062,-252.253558,-226.322171,-244.88462,-264.081247,-232.550719,-113.217101,-60.307031,-48.018348,46.532032,107.736147,143.438177,98.549557,-21.296461,-35.517676,-1.728054,-15.796132,-22.06903,8.241546,38.832641,111.631176,148.674095,236.85415,307.283298,312.336436,263.771808,223.16713,107.92956,37.495017,-19.703857,20.704201,124.73385,130.449358,142.223782,251.223895,276.313273,116.591346,-3.98001,-101.85615,-75.335496,-68.0515,-70.255987,-72.971368,-20.137867,44.267027,132.476083,131.690697,123.492466,149.784906,141.664065,47.809277,-1.877394,-0.340763,34.677511,67.091588,88.607678,121.31836,170.384589,152.334775,55.428223,19.209068,36.866158,77.60044,140.884939,158.774162,193.540242,331.530324,378.948388,334.637889,283.415224,239.010971,199.003663,185.929119,227.991386,250.774753,228.639188,181.613211,65.523953,24.517512:-79.93501,9.134141,14.344226,-32.442768,-74.574617,-188.772074,-218.524167,-125.170398,26.930681,64.041511,56.143253,28.584042,-53.649435,-95.125248,-69.268707,10.615128,166.107386,193.184577,164.535349,60.743565,4.369785,-76.90492,-78.606299,32.211047,167.746604,198.835341,135.318498,39.445513,-161.220015,-221.344609,-224.839153,-171.791095,-22.688118,14.032578,-48.236139,-178.678088,-201.090433,-270.124548,-328.020574,-366.614044,-308.813633,-299.316954,-366.523158,-419.145016,-533.612378,-607.423608,-704.579125,-678.422467,-480.129936,-252.155674,-210.719664,-254.216437,-275.238437,-271.579853,-232.172785,-27.257006,164.18215,177.215855,79.657148,24.630187,-97.434464,-190.988439,-315.160591,-285.251378,-131.182324,-76.323748,-114.29156,-248.179355,-298.628714,-327.365507,-313.018129,-261.40949,-231.973457,-213.684535,-135.96964,-104.931814,-165.579983,-235.048451,-244.565786,-167.628104,-27.914423,9.67025,14.592845,27.052045,7.794078,-99.694343,-121.244172,-19.153913,103.545192,120.44911,79.448824,44.854647,-28.880142,-66.814512,-114.16652,-126.675414,-157.481406,-170.720879,-211.593537,-371.123936,-432.402113,-475.281309,-459.672051,-351.805874,-239.177933,-205.443776,-188.90027,-218.996244,-359.252651,-425.697324,-396.344808,-317.712683,-197.646593,-142.540128,-150.887873,-235.934357,-265.458743,-261.447599,-227.732148,-126.736166,-28.071722,33.223259,98.205979,62.253729,-75.629768,-118.712805,-99.553524,-72.870961,-90.445075,-181.863277,-222.482907,-239.577597,-225.923798,-174.149473,-113.61716,30.316175,110.326081,147.197053,181.842343,147.789818,1.85604,-54.274514,-26.472411,37.952062,192.621606,265.632234,233.584052,123.817554,87.534968,60.440503,67.388096,138.716315,281.754658,332.757057,246.826344,128.538858,-73.810746,-123.420664,-129.55728,-106.292121,-55.469892,13.537158,32.967243,-13.276368,-58.939405,-126.346094,-128.762674,-40.252338,131.135745,193.169767,142.208841,61.943701,-33.401925,-48.272501,-47.580143,6.513153,267.7147,486.454035,463.911711,213.18356,91.320179,0.01728,33.244785,188.578996,291.888539,300.711016,227.515203,147.067465,-21.584737,-69.003455,-18.360961,65.099258,172.820664,141.874409,132.583771,132.79851,105.955615,18.403288,10.994419,100.425634,189.540386,210.866776,197.328887,159.055781,43.218527,-17.796916,-80.946816,-63.254183,13.650564,80.527775,100.077422,86.424708,50.416992,-100.055805,-188.863197,-237.223409,-102.753625,-32.728325,-6.545245,-52.397107,-173.989268,-208.866614,-183.460081,-144.585245,-55.170277,71.458914,114.151831,103.850158,73.333739,0.133322,-20.212787,38.130299,117.083133,110.15737,11.901035,-53.387928,-151.869622,-188.569993,-227.580339,-194.132847,-29.121438,93.984617,89.716426,-17.559227,-69.540756,-129.652765,-148.585644,-129.727084,-43.705732,-3.349002,8.883358,-33.108952,-170.337339,-234.054337,-271.570973,-234.935692,-145.354036,-114.372853,-120.047459,-177.667632,-220.866913,-248.553787,-193.436457,-1.798254,110.648235,118.199565,79.167777,45.364957,-28.326379,-63.119079,-91.960646,-76.978926,-52.079199,-34.867234,-4.9405,28.696867,-9.867431,-147.133879,-168.114418,-63.469791,55.119161,92.760341,120.417725,95.737135,6.722406,-44.604972,-153.943972,-172.329669,-49.19255,105.426488,127.048788,117.559236,99.421554,49.387182,48.77052,112.338714,197.866524,241.884802,272.795242,237.830002,104.812164,37.394203,-18.351103,4.547906,71.021983,96.08394,90.713145,54.893387,40.680589,-10.772693,-47.069064,-61.032709,4.297718,39.832839,15.437322,-63.035298,-252.32496,-323.934132,-397.37491,-391.2503,-336.472246,-301.858025,-301.601922,-326.043502,-326.98717,-303.101569,-287.953291,-205.351947,-40.210842,25.124359,25.246892,-33.257891,-170.397488,-202.433193,-138.491571,-86.202558,-74.68377,-75.66861,-59.990564,-106.847271,-145.34437,-138.334984,-90.435783,83.732404,256.113673,262.307098,131.299479,63.672764,-25.117666,-57.437566,-55.288261,-27.761508,27.708116,102.095153,111.926333,20.265387,-36.782516,-68.81957,-58.718126,-70.794546,-78.022512,-46.017981,-20.923991,-61.394347,-117.170985,-100.988338,-48.51854,1.02508,178.470842,218.528166,143.598859,-19.325596,-55.177393,-62.930228,-48.263955,26.653757,147.935126,197.81949,193.299771,141.881504,28.059256,-5.592145,6.71876,42.694921,124.033351,178.022943,179.76281,153.619935,142.006665,114.612193,111.250278,200.22558,299.742936,289.136215,182.147281,121.764125,29.752356,6.564865,27.628981,57.089522:-168.536516,-25.940319,-15.477321,-48.330555,-30.113526,37.930523,35.951659,-28.820641,-120.508757,-133.403973,-53.366756,-3.079466,23.196234,-6.62193,-41.143737,-3.654541,95.478421,156.654749,189.91183,219.743667,206.136753,130.055179,75.582347,8.891667,86.641823,164.018135,212.231756,122.589322,-128.977737,-171.547511,-96.120735,-87.140416,-186.740637,-140.287111,-56.397865,-28.839094,-105.71846,-267.799253,-310.094597,-374.753795,-476.254316,-520.094101,-567.138241,-573.5858,-551.961596,-545.490246,-556.149251,-510.770332,-281.78017,-126.503262,-104.279078,-85.872773,-75.973257,-57.346526,-35.518703,52.962661,121.484528,131.021178,135.985652,132.698063,57.807402,-17.827079,-114.935417,-102.341253,-74.106804,-131.228036,-173.767901,-238.278645,-237.458169,-201.010711,-201.82303,-241.068148,-266.778697,-249.711776,-128.903135,-44.047384,125.054156,177.034052,153.626209,104.050071,6.542125,-39.804956,-40.156935,-27.750906,-11.768396,11.144919,-15.702956,-113.127934,-102.322806,-57.56365,-65.070318,-127.271619,-218.82331,-235.618681,-279.711489,-303.907824,-319.548829,-294.667191,-286.72176,-334.978085,-380.299652,-448.115314,-444.440005,-352.02458,-248.73043,-219.806384,-195.41908,-180.013364,-86.682924,-25.496077,5.640372,-25.668763,-69.364401,-39.272297,-8.013058,93.531956,154.704933,210.134715,188.294769,104.901092,65.64573,100.189401,236.518534,261.108512,182.090871,135.237167,68.229144,7.43712,-182.983015,-277.519732,-257.780824,-189.95574,-184.293575,-201.56971,-162.609075,21.061084,110.055023,102.39328,69.390378,57.72504,29.924608,8.546795,37.21779,100.26601,191.340655,171.404402,160.477427,211.459607,256.412674,272.074903,244.522042,214.411157,197.537458,188.702953,176.95507,148.774847,83.290998,67.771798,-36.145132,-139.39674,-255.411229,-114.159444,-37.715362,-38.511767,-65.362367,-66.507336,-54.126435,13.106598,149.092989,209.413841,240.401388,209.563323,176.245648,197.065964,199.769392,167.895531,157.717659,239.61157,276.471132,360.62961,416.818681,413.930266,334.539067,252.267,372.865471,419.32729,374.861919,297.925787,158.835991,135.200931,154.720319,161.006158,120.641677,126.80421,136.826931,64.882637,25.981877,21.813313,23.459034,52.631975,154.503839,144.615643,-54.758311,-152.819249,-188.577483,-177.501611,-223.323403,-247.760609,-213.276312,-91.499454,-37.108717,8.551261,15.603366,-17.781367,-49.553534,-20.670336,37.831335,26.84665,-20.487266,-44.892851,-103.288496,-134.697544,-176.698965,-175.808764,-111.793262,64.003776,154.738827,218.375224,209.645875,207.691277,201.073707,145.348573,171.969909,223.941107,256.97677,207.865963,46.094066,-25.266819,-75.910799,-43.39757,84.782131,179.846813,188.767683,167.530996,165.723368,154.302385,126.743781,53.188938,14.51467,17.332167,-16.999471,-93.033073,-270.533256,-309.846425,-279.711032,-236.625791,-125.704964,-38.037822,-44.095156,-131.28514,-154.444343,-88.932388,-14.422059,142.507165,189.296563,170.251115,117.696885,97.641497,85.103898,96.080001,126.706653,116.243785,26.573274,-15.743228,-2.069845,37.319835,49.982597,17.074682,-23.117638,-20.511076,125.657348,195.541434,231.358579,200.639865,113.845549,75.099449,46.765504,63.120305,108.214368,139.447405,156.427556,168.846009,164.95092,152.176172,134.374715,80.8504,75.425639,108.534166,150.130762,136.511011,157.362347,206.353548,269.22545,267.836124,274.950101,319.635504,345.88999,385.943782,370.772238,237.006211,164.130903,119.46043,125.357153,123.980197,134.402805,127.329098,74.444458,29.385671,-76.023856,-99.576664,-85.194461,-63.010922,-55.755706,-50.221176,-60.203201,-124.09596,-152.982673,-134.743924,-62.280415,-17.656929,66.43656,84.747808,75.271804,48.697564,-36.512875,-72.99142,-111.090719,-44.855416,33.354212,164.664708,202.543597,263.029098,301.11968,403.672178,416.562817,335.274269,101.515306,34.572355,13.657385,3.004504,-42.897797,-47.286172,-40.765168,5.807665,71.92381,185.682078,180.637242,22.516713,-81.52931,-155.305347,-60.381609,-16.153232,-36.238487,-86.589074,-86.889981,-24.624832,69.446149,70.923012,14.972053,-3.837146,29.250777,89.070065,74.76413,12.702388,6.237866,36.577936,8.954196,-13.235727,33.081899,77.38526,57.796944,-16.98753,-111.303188,-74.45642,38.28408,115.26408,167.187426,250.815967,260.593488,220.223888,177.731571,94.393762,85.776551,111.081609,155.894148,142.933263,62.535131,26.620262,19.92821,46.19938:-99.367324,-174.935595,-184.6146,-111.487376,-64.861778,-69.699622,-114.778788,-147.346784,-62.66746,1.701734,96.882392,107.512188,68.332747,38.443561,61.705843,129.364649,265.264154,315.474459,327.752917,332.85464,315.701509,241.863149,196.536554,163.94288,284.743724,357.256249,334.008849,230.717554,17.033511,-41.339433,-71.865115,-67.738988,-64.414141,-29.925079,-7.212536,-49.174866,-96.490993,-124.834918,-122.339801,-209.145685,-382.006826,-438.8654,-493.260126,-522.378841,-625.846358,-690.385582,-704.439079,-620.390301,-427.602551,-332.912032,-284.808084,-152.474746,-99.885829,-110.698479,-123.40923,-6.776402,123.395215,143.856941,122.224827,70.483676,-99.23505,-179.234535,-223.590047,-184.969309,-137.966461,-207.120353,-243.739099,-241.299645,-196.023853,-137.852073,-164.226149,-223.668363,-159.091068,-104.220845,-58.31664,-63.507906,-37.760753,-21.497713,-41.292747,-48.943556,-84.118571,-188.504735,-204.491619,-122.92469,-68.606416,-41.178714,-77.956072,-167.886043,-138.515887,-98.106205,-101.281047,-133.745826,-142.009626,-140.574411,-231.484189,-289.394964,-295.178871,-235.525971,-239.459354,-270.494477,-268.841921,-263.901708,-255.456707,-163.859027,-27.39248,22.173833,46.947607,29.138525,12.132891,26.775665,20.916042,-18.451894,-47.377949,24.124401,18.852708,-38.400025,-18.556772,66.701362,68.469636,15.726935,52.119714,105.385437,136.601461,95.25497,17.015219,18.970402,64.114786,58.065847,-68.06138,-187.590145,-193.404232,-155.458209,-140.072416,-101.870276,-61.897428,-1.118261,35.318438,105.153271,248.75195,246.822951,147.819771,109.328674,108.244377,128.662156,134.926046,90.290902,58.351084,40.522322,69.969564,123.015031,128.408611,116.855806,113.814991,138.080926,160.690736,120.739636,11.177568,-21.829949,-57.918326,-82.624029,-149.606133,-47.785474,78.034422,220.950837,174.785165,21.386913,16.868001,126.60829,194.930443,209.282242,212.291839,193.712595,156.890373,143.400503,83.081279,47.798681,83.130675,243.587691,290.701625,301.767013,311.288919,323.078741,293.942258,207.914202,185.678195,198.688491,192.780141,137.120219,-53.399001,-119.823146,-86.181164,-22.172685,36.763675,49.096102,64.696756,10.711736,-41.583257,-60.145173,-38.813307,-11.527498,47.416153,69.139956,-30.438687,-116.075637,-193.99264,-223.882628,-319.350593,-304.524036,-138.493601,-80.92983,-117.504961,-145.908631,-120.845629,-141.622741,-178.305273,-162.578893,-102.459187,-81.697486,-28.084032,-18.466932,-91.488963,-139.230594,-140.471969,-90.181993,25.542907,71.469079,64.363084,79.698361,132.471926,197.514552,174.24538,103.748424,55.652469,55.433803,92.60654,86.243399,-3.203533,-55.041745,-131.500334,-163.504662,-182.355861,-73.015271,-28.15741,-87.885592,-133.122976,-107.13152,-72.240724,-99.238575,-239.308261,-281.274976,-250.806714,-235.618944,-310.772065,-370.502906,-423.379661,-400.235171,-256.14216,-72.025725,-39.053808,-132.533687,-198.101911,-227.890621,-174.232811,-0.169283,22.579693,-36.782916,-141.695591,-150.84166,-115.029919,-86.585907,-3.662679,20.734321,-5.811084,-14.436209,-13.914396,-100.609016,-177.336964,-268.627274,-259.215664,-188.482089,-131.966928,-97.913941,-24.747069,-3.624572,-21.014582,-81.918002,-225.658651,-226.542803,-91.354723,30.629247,71.03171,169.114169,205.281083,163.818088,119.412607,92.792852,98.404619,117.579032,196.871683,214.990411,184.125704,169.626019,218.833342,282.55168,398.358511,437.604507,440.557215,414.772347,380.045153,246.703319,169.502481,72.819373,11.814518,-13.701695,-34.195528,-36.501389,-80.402602,-141.352032,-262.265364,-269.917748,-187.408791,-112.289807,-92.030619,-31.878081,-3.695026,-69.868342,-149.233017,-198.527807,-13.983027,122.577284,298.46764,287.398301,145.056029,61.705704,-72.739897,-100.977761,-69.557918,10.24147,50.759561,145.356605,191.606618,229.805945,246.788358,355.461613,385.887818,322.684902,183.675164,162.963292,137.144469,66.744038,-91.446044,-94.22384,-15.091452,5.871365,21.276423,101.734148,119.298601,-13.425347,-127.803987,-244.672735,-198.732397,-161.569698,-90.859637,-61.08725,6.631767,42.595075,82.716221,87.78911,79.824669,62.844229,71.784792,112.030488,121.637292,112.08776,102.725064,81.212225,44.269435,39.167813,89.076954,123.078204,127.171235,85.865729,26.569109,49.428799,130.37854,228.678373,304.161734,441.819011,471.341217,388.796474,287.639224,103.442578,37.740986,46.843243,82.281133,82.467746,38.537829,5.186615,-9.3024,22.234392:-157.965532,-68.739364,-21.101491,25.872845,32.117237,9.09881,-20.810439,-55.887619,-98.049185,-116.199615,-57.52543,-13.811003,7.663286,4.300188,-14.251242,-22.299059,48.088669,162.259036,175.085605,145.85756,129.574558,56.363858,1.070177,-61.926279,-8.580136,45.747957,77.601007,19.744388,-167.449759,-229.959967,-215.11612,-163.707923,-64.212216,-8.155333,-11.264984,-65.12281,-81.49584,-105.42393,-139.118401,-250.030814,-384.755055,-440.772044,-470.146721,-444.58711,-424.985368,-462.822009,-533.207911,-504.511205,-359.346659,-282.739227,-258.216345,-128.22214,-47.806836,12.607614,6.212993,34.158179,102.718859,118.383038,79.842627,39.643731,-41.955516,-71.921657,-97.99174,-90.599217,-33.901422,-16.501169,-65.365978,-181.419763,-190.239236,-184.266497,-200.258413,-185.24404,-146.767049,-147.766025,-125.660876,-101.366504,-70.01582,-61.44605,-49.569631,-55.210654,-100.129316,-86.772317,-36.325345,82.62768,124.28718,125.266185,75.084303,-13.674109,38.443475,86.293573,140.003571,136.116187,61.61087,6.165097,-77.152356,-97.672201,-162.344163,-278.988749,-348.816404,-473.491706,-476.614239,-360.083554,-312.549312,-343.044962,-350.367308,-279.515937,-182.242276,-218.105723,-285.113343,-246.80031,-93.779522,-39.20974,-49.922208,-98.844848,-75.01234,21.612398,49.02537,72.340318,77.120877,-8.342776,-79.838119,-18.925333,160.102596,188.952904,108.042236,29.226008,-119.348372,-166.224905,-242.361849,-270.16508,-248.182859,-238.445806,-271.667703,-305.510451,-258.57393,-72.09925,42.378193,59.04,65.71939,54.496692,40.306114,57.933991,86.804964,70.61832,52.689645,142.709997,175.189653,131.309318,101.384163,122.258276,156.321555,220.171625,223.396682,218.123199,188.444496,133.791033,27.457658,12.363871,-6.915545,-31.11313,-72.271016,-18.127031,28.794582,22.920218,-32.028114,-92.194359,-61.456214,47.02175,82.610526,83.296399,119.756104,147.673419,151.531657,116.099114,54.761589,68.405928,180.576978,265.628498,272.676742,287.280758,299.140775,219.603147,144.403482,185.387821,431.580832,475.136377,327.660871,204.858559,13.065651,-18.821838,82.359471,174.239021,233.126024,114.242961,76.746386,103.310411,116.762399,36.25932,-20.062712,-16.47526,96.991651,117.659371,3.222991,-94.203013,-222.041185,-236.304739,-231.529832,-233.231443,-211.962386,-99.002313,-43.917306,-17.476287,-31.983565,-78.636192,-98.876565,-70.494364,-23.261509,-49.931961,-175.516615,-217.860376,-223.299284,-214.432819,-186.811216,-170.857845,-176.359542,-125.131991,-42.496851,129.393897,171.462491,118.229034,44.015442,-56.894009,23.095166,110.500629,164.102814,90.89011,-84.758487,-136.851985,-149.724894,-100.504752,100.784761,261.030972,240.081407,82.565502,49.414557,101.599424,124.256634,122.303535,85.535819,57.55847,-29.240695,-94.923031,-215.342434,-238.653005,-180.79308,-117.721999,-49.339383,-106.65751,-136.716632,-165.17344,-164.027267,-106.854151,-56.91539,50.681825,110.345497,118.506959,84.105576,27.423376,-83.16207,-82.720025,21.721033,62.783376,35.830992,30.843575,56.801184,49.611355,33.369689,53.7107,77.627086,136.91228,176.350166,194.153521,207.236996,174.083675,86.823565,70.954495,62.921894,48.460938,40.86199,157.933609,226.166286,226.445901,181.950375,130.757757,140.598984,227.22228,296.695099,287.566698,198.638186,158.970454,123.797145,104.251958,46.821907,33.665203,80.315992,188.581185,228.758372,231.234405,205.455192,98.547687,24.061165,-40.239909,-3.969039,-10.698839,-77.263322,-114.162273,-151.297362,-161.227406,-215.41909,-247.899147,-267.233003,-241.35937,-226.270782,-201.928169,-204.611571,-206.06714,-166.973455,-65.914744,-54.457582,-45.867376,16.361379,38.642154,33.157306,14.436942,-41.402151,-65.761737,-60.876392,37.224199,86.935255,107.315324,107.853629,130.149274,149.458932,275.696121,344.662092,285.406083,154.846326,149.44116,165.436894,124.984559,5.285623,-3.042539,85.392205,113.692142,85.197671,61.973713,78.553046,57.01916,8.764632,-41.702539,-41.444897,-52.023281,-37.731114,-14.17997,14.108435,15.243196,41.673762,86.94265,134.235058,56.612101,36.870309,72.155434,91.656089,72.0701,46.953544,43.135606,59.740132,52.868274,59.099355,87.058466,123.913985,98.177891,15.042302,7.831041,34.585835,37.783174,72.670571,206.053886,247.42842,216.207076,191.958527,231.619551,172.325157,86.226237,32.6081,70.489718,92.436082,56.475441,14.927622,52.381654:backward
-108.893734,-67.908842,-45.450392,-28.269597,-50.254526,-112.327684,-108.647607,7.799857,111.989772,108.547169,37.916349,2.02365,-59.191012,-69.266539,15.795833,82.154959,152.906614,165.288517,158.96092,113.332684,88.633486,74.985949,85.656109,129.586903,241.111489,314.778905,395.415411,378.105808,254.228362,160.871067,-19.91064,-69.148895,-75.46217,-54.666913,-74.371079,-130.912179,-137.648576,-143.381293,-145.611228,-107.598313,-69.692033,-55.046911,28.760981,82.696498,82.854649,23.048084,-59.788419,-45.486836,-23.293514,-121.615933,-157.324675,-133.041289,-100.269107,-58.397927,-70.440552,-129.319746,-83.977337,-18.739902,75.203462,82.246883,43.485598,15.881751,14.164884,28.041088,-8.766211,-29.378927,-13.402939,39.849489,92.608204,205.01963,240.314496,313.436509,373.3938,383.944608,382.871201,363.636443,291.368685,255.886136,223.337622,222.436015,214.993665,232.653907,245.991304,201.481972,144.605456,29.813716,-5.688649,-37.226688,-60.646122,-51.083892,-29.017038,-63.211389,-166.537349,-166.373624,-52.308542,12.941726,75.028069,33.897173,2.419418,-88.888483,-162.466938,-250.444785,-198.498562,48.70961,244.328074,267.088884,147.990714,77.121374,86.360819,126.00725,107.943194,53.935908,-15.656645,15.698147,26.251853,17.51404,22.67153,17.065242,2.288822,41.763697,131.607938,166.477916,207.257813,186.162656,65.055167,24.662041,56.571068,92.131369,142.232109,178.41816,172.963203,127.568629,115.781497,121.747832,122.520301,60.514395,-61.855353,-95.747494,-88.6426,-75.682684,-126.794361,-190.498817,-263.733673,-261.804126,-245.863716,-168.026968,-124.063452,-118.198685,-137.81706,-171.826818,-186.717581,-203.975272,-200.850619,-194.819559,-200.369297,-213.341066,-272.843378,-328.454765,-405.816329,-397.296521,-351.428584,-278.592242,-220.682845,-141.526551,-156.198956,-243.847312,-254.049734,-143.674653,32.906776,97.951851,115.063113,77.089313,-8.355563,-38.903609,-15.534865,42.73979,128.505889,120.755709,113.241636,165.04234,208.669023,241.521475,235.874459,226.874062,251.285275,279.421381,273.232274,217.73359,79.866614,19.10814,-36.593084,0.555354,158.857655,247.218014,238.430623,166.371668,120.182614,22.935711,2.906936,89.441701,185.221246,168.774673,90.067803,85.75768,146.011254,154.014005,57.447689,-8.473536,-90.920449,-148.354895,-193.569503,-276.029575,-276.667463,-209.524607,-180.963545,-179.320961,-194.092693,-177.147515,-172.499992,-223.132625,-373.053948,-416.211239,-378.015127,-342.933067,-315.323824,-269.642868,-247.602676,-256.270346,-293.955231,-387.030777,-397.020957,-302.810415,-162.406034,-114.879517,-75.731947,-64.863517,-2.738954,32.688182,48.019625,39.717244,47.616054,82.984147,94.089851,97.636625,112.494936,164.296873,172.585876,139.982793,121.724486,139.818019,133.973008,73.378141,-63.037182,-81.753966,-37.707525,-28.790118,-99.292378,-111.193821,-50.936567,90.74709,117.637885,58.489158,5.747307,-61.425267,-29.567911,12.194021,79.366754,104.109963,134.60303,119.795296,60.409856,45.19412,60.249095,109.215445,131.917703,120.01227,71.502603,-22.009698,-15.044524,99.059534,198.52582,192.781507,55.449731,-12.330866,-25.765565,-2.420733,54.880408,89.966318,98.391677,42.691707,42.668366,78.887898,61.569085,-46.93796,-72.673799,-30.458885,-3.313898,17.383381,107.453219,144.160282,113.735114,62.517665,27.831617,52.75273,118.032409,209.060383,251.441984,243.93883,176.296377,-34.31058,-123.458573,-188.702206,-138.909553,-88.129751,-21.873993,-23.363629,-52.119916,-64.237763,-42.530302,-3.259006,115.981559,239.838234,262.046204,220.484943,184.931245,146.407085,154.638489,182.027808,136.083103,76.331902,-45.510845,-70.994833,-116.249908,-176.237859,-300.201647,-307.915104,-204.203978,-79.755789,-48.323139,-68.149044,-110.618912,-191.655854,-193.130298,-141.968076,-146.842953,-154.597635,-136.668591,-120.953929,-114.946868,-129.460033,-155.806054,-157.297677,-134.468564,-108.414554,-107.12906,-122.677016,-142.13806,-176.192564,-154.635063,-2.531893,196.23202,270.329126,290.729417,246.970365,154.362997,134.684908,154.088105,160.138214,170.986893,272.070709,306.096635,262.535027,220.256778,160.49698,134.430521,87.237111,102.684155,117.920031,84.632859,50.389397,7.98035,-19.405915,-72.477124,-63.469083,-3.28706,-15.529865,-63.792127,-125.14787,-105.993459,-72.637245,-84.606528,-81.163003,-24.443904,6.89069,83.4205,109.681381,40.837223,-23.335474,-23.401226,29.646015:34.471771,97.844944,100.772486,48.530488,9.095284,-65.692418,-60.333121,73.812622,226.348652,259.685973,186.822339,91.622838,-68.491804,-71.466355,41.290731,78.217427,44.641188,66.417563,112.085345,88.380858,15.897475,-54.302493,-18.197728,111.695393,222.791915,257.021549,254.797713,219.397127,67.744827,-42.355416,-154.241492,-126.046409,-66.798071,-128.489724,-180.861087,-220.322291,-221.942698,-272.084082,-309.230407,-341.325308,-230.198453,-147.608716,-72.070896,-69.413514,-101.833196,-149.127623,-206.468985,-177.994804,-108.701158,-110.765613,-105.027333,-67.211841,-75.181438,-148.476488,-168.497898,-170.254462,-82.409807,18.053752,155.864744,137.183318,-9.403136,-79.768763,-123.282568,-102.083186,-41.421258,14.889831,31.715011,51.820607,69.438566,111.889188,135.618818,208.232526,295.385099,315.523511,297.662212,286.987274,256.956167,203.328736,42.421341,9.124306,138.010032,232.725225,181.129946,32.591828,-10.9307,-65.329123,-92.37602,-93.580451,0.315267,48.684129,26.899181,-58.576923,-247.959039,-277.70311,-138.42846,-32.55673,27.775944,-57.142369,-85.525509,-128.040522,-167.680528,-242.777911,-221.697571,-20.336467,183.491021,221.153183,177.214588,124.949387,16.259463,-21.202943,-6.602285,27.810227,57.139083,54.722427,46.984485,-29.028387,-88.561148,-129.568696,-78.557621,89.851011,203.66419,208.024717,127.882242,93.846852,87.20728,78.506183,28.365265,9.443728,39.593206,129.07104,133.460893,65.982552,26.483617,-15.48165,5.544136,47.46014,-62.441503,-127.73294,-159.525041,-146.364301,-180.046373,-229.535272,-288.954639,-275.446733,-198.680084,-107.69189,-88.129287,-149.703031,-211.025508,-310.875688,-326.489869,-266.912938,-140.419942,-102.790502,-165.320443,-238.023842,-356.24357,-393.317564,-379.38535,-332.967037,-278.586361,-260.606384,-228.966287,-187.401612,-212.686829,-292.667846,-294.843719,-220.990669,-108.720202,-36.942385,25.693433,-13.667859,-94.374737,-86.856738,-25.060366,2.721061,41.040219,97.637965,128.498667,150.594761,129.803471,78.917653,95.873145,188.276514,251.75858,262.925771,166.465154,66.578037,-89.354095,-129.04876,-108.679214,-30.812626,136.599561,171.274165,163.379041,140.20629,107.034336,9.367451,-12.179852,34.532589,93.864474,120.929869,168.838885,146.215188,1.419866,-63.766708,-116.803397,-131.88772,-182.322525,-220.35132,-252.599092,-355.208087,-374.246533,-312.217592,-257.224292,-119.963161,-79.370215,-112.917701,-193.247502,-221.35147,-329.548947,-418.6672,-464.64378,-378.803056,-140.057148,2.452698,13.45567,-70.066683,-139.594704,-205.651737,-174.081591,-74.563952,-15.389497,1.255838,28.857729,32.969771,38.505112,77.652746,191.018937,195.10986,97.143816,90.695386,124.183987,112.943724,86.320543,87.788399,100.59935,116.789574,156.023046,169.775092,118.902486,53.476808,-97.230883,-131.403209,-80.884915,-61.999212,-109.848157,-84.546234,-43.748199,-25.633064,-45.683372,-73.498092,-61.38704,6.481361,116.914362,178.045351,190.58775,150.065704,122.42985,126.243642,103.491102,90.611882,119.916495,231.429547,266.44398,210.599912,135.292837,-21.962261,-56.39696,11.185271,127.776651,122.855633,-40.955875,-112.185876,-87.286662,-50.372541,-4.682898,34.0161,98.398449,94.667085,90.687653,73.064119,41.881868,-5.472347,9.657538,68.874786,154.011829,224.351285,312.618109,288.36876,137.752195,66.755802,67.865983,119.791188,198.782292,286.167315,339.392117,328.144852,251.959284,108.474222,90.554105,105.227232,95.617122,93.258437,76.489588,64.279749,57.221294,57.639243,82.697345,121.940764,265.143143,415.952681,419.822602,306.677291,260.988839,239.817258,240.734322,245.465283,234.656924,207.307714,140.649855,113.644811,12.695258,-64.227605,-154.357846,-147.794828,-95.410917,-32.606059,9.267821,55.532503,15.026099,-114.037115,-112.048811,9.470842,8.977097,-42.709481,-113.140539,-125.181454,-173.341234,-201.03727,-170.376423,-119.313467,-57.530141,-105.329583,-129.476943,-103.257302,-96.399086,-143.405041,-131.653306,16.790164,135.212555,152.837234,176.005425,185.380996,117.145042,59.654217,62.188886,109.231595,161.879438,169.252618,171.23991,123.551307,58.036304,-41.691999,-19.657263,75.32408,43.118467,9.145205,20.804402,29.20552,-75.028289,-129.866376,-68.083855,3.606693,56.436661,3.989227,-18.582963,3.783721,-2.725749,-153.474387,-214.88688,-134.692075,5.024499,17.208401,-30.239382,-55.59563,-96.477267,-111.53372,-102.585084,-83.890135:20.456081,116.393617,119.799879,42.147497,-31.401596,-113.095232,-69.97547,98.306914,199.774713,211.390525,176.684655,140.670622,38.339425,-11.33607,-17.956359,21.760821,77.72197,55.174558,25.397931,-71.821918,-121.870658,-132.36037,-77.242445,67.503253,124.820328,127.173661,121.624884,100.215901,-12.426234,-81.535516,-136.730953,-104.21678,1.637932,17.893899,-27.267801,-154.867374,-199.657711,-241.502912,-262.265655,-282.301731,-192.795824,-133.493554,-94.725174,-106.443848,-135.932723,-158.55213,-186.429148,-165.40616,-87.826037,-56.685524,-54.257772,-48.335405,-61.053018,-118.156735,-138.105521,-126.316584,-10.880351,55.194972,80.205243,46.575822,-66.383724,-131.420728,-186.866829,-162.250714,-33.394291,83.264451,86.734753,16.203489,-23.488263,1.442376,84.704445,244.58218,231.575702,187.480077,101.510859,80.621159,83.96485,80.543064,39.872537,21.50009,52.693348,143.47084,154.794196,76.835361,7.111211,-139.649141,-184.606021,-157.176636,-39.496149,-16.73721,-87.821932,-144.896822,-214.27367,-197.883429,-80.411474,-23.123607,29.893135,-10.046929,-58.863944,-164.993147,-214.269172,-277.650932,-247.100981,-35.493446,174.63214,210.049751,131.048043,54.519416,-56.812707,-63.478503,14.9301,58.068817,76.873146,31.125791,-14.984011,-93.580526,-96.158258,-74.078188,-77.079416,-67.451452,78.968529,175.373794,223.29741,146.484624,-66.006914,-111.233498,-50.635708,-4.390854,41.164713,77.63742,92.824161,47.676158,-7.230668,-82.689411,-71.798624,12.223519,78.278742,90.135163,64.268475,22.277182,-106.09787,-161.22356,-185.927821,-166.250848,-105.771361,-65.335098,-80.291755,-145.201093,-172.869927,-172.301422,-125.953242,-45.874591,-71.074781,-62.736129,3.335815,5.526517,-99.745821,-163.581198,-220.966778,-209.098635,-86.761272,23.94115,9.767085,-109.151578,-177.32794,-225.682589,-188.809641,-71.475178,59.984513,108.980223,97.527571,47.255081,-103.159554,-165.073775,-124.876373,-49.011044,36.296973,69.569604,103.65622,148.400274,115.815876,0.899085,-12.253271,46.230844,118.573292,145.933386,126.613059,76.161656,-36.50613,-82.351991,-129.704521,-97.356239,73.343618,136.840961,98.62385,29.821197,11.553252,-12.207482,14.438029,146.971416,175.804729,129.070717,43.860148,33.536723,15.157097,-14.401623,-69.890473,-87.364737,-133.630858,-226.207726,-287.956063,-379.721291,-387.767966,-317.501127,-258.616062,-157.295475,-57.670601,-22.301746,-63.829251,-125.582524,-248.614887,-282.335377,-264.209322,-234.800749,-139.838922,-18.644061,-22.638981,-139.103149,-169.564993,-98.195261,-26.369824,97.008432,156.776783,170.56477,167.293054,151.692839,106.389695,86.802838,101.084562,125.512636,155.529512,186.936013,196.011787,164.273681,147.594047,153.253751,140.136181,37.242279,-34.053807,-22.634186,27.625373,20.571793,-104.276415,-172.903757,-163.367605,-97.011938,-11.346443,-89.228434,-149.069323,-210.566184,-224.792291,-276.618886,-275.537785,-109.565093,132.97404,209.170578,215.781508,158.173177,44.020583,39.840793,107.08379,134.365016,161.153589,156.497601,114.479405,-24.96684,-81.659353,-115.088148,-91.276426,-44.113906,-82.328381,-108.017733,-113.85634,-105.539954,-108.130567,-100.204239,-3.311423,56.146671,107.545119,103.728546,93.267104,58.344542,23.29613,-27.7104,-11.487149,74.86373,193.275694,251.584302,264.729358,218.899889,148.263807,141.689628,152.101514,162.080367,215.902341,347.042689,382.368405,301.020582,231.532029,186.025077,224.357664,319.199827,312.931461,285.531836,255.037137,253.045824,223.437723,198.335135,176.794558,176.810539,224.911767,375.857325,424.894577,385.086279,328.903918,237.341151,205.033355,203.932648,344.55914,390.220533,268.875066,150.697045,-23.943202,-76.162839,-118.88714,-108.767907,-49.641566,57.656302,96.912288,43.724747,-27.711,-116.197541,-113.008951,-49.117956,43.714106,70.529543,35.358222,-11.379201,-126.66107,-178.096444,-157.648219,-92.487295,10.356999,-0.677521,-40.948786,-118.495394,-136.602626,-97.282073,-43.830083,55.719333,109.939986,136.889252,149.308188,107.071171,-26.79042,-53.163948,57.488627,121.528689,106.294468,59.171558,69.586911,99.857466,79.541981,-60.662454,-133.092336,-151.68364,-63.415281,-33.983956,-33.079968,-58.307907,-131.679228,-146.242978,-59.16806,11.569567,72.796457,27.036854,-5.031995,-56.475314,-100.201612,-210.51246,-210.242431,-69.570235,0.040714,-18.529264,-23.258147,-15.405863,-82.769324,-127.194193,-104.664676,-49.121561:-49.347593,-53.134726,-88.983569,-128.728335,-122.832916,-114.078947,-98.046856,-12.694053,113.902243,179.570243,200.370309,146.806397,35.561098,7.938872,13.766043,39.202937,124.514882,173.869025,124.860052,-46.472484,-81.353752,2.83517,68.871309,137.123637,155.422802,175.685096,219.911738,213.155844,104.268666,25.331644,-70.037675,-70.906737,-23.877673,-7.741605,-39.623179,-111.958018,-120.644084,-105.841852,-102.046777,-114.518748,-70.516158,-6.674655,107.863465,113.496565,-2.605954,-92.749387,-187.640985,-167.567614,-132.460607,-177.689517,-167.999928,-74.507668,-44.994331,-89.840785,-132.154167,-145.977266,-55.345628,-3.650603,43.212757,26.379954,-82.688948,-141.592591,-130.586192,-71.172855,-16.538042,-65.434604,-79.172296,-39.578988,-6.192023,82.603747,162.410688,304.399397,321.573886,319.756602,323.428721,322.746523,293.689296,251.987153,183.264875,200.071813,302.893984,329.275006,290.596925,185.489381,141.6429,44.993306,-14.988503,-90.914181,-46.649503,-15.729738,-38.226005,-92.190669,-188.071907,-203.557761,-174.433187,-124.589033,-22.418822,-63.580752,-122.438914,-223.238674,-259.683647,-289.415317,-239.620687,-12.005507,172.052751,210.636048,164.314036,96.892525,12.446636,25.459719,86.442928,81.129399,-1.277883,-23.227556,-27.935127,-111.741237,-156.586508,-163.406758,-122.295807,-13.808718,39.41816,58.275639,81.378345,60.153535,-26.399248,-40.85604,37.207964,75.967012,91.403459,143.636375,179.344975,208.747538,184.990411,83.340168,58.197851,72.996216,15.144358,-26.029236,-45.041649,-53.442591,-138.002941,-194.449355,-234.013485,-199.85724,-124.037511,-154.390489,-175.443967,-154.126314,-134.866694,-148.999235,-163.106896,-127.052488,-35.2585,-0.126059,6.005705,-16.327043,-112.427633,-183.442371,-268.541049,-257.002606,-167.771353,-60.944467,-36.208186,-75.050344,-112.962785,-156.582381,-162.114372,-128.849658,18.885705,109.332447,152.594907,83.701594,-86.125973,-130.981865,-104.254539,-56.6072,3.32067,52.628839,89.251358,116.302734,85.50103,1.802608,-5.954055,64.547345,186.708926,219.096502,126.625062,32.044365,-68.605645,-49.053502,27.806712,42.716392,49.694977,102.7594,143.905255,217.647013,218.835182,133.943473,95.065958,121.738565,213.316091,232.520746,209.981212,192.715246,140.246323,101.652147,71.736957,64.536745,-30.669163,-170.551654,-224.473142,-282.617747,-280.372197,-188.732733,-120.781862,-86.313415,-159.730622,-163.80495,-200.869444,-274.949589,-394.010269,-399.228322,-356.386093,-329.200216,-266.399865,-227.09337,-242.591665,-307.973872,-329.727824,-315.132312,-279.241309,-186.387501,-83.257596,-28.809767,21.557809,5.074988,-31.892484,-33.622284,-24.504995,-7.472876,77.124953,155.30799,154.671248,110.018892,103.378597,135.403542,160.245269,162.334909,83.726579,75.502658,94.087565,59.107763,-76.192401,-139.681758,-223.636608,-223.97227,-146.400674,-121.824765,-155.478479,-202.924205,-189.906268,-137.767942,-108.096543,-34.877649,34.026877,68.496034,114.2562,121.71269,142.64832,158.812515,163.832018,141.202732,91.710555,115.697834,119.366837,16.632569,-62.554066,-164.714166,-163.683339,-72.310234,-19.412245,-47.550237,-130.894581,-135.62573,-84.189901,-63.696529,-15.794292,13.501007,10.520944,-31.784646,-32.222213,0.561954,8.089159,-25.71273,-42.540759,-30.800069,26.983509,76.033147,148.028658,143.390906,86.037982,52.042262,13.235612,31.864445,140.159192,250.88785,278.078013,252.274053,209.409362,155.993798,165.564747,156.215151,70.439551,54.040585,92.053632,126.143233,167.266354,158.806281,135.240477,149.175795,239.738444,366.141038,404.723844,393.069903,338.841944,170.879408,108.336049,93.610037,157.487438,182.695589,132.517926,47.309786,-164.06901,-245.864646,-281.22282,-244.338603,-178.103392,-108.993062,-52.494861,-2.646953,-38.232319,-129.500675,-133.142412,-74.361298,-50.162353,-57.538012,-93.303908,-122.54008,-213.031768,-262.448649,-261.127676,-192.465361,-25.262003,2.981837,-13.52261,-7.043707,-12.013243,-84.562501,-104.753723,-10.622073,151.157459,201.330947,211.234315,175.398988,36.274761,-31.602076,-38.383636,4.276438,67.258888,125.6855,148.922936,139.565521,112.713025,40.913582,3.1387,-37.198205,-26.099518,-27.610775,-55.704582,-60.510684,-46.898121,-41.581073,-24.760532,-22.067404,-64.45629,-101.031926,-101.360315,-106.760127,-124.56016,-177.053065,-192.164006,-167.286663,-102.485784,-90.41757,-99.737723,-89.064318,-48.638384,-37.016254,19.121169,57.881109:20.354482,34.381794,-3.922738,-49.354383,-64.295731,-135.405217,-146.710057,-58.516604,97.876053,177.197842,267.663437,255.848203,118.001331,35.617434,-20.159163,-7.565796,14.798853,74.797414,88.281993,-48.703087,-168.836492,-262.108631,-194.512738,1.552608,91.16691,116.29623,169.889319,160.447608,32.366694,-37.700909,-104.412279,-119.372782,-108.987894,3.537437,37.670603,-31.126166,-97.534001,-181.951011,-195.99088,-154.34627,-55.133638,-46.2592,-85.502192,-86.829317,-98.97079,-150.736629,-260.069317,-254.446639,-148.396052,-87.692311,-76.399843,-58.584585,-72.825533,-137.211353,-147.640507,-100.512717,-17.824755,26.397628,90.935737,79.352319,-59.590044,-124.641083,-104.237577,-59.112626,-27.387619,-12.041672,-9.324402,-21.411053,-13.133352,42.459957,89.437357,208.87037,312.772758,338.826758,314.702547,277.469422,155.259332,67.639435,-36.403017,-10.912066,145.619115,269.857108,254.487824,88.7198,-9.892123,-118.370802,-107.851168,-42.363123,-41.260446,-53.378686,-63.966614,-74.454543,-177.333361,-258.19684,-274.658491,-172.853229,39.573744,-20.058048,-120.267071,-258.469982,-280.627148,-246.933228,-181.711424,5.61032,189.199211,234.059882,128.373221,24.309356,-81.5408,-68.247848,6.338771,27.82355,13.2593,-44.192283,-89.242488,-176.687526,-217.073469,-255.956478,-214.665217,-68.206175,5.245462,27.439559,73.585405,74.127927,-13.324345,-61.331932,-44.361837,1.601552,106.18779,192.585514,169.805087,10.527283,-49.682134,-20.92701,35.823173,92.700251,102.183849,141.954296,202.92426,172.440566,31.494757,-46.747924,-168.103165,-179.894141,-89.242404,-8.107798,-19.983892,-112.973594,-156.248818,-134.260054,-64.539703,50.76764,97.828612,131.785312,139.111785,85.796827,-63.458945,-109.674352,-82.831981,-27.674821,102.773049,161.682365,123.492508,-30.639946,-77.199714,-29.239437,30.280756,132.131848,225.813604,253.740941,207.27066,142.376284,-33.31558,-117.538923,-124.001731,-37.407659,131.739129,141.405101,94.001218,-2.387176,-21.153924,-20.5108,2.01122,105.425188,190.210092,189.257622,99.569721,32.670611,-85.348594,-111.28832,-58.757386,5.461578,141.711101,210.867121,201.325255,154.962073,126.186511,56.551462,77.262718,272.241628,418.242524,424.244673,327.252699,253.951058,133.661442,90.902334,23.238491,6.502584,18.246751,-29.036353,-89.3591,-179.938992,-207.894247,-229.789429,-188.611133,-94.924993,-147.635389,-168.873886,-157.165749,-180.270212,-306.747287,-353.411565,-301.057294,-235.964098,-162.445185,-153.098998,-163.233142,-202.845429,-221.177491,-199.232817,-124.420065,68.375613,166.442216,186.662486,152.526437,104.09087,37.362012,26.184362,10.959283,19.311765,90.274249,140.969972,158.05531,200.851146,194.911673,131.346758,117.563637,155.602851,217.506551,227.268617,169.128374,99.840758,-117.986121,-218.545156,-247.729127,-197.643373,-78.862277,4.782778,-17.912305,-149.382925,-189.759237,-188.629429,-163.830266,-75.771027,19.273447,60.22441,142.112728,169.124312,137.577,87.312843,5.662879,-4.468524,35.908929,89.615121,66.688845,-106.956474,-196.714063,-216.445086,-166.769927,-124.011388,-125.011489,-126.080867,-194.766556,-245.251191,-310.582911,-303.060886,-182.3511,-111.798151,-23.176807,33.825499,37.608717,-27.964525,-79.205978,-130.748479,-111.793126,19.733149,216.145092,263.992627,199.046783,149.744174,93.474848,61.881479,46.449302,83.089121,180.61478,262.919153,270.348765,185.479693,128.485519,106.471283,136.446083,177.997119,226.924801,260.54972,235.634331,174.139927,68.312785,56.86239,110.414622,146.948243,203.457756,289.96574,326.665534,284.041578,199.971999,33.362682,-4.017862,5.250066,101.307048,142.435076,102.274975,33.369326,-115.792839,-160.967456,-132.823711,-90.525636,-9.437272,90.298094,119.896246,50.837491,-44.555457,-195.124309,-195.36305,-79.737228,66.911836,108.07896,41.85182,-55.153014,-235.446285,-266.00892,-169.760114,-79.928898,40.677971,32.980862,9.071034,-34.298649,-65.124536,-114.26166,-93.489361,51.999702,196.00136,215.287299,127.28682,42.552207,-73.970205,-53.301428,85.316114,120.056609,90.270657,76.674721,87.906551,110.467185,72.788288,-110.986053,-169.24095,-109.401276,26.633347,65.54847,33.504731,-34.246692,-157.786578,-156.174909,-47.025786,-11.474943,-37.344116,-37.193665,-21.666538,-73.690584,-146.175353,-231.513317,-200.300114,-55.192035,14.081412,-9.779028,-51.863729,-44.141629,-83.92582,-121.210756,-41.875673,65.671074:-166.160125,-231.37074,-285.161923,-285.560776,-232.206991,-167.552565,-174.242987,-130.663232,35.598474,124.649848,193.768417,164.14398,89.927464,68.472356,71.855096,107.912753,185.494756,162.289376,130.229425,89.11863,68.710957,27.63788,36.685113,98.029522,175.933825,240.413129,369.011889,381.560648,279.50302,208.482982,119.524052,93.925498,33.576472,-13.478083,-22.562534,8.918867,37.478163,12.579785,-37.06235,-54.931466,51.317537,114.872351,190.72692,180.238118,92.904803,41.286069,-16.003805,-18.774642,-40.075835,-106.354707,-127.951359,-79.701188,-23.326598,38.687969,24.884644,-13.299497,36.553311,77.446227,118.139387,108.445729,36.475735,-0.513687,-12.443209,-10.371972,-55.531501,-80.274523,-60.549885,16.159825,50.937102,98.75105,139.569161,259.727187,347.791921,398.279128,502.676278,504.867169,387.260857,317.688693,298.786465,352.899264,432.595434,377.588784,329.991901,215.57766,145.867002,28.585969,6.243884,8.879414,3.238455,4.929386,10.306636,8.160894,0.124694,-12.419051,-42.163411,-43.53599,-5.205563,49.969897,39.246615,-122.412584,-216.431402,-215.240344,-116.763399,118.854958,282.797868,317.212911,216.945047,109.802394,20.135896,81.904201,234.279413,222.102564,81.983808,62.777942,60.912933,2.756942,-16.411986,-61.382055,-84.903467,-25.676711,100.636421,125.906669,81.685887,56.510827,48.671343,30.613677,-5.301732,10.354924,78.842404,170.908832,207.546197,211.890453,193.238166,173.317307,183.192811,181.121773,69.995575,20.725751,14.052374,18.223073,-49.970144,-105.619524,-149.382134,-120.999,-50.717437,-35.735383,-33.868586,-15.956131,-8.009102,-51.147365,-89.577756,-88.753751,20.934157,61.980658,16.847986,-43.734522,-138.103955,-179.066446,-253.4935,-261.511885,-181.87967,-10.957529,45.283764,24.947162,-15.070441,0.398086,64.389578,151.282429,160.940128,179.027257,195.531169,172.644575,63.602838,16.471239,92.083778,180.60487,245.681389,212.559095,207.817766,211.557875,211.804746,224.874696,243.282888,295.393237,322.649961,301.140814,189.714478,126.06886,4.270091,-47.905879,-37.086779,32.47159,138.859722,158.049392,183.637088,244.183024,239.948283,166.064193,141.249583,204.40655,368.899779,404.435958,313.244363,238.809417,144.966233,122.887533,143.670766,190.708173,191.259985,-9.532266,-90.024825,-104.752351,-89.381659,-116.267987,-116.579266,-41.71039,-25.894776,-48.967813,-135.220188,-210.702679,-383.716097,-432.415022,-398.98914,-356.747782,-321.118065,-319.184115,-329.446994,-367.012188,-380.341768,-405.727048,-417.436273,-377.665447,-271.033608,-233.411856,-210.227302,-205.432465,-156.093204,-103.284865,41.347076,92.140902,113.912768,169.078162,202.513376,212.998458,208.690113,235.990439,267.22566,305.936572,225.729133,164.544317,80.178395,46.970146,-67.366347,-140.870625,-187.286928,-147.406108,-80.57829,-114.4738,-146.2424,-132.182025,-81.402191,-54.27192,-89.404541,-115.457429,-54.14619,-18.611312,-13.082964,-42.943002,-41.044881,-5.053418,17.668149,10.145699,54.84298,118.720929,101.401392,-35.512481,-110.781955,-184.306132,-177.056325,-96.538374,10.73093,40.922388,19.688256,-8.270538,-13.104094,11.351534,67.226305,78.707248,44.529435,-5.942225,-15.510718,-18.502855,-20.838867,-48.481175,-66.11977,-93.088412,-97.448948,-58.3572,56.01767,66.66356,-51.962654,-107.456949,-43.818035,23.732098,69.064455,102.413527,134.647881,138.875817,101.289583,14.20048,-30.216447,-153.8315,-195.63224,-134.459581,16.08563,38.322558,9.22341,2.676983,-7.095898,-35.545561,-78.591646,10.20298,75.145763,116.023471,73.266315,-66.040847,-98.469391,-48.262647,-39.466274,-81.197682,-173.572873,-198.536653,-254.271758,-310.521405,-408.956053,-420.009843,-364.776857,-261.707119,-217.500559,-178.470338,-205.283177,-288.302799,-277.008871,-136.111536,-69.394071,-97.787673,-187.713393,-233.230456,-310.651737,-315.299634,-223.656658,-149.382365,-44.707441,-85.471089,-132.897824,-150.42005,-120.342028,-95.347086,-99.694619,-20.699387,139.405748,201.549506,250.894658,243.340479,187.056854,146.440606,114.167482,121.880784,137.004341,176.833691,193.685046,185.504822,160.672613,133.679989,141.144055,101.81077,13.646921,4.798652,38.992818,53.329157,19.220839,-16.466569,-31.067019,-10.835649,4.241251,-96.20274,-171.189085,-235.800436,-212.637144,-193.523787,-221.157196,-254.480463,-178.095761,-101.015328,52.825787,91.527931,90.900919,100.391764,212.005699,273.960797:-172.7016,-162.372117,-165.45424,-162.113526,-153.524416,-145.547184,-147.482402,-115.101422,37.241906,139.723042,229.575554,186.885585,21.518933,-47.930691,-52.476517,3.678684,86.249842,93.649324,80.239818,-26.295678,-104.043059,-157.005326,-91.715581,108.354261,216.107844,236.702371,210.867359,180.0165,136.793166,99.223593,-19.496196,-43.970333,3.42788,-37.563658,-97.296851,-150.992138,-146.770835,-179.827834,-211.70962,-182.524699,-37.148073,19.72854,38.391024,12.464371,-51.036036,-92.075641,-174.392846,-180.314966,-112.571804,-49.726805,-44.079653,-42.736702,-47.046123,-101.997562,-126.648535,-98.453351,-23.891255,10.09324,38.045796,24.757462,-38.224886,-74.102299,-99.447096,-78.489237,-9.3369,-7.388681,-48.170189,-110.042874,-95.635834,-12.15983,35.032915,173.129861,356.862015,393.735616,323.991978,285.791065,252.455808,212.498088,141.553674,177.552708,344.001183,399.628202,344.891214,177.063955,115.220695,22.951142,-6.871702,18.986556,75.955856,67.024895,-1.583741,-27.954887,-102.346797,-163.552233,-179.251396,-103.150962,50.72759,67.29494,16.89995,-185.456524,-279.57008,-283.840915,-189.568275,57.52866,241.74214,266.72382,137.723266,36.697616,-73.522982,-59.469173,53.423792,79.288588,7.886933,-61.64383,-87.923825,-130.378801,-132.742762,-116.141312,-93.478209,-22.074065,32.334791,52.088448,38.438503,-3.01905,-71.938211,-66.380627,6.969711,48.20874,133.609777,253.873259,273.296784,147.397578,48.388716,-37.606701,12.793063,175.60323,195.046374,158.290858,71.088474,22.86591,-62.847358,-75.118168,-35.771838,-19.948324,-49.576537,-61.311251,-49.353972,-70.069209,-95.413803,-110.111119,-100.515326,-53.03774,82.038999,152.105575,110.817643,19.099424,-113.849446,-143.816815,-116.292702,-40.083708,149.308669,183.815726,131.205618,25.275884,8.430831,-12.021054,-25.790588,29.135047,209.197927,287.056043,289.542554,213.795324,21.810918,-48.821651,-50.341873,19.245634,161.889774,191.949241,177.196359,163.228206,158.771744,106.570055,73.920686,59.165708,135.711247,166.648456,106.866611,37.952988,-73.268768,-89.250913,25.28534,132.126681,259.954063,264.815461,273.859084,287.203678,258.639335,182.030738,202.945852,405.952593,572.937101,577.80931,493.301406,440.311056,309.955333,235.946685,175.430828,198.332877,241.485272,138.039804,33.731384,-137.079482,-173.603878,-156.179102,-106.438539,-24.787524,-37.898008,-42.059607,-98.217814,-175.145476,-330.437768,-361.582049,-296.419406,-232.979373,-180.960367,-222.84506,-232.392082,-225.431042,-246.339896,-334.261728,-337.542108,-199.256247,-13.964457,36.818415,9.136165,-32.776327,-43.312064,-1.392039,134.714393,207.668095,299.1895,248.270814,182.248521,124.556102,158.232805,266.208882,313.761097,332.974826,218.376316,154.807177,88.507317,50.537019,-110.425513,-193.455181,-232.977803,-194.387278,-120.572753,-130.731574,-148.437353,-163.989822,-175.205832,-202.144915,-190.162329,-110.975838,-20.814417,18.116175,33.78725,8.273472,-16.224103,-1.943489,12.664205,8.454738,54.753566,138.375578,119.842089,-62.074724,-164.033375,-257.344778,-241.522815,-163.668431,-114.324554,-94.76395,-84.311383,-113.47092,-217.646168,-250.56056,-189.537774,-120.631095,-38.939225,-51.173426,-63.02215,-93.517795,-122.110294,-166.772175,-149.096339,-21.519266,93.148592,104.76734,61.446926,27.30881,-54.931434,-80.925017,7.32578,94.513619,178.035678,152.533193,127.756287,49.188584,-1.370578,-49.531837,-40.276017,-36.983064,13.974136,92.57459,170.851532,112.488637,-60.857447,-89.853675,-14.006045,35.431695,113.836006,185.580841,180.668946,82.022029,22.151622,-90.080828,-128.528306,-119.80545,-26.472443,10.427665,-44.35026,-124.170632,-276.288919,-328.847008,-350.014588,-301.450161,-152.976939,-68.272551,-57.385041,-88.029643,-115.551358,-147.116628,-146.779445,-121.94334,-62.552807,-30.368754,-51.583738,-121.737079,-275.616434,-302.56011,-237.990244,-163.084578,39.160639,130.845909,86.129599,-48.768784,-87.437485,-114.764318,-99.979682,25.148312,189.685515,251.304874,286.974888,238.19433,68.714443,22.357573,61.756701,93.377956,156.412398,250.870812,250.354015,133.983342,56.724229,-46.734486,-49.483507,34.175597,112.459641,113.119084,50.715717,-7.275604,-118.00964,-107.88929,65.439746,143.662435,128.514644,-14.818572,-70.577201,-128.55436,-157.002034,-212.756842,-204.929357,-98.486916,-3.257623,11.286805,22.097282,32.824541,49.454338,52.927234,118.603064,190.239298:-417.350634,-466.903207,-425.948573,-276.835862,-228.860632,-241.993891,-257.850902,-158.534876,43.634305,134.353044,255.173877,259.210995,158.395971,89.799425,12.398073,31.181772,119.359711,84.665756,55.602214,68.894133,69.348286,-2.409884,-42.520988,-29.678106,92.375144,179.794162,343.755725,368.154243,282.977979,209.443961,77.582192,24.39416,-53.54013,-52.492414,-48.295708,-73.426736,-72.136198,-34.826854,-30.860694,-20.763812,49.952243,102.607789,214.774205,234.833753,156.133488,96.363855,51.607951,64.577134,65.343949,54.999349,70.776403,70.661473,62.26064,108.674186,146.854188,164.658475,143.325326,171.960318,254.668252,262.562221,178.702039,100.437629,12.200884,25.02889,27.095852,-44.264965,-60.538697,-56.0875,-57.520087,-4.627061,88.96082,329.880433,428.354469,424.965204,432.234771,445.680674,391.200229,315.046383,214.071109,228.585942,277.663205,268.862103,258.214521,248.696126,246.830758,178.964845,122.961962,108.620667,176.372496,184.863942,175.530858,174.608901,130.642515,79.263123,-10.496419,-21.043486,44.341488,134.407859,131.597832,5.859872,-63.428886,-66.555307,14.12711,265.736163,422.652401,433.51152,377.945901,360.349208,414.572901,434.824836,383.254288,346.093999,285.065331,242.162541,238.161373,214.972637,169.893894,52.788185,38.236754,132.463247,228.785684,237.670792,166.71423,117.760637,82.097051,69.01467,8.510891,-0.963038,78.632128,228.934558,301.457341,393.032852,399.241966,313.982522,251.215829,183.513266,134.562823,119.99157,132.316871,108.875368,-9.430243,-38.64799,16.78295,59.233541,111.04695,169.650961,210.909297,276.809006,288.844374,304.19642,313.972305,296.448196,200.481545,160.56646,176.152235,190.512963,89.170669,-16.408299,-151.331665,-119.248831,61.851682,178.921791,192.223503,193.970679,219.025632,340.429031,398.400687,407.789067,395.835995,430.107371,439.318153,381.931825,281.901113,302.053129,446.88939,490.96449,442.489168,399.97987,409.783772,443.239169,452.712519,424.882989,404.939739,404.229603,380.983468,335.790263,184.523228,104.219754,40.238185,50.189832,91.36082,141.464364,254.646392,266.949557,261.562198,228.992733,185.023689,128.337043,140.430552,214.065149,317.733313,338.967363,269.308173,222.672398,196.031174,201.589293,265.105828,333.983308,415.953316,328.451999,268.348256,196.426906,178.864916,123.415228,91.60135,76.320277,67.518924,55.850227,6.766826,-57.608562,-215.666051,-251.466615,-189.647607,-141.036583,-113.253551,-152.751147,-192.692268,-248.936798,-254.196546,-298.033811,-333.522928,-318.054658,-182.524248,-124.956134,-105.032252,-110.84122,-47.363896,12.571518,134.692297,170.148627,156.688311,168.763543,209.74334,238.081511,204.451078,174.204291,215.722893,303.981159,277.936163,238.174344,116.927121,45.253019,-85.41951,-147.25899,-199.978556,-180.497287,-141.080838,-89.492018,-68.982626,-91.634637,-110.454635,-135.000736,-148.031758,-136.734449,-114.931385,-151.177227,-263.224979,-266.54903,-166.663649,-141.796141,-181.580165,-182.211091,-107.532324,-138.07167,-220.735597,-330.334721,-291.125872,-130.269746,-83.565217,-29.680775,76.544686,116.036779,72.268713,29.367912,67.593971,130.814049,181.155728,148.839268,66.614198,98.748539,123.011607,96.646713,51.890205,-71.49451,-127.009555,-209.482881,-258.750448,-243.41376,-156.017707,-133.734185,-194.012308,-238.506327,-195.015902,-107.372015,0.539302,-86.009674,-141.842641,-152.84489,-131.367917,-185.188204,-248.834258,-296.920138,-274.16824,-295.534785,-396.363822,-430.874274,-436.854753,-443.559369,-477.04685,-487.511163,-515.379626,-513.143926,-483.082133,-445.739041,-471.6754,-557.432243,-561.759248,-492.32997,-473.02929,-485.65463,-474.819236,-445.120018,-419.740064,-448.63193,-548.158939,-595.302664,-624.60564,-482.444761,-387.537744,-315.062319,-336.774315,-348.037804,-312.059462,-248.010246,-276.848655,-272.600619,-157.326113,-108.958539,-165.638102,-230.808988,-254.255179,-213.763939,-167.831847,-204.580769,-209.221605,-150.087784,-117.789722,-99.166754,-91.517228,-33.107585,66.751812,126.282914,232.224631,253.838494,212.392199,162.660275,97.687696,101.798293,132.212332,153.242239,159.583991,190.07743,221.853066,226.266711,174.279529,31.266862,-49.857723,-36.035839,36.582086,58.875363,65.882828,40.792899,-46.554729,-67.831312,-67.97574,-167.422168,-246.474866,-313.335741,-297.033563,-238.343982,-206.713057,-159.927965,-86.444523,-14.236449,118.859713,142.03813,165.570917,212.535993,339.593894,371.477677:-271.475901,-238.593255,-252.293107,-300.976822,-314.521698,-325.394809,-317.317438,-237.148558,-102.377874,-38.670856,32.8066,46.750117,33.823382,4.564692,16.899222,86.802295,233.119632,233.703924,186.796113,112.967855,106.57952,97.317855,97.252715,157.267856,246.553689,289.293647,365.54981,358.237444,216.679051,133.370183,73.089357,93.701164,106.44219,44.763995,16.015249,16.579662,49.533923,71.679651,48.973595,36.527718,37.192432,50.808376,200.620948,291.972213,285.789637,194.161827,72.355852,86.495839,113.944647,26.477217,-15.827645,-36.211295,-27.207956,-45.427773,-70.367197,-84.966952,-25.345163,26.9427,131.051228,158.965577,130.924886,92.906362,44.244074,32.468401,-19.552009,-62.687479,-54.290422,20.701993,86.614803,202.035728,212.214528,190.915915,290.547424,374.436934,487.043489,491.766223,433.097247,390.770693,307.227246,276.973221,251.016493,283.291395,284.244062,233.183309,209.250748,110.40829,47.281422,45.675683,82.95523,63.515452,46.585995,72.497523,109.658405,75.979916,-35.102351,-39.693986,65.337467,140.072421,119.350676,-31.331968,-101.497371,-85.006469,5.087647,251.47219,409.923207,422.894862,343.382803,293.138161,295.461291,331.568735,287.79431,197.899737,74.716541,134.053002,171.527681,160.639416,124.713683,63.334016,69.523597,149.921998,187.594962,188.92125,166.892081,128.30263,64.238533,88.293557,223.566473,260.685666,222.264708,239.275606,272.682266,309.436027,316.942032,289.420873,259.34933,223.498321,163.517348,116.536436,74.744631,86.783057,59.252441,12.705855,7.220928,54.18865,125.547606,157.048534,162.451907,172.291759,184.69333,154.459158,102.618045,15.072085,13.376417,25.815714,52.290577,62.660677,31.705994,-8.397281,-46.420192,-38.012813,-31.849294,-4.416811,40.287769,150.476035,192.139918,241.67231,255.840267,269.382101,281.106303,289.335981,277.268956,247.731863,163.676095,130.717812,148.461895,191.406059,238.257607,250.348648,276.925356,368.481587,405.278886,382.261467,337.026973,273.323753,276.056097,278.271822,208.457883,148.799932,63.37805,35.031019,-5.278268,10.332592,129.841653,217.046985,210.428714,165.758162,155.073656,127.735191,118.355395,149.708726,158.840669,149.13399,139.061379,136.303637,119.001917,112.411277,149.694697,190.860221,228.601446,147.474452,76.029569,-32.983656,-36.083544,-9.105597,-5.264908,3.459034,-59.256268,-105.910186,-181.480023,-231.505357,-334.978186,-337.157472,-216.709969,-169.542766,-200.867766,-207.58117,-192.337408,-227.518068,-264.860477,-315.910346,-333.100295,-328.110352,-213.334188,-152.486138,-132.137553,-162.487726,-194.331852,-162.637879,-32.962346,23.149904,70.100085,80.158332,82.427695,55.618899,28.707671,0.597935,23.783613,120.609297,130.157826,107.557108,67.352716,44.896782,-17.388369,-62.573236,-127.73861,-128.116446,-95.735278,-52.46781,-32.205069,42.247168,79.095141,26.742953,-43.174313,-127.439741,-131.747257,-124.13538,-120.408608,-112.734909,-72.69971,-70.176,-95.615699,-88.024473,-40.094085,11.425131,20.349701,-54.501586,-104.885363,-96.724594,-39.729437,65.670394,130.729831,154.922733,151.87851,133.791337,108.705308,97.745367,86.33626,96.783508,112.037237,90.864195,76.064285,59.710904,56.596036,10.615319,-33.140409,-95.602969,-95.58949,-57.816771,37.405869,40.23628,-75.181136,-143.482497,-117.815843,-32.438066,34.362442,-63.593025,-84.976508,-60.778281,-78.064947,-234.079818,-320.384946,-398.466667,-392.489358,-382.161688,-380.429025,-379.733682,-365.023188,-369.992471,-378.268074,-374.247457,-363.426952,-237.088547,-162.306597,-163.727155,-226.304313,-330.831502,-346.937422,-356.719513,-370.216067,-363.459021,-332.95296,-310.696926,-289.254819,-320.698963,-432.940746,-469.706686,-474.908247,-428.935236,-374.934503,-235.114751,-213.230631,-290.079363,-316.240263,-294.092683,-300.086207,-303.457189,-257.916186,-218.576528,-166.07899,-169.648194,-194.611162,-177.712166,-101.112506,-99.890515,-105.084968,-20.935488,24.763871,1.908945,-17.243696,66.825638,215.778634,266.895168,279.342212,260.207059,252.241477,247.287291,210.065609,193.585913,149.459169,154.645566,196.889252,288.283286,310.252129,276.423877,220.789675,86.816309,28.270084,38.081375,61.219178,48.490222,-14.720071,-48.690148,-83.631952,-77.087611,-49.362234,-102.255828,-160.996094,-217.11519,-199.887157,-168.08125,-160.707144,-99.832881,36.660081,127.710162,270.547341,278.972161,169.672621,107.992803,104.142984,149.847498:-262.147838,-346.048407,-326.332026,-172.331459,-116.595877,-168.200932,-215.808419,-170.394246,-37.011702,27.11467,144.20558,169.801661,137.719332,99.811266,40.386622,44.913312,104.70313,105.579838,60.174098,-54.43942,-72.932454,-23.168125,6.598921,55.151109,121.461006,154.523795,203.821045,205.41574,148.097259,104.751773,25.260441,-9.974378,-79.342702,-110.294983,-115.480096,-139.487438,-140.858567,-132.533087,-137.349458,-122.880194,-43.139185,6.458042,99.787392,132.102214,107.160995,58.922742,-1.370644,-2.896052,-22.23773,-56.322989,-45.761111,22.345333,58.191768,69.914305,67.184523,131.483095,156.416799,137.392663,136.90591,151.341169,133.58609,106.338752,83.172965,72.881291,11.14922,3.674802,14.863524,-14.113175,-45.976185,-59.924256,0.523125,250.137092,385.455922,368.378471,328.298984,329.644262,283.564107,226.049739,143.749465,144.024457,228.11225,331.450249,314.419543,183.535762,147.741472,135.244928,119.993957,85.605718,98.303565,127.585096,194.272156,213.25182,171.137314,99.878769,-37.719733,-54.044346,12.285207,87.355001,86.829459,6.039543,-36.208408,-7.573881,69.882758,263.152013,375.121681,373.115771,244.394603,172.045867,169.438817,188.235108,120.403072,71.539701,2.589497,-32.758803,-18.14329,5.809768,-34.001077,-137.936375,-117.641806,63.017166,167.015747,156.689828,105.370581,88.404491,16.401577,-52.019084,-114.443447,-67.595434,87.538258,192.077863,215.269698,216.485789,214.971316,197.914026,178.319428,195.585878,203.759729,169.486212,121.877166,107.196789,16.700574,-34.554197,-23.432649,16.699941,28.277662,30.529626,59.393226,103.253341,91.856627,15.18845,-14.41193,26.268779,150.289289,177.434342,79.968151,4.400377,-64.710143,-94.685721,-162.061122,-123.198185,77.36855,165.66246,126.2521,21.06827,32.154002,117.689297,142.726328,198.913729,236.49131,228.077095,162.173108,106.941799,37.565767,44.079229,122.262672,189.608266,311.429591,338.706577,335.388038,358.853074,362.776642,283.598557,235.811877,210.504752,242.346498,250.264371,160.972086,78.147767,-25.490776,-25.787428,86.21349,180.04,272.848667,193.361182,164.020279,176.420232,166.432834,99.549449,118.863045,291.783501,420.03917,431.364162,328.4966,249.170363,193.267174,221.326108,311.253052,349.614635,355.021846,249.766746,166.774304,9.177861,-39.519188,-66.430303,-37.164392,70.914403,89.213437,62.73734,-6.888001,-66.621924,-201.78113,-228.49392,-179.070631,-138.268259,-123.096842,-190.093724,-208.08586,-228.039057,-266.70892,-380.141139,-390.980767,-257.403091,-124.89946,-118.956755,-181.329085,-202.372904,-120.620398,-24.798259,157.469643,206.502742,236.958787,265.208886,278.586843,283.823857,299.380486,381.108581,425.872396,436.884966,314.826958,240.561923,118.328114,71.786271,-27.83392,-92.80188,-183.68996,-190.315485,-186.861621,-171.270495,-160.281394,-156.090497,-161.970273,-205.711104,-218.614515,-171.04678,-146.465157,-156.011565,-169.184144,-151.914792,-86.81019,-82.362749,-105.333201,-100.51124,-78.996767,-65.65565,-98.251427,-251.551305,-318.142352,-312.517323,-226.778436,-2.456848,91.743647,80.463602,6.538598,-35.274151,-91.209326,-114.560407,-150.271014,-139.570268,-72.961701,-6.555737,0.481641,-39.824966,-57.948307,-56.560664,-50.718349,-83.978555,-185.531588,-209.454071,-180.691887,-179.677812,-217.269472,-213.722641,-124.088483,-61.599002,21.433169,17.479839,-5.934769,-63.185678,-88.895781,-96.475748,-83.971668,-138.668197,-232.334356,-221.199314,-162.964415,-161.100116,-181.829274,-199.660302,-255.188977,-269.628355,-229.937715,-127.832226,-112.26905,-230.177723,-289.454524,-267.522231,-232.359136,-257.655083,-332.917378,-335.49509,-336.317196,-353.209861,-397.819463,-433.504263,-478.656043,-458.234023,-365.014624,-249.00245,-193.585435,-134.604641,-123.147996,-99.397175,-102.918042,-129.160228,-111.101246,-76.119068,-48.5058,-86.217,-213.060641,-265.653477,-259.836107,-206.725845,-113.888097,-139.219855,-172.961933,-137.926672,-90.19928,-62.863111,-55.795036,15.086919,132.587913,200.019777,249.794199,216.95838,156.619169,157.9933,159.730991,138.094522,89.918664,125.060666,165.749989,218.617347,207.841746,103.307751,46.004956,-4.369305,-25.859618,-35.597302,-12.623609,19.350671,30.117758,-2.184437,-24.583178,-9.031087,-52.608448,-156.190241,-186.602575,-216.423523,-213.666733,-154.162139,-121.70226,-104.657148,-45.367579,20.598368,88.60038,97.340999,151.104822,166.386704,166.556177,196.237312:backward
302.562686,373.473597,431.288305,498.852234,496.135686,449.187188,408.336164,287.680836,210.482701,210.459556,203.676236,186.310741,141.877623,100.569875,-27.18172,-88.597269,-107.657933,6.999035,64.920796,130.577414,117.915252,8.240331,-36.842881,-76.084251,-92.50672,-75.609652,-46.601809,-89.195649,-281.047716,-345.262593,-334.805724,-327.486112,-319.170891,-182.928867,-115.781057,-77.405352,-76.126585,-48.61837,-44.529428,-78.813525,5.148039,113.406887,272.508206,272.246077,164.308141,107.69037,29.934561,-25.676576,-135.388266,-64.344935,20.466205,182.381362,228.376208,182.614457,115.957658,31.855871,43.310407,63.61123,121.437188,160.113128,192.09258,156.792002,26.444536,-35.68741,-106.643645,-77.760914,-44.929527,-20.723996,-47.876974,-127.892862,-140.173014,-133.561617,-134.505111,-117.1913,-80.451956,-55.031853,41.389504,75.427454,101.856907,121.819268,153.313887,214.065405,270.03407,306.180097,237.774691,33.063571,-15.833742,-27.976668,-87.249425,-113.134286,-143.923696,-174.779415,-230.034573,-215.753202,-119.143715,-105.343281,-231.915492,-343.485085,-334.192258,-240.053178,-201.333468,-187.792951,-199.204941,-242.999611,-266.960911,-238.619265,-94.319567,-7.6779,97.138625,116.477405,132.711173,114.304568,11.061829,-56.283013,-39.122897,35.437371,39.78087,-38.220053,-74.342151,-74.612928,-21.058559,2.222342,-21.430856,-57.6076,-74.868236,-52.726968,-70.952386,-124.242404,-175.119905,-127.775727,-105.49588,-48.252288,-33.302183,-98.858903,-139.756099,-151.165061,-131.862331,-109.031881,-35.356544,-10.435255,-51.201995,-101.047464,-110.353989,-51.104767,47.346272,28.77444,32.89231,89.446488,95.333684,68.438407,68.847231,22.015285,-134.449188,-174.78636,-111.453176,-61.285832,-53.393125,-73.088385,-67.553382,-62.279185,-69.735232,-55.935887,-53.693129,-52.137855,-48.705944,-68.534477,-78.1093,-90.855318,-162.736224,-186.724323,-133.380199,-93.893129,-125.981723,-184.00861,-246.435799,-259.517224,-344.062131,-445.187289,-458.730648,-347.811447,-258.006654,-232.519643,-317.323339,-494.261202,-470.024435,-396.026434,-304.932733,-313.010827,-291.157496,-223.892219,-77.90145,-44.932941,-27.351514,-10.237593,8.89308,140.589095,223.790558,260.208814,204.730067,75.374431,56.566884,62.909083,40.390415,41.177116,91.884348,96.844158,38.25967,4.557301,-42.054706,-52.302321,-29.741853,95.121325,152.267763,90.855368,-9.691081,-165.447445,-173.12843,-145.504844,-58.190808,-6.197709,45.409892,32.25728,-3.582778,2.707648,57.3107,94.783902,86.529001,47.902987,44.29839,96.473593,119.34723,34.35806,-114.905461,-139.359521,-133.653013,-124.808627,-103.763229,-107.655257,-179.063567,-242.596548,-298.197979,-188.032976,-128.797343,-60.546939,-49.859146,-42.811663,-20.534172,21.709016,-57.432416,-126.50126,-148.549987,-70.301852,96.295929,124.483533,92.573677,39.920029,-89.525269,-72.929396,-15.907156,95.388934,144.411272,201.007446,196.832299,170.299969,174.549301,167.932457,121.10837,97.075687,31.114341,-2.657986,-31.570472,-48.884626,-70.490873,34.314395,114.6738,240.184349,255.110449,186.907765,139.553299,51.860505,-35.998977,-48.694048,13.571046,71.640641,136.226111,106.379801,-13.162161,-46.404527,-17.685352,20.560917,25.461547,67.590078,100.142015,130.400766,135.146371,152.419915,193.722132,214.53886,213.077899,205.523164,205.625102,198.58807,142.475119,88.786189,-69.505785,-200.849473,-208.144762,-82.620015,0.760335,39.291281,-2.089059,-55.80768,66.430322,165.14737,268.248013,257.606281,189.588724,170.277497,148.208909,98.6976,-67.116108,-111.975464,-59.610372,59.784521,66.898119,-29.014688,-109.24438,-269.093355,-283.203555,-241.481182,-167.439942,-115.942595,24.98767,51.039169,-23.510183,-81.753938,-122.093349,35.836816,150.199194,281.176093,259.881928,117.614735,66.697337,53.095412,85.671599,93.569096,77.241672,77.615772,94.876964,82.674245,43.231056,36.14572,44.301735,103.412323,151.543935,263.211015,302.842689,296.076269,269.894957,226.35694,176.349808,165.996318,253.099452,332.566183,400.065394,374.113005,278.554107,224.412658,143.668477,167.198124,208.583583,225.589517,170.878689,77.624752,109.703832,258.390271,371.280211,421.707737,522.987289,554.661691,532.025144,500.448475,477.784352,459.777738,348.633868,306.504571,341.097756,450.821412,486.38801,397.399185,292.896487,142.963369,150.951242,197.189415,325.147594,377.87233,389.316427,364.008939,296.049031,227.914012:186.593343,258.375874,258.551577,290.055227,297.271365,246.454652,235.726691,225.210967,152.470052,114.944782,63.25921,56.828903,38.231428,1.372468,-72.490336,-94.291929,-128.326232,-56.904865,27.278279,156.695597,173.871408,172.787999,154.870277,19.713066,-62.501025,4.573667,192.350847,185.795044,-50.449427,-155.827563,-208.666831,-228.058431,-294.080879,-175.132875,-63.302334,36.118278,23.768384,38.214445,61.587728,42.411684,31.171119,69.98921,179.411086,220.355013,175.503957,81.953761,-120.917758,-179.563446,-170.478953,-55.203037,5.097539,77.978456,81.610012,39.615019,8.653299,-39.94271,-35.923948,-3.07303,95.001228,136.452064,135.458713,85.217457,-58.652648,-113.921088,-119.602918,-67.465934,-57.194255,-51.351432,-73.686883,-185.378786,-223.129857,-206.283732,-183.816706,-175.675284,-83.211721,-4.144761,87.103418,83.189375,68.536296,72.359307,123.987276,253.234895,306.440523,337.048757,296.404516,111.764753,24.941404,-83.382187,-125.74494,-130.65296,-168.080608,-172.402435,-83.103652,-48.379945,-115.587806,-174.586572,-237.978928,-233.248878,-186.229961,-9.528686,46.87803,-2.202631,-58.280079,-118.330885,-98.251088,-94.018506,-106.267798,-85.829332,21.930643,77.175933,83.439466,23.559816,-74.129416,25.229766,87.156355,57.227435,-3.300827,-95.032124,-121.522176,-149.832209,-184.219414,-196.590865,-161.823523,-120.623728,-57.510304,-65.685772,-159.918069,-221.568786,-301.206588,-247.021177,-176.501415,-63.290761,-73.637115,-204.264575,-277.438869,-370.563745,-350.76925,-312.347931,-178.44059,-96.17908,-71.983606,-143.6794,-214.349266,-154.223589,6.184409,-11.972568,-64.449291,-75.880668,-19.92185,89.162863,95.595616,9.081794,-93.03562,-111.356545,-62.392543,-6.196161,90.975007,100.018504,10.36972,-60.032496,-158.851236,-183.789056,-153.746823,-41.761477,-13.615469,-46.112526,-71.452565,-128.741836,-183.48124,-173.458626,-143.893849,-159.377649,-213.320028,-227.479246,-253.241624,-283.233629,-376.46249,-456.786828,-449.047485,-305.502961,-238.874159,-250.629068,-294.100881,-370.285716,-408.071482,-395.12452,-308.8199,-248.857169,-107.312333,-49.822806,-48.001401,-82.287176,-91.191915,-14.173112,36.904734,142.266275,178.789453,202.221291,195.994037,151.956599,78.134991,32.858041,-4.923433,49.711546,213.401483,218.630693,73.623945,11.975221,10.571836,83.636535,126.13792,229.530851,248.547333,134.923339,46.31298,-46.765288,-47.8627,-35.602543,50.50202,111.439218,181.501041,182.292914,120.178641,62.335785,10.38206,140.91675,202.02767,174.150993,111.949925,46.605186,50.924149,19.388349,-87.346912,-113.920978,-26.796888,41.637521,52.864797,4.844195,-76.433332,-85.388781,-19.490666,0.148374,-54.348726,-139.410091,-120.491575,10.679178,72.748237,60.109371,-38.575677,-55.679173,2.891535,57.133494,91.620045,62.1381,12.831219,3.847613,-10.377772,21.465912,51.468785,114.909205,151.449135,206.676886,185.568757,64.976731,55.057659,99.813986,192.029693,212.01889,130.271733,61.845792,5.524213,13.273649,47.189313,105.240295,137.725716,153.454786,139.774422,143.096603,164.18936,180.432401,201.497198,230.762418,251.050361,240.492407,221.976507,200.715864,131.093147,103.140076,68.611043,89.293029,123.669653,197.285054,224.57581,266.672747,274.038096,225.513312,202.439995,234.38121,314.232674,339.652274,319.485224,261.682114,96.879798,17.97544,-93.92688,-205.87798,-248.799333,-180.886881,-102.415532,-2.211507,7.592896,-6.31276,96.744612,194.217712,337.048229,361.059078,330.219696,293.01704,177.65349,84.806439,-88.490586,-129.446336,-106.220437,-22.610874,-4.800384,-79.731118,-140.286845,-238.089155,-232.636404,-160.936298,39.867494,100.44771,69.894532,18.647319,-31.099061,-28.291198,-45.241735,-52.971609,-2.463179,159.868742,187.364963,63.557581,-12.865951,-59.404688,-28.184257,-2.408892,51.281247,63.698849,59.81467,61.958896,75.73998,80.024222,105.714077,165.947313,196.536746,198.417003,168.307226,139.570269,163.867437,213.304646,216.537107,236.618866,327.478928,362.360644,342.454683,316.995777,311.134254,311.472683,306.951238,313.865577,305.79939,293.995503,287.939995,262.88775,252.779358,275.242129,428.757973,505.71187,545.015258,524.808858,480.553363,477.366914,457.676263,396.361486,261.612406,331.746603,408.699811,438.625526,373.075041,220.055102,182.433102,185.199599,237.50686,253.498077,290.088535,325.92379,314.266916,248.013383,132.776493,111.065144:112.822164,214.519238,256.439813,308.848535,294.100078,179.663656,124.344037,86.121817,118.649786,118.098464,33.112474,-26.144977,-101.151164,-99.274894,-90.835779,-120.682203,-116.075899,41.021808,94.809237,109.857475,106.832202,145.432816,172.510483,146.143577,96.855394,139.694414,267.009747,253.982273,68.436538,-9.567413,-42.411153,-49.193035,-96.62871,-64.586494,-3.044134,93.237978,95.937946,48.023135,8.064723,-62.139033,-16.732105,42.818227,168.425398,209.516653,174.006816,103.354791,-42.210002,-88.098758,-89.020403,34.213516,93.156708,69.296838,-9.895867,-138.564786,-140.953946,-131.793227,-138.72735,-78.551883,93.833652,128.271924,34.98432,-55.828733,-199.361594,-229.579935,-219.981325,-157.744637,-108.800869,-55.78281,-93.6903,-219.538439,-245.299555,-205.156125,-119.042124,-89.710084,-71.377762,-35.992314,77.089868,92.234465,83.784539,122.53088,241.438228,277.388426,272.476346,235.78919,191.781808,120.962404,111.927374,72.134148,16.005187,-13.740288,-86.179142,-105.878362,-115.269727,-114.073351,-104.20205,-127.470606,-244.187922,-286.478923,-251.734314,-155.013973,-124.592794,-103.506893,-102.289265,-146.858931,-155.097495,-113.383192,-42.988042,-32.073882,-57.416732,-82.600117,-100.772744,-104.527922,-118.242955,-71.97119,-22.165094,58.064242,44.826217,-66.969481,-116.336812,-148.425693,-128.630121,-121.974757,-156.243052,-182.213272,-187.327729,-177.390286,-196.73424,-227.425095,-270.566865,-257.227328,-232.578853,-168.919055,-162.819248,-209.062832,-237.049689,-303.149343,-297.269991,-253.093983,-172.401882,-150.863341,-123.802316,-100.544984,-56.646434,-59.303949,-32.949824,64.703732,85.985368,45.792666,5.438276,-42.959991,-39.846976,-38.600516,-66.683374,-65.530859,-33.465359,-14.476281,10.791141,8.204398,-56.578731,-113.958081,-172.932724,-136.741459,-134.448829,-161.363448,-163.587309,-143.853503,-143.403442,-188.166978,-197.572375,-179.205845,-184.371794,-205.878948,-198.445998,-169.204405,-171.751595,-215.299352,-287.489157,-292.263357,-281.976386,-209.093629,-155.626931,-112.586826,-145.754183,-281.155736,-363.773597,-352.109968,-260.464884,-207.921212,-135.796862,-125.21671,-152.160466,-175.100713,-155.034567,-26.660591,38.537947,119.831863,142.863594,178.356976,172.165042,83.167567,48.531142,79.99145,141.247161,158.985665,177.925311,154.737901,27.495372,-35.51732,-51.307742,51.159157,106.569203,181.19779,184.89307,138.734844,99.796679,18.168844,22.777988,49.613008,120.411543,166.78283,219.91549,214.481358,166.980131,128.318908,87.286646,183.360144,248.818698,261.49939,193.560473,41.655665,-5.706292,-60.852981,-40.01747,-5.920985,69.125206,102.71452,105.987153,69.229302,-9.46509,-28.691338,-17.293912,35.60787,53.212777,38.789176,17.60961,15.045478,40.122568,60.023124,7.745675,-8.26074,35.568144,73.930474,83.455198,44.757385,-72.142304,-116.011235,-88.864696,48.785904,108.994762,157.971698,145.169694,85.11718,55.664675,35.736762,94.675492,127.169,155.889223,149.245048,63.053224,10.347643,-2.530359,41.71672,151.75004,164.89598,155.595192,152.256288,135.622345,80.591873,59.903545,71.126878,182.294778,239.3,257.827729,231.835097,202.449513,197.100377,125.521291,60.458619,-12.356569,52.010847,114.760231,191.759417,176.750091,178.069829,233.833951,319.255795,339.942178,360.020488,407.350308,421.289253,373.435532,314.674232,192.026081,126.798639,-4.899745,-68.449468,-64.963041,-23.360838,-6.077756,18.305646,20.129058,20.912823,137.564181,221.363656,337.93089,361.011449,330.158675,291.943029,199.478115,151.781418,76.47031,7.378799,-13.657298,17.111767,55.803756,91.11603,71.474545,7.024949,22.959436,59.361345,124.98638,146.437102,144.689889,117.198895,27.617761,-17.822583,-43.280015,13.462825,39.429977,85.68772,103.147093,46.910598,-15.01958,-80.328249,-44.301873,-18.757845,-0.887422,-2.688893,27.550654,42.68612,-15.548413,-62.175186,-56.767314,45.27963,88.253445,121.308102,106.94743,83.382114,101.071966,125.273953,85.820892,104.649178,314.094993,430.400284,428.356889,346.613463,294.462109,343.031866,439.857501,374.725919,311.332278,261.436451,280.210484,324.513743,305.87445,203.551665,300.455357,428.630624,548.052269,495.323695,316.623651,250.076084,220.947943,262.111476,365.837656,358.654087,330.903707,289.837299,259.907477,175.484497,136.078499,78.133703,113.106989,167.307493,255.65091,259.756822,208.28829,190.705119,185.077666,170.541143:239.526439,341.701788,372.187125,373.919571,338.695553,258.829915,251.251425,255.037272,202.375456,160.369153,78.123002,57.037381,50.481793,45.401467,6.192119,-34.974075,-125.204313,-104.966249,-51.800187,74.943982,126.761605,160.259999,129.715268,4.061645,-46.992989,-22.137144,20.37105,2.096532,-102.079759,-149.4667,-162.116728,-148.193009,-160.638306,-163.309958,-127.926891,15.01874,88.515895,132.229423,96.5971,-5.123249,26.536941,104.750939,244.750802,264.500859,212.239777,172.040591,98.813549,54.552103,-7.337653,37.226921,70.478288,109.57571,108.327661,47.571268,2.939718,-74.127259,-83.497254,-36.742694,104.800406,141.84096,83.026689,26.972292,-26.748219,-43.265292,-105.492119,-105.34718,-58.963866,45.311633,57.753254,9.041048,-20.746952,-74.959381,-100.682865,-87.582397,12.133771,96.89751,200.614443,183.116723,128.383437,135.229312,182.155266,249.518576,294.597962,349.351345,329.020834,222.228525,180.264889,111.848159,19.807342,-12.205128,-23.971419,-1.53651,64.268635,68.535856,-0.088149,-54.559846,-179.89308,-252.627273,-246.092326,-176.744091,-152.562827,-179.43834,-213.49345,-259.770017,-219.547939,-179.171523,-111.672959,-95.906576,-111.458526,-115.605094,-96.922424,-116.508441,-194.34197,-136.04078,-68.49814,-20.0305,-51.798873,-153.635323,-196.146839,-238.644302,-209.837979,-174.649926,-141.137422,-136.14489,-100.673051,-115.207875,-264.384681,-331.751845,-361.74215,-368.379801,-350.348585,-187.903618,-95.749562,-53.349636,-104.855972,-224.951719,-215.132148,-182.209039,-149.59325,-137.829764,-81.998338,-44.381007,22.646152,39.334619,47.759827,113.781743,154.027189,145.394937,124.786931,161.252472,178.914447,66.997485,-102.600819,-133.325654,-78.646806,-9.429309,75.682236,44.571859,-77.176836,-115.809713,-140.467369,-164.939002,-181.275607,-167.941562,-147.992524,-151.802512,-174.125021,-230.309431,-244.107404,-230.056202,-215.440519,-215.961451,-209.224412,-198.094182,-150.393296,-136.832529,-187.906999,-266.632124,-279.051885,-212.660074,-159.317213,-146.344651,-202.865615,-356.353496,-393.529399,-341.953311,-231.510647,-215.401405,-191.463705,-149.133062,-48.591384,-17.447951,41.438329,93.705156,101.278472,155.999723,217.230958,273.624569,224.770389,63.393168,21.918933,35.564296,55.436497,86.749715,181.629992,188.071809,92.964885,40.418566,18.465059,14.375273,-4.400906,65.945067,148.237583,151.667882,44.736176,-152.575921,-127.236333,-70.098785,38.924573,83.125018,147.452892,184.938564,253.605559,241.059943,164.548404,161.442112,168.967687,149.403032,119.294434,66.431273,48.505393,-26.812678,-85.543666,-76.901806,-21.899946,5.294675,-21.373721,-82.204004,-176.827238,-179.582617,-132.49002,-59.623909,-39.259729,-18.702301,14.364718,83.445674,82.398221,20.667413,-51.753617,-83.371961,-76.934142,-22.866133,63.706105,43.447223,-87.982643,-147.851794,-168.656756,-61.058988,12.839455,133.134122,159.202783,140.822815,116.32226,97.67814,115.8625,130.746747,181.446229,194.263182,133.555617,88.878049,33.811384,-2.516612,-39.91049,91.437828,165.937757,221.058841,201.027987,127.911504,109.518008,98.2488,84.682612,101.103863,164.015702,183.572393,180.055721,158.661077,88.61618,48.041344,3.971409,41.86384,76.473379,129.695226,135.027273,133.474459,140.384858,183.173534,268.474892,296.034286,313.610568,336.265575,364.02389,337.871682,248.603417,181.405871,-26.457744,-156.897014,-150.993185,-56.475604,-7.003833,45.743697,53.431688,43.397919,71.880362,128.025021,285.779564,345.958764,341.682519,292.910587,208.753141,181.682333,146.050346,113.47846,92.565927,95.294711,112.75937,94.161291,49.825571,-63.670788,-118.676588,-91.590035,31.786627,83.069959,60.082138,-9.520633,-129.21571,-152.814106,-144.965883,-56.155708,5.769275,112.234811,137.111018,102.953071,42.642748,-77.814001,-51.473405,-11.518654,12.45933,-0.485058,-51.168451,-91.72233,-115.056315,-77.270104,-9.487583,41.194531,97.012099,218.050324,228.019648,123.310761,62.43967,29.398618,61.461084,88.739411,230.087906,327.822077,421.337024,401.850539,304.324981,244.772852,155.115765,133.979548,125.037503,89.311807,76.999242,79.58324,86.311502,122.687291,260.589628,344.824377,435.811879,446.877169,441.911863,432.966148,430.41089,426.567025,386.333422,364.334885,366.242492,358.413259,324.579735,189.627014,121.603552,43.516664,55.137871,91.617792,223.527031,299.838229,370.390305,356.655257,290.993896,251.010064:48.603041,240.425527,275.667248,280.493564,256.323178,191.903896,179.874738,153.391078,103.30082,84.888406,51.576088,25.563905,-42.103602,-59.353372,-61.879645,-68.943994,-67.676315,-5.352026,42.505265,124.765707,139.702765,148.833136,141.183868,60.856248,40.845317,81.098985,123.869726,81.991452,-64.537079,-103.427748,-123.383803,-156.958794,-191.379376,-61.121168,10.013148,102.081143,140.926094,178.14075,126.725783,-77.255374,-29.557655,100.821683,277.415591,271.236973,158.935445,119.672855,104.132955,93.170422,60.166051,81.282941,118.188749,127.785262,54.129426,-97.817436,-110.835395,-128.24686,-123.721365,-48.474944,94.7,95.655051,6.353538,-32.034857,-67.188997,-104.912097,-183.956796,-88.410212,-1.905946,102.577001,96.571105,23.178267,-15.623191,-85.076658,-51.779183,10.468801,114.783904,144.318488,134.673318,89.804262,0.328869,3.644729,151.670663,307.286251,327.168071,276.062653,222.196282,98.79016,41.076928,-57.491468,-79.023184,-38.64648,91.7593,118.57322,50.367505,22.572731,19.036263,-14.236623,-137.569442,-154.994989,-110.592326,-8.112082,5.81383,-88.334324,-162.135591,-236.245432,-182.329281,-147.876306,-113.844925,-95.474836,-59.407404,-60.582202,-111.230645,-156.101488,-202.478248,-112.193268,-50.671371,6.792324,1.72054,-53.909474,-119.014311,-257.297499,-209.911689,-132.807069,-38.943386,-42.196048,-114.855652,-180.360464,-335.043553,-366.705309,-314.68458,-323.074919,-327.038551,-187.019024,-103.620115,-87.328818,-132.601159,-208.624157,-176.030373,-135.668642,-78.240107,-59.511328,-48.400118,-54.84451,-84.241244,-107.476906,-61.284048,121.945069,194.644517,219.0759,175.991345,81.198516,58.726075,14.737197,-53.000924,-70.432468,-24.663799,27.319805,57.890039,11.091638,-107.557405,-143.739845,-169.93219,-153.099513,-128.336101,-88.236047,-98.971988,-159.714865,-189.322882,-275.649177,-323.719845,-300.36139,-235.803648,-204.420594,-161.190848,-171.648515,-216.985555,-225.657092,-232.365241,-190.803064,-146.234863,-94.181605,-104.143079,-179.841613,-240.378944,-365.278478,-319.865789,-239.008997,-138.767648,-127.328497,-119.46378,-116.175423,-108.956758,-85.933464,34.67208,130.387254,156.170566,238.35241,289.830468,290.574398,213.201267,48.37832,54.323441,93.900076,197.499815,257.376945,266.017722,201.525528,71.141589,32.627624,16.487729,77.562513,117.545104,203.519914,216.849501,118.302397,40.687329,-51.28872,-1.612709,27.597405,96.623826,176.703158,292.434463,271.567077,150.412179,107.696016,132.041105,191.954484,198.16828,201.088298,192.540774,122.73168,63.159067,-64.957048,-44.46198,17.036974,97.587588,113.777105,109.357804,82.373653,11.115938,-19.826169,-43.267161,-10.420632,20.161703,117.023392,163.051703,182.535481,147.912824,29.297607,-35.929235,-26.908621,69.965719,130.426065,133.765029,66.532792,-112.224661,-176.852914,-156.440122,-17.468913,42.82347,112.357593,103.663069,27.680122,-3.602328,13.128692,99.398659,150.353916,284.710357,316.893186,193.941837,96.537372,17.338175,36.235197,111.603344,178.634531,197.169204,170.502007,124.375828,40.182411,16.926066,-27.361801,-30.273994,7.081149,120.162388,146.59373,99.220884,80.69766,117.301334,124.542306,61.002812,26.211441,58.977096,126.066614,102.520813,7.543217,-14.544208,5.22137,106.270799,168.584094,261.50865,279.765989,219.886957,152.59652,15.403672,-39.699526,-96.374961,-109.867535,-115.778238,-70.841732,-22.024699,27.363266,2.474375,-89.110356,-75.748918,-4.841507,196.492525,265.543397,257.622053,204.624179,70.771904,12.647498,-22.34633,6.019025,21.796535,92.551571,126.788911,96.644475,40.527187,-54.45627,-37.007684,8.872197,80.179267,75.152607,-34.035692,-101.734699,-170.580691,-182.743185,-192.51722,-115.169638,-38.411105,80.098221,71.184353,-42.824656,-90.5798,-118.057901,-77.217118,-52.650352,-48.979942,-71.644993,-122.71277,-146.485344,-210.503065,-236.60761,-195.437979,-20.396546,89.187383,230.386882,208.864736,48.861944,-14.389217,-58.378701,-25.829486,32.101123,224.457717,301.815367,277.84325,201.097577,87.117973,85.095785,137.664678,138.222437,133.538296,148.351175,142.981923,83.095467,59.641209,108.888589,258.328408,314.85993,354.342259,370.513093,398.025803,391.02955,358.19026,352.353418,371.047703,399.35037,413.419284,397.071537,350.335876,235.834856,163.308657,-49.851168,-84.703926,15.829655,261.921922,338.576875,353.144203,310.714452,166.73694,96.485318:190.266644,427.385344,519.786745,490.179814,412.294847,322.377307,335.307991,364.032223,322.883707,313.424198,280.368919,234.221848,157.2361,145.744959,100.35217,30.237609,-134.526852,-102.316586,-17.686542,94.872746,88.136555,24.394164,8.002762,-27.985087,-106.98538,-118.574614,-113.574969,-148.925765,-323.487686,-393.968313,-355.227735,-288.035351,-193.470697,-126.322599,-88.588241,5.431204,45.825981,44.049685,0.394956,-114.708757,-54.160279,74.398122,315.390276,350.749058,275.674207,225.397547,154.046208,102.527545,-4.861473,36.930111,101.298679,162.936903,147.183106,131.552892,143.218815,95.345,-23.3841,-52.470451,-36.003095,-3.632848,28.562261,7.130255,-65.79986,-97.894685,-123.226162,-53.394416,8.092839,96.57988,94.766652,25.356978,-10.229609,-85.203249,-142.556986,-124.557682,-32.407781,8.086304,25.249179,-1.580624,-46.138232,-37.82787,62.828005,226.979357,277.592806,273.459292,242.55719,129.177074,45.873825,-70.904247,-53.898329,-45.640413,-97.62492,-114.948128,-58.341005,-23.060346,-20.619654,-61.396435,-173.042942,-174.026452,-141.711053,-94.645602,-104.131837,-198.900492,-229.847665,-206.283725,-203.702083,-200.175612,-99.028039,-13.139234,97.174035,102.048105,71.043822,40.348777,-42.86783,-99.027084,-115.023496,-119.484716,-111.116414,-113.201522,-128.118873,-177.785921,-217.10442,-209.502703,-144.366251,-102.564312,-59.75876,-69.024226,-152.362373,-207.181958,-253.947471,-273.635081,-280.608274,-162.08678,-58.963644,34.266321,29.718673,56.103715,102.700508,104.961449,96.802425,93.467019,62.097665,46.291642,51.405965,48.441206,27.584666,120.467085,209.281736,307.466035,275.59033,144.774425,87.249839,-35.41918,-135.982428,-158.714972,-170.171538,-159.451692,-130.773572,-121.317212,-89.32921,-76.99051,-88.558795,-97.892282,-81.297192,-24.347906,-2.694454,6.519188,-20.300271,-149.659186,-241.96803,-229.209998,-80.022231,30.07437,137.33357,88.024991,-91.338437,-149.740388,-185.049228,-207.256876,-218.236197,-210.331831,-199.518339,-207.581894,-233.380983,-342.38182,-370.539207,-301.716807,-167.274834,-144.342719,-134.221472,-137.010797,-115.875369,-66.346551,86.812117,168.759938,149.181942,106.537055,133.123516,247.058987,282.96917,193.133842,15.550376,-13.467823,26.075094,33.361246,-34.973616,-66.735178,-25.349852,1.532436,-70.470985,-115.785442,-62.292841,66.089968,87.642467,7.445479,-68.707159,-154.485017,-106.437032,-64.24134,30.274319,82.265278,133.859774,122.676992,92.163889,85.170862,76.809697,74.446428,63.634899,23.431526,11.32182,58.885063,100.417396,61.741288,-80.611586,-102.836084,-64.72452,-51.455383,-94.495327,-124.929294,-115.435664,-83.046638,-23.353713,-14.220029,-4.037186,105.616351,156.594433,112.120271,57.874996,17.239486,-18.431054,-67.527553,-118.548372,-69.866151,123.57893,192.047018,150.595632,65.243324,-56.796568,5.106082,76.171453,232.305109,290.115627,313.53421,312.21566,374.58163,370.266202,305.736957,199.982496,187.336068,157.76374,103.989961,-45.43261,-73.655588,29.707346,155.034486,186.188385,236.784316,248.710007,214.008594,178.123312,91.085994,44.801627,63.793941,158.091143,205.341761,202.852593,134.326991,-29.179933,-79.989386,-107.094655,-52.554122,-22.365521,9.19866,24.025162,51.567731,45.684686,16.293188,102.382217,173.078361,197.281601,156.81937,120.525684,135.213879,156.13217,123.568229,-39.064498,-106.749904,-68.380885,-7.093109,-40.093685,-156.104171,-174.486109,-138.634401,-66.158143,-10.434092,80.049519,98.470189,106.603281,95.837189,11.419326,-63.18732,-174.062806,-109.592038,-65.332081,-83.266301,-117.98496,-124.602931,-115.346363,-168.822658,-230.958403,-226.328501,-175.530257,-129.61754,-44.584782,-46.949703,-123.603454,-174.910473,-249.742735,-182.332582,-75.470971,143.674513,147.510065,-45.539426,-122.528639,-99.253977,28.889454,72.484439,70.379755,53.957173,14.210903,-27.829819,-91.559395,-83.159934,4.403442,139.716293,190.560915,228.416863,211.779608,107.381618,54.020443,24.957826,73.55373,112.749829,245.567384,336.106648,410.611467,339.356665,86.164028,-3.614822,-21.775764,32.29926,28.787031,-38.046321,-60.771687,-44.107743,-40.375128,-32.627988,107.690534,206.864523,362.289401,404.205927,381.011849,335.281336,279.393635,269.577765,253.540571,226.349365,210.951102,230.017895,247.708252,210.973606,163.110816,52.832472,-23.700539,-27.316545,59.957226,137.732763,218.943128,194.670102,112.966281,69.339342:150.021542,292.163112,330.963927,361.67011,342.460776,271.107582,246.513239,177.74923,121.936511,141.514484,211.518953,216.999697,132.111617,72.770988,-18.279309,-71.346665,-177.093877,-140.181235,-58.989347,123.508263,158.538095,59.700804,-31.757288,-171.505975,-151.313129,-94.964158,-8.197805,-13.293172,-164.574346,-272.541052,-380.483066,-365.466701,-251.196764,-96.121412,-28.445918,107.476552,177.549127,225.967036,169.175487,-32.294385,-52.456928,42.077337,255.721084,311.170416,290.447897,246.559044,161.898337,108.699535,1.127421,62.145396,156.026985,266.646505,221.786594,33.797761,-29.782395,-67.603034,-34.405644,4.936392,74.713616,87.412575,86.714984,75.739703,-12.631815,-75.606806,-86.11215,67.245436,137.255466,207.349326,201.087984,110.423557,48.424119,-81.247954,-119.556279,-61.449395,112.722875,165.808199,119.524787,40.584083,-61.045263,-46.226908,54.98302,233.663012,333.559139,403.924946,355.791368,145.903635,27.694384,-87.883736,2.990068,57.202157,118.244924,143.374704,153.94071,132.062117,49.871817,-18.572634,-148.061111,-92.654578,-8.470415,89.644044,51.133858,-131.083613,-194.477305,-184.492424,-120.47387,-114.237752,-78.31295,-27.164437,28.88051,1.274278,-94.631531,-137.779491,-192.48725,-110.735274,-31.996593,58.07704,38.822742,-79.231729,-146.60808,-278.746365,-308.67864,-232.357956,-6.885912,42.341214,-56.518088,-136.955914,-241.313427,-280.777416,-335.092547,-306.46,-258.77972,-115.971708,-63.669855,-67.040815,-103.724142,-190.670776,-184.50874,-124.97645,12.51093,38.380523,-18.724173,-41.863363,-32.61231,-32.822655,33.553363,220.727661,298.892927,359.197901,332.553255,203.059532,138.147695,36.958272,-43.220293,-54.262025,11.257492,56.958369,47.865675,-13.21224,-114.032757,-125.339782,-111.87564,-91.27316,-73.710579,-33.340698,-40.317527,-85.541266,-105.635662,-210.2944,-305.716118,-281.065066,-120.991655,-43.170051,-57.671206,-132.613637,-220.791364,-228.043735,-229.666576,-202.902292,-194.941159,-157.804298,-124.025802,-140.087628,-214.927799,-392.054377,-371.4221,-279.428454,-130.560756,-110.202667,-128.981723,-142.0206,-131.947398,-107.16961,-20.273968,66.363045,90.8808,159.95633,206.36041,227.064538,174.561987,12.148733,-51.380089,-30.907109,59.047903,100.136778,87.41946,30.366375,-61.860225,-54.007478,39.17344,70.853876,61.938408,117.034316,154.821651,101.621033,17.903928,-131.05694,-111.225224,-41.944593,113.741783,179.044408,251.34888,245.066361,150.963637,103.90207,123.873789,180.524901,185.246691,205.767295,209.614665,150.79484,97.635097,-36.784528,-78.835701,-29.252478,89.747745,116.760751,65.102284,1.897675,-104.24269,-130.451606,-78.904676,114.639155,192.044806,214.755152,188.790575,144.538594,120.846616,64.942923,48.139734,42.352524,45.593055,71.89673,149.347876,166.271017,64.859091,-39.283929,-148.340711,9.379533,124.414721,251.456776,234.358456,103.059137,58.11917,92.023426,195.653865,246.599756,344.788025,370.482953,287.727712,185.192936,-10.719821,-52.01077,2.040615,114.230003,164.505112,227.906957,198.149365,23.406591,-67.721221,-145.271968,-41.752138,34.125312,149.768446,178.317298,163.794085,121.650778,-53.149777,-158.758827,-215.35261,-39.458991,37.214961,40.464129,4.399593,-24.06833,-33.574153,-90.023505,-29.409251,57.787304,195.479806,204.998013,124.805682,85.057981,24.150392,-30.526596,-127.797257,-141.65367,-134.544923,-60.472325,-7.574549,-12.208334,-90.260729,-251.126101,-191.294481,-93.456052,60.835833,92.881117,88.206138,48.486275,-66.317355,-102.670617,-99.313996,-70.338272,-55.016106,-7.167054,-6.263902,-86.524299,-133.877992,-183.485653,-164.717505,-128.428775,14.059923,101.166666,109.123759,-12.685347,-308.094452,-385.193,-363.03313,-178.71323,-56.793709,94.605978,67.646974,-97.039521,-152.168586,-161.346662,-123.585762,-93.157688,7.763279,48.221294,-3.844286,-88.000986,-241.066702,-278.879339,-227.059004,-40.226883,45.040973,138.836338,134.821569,20.161922,-65.952502,-191.749878,-130.567909,-41.238004,147.378174,208.631138,197.381927,140.330988,6.395418,-43.911814,-36.464816,64.788817,92.903985,51.759461,0.041059,-59.467329,-48.76588,6.601015,128.141134,221.815394,383.843542,424.949387,427.437812,405.172071,321.066168,262.448719,207.734872,271.443336,313.683719,340.160034,297.043483,147.981546,81.351595,-14.395316,-35.577764,-15.276662,117.169577,228.919533,368.298773,334.217469,166.740036,107.641483:-14.697762,180.68728,301.899889,380.275068,316.915393,181.638986,188.052556,256.959329,193.137344,137.208736,68.679547,67.312755,116.756502,140.577848,143.032673,114.916657,42.35447,65.1773,94.840397,120.168074,109.899788,50.288028,23.155319,-18.045682,-48.627565,-61.278162,-156.228679,-229.606021,-362.052989,-398.96602,-353.503159,-288.895345,-146.376868,-21.7547,7.628252,21.096134,30.565107,19.741111,-11.384148,-36.00974,83.120882,175.517102,290.388926,285.415744,213.604462,184.231371,147.650043,123.247087,63.323852,63.609749,89.598081,142.195513,164.884433,185.155248,152.663144,-1.933911,-101.261538,-111.918203,-154.711656,-187.077316,-212.454833,-197.774994,-177.50543,-209.084619,-286.597093,-166.43031,-38.99653,141.192666,147.271103,78.421327,48.629629,-9.193588,-80.594812,-100.677962,-65.950968,-21.304407,8.666459,-17.346596,-53.358566,-43.38051,31.436883,156.869339,207.514168,247.393767,231.135611,151.526952,121.923829,75.171764,-31.808668,-80.421865,-110.620786,-100.713731,-119.744171,-162.218195,-172.050602,-123.634706,-75.836815,-95.802357,-92.791854,-61.218355,-35.577646,2.273526,7.08683,-3.38672,34.242456,98.822095,245.148163,292.42329,333.77791,341.499651,368.354417,370.370335,268.574043,132.563672,104.48326,83.502822,59.282502,-26.059072,-66.172617,-137.3818,-199.185138,-191.802993,-95.804286,-41.055233,29.940603,53.916922,90.302355,89.318506,38.173562,-40.292023,-71.292512,-40.218176,17.954824,79.313865,79.491578,108.602141,170.339945,200.821274,219.696429,204.460087,148.921866,125.370383,117.163772,136.106752,240.688027,346.648014,366.202829,365.956001,351.120926,284.357157,229.292775,76.361391,-39.328593,-61.327444,-72.957011,-66.906888,-50.67044,-43.531762,9.345576,52.529729,106.012355,87.310477,94.704178,178.20376,204.460671,163.674694,132.620543,65.574908,-70.481929,-96.464839,52.567382,166.592099,267.056384,249.466636,202.276037,180.493125,118.26762,56.862214,4.767317,-97.933365,-117.44584,-169.925903,-223.800053,-294.472761,-270.470531,-266.979574,-301.500697,-291.674794,-175.295638,-119.564658,-79.761449,-61.096133,36.470581,88.244862,72.114821,74.938236,119.215027,192.92309,176.464029,37.08412,-91.46537,-95.818473,-62.454961,-80.407925,-145.160969,-145.439032,-97.343936,-87.62546,-111.856657,-132.741895,-133.939349,-120.551456,-117.587748,-136.474729,-149.810097,-201.604889,-273.330258,-277.033825,-186.957613,-123.270681,-60.269824,-74.660421,-114.520129,-95.494068,2.513923,2.056281,-56.801558,-124.725749,-93.281392,-15.005259,-11.650398,-68.037845,-124.366992,-119.324349,-49.509419,-14.864314,-15.76798,-45.696741,-90.328414,-86.65794,-37.053931,47.23846,87.656287,113.821901,94.87404,29.901313,10.742221,1.674347,-43.048456,-58.795195,3.81793,59.706791,116.2652,120.017432,111.402324,78.367917,-31.975129,-51.367879,-12.830484,99.708707,137.419969,162.742287,183.100181,231.581928,226.563005,238.349346,317.43269,319.177939,124.0025,-8.184245,-113.132145,-97.471416,-52.955696,21.923126,56.34825,56.157898,33.582081,-16.122742,-60.174707,-219.530552,-305.234512,-264.159871,-106.887542,-47.946851,-39.835895,-82.135255,-149.317317,-146.439719,-108.866974,-104.74441,-107.508584,-101.291593,-110.809852,-146.629145,-150.793894,-123.30594,-32.735779,14.148777,14.10543,-11.97442,-3.132488,25.427938,35.416759,4.614278,-68.058845,-122.767626,-149.227069,-126.083417,-78.229469,-64.016393,-111.376997,-183.519839,-131.594676,-69.038983,49.816558,84.988793,107.214381,88.478595,-21.799537,-101.149575,-202.833586,-160.44491,-140.002196,-129.89246,-105.194626,-59.971826,-79.752693,-205.168162,-301.518298,-299.640184,-247.8586,-227.658143,-250.007601,-280.229773,-315.777949,-330.770639,-335.117556,-228.49405,-182.315786,-160.801923,-163.996801,-165.896635,-148.41416,-55.433064,66.262683,78.373187,-39.983028,-104.813964,-138.898594,-134.91808,-159.588307,-192.473817,-252.101225,-161.506404,-72.070387,23.162146,16.474043,-37.452214,-70.773835,-151.774013,-169.769187,-122.921136,34.534771,122.581241,218.473584,177.410673,-7.233766,-71.896485,-113.178504,-128.355133,-126.068304,-124.083216,-151.838269,-217.1986,-209.632097,-110.707601,19.260918,57.075415,24.112872,-9.387978,30.741375,83.90747,80.252315,12.730592,-93.999342,-40.825239,13.339757,97.996823,93.707812,-17.756083,-75.627873,-159.940229,-179.633946,-146.168236,-49.398449,-16.072392,-26.487627,-43.631719,-29.532215,-28.209051:112.122987,221.821988,304.487899,379.925885,342.866209,249.214098,235.298018,236.062432,232.667506,231.377077,208.939624,180.086645,140.912557,137.676873,84.836167,25.187654,-49.781452,40.231377,100.535032,107.511495,40.834243,-106.019663,-129.068702,-123.662662,-163.944153,-209.202252,-331.268422,-377.382834,-417.362352,-426.755726,-410.081848,-363.985893,-192.997383,-29.912644,-3.822499,-84.2814,-138.712532,-165.661671,-156.524002,-151.480362,-30.218434,92.406611,272.448581,283.929205,234.652943,213.548387,154.733912,92.397922,-34.217194,-35.461615,-5.198064,65.691339,99.170479,121.034161,102.41516,48.017849,35.862305,45.791489,61.560746,62.683527,42.608506,14.902061,-68.823597,-112.63464,-132.521264,-39.732854,3.934541,7.934453,-22.090649,-33.419303,-1.602238,5.32818,-73.571278,-89.137315,-70.603917,-36.498605,63.168558,86.123236,96.213021,105.381865,99.485425,128.593093,174.642124,222.889301,184.167878,42.860072,-1.015366,-42.67405,-137.072262,-179.834724,-213.311948,-219.432433,-196.441154,-157.827339,-93.278969,-103.979873,-182.256904,-235.855905,-241.400672,-167.776619,-106.53368,-86.86412,-122.500904,-148.78816,-119.190777,-94.608668,11.851793,95.650878,238.137764,270.210393,293.397177,281.274635,175.554694,96.981122,90.857071,71.828032,57.776039,56.255585,54.225341,11.208797,-55.575781,-79.977906,-86.123994,-69.475709,28.584751,111.37974,215.363902,187.191219,32.055875,-90.293959,-103.555671,11.486805,97.695967,148.988662,134.248464,138.569023,151.173641,146.658282,106.078996,84.68115,79.425989,88.264659,63.894549,29.280868,51.365575,207.021166,250.093059,195.608045,145.915254,128.324648,139.615329,49.883824,-120.335069,-157.921961,-126.459942,-101.299617,-101.950937,-97.359743,-4.90678,55.600533,88.724527,15.407125,-1.515062,15.605512,12.725835,21.125982,61.288498,55.975295,-142.072934,-204.398191,-143.783055,-69.092842,-6.709217,-22.912517,-45.133299,-60.390155,-159.008853,-237.15696,-234.921182,-195.005145,-194.612288,-290.80223,-360.877774,-455.909692,-481.333914,-478.226569,-466.708955,-431.012455,-291.30847,-246.271508,-227.040132,-196.014598,-49.975384,64.623761,74.836303,74.079564,100.272105,152.375086,146.109306,71.979816,-49.712056,-88.412974,-95.58844,-107.719409,-186.220808,-206.514922,-161.743819,-141.424971,-170.611116,-179.806337,-138.539789,25.227987,90.405879,3.074696,-120.44218,-277.395242,-250.121554,-200.522515,-89.715768,-53.510619,-50.304585,-80.385566,-143.038491,-146.36727,-90.311581,-67.075577,-80.710139,-62.682047,-35.025314,-1.354182,2.802636,-79.770879,-247.958126,-287.969011,-271.484023,-253.3598,-246.195283,-251.471503,-250.652008,-236.97456,-176.765644,-163.244625,-185.904535,-161.205521,-101.384938,-5.271882,12.642693,-3.648043,-84.958162,-124.253,-143.055428,-106.173867,24.135617,74.12023,93.171745,62.216719,-70.612792,-140.756713,-114.016487,-8.347281,45.292836,123.168489,137.95207,129.296812,133.659738,138.379877,118.804406,92.471343,-34.509868,-127.947446,-253.641149,-253.19638,-140.372467,10.201909,52.041074,81.290824,87.897609,29.058853,-59.259976,-286.460267,-425.808711,-417.811854,-267.174534,-167.400526,-29.879952,-24.633332,-133.795429,-214.921848,-313.48718,-264.246523,-222.545538,-147.61284,-106.5503,-79.721215,-100.971178,-108.303015,-43.896715,-15.410859,9.790251,10.81026,-6.685859,-28.006795,-97.443636,-133.178288,-177.432702,-177.612701,-157.088573,-70.344492,-30.12493,-41.692378,-67.693972,-45.376335,58.587796,103.456655,128.027565,122.129718,147.221714,165.657951,96.438393,11.10973,-99.771716,-40.821961,-3.632886,5.359676,-17.648716,-102.046853,-154.424049,-279.862878,-336.620612,-302.791194,-226.267058,-202.53014,-138.858469,-123.7676,-190.570571,-249.501487,-284.265277,-154.292952,-72.120799,31.807724,30.621647,-54.221351,-92.422081,-93.757346,-9.20903,28.16641,5.970499,-26.291704,-67.989497,-87.334133,-109.595071,-107.91036,-91.743248,-21.301193,25.424184,107.152645,128.254271,83.384135,39.322191,12.021783,75.446634,96.206898,76.165338,85.968765,162.215945,160.435246,36.122165,-24.181334,-35.643195,-10.239226,-35.948067,-144.613357,-193.64039,-217.023454,-171.833752,3.685612,180.472861,233.706087,233.168737,210.523494,229.889142,274.102316,337.248132,313.612751,170.512435,116.142493,157.721225,279.90681,308.348099,218.374578,120.960243,-31.903241,-13.765087,43.742796,165.431483,203.517194,205.940062,187.312517,178.739341,175.456555:192.499272,303.619513,347.275602,379.221849,337.281116,203.867427,181.211215,226.973576,246.026262,221.98573,100.582823,36.377236,20.030344,58.454405,62.848543,-10.276439,-162.939862,-106.881486,-39.555648,36.797903,42.483143,30.696276,24.360124,-34.216135,-95.534347,-103.623567,-154.87078,-199.550577,-322.57896,-402.179719,-459.583492,-388.520295,-159.484284,-54.941973,-57.801971,-32.50884,15.818751,98.825553,112.234284,80.124529,63.071707,108.886765,206.333287,215.761518,206.70538,203.749347,177.759566,152.434335,109.064942,85.017299,79.706179,106.27686,136.581729,180.373205,163.640162,13.836083,-151.332167,-167.72854,-121.020324,-114.985672,-155.894852,-167.733697,-136.916266,-114.174365,-85.959038,-35.902523,10.751485,90.030871,76.040901,-14.873512,-34.739005,-60.659201,-110.969258,-104.720066,-49.093652,-23.752891,-21.277134,-55.730871,-124.108936,-139.775668,-116.259372,83.572831,207.20848,326.436396,309.550605,147.064887,46.310377,-32.967612,13.443851,20.165605,-14.497193,-19.272874,3.780925,0.718617,-46.154374,-86.660987,-166.391286,-117.840278,-64.948717,-30.892136,-61.135947,-165.602424,-191.497837,-115.140783,33.258419,64.988845,2.69412,-43.764072,-67.647421,-43.338875,45.82504,75.702268,46.63685,7.489172,-9.415449,-68.707026,-102.069113,-159.954075,-183.561223,-255.625235,-261.464128,-198.375649,-63.003355,-38.602844,-72.128673,-94.688969,-111.184371,-137.957107,-235.022029,-266.95419,-237.825775,-106.222638,-47.791646,-50.016878,-81.491577,-71.191315,-16.162126,-19.164764,-41.733109,-10.40499,117.610716,161.047365,171.212233,148.250135,120.763068,188.152146,231.744561,275.309674,277.535334,274.492941,249.34383,89.07058,-88.525762,-118.013161,-73.155698,-28.897225,46.993412,53.606081,14.700649,-3.29856,-2.8777,34.359117,67.902633,137.243329,115.135261,-12.595894,-34.429607,-32.760624,-127.243884,-160.269584,-94.84669,-15.042434,84.219957,65.324509,-0.20254,-11.375454,-62.102596,-141.027737,-148.320493,-125.268729,-136.9319,-244.251836,-300.109682,-319.076496,-248.198445,-227.735723,-252.500196,-236.722138,-66.353542,13.316181,-7.006563,-55.650453,-21.939069,65.359784,60.996117,70.371427,100.336557,137.111436,138.99764,101.278385,30.530314,18.956388,25.148782,16.079256,2.543156,19.556729,12.36066,-44.375219,-130.10345,-57.01772,-8.18618,57.619819,68.235088,-9.956852,-94.227477,-263.09149,-294.654452,-249.162701,-115.399843,-53.398737,13.877921,2.95359,-62.687949,-71.637802,-29.823183,0.939382,3.106478,28.976427,59.049813,84.320111,63.905644,-34.511827,-132.430439,-118.996675,7.875992,44.353982,-39.138687,-109.03212,-163.463519,-155.806598,-84.696127,53.931916,105.733536,157.044421,165.367189,139.395746,110.620702,29.61593,-25.149403,-23.975818,2.847969,28.715822,85.902501,108.620385,111.260803,61.511227,-53.431437,-24.564911,24.581382,137.59498,181.980252,182.510272,155.696418,178.586724,311.477366,340.434345,251.073692,183.604578,66.443188,3.46363,-71.916688,-50.625373,76.368058,163.603387,154.683086,120.270837,121.055429,39.20687,-55.107096,-159.20182,-81.874782,-50.272105,-12.810087,27.31917,85.666888,71.05083,-14.173687,-69.211067,-133.007896,-57.451806,-12.9122,4.622185,-15.224941,-71.626511,-96.807385,-160.407834,-105.167908,1.698341,176.878493,193.79943,148.676233,132.198922,107.716116,60.831087,-67.742912,-124.552025,-119.569004,-64.599247,-42.763439,-69.190581,-104.94346,-165.460667,-126.408762,-52.546879,107.132184,143.331273,65.295605,-24.540734,-146.815306,-156.98469,-125.64549,-68.721064,-49.794765,-11.722753,8.796817,23.494423,17.850874,-58.214723,-151.924715,-132.636195,-11.566332,24.827156,-40.035595,-115.037293,-190.356609,-180.218871,-154.206593,-90.988454,-29.284614,79.967684,78.764784,-24.729149,-68.893308,-74.259341,-0.306033,29.379755,21.939278,6.373579,-12.35746,-11.137497,-5.460757,-24.696253,-95.881444,-81.397899,-16.008662,104.134081,110.944396,80.881457,75.551763,31.776307,-41.157348,-12.388573,180.703334,275.557558,284.497914,189.580815,-6.394551,-47.10746,-13.463214,77.629638,86.999068,22.120694,-31.895723,-126.308119,-130.702989,-46.153076,64.231307,119.557625,232.725087,268.508853,247.675725,212.60425,178.981637,180.810077,188.461416,140.507319,106.092883,94.859386,88.970065,18.611592,-1.134885,10.26934,-51.832656,-70.347691,26.09567,110.390264,203.958871,182.587633,59.665693,-0.154188:backward
-5.545012,-73.218864,-80.554554,-75.074232,-70.670599,-86.964998,-111.098926,-150.923788,-153.636106,-155.395575,-133.345717,-82.000854,46.600614,68.210126,24.458199,-5.003172,-64.392901,-109.07854,-108.819554,-58.654955,-23.273968,-3.082212,-33.991035,-117.243343,-116.133943,-76.151485,-3.063551,-7.073852,-83.631101,-108.500063,-85.077054,-90.422936,-159.051182,-61.371721,44.786636,163.325729,163.389731,136.213675,121.325484,36.96044,-114.113257,-148.18849,-129.911668,-124.666751,-127.717498,-120.229925,-120.597317,-148.216144,-198.404344,-143.141824,-95.98211,-28.377167,-25.301738,-60.468104,-51.016449,-13.007734,-122.459866,-174.510682,-105.57206,-27.787205,16.854496,-21.537951,-119.772252,-166.483247,-214.555824,-87.897864,4.074953,58.800781,33.693767,15.981012,28.339608,31.752305,62.429244,149.318716,340.677199,345.341405,237.201089,207.092714,191.484764,161.646467,91.870049,170.63035,247.131452,338.109128,342.899812,311.031991,283.382879,174.117772,-1.975961,-71.685379,-145.133231,-164.503348,-179.037784,-175.397041,-183.817321,-211.791503,-267.734491,-211.481372,-149.709573,-6.018012,57.106879,85.610461,56.309196,24.218307,88.853297,144.382928,267.417217,301.882481,258.898617,207.55875,141.267979,129.084676,106.805581,90.464641,69.235835,0.619736,1.951592,97.807378,134.806994,66.476674,-52.328662,-38.728815,56.509956,84.751349,127.756205,140.619344,86.414144,31.568409,-43.977841,-45.020593,-67.219065,-156.434629,-167.703322,-117.896615,-90.56213,-68.14251,-58.594163,-27.332932,94.08059,178.717361,323.099825,319.408831,174.084526,96.004997,-3.173202,-26.970113,-29.048196,-40.999205,-30.534077,-8.893825,-31.424023,-98.114603,-117.685854,-99.838767,-24.368168,15.5678,75.942,82.146126,15.773687,-44.534429,-141.527404,-112.750626,-69.624502,-50.453164,-92.705795,-201.715174,-210.958758,-155.047243,-147.574889,-131.947321,-34.977681,5.462923,51.06587,82.290465,146.755973,141.520755,81.850773,85.190431,98.129864,117.299428,134.997978,159.495532,151.112128,78.457084,32.556428,79.52628,191.619551,182.65774,79.730672,43.52942,36.975367,51.508908,107.408254,170.044156,184.971644,218.956419,241.602775,211.090496,151.235911,23.809096,-77.320459,-115.506135,-160.37105,-158.749055,-85.030314,-45.861397,-41.010054,-60.650275,-106.330847,-125.879689,-105.388672,-11.428743,31.383799,-15.484752,-89.559008,-160.191874,-130.73796,-114.66073,-128.944876,-155.167128,-176.454244,-182.570096,-218.747996,-215.897331,-162.772663,-180.691198,-230.492936,-280.647457,-239.279116,-115.189272,-87.659624,-105.909849,-114.692901,-79.555358,19.601008,34.389808,-4.624714,-24.614562,-47.460903,-62.614442,-80.053116,-39.350786,4.783236,147.622729,214.165484,202.193594,139.110365,39.598917,23.562208,48.226684,149.520428,207.980983,250.083506,207.560859,111.354596,112.323929,159.950727,167.041802,154.514648,163.115508,190.163363,169.175501,105.988709,-29.612354,-97.671628,-78.759557,38.492648,86.154154,84.629234,56.035257,59.545861,94.89558,122.38024,61.314446,37.096606,33.630771,35.673497,24.519516,18.112867,-43.199898,-171.098821,-186.974888,-67.84233,8.719861,27.3164,-31.25787,-107.663419,-91.753387,-50.619753,-27.667823,16.795747,145.72555,180.367067,136.552547,62.683145,-146.051611,-243.517416,-218.68127,-145.421051,-113.398657,-36.093857,-6.84659,-4.826822,-35.929292,-103.349662,-78.988927,-57.892619,-40.816296,-28.39526,-49.500199,-112.189111,-257.438733,-282.773655,-244.482044,-125.799242,-62.360073,25.543121,25.207697,-19.492092,-29.386592,-37.690713,40.180547,131.77118,294.597648,329.607259,293.098728,226.677322,50.547855,-24.427939,7.746291,126.716484,185.863987,248.555193,213.777663,55.279121,-14.097089,-74.85858,-22.628169,0.465901,-8.238667,0.854518,68.949197,88.132553,25.002453,-85.953645,-95.792153,-22.615161,46.223861,192.399799,227.638897,224.109273,208.566255,144.63051,96.324651,101.026132,137.23036,144.305917,104.920103,94.506109,151.864754,163.825926,146.472974,151.066643,160.729601,134.524653,103.206356,62.123654,55.878536,44.566644,51.745109,73.636013,180.971125,238.958657,254.916223,230.282442,212.45587,231.468644,246.545269,238.836425,204.050893,165.472959,173.194611,160.613485,125.476414,-5.728171,-163.621664,-198.596444,-152.857194,-124.638303,-99.68803,-64.647505,4.422036,-30.824728,-34.301303,21.52797,33.500339,5.725293,0.692347,50.846427,82.480077:-57.643778,-75.659952,-66.384022,-2.107603,35.338802,38.400387,-17.420225,-144.901938,-88.866877,-23.088161,41.504912,72.499118,179.222822,202.420113,143.293069,89.343134,-11.717047,-44.025307,-28.360106,52.636613,94.280458,70.879605,-3.996035,-122.43577,-54.601961,14.785405,130.517703,156.906795,83.326068,1.420232,-91.696015,-91.170693,-36.86723,56.101528,81.189782,110.073968,137.51035,128.050921,59.872012,-92.433445,-128.635487,-112.939985,-91.870747,-87.897699,-77.663753,-87.578926,-146.693491,-198.519346,-325.548448,-304.695495,-212.295532,-15.937026,17.216829,-62.412766,-127.087068,-193.422636,-88.362242,-14.646259,33.323587,19.324165,-11.531259,-26.767109,-119.872029,-212.617761,-329.602744,-166.541935,-55.113045,30.568836,21.639605,-20.661039,-53.44568,-110.205899,-80.697521,-10.354156,190.457426,270.371257,288.79751,218.475541,34.369965,-25.346818,-30.09732,105.694583,191.352538,306.587528,301.364606,162.489025,82.202087,-14.592802,-34.72142,-34.398524,-75.941642,-108.226509,-174.536337,-208.143586,-233.598256,-230.398327,-204.024639,-109.515811,-53.138473,54.831982,81.489503,29.199855,-2.917382,19.084588,93.396457,130.337748,169.561742,161.295165,120.549748,97.022907,29.169338,-11.138079,-48.674289,-62.666309,-90.100707,-81.630136,-23.764756,18.118756,-52.960035,-238.639658,-215.319702,-123.802972,56.006788,104.314807,111.035996,84.600773,17.167787,-33.840131,-128.408701,-107.06449,-91.320935,-70.934692,-47.219014,-38.666193,-65.105428,-122.272238,-161.072991,-149.60858,-0.498179,111.686044,271.470266,286.452836,200.199545,121.705207,-30.119826,-81.616598,-50.343136,88.081671,127.861771,66.518014,14.605998,-41.290161,-22.931172,29.010474,159.572111,196.79157,157.392949,93.245411,-5.20584,-27.539079,-77.453625,-91.597054,-67.640507,-45.71132,-95.210014,-260.065871,-290.740972,-235.857963,-239.739649,-255.745873,-180.986597,-89.693754,71.793379,101.084454,73.063445,32.759253,-38.487554,-44.079955,-35.600274,17.082458,48.783534,17.858734,-34.698949,-98.817185,-93.713017,-70.272764,22.58456,73.076127,113.015316,85.054374,-10.349717,-26.023157,45.734663,153.503555,178.657588,170.291966,153.408047,89.698731,29.13355,-158.410983,-288.553091,-295.161873,-267.119634,-224.343495,-34.565174,37.401638,-50.355563,-162.102776,-246.212657,-89.138874,-32.217114,-14.001445,-4.594583,-42.06382,-99.678874,-148.432973,-118.639178,-104.032413,-56.109325,-29.55382,-16.090994,-44.775196,-152.33943,-198.87763,-217.194941,-179.420533,-195.237453,-255.020132,-218.814458,-4.859212,75.118476,10.977737,-97.23192,-60.422129,34.93432,38.885294,16.884894,5.241903,-5.815417,-9.401529,-11.170803,6.852822,11.924405,93.806909,170.066102,163.693464,64.051483,-72.577853,-30.500993,-9.353052,14.331759,46.918614,137.345557,145.846741,38.169413,-37.590617,-88.942571,24.709205,102.903031,206.972092,197.178268,53.53086,-37.472663,-139.64427,-71.739232,-11.437189,40.988794,45.423599,65.24975,59.389737,-5.007226,-44.976282,-74.379827,-11.693646,22.622581,36.088004,23.744585,4.392272,-4.242584,-48.590621,-74.594995,-45.201162,41.708551,59.714347,44.201924,12.555122,-72.839052,-81.951148,-4.131469,71.209213,91.197157,163.497252,213.18546,221.787243,147.123147,-70.351897,-170.36414,-156.240263,-74.0605,-22.644592,50.049127,35.991265,-63.911314,-105.298147,-76.646767,64.873887,100.591696,94.136537,81.031534,16.563448,-43.342724,-176.125091,-220.455185,-192.52328,-103.558917,-53.976812,59.021177,94.752355,84.037105,54.191436,39.192473,141.521947,203.560403,309.917217,335.252264,257.214711,170.123062,3.91707,-57.531971,-16.150436,165.860142,253.284299,325.288512,286.073841,99.519335,3.399583,-93.25824,-36.976319,21.320215,133.448193,170.805534,166.639429,117.642717,-26.771435,-114.433538,-98.926361,38.867129,120.716483,212.159406,203.757936,107.406181,66.712926,86.9761,165.944766,207.303941,296.354668,307.718381,191.180083,109.667128,87.512676,211.747696,234.622672,210.095156,224.935789,235.903259,171.334914,8.977549,-27.648961,-10.3287,51.972321,77.00952,152.842322,197.732469,257.804389,288.834629,299.144699,240.889649,244.575869,239.308881,194.239737,137.182223,152.555146,143.262489,68.65228,-138.709895,-163.657705,-112.696795,-36.869399,-15.912583,37.689475,55.114769,-4.236629,-57.169745,-29.203747,-7.282458,-24.104971,-1.46182,24.395975,-22.986237,-96.18594:-150.721555,-108.251044,-55.739711,101.556549,147.813255,106.950288,48.344341,-50.543728,-52.938229,-18.189336,69.124217,109.883425,142.61352,126.292182,75.230574,53.363921,11.374376,6.064764,22.020374,33.252387,22.758739,-0.996471,-21.210346,-92.396136,-96.683488,-47.005108,92.768051,165.959949,260.619421,230.379795,50.522602,-17.879606,-16.143966,67.731819,92.634033,162.487339,216.135454,240.559299,182.971443,-0.665066,-42.69171,7.455508,50.370698,24.849256,-26.437691,-47.80498,-103.376661,-145.912042,-237.494513,-195.963447,-116.784593,29.303312,37.118632,-65.080916,-113.586721,-163.040757,-134.360972,-89.856812,-39.418171,-23.745244,26.931298,20.047532,-141.389845,-255.602229,-324.667943,-168.792283,-96.270337,-42.635531,-48.253596,-79.189505,-94.513438,-128.011673,-106.225589,-41.260295,87.280279,115.454838,136.818157,119.216939,-5.780635,-76.166901,-122.398049,-20.552548,58.166031,169.705256,168.641287,72.533483,15.885304,-64.073351,-102.913725,-115.082693,-105.119071,-68.114802,-36.982062,-86.323172,-206.769617,-230.670351,-214.10349,-160.077711,-133.675333,-57.017229,-13.330021,9.370959,-7.7562,-50.230266,-41.791624,17.457147,179.363941,217.788641,155.786527,90.09255,-1.072194,-20.819638,-41.594768,-34.891406,-27.91652,-11.666412,-13.838901,-69.795253,-101.922733,-153.388991,-162.977625,-126.705086,-11.86003,35.480485,59.932474,44.490419,-5.983354,-49.087602,-133.855331,-141.508973,-133.579584,-115.554461,-99.863019,-89.714795,-106.606105,-158.259273,-185.304677,-157.763036,-29.630379,34.951107,97.218978,84.705027,17.638763,-11.030601,-48.577103,-58.592387,-34.13445,39.508525,41.016751,-28.514942,-54.412192,-58.152612,-29.220431,-2.218959,22.333425,24.242661,68.254559,91.273839,89.283338,62.433094,-52.061608,-149.652447,-148.151222,-109.098066,-134.951086,-237.257072,-248.719729,-269.314709,-324.148804,-286.869312,-102.449625,-4.25052,123.029015,124.733447,12.55226,-53.35855,-61.879014,34.214182,50.87293,69.538414,89.501953,44.084699,-21.617361,-111.412488,-135.02316,-118.479963,23.192663,105.194535,124.150053,66.198768,-29.06208,-35.500584,8.225138,71.851505,93.304745,125.540821,136.772543,136.548826,114.326847,-34.764988,-196.449601,-213.875286,-167.236255,-110.488813,26.415035,56.429121,9.379681,-48.115344,-118.740635,-16.726307,50.928371,130.903702,133.089705,50.426993,-15.767955,-154.353355,-200.955123,-169.367981,-79.893115,-40.700278,-16.832113,-48.815508,-127.99173,-143.468466,-131.049259,-127.316099,-136.654919,-111.126889,-65.044994,40.18612,47.477207,-105.153014,-243.880323,-212.858491,-43.296112,40.605475,118.454396,87.666895,-31.053938,-74.398265,-102.904119,-20.532005,56.850968,174.147391,170.940675,63.737462,6.413133,-67.639006,-89.134624,-63.445924,21.79627,48.321195,88.565491,105.682854,42.93315,-33.054297,-108.929355,-1.613959,80.240847,189.288708,186.50133,72.307892,-12.260749,-155.276962,-153.246051,-95.718639,32.995073,72.920026,55.764936,3.215927,-69.761528,-56.950081,2.035973,-0.816408,-4.618739,59.65305,93.394034,55.579738,8.388075,-56.897828,-43.908987,-0.948181,70.289802,72.947583,65.279678,60.906184,10.058309,-9.678227,52.016218,157.582303,198.720548,281.24827,301.709992,248.92359,186.060456,45.268748,-45.225685,-51.624651,32.290079,96.967808,164.502133,161.234681,130.826884,105.175312,49.623282,57.289916,81.493592,166.247326,209.435067,156.15728,54.610784,-94.347354,-85.38046,-87.171848,-98.322379,-58.086089,85.671871,133.013357,132.803503,104.060811,91.136375,206.496483,267.49007,328.797114,320.903331,196.726898,94.367294,-95.642647,-112.725007,-49.729405,90.906023,142.018397,204.48671,201.165459,87.966409,11.814998,-37.408542,-4.196819,7.953918,35.594945,33.579174,-8.685069,-33.295688,-75.460894,2.475232,76.075353,160.457787,175.06323,179.614317,157.574034,74.289129,42.914033,92.863421,228.379207,253.753678,237.592505,228.494932,166.433247,109.220273,49.45992,159.657864,229.43049,233.515205,181.042707,78.792655,32.851004,-53.479778,-82.736056,-100.612422,-50.629658,-0.002193,141.957601,195.19163,159.936261,109.553429,102.818697,169.829113,182.285881,149.030151,128.687654,114.462881,97.231512,28.574758,-18.580755,-131.762529,-147.650389,-109.978259,-46.105401,-44.865524,-85.271544,-108.399077,-129.740273,-110.694577,-96.231331,-89.190293,-85.861438,-48.813874,-45.075966,-138.416612,-212.148837:-0.184584,-26.132737,-27.959302,15.397663,35.655751,27.779168,3.271473,-73.887962,-144.295162,-141.52372,-56.317522,18.634371,166.265185,175.87033,65.86442,8.036854,-40.929979,-39.136418,-37.628874,-22.297823,-8.462553,-14.344646,-30.150218,-50.497603,-60.93498,-44.051177,55.582267,107.063223,133.544249,110.88194,37.593438,1.632873,-5.18961,89.60427,130.117576,166.977673,178.248559,169.894195,145.044449,67.471578,-24.956334,-57.27042,-78.917152,-77.788421,-85.823897,-104.169685,-152.568421,-169.077245,-173.91536,-147.160915,-119.133224,-35.096533,-11.377218,-76.87211,-133.185728,-185.660752,-176.805827,-160.205431,-113.817778,-97.204129,-109.028718,-135.961069,-187.958641,-205.010611,-217.131243,-140.58159,-78.157208,-4.505471,2.972382,-9.388719,-24.064124,-40.1619,9.470993,69.541175,197.13252,234.679813,242.986332,208.11984,100.346763,64.825345,71.539785,151.324663,197.912266,247.957233,234.58292,176.657602,162.381366,121.347243,12.471308,-17.723698,-31.09725,-46.550031,-83.752886,-99.31058,-126.076566,-142.87294,-194.969864,-185.894735,-145.225946,-25.78423,46.458209,135.755771,136.321833,119.205102,149.492199,205.656097,316.838504,313.614033,215.839078,171.990803,119.598325,91.272692,50.185379,78.036123,75.586674,-13.863067,-66.298643,-104.769636,-86.466317,-79.636857,-192.07434,-204.342497,-67.933703,9.748556,52.965492,31.143891,-9.583799,-31.534445,-106.493884,-125.28968,-103.612376,-61.785092,-67.989529,-140.583233,-165.008681,-153.597588,-120.666508,-77.569447,50.569827,97.752515,116.712117,103.750389,59.775425,17.414144,-89.696573,-124.774181,-131.2891,-166.750687,-180.732943,-187.057703,-180.090309,-146.943398,-78.845383,-40.035084,-18.730129,-24.199269,23.971015,57.589149,28.183184,-25.699569,-114.130689,-124.230164,-118.27501,-139.307894,-161.484771,-193.338214,-185.043838,-123.775699,-123.417063,-133.088784,-57.88032,18.240817,135.158559,149.914754,126.746408,102.837588,68.229405,85.902604,91.337692,127.640441,170.589668,199.548318,157.461682,49.125595,45.364357,88.350763,211.797015,257.060808,230.711171,178.67716,144.035002,164.987762,185.531259,178.365518,156.205948,137.785726,193.248474,289.272799,236.833236,7.881518,-97.844765,-89.800197,-96.28546,-102.494386,-19.288106,39.419643,85.200979,68.74567,0.442493,9.27724,55.385088,127.729751,114.979306,-6.721116,-62.340523,-66.317768,-30.430106,-33.54157,-62.831458,-68.612153,-60.25188,-75.729668,-147.812251,-176.568638,-194.35429,-159.17479,-143.138037,-117.475157,-82.346951,15.600788,33.968392,-72.059503,-185.625262,-149.679541,13.0523,74.710107,114.415937,96.19779,16.572179,-33.17521,-96.115547,-29.612973,12.46703,19.021968,15.575231,55.925333,61.859351,-42.35557,-117.985363,-77.721778,18.938229,18.882188,0.061103,21.10032,48.655757,18.805712,-40.799079,19.872504,67.676684,134.101519,152.261767,134.063034,85.089977,-88.570006,-199.743748,-165.517931,-18.299909,17.444989,-36.7779,-83.780787,-53.19991,27.750365,155.537786,148.002892,124.608781,102.80067,98.794238,73.601646,49.257296,-38.16425,-107.590095,-85.207644,31.299481,70.688265,52.417982,17.329272,-16.442863,-11.826803,-17.587893,-14.310224,17.145269,96.004971,115.126723,95.511178,53.656785,-60.214338,-58.26026,-17.988824,29.817537,35.783714,27.164458,15.458124,-13.442567,-41.46735,-92.767758,-77.885761,-65.403071,15.532117,91.38423,134.568883,59.889785,-145.956937,-217.539114,-187.005904,-86.810845,-35.185359,53.644757,66.618805,54.613552,60.349925,65.623575,115.371952,192.360545,328.67538,330.205283,203.93118,118.889018,-24.561013,-80.953551,-69.253898,18.625885,96.624083,237.233441,233.245014,76.34366,-15.995112,-118.771245,-98.309062,-64.803405,11.293662,49.575547,87.221897,62.924795,-65.076925,-136.013832,-97.967445,14.419542,37.631173,61.734187,93.24392,148.315076,141.666204,92.6759,61.468836,56.99623,105.273861,137.73449,109.658221,70.082928,45.034876,55.16629,49.315672,42.747446,61.397075,113.248983,105.425028,-19.503636,-100.734571,-160.229687,-36.595789,36.873844,121.536506,139.382533,171.652183,192.447413,188.340505,160.153902,165.21324,140.154743,98.568209,48.077477,30.142459,-65.047388,-127.204137,-228.421933,-232.114875,-191.234295,-119.399534,-124.346237,-173.546753,-177.311133,-153.488101,-160.050107,-166.82599,-147.307795,-106.337036,-33.018221,-48.430615,-124.290514,-132.07278:-145.206994,-12.356256,82.172071,177.623538,154.229721,18.364448,-63.695315,-186.224792,-158.113609,-95.962353,23.698351,71.177258,140.39618,140.396723,48.05958,-25.926006,-136.176522,-118.798882,-76.475875,25.962738,64.351879,51.881068,-11.220867,-182.296212,-194.884232,-119.903343,37.414607,87.870653,140.942236,119.557042,20.832385,3.481423,27.071614,34.585142,48.678963,139.28494,190.337459,198.711533,150.671665,43.505581,8.21074,6.706438,2.961003,2.164463,-3.225003,-22.630035,-80.594394,-107.507036,-180.163054,-219.054818,-167.901896,9.707653,48.846983,-39.084856,-125.675202,-256.573033,-218.893385,-153.389794,-40.038092,-6.639741,12.267011,-10.867052,-145.235734,-240.496775,-335.816733,-248.763821,-205.506226,-154.939329,-122.426005,-99.138213,-137.052108,-243.054643,-215.659656,-128.772008,74.137459,134.785766,116.09606,50.412299,-96.255154,-149.081989,-175.518214,-56.900538,40.01655,198.55217,217.153211,113.868192,29.558155,-114.013481,-193.100997,-188.565278,-119.217608,-86.607446,-61.80229,-84.825532,-201.618496,-269.45408,-324.725001,-214.392133,-144.291406,-49.708458,-11.962133,23.902293,4.976756,-38.471594,1.454424,60.224008,214.318632,271.098007,241.901261,157.954825,-10.99121,-65.861642,-103.188667,-22.999124,6.542093,-25.497906,-62.230498,-120.478933,-148.542558,-224.307068,-197.092715,-132.201354,-48.534904,-35.172715,-2.387793,3.147216,-57.42512,-124.66749,-237.15975,-210.694857,-181.32407,-148.255917,-138.752359,-135.454736,-155.363822,-235.01637,-236.90622,-176.066622,-30.399164,17.018811,20.434551,-26.454659,-119.296267,-144.736759,-210.268255,-257.186717,-239.82828,-147.103983,-116.487867,-137.755149,-160.13104,-192.398988,-181.855737,-140.879424,-44.071619,-19.353659,-3.424195,0.300039,-39.583863,-94.514902,-208.707912,-228.850661,-206.641871,-155.124021,-147.805158,-178.783193,-209.331313,-291.810573,-269.908529,-204.377703,-85.14859,-17.944235,155.605589,191.943721,62.651531,-45.757124,-133.717715,-24.249786,42.31496,149.458407,180.108067,160.500863,124.887811,44.099347,-24.3707,-27.108665,75.151946,153.567818,229.825657,210.491294,118.41638,62.722155,-19.940432,-1.415645,37.959835,157.257795,216.28462,247.86451,196.259975,-30.711176,-178.443736,-147.498434,0.120583,67.547557,157.735346,153.763267,57.263687,12.415801,14.400127,118.995324,162.152844,184.125224,169.438159,75.15751,13.090437,-33.644118,-4.484819,0.761314,30.90455,68.073192,93.203202,65.131046,-5.266942,-42.621654,-100.807919,-46.833989,11.122382,136.159929,172.087511,114.643256,35.505134,-117.41578,-135.403805,-93.318412,-0.816053,39.632802,119.744078,141.016619,97.907213,46.986919,-18.561918,-2.1926,22.881567,132.033666,193.919786,151.212373,38.812119,-144.415684,-108.211829,-46.553651,43.600328,68.865822,115.985553,130.202626,95.85392,47.117256,-27.904681,16.472911,73.430915,189.746339,211.841574,148.225251,79.948467,-105.724008,-203.100427,-156.090053,-20.400993,0.930273,-8.905556,-14.408887,-19.964685,-9.487881,68.32822,146.966782,145.045513,131.018659,147.573176,141.329542,93.496182,18.018469,68.915173,90.039379,91.864139,111.123798,151.46661,134.152508,58.474135,20.312246,-34.996339,24.187538,102.713451,246.749431,265.206467,195.300355,131.689642,-25.830126,-84.507434,-34.084388,120.733788,173.995404,201.456881,189.901641,93.987383,-6.442315,-149.489521,-31.896489,56.392027,160.082939,166.578255,93.380905,28.721213,-114.529066,-174.204581,-156.262411,-54.2417,17.006756,96.961393,83.140363,44.999759,50.953749,84.960683,156.099847,218.758,329.525731,336.300703,202.520568,81.561965,-122.387332,-126.660136,-64.283649,96.273953,170.41523,236.841189,213.948118,95.816538,23.969541,-108.683824,-184.223932,-186.466034,-94.30395,-25.933544,22.276869,-15.661292,-140.679762,-151.455516,-95.222048,21.738633,49.614692,76.068601,93.03936,110.011985,90.321285,31.557374,69.906073,124.882281,235.984385,252.294345,173.853176,116.137536,35.873639,32.308753,59.048133,144.728469,199.942743,275.443559,262.409589,122.1859,19.623538,-101.478204,15.044528,107.396766,215.380977,220.998459,175.047399,139.548514,64.746967,53.603109,86.123567,129.663628,117.348033,55.50519,-10.761831,-195.35362,-257.032594,-270.469019,-201.422528,-146.812799,-29.081972,-6.733709,-79.342369,-129.705217,-179.817472,-211.117686,-219.844454,-201.806462,-178.916913,-145.054415,-145.908442,-161.093313,-169.067503:63.706804,-5.799325,22.48502,70.284608,30.427899,-75.195742,-80.425989,-57.328931,-126.018994,-138.146613,-27.957044,47.708191,74.755073,10.493511,-121.522656,-137.09719,-141.987439,-195.05963,-200.461708,-147.691363,-127.474831,-125.328474,-108.38208,-56.012005,-130.861598,-171.861107,-115.940502,-51.605904,38.206289,42.079397,-47.278261,-108.342283,-151.090128,-44.589146,13.600506,76.025616,108.61795,133.324927,99.907451,7.193741,-73.513861,-91.684648,-61.856476,-38.961716,-23.061703,-47.18805,-159.850769,-199.573154,-176.869733,-110.170518,-80.867266,-15.432004,4.385116,-31.122561,-74.359551,-176.474941,-282.925384,-301.607054,-240.338016,-188.773564,-129.000492,-131.936782,-135.741008,-117.825659,-93.393326,-95.588798,-87.6227,-63.343914,-45.087675,1.667314,-3.036275,-41.654448,45.907266,125.108362,237.53992,257.965152,257.976169,233.634368,166.915072,158.672763,204.954628,277.927844,302.903586,316.415943,306.683359,261.120099,236.700145,116.741831,-103.737512,-166.469995,-166.596649,-150.435642,-150.079407,-163.489043,-209.005598,-243.250167,-305.902949,-266.561598,-194.305642,-2.861054,71.677893,125.940871,121.840151,105.331424,164.28633,218.583555,302.720611,318.245024,264.444734,211.17345,165.508469,177.886536,164.452069,85.481811,70.534662,101.684594,109.505283,71.00994,54.832557,36.507813,-27.47253,-43.198483,-7.288477,12.620118,20.123967,22.1872,47.673374,43.095583,-49.893617,-122.350174,-126.559073,-109.8683,-91.482924,-69.301768,-67.387903,-39.429485,44.520291,103.783235,163.985211,165.521935,189.878136,199.996633,166.282284,122.669517,8.447042,-36.602789,-34.5654,-75.306145,-112.892546,-139.92128,-125.612862,-111.562711,-138.176731,-133.619974,-59.886619,-14.208137,34.391852,38.902783,18.526545,-8.001836,-67.590738,-91.126196,-81.994758,-41.444403,-34.71719,-71.438842,-82.398285,-61.342097,-36.165419,-2.964716,122.419295,185.248107,231.552194,218.355806,202.359658,205.718989,191.534149,177.507481,199.317387,297.366724,347.004557,348.268914,291.86699,203.281354,305.373966,382.054889,406.704826,366.0611,294.618631,263.987956,224.524762,241.653193,271.417278,201.237504,188.813318,280.76816,327.802681,278.263249,220.697931,160.201903,57.755507,4.237607,-6.502848,19.966303,109.114598,168.822712,219.866772,185.671007,91.406084,104.099019,138.028767,166.412466,136.672878,-26.233624,-115.096055,-141.698029,7.739616,68.465976,40.198931,-21.674492,-87.49272,-88.222963,-107.860777,-127.394951,-145.16716,-131.897337,-121.234805,-103.800696,-90.296527,-67.409438,-74.05776,-92.68726,-73.634443,-56.456657,5.097807,67.018363,167.648977,138.323181,-6.874882,-36.963461,-14.889012,21.019449,38.202727,33.050458,20.365075,18.988087,4.139935,-102.088927,-138.828722,-81.865273,74.360327,121.682387,126.355812,96.636034,42.637375,48.12864,90.237121,53.638569,30.266832,141.19019,241.609532,241.330823,121.102832,-154.117755,-277.569116,-248.194527,-66.075682,1.528265,-24.544491,-64.393396,-5.063491,79.687582,129.786913,24.791505,24.049519,133.890363,161.800587,72.833425,-13.608442,-161.938161,-173.620447,-125.595194,-24.019624,-1.933701,-29.972972,-74.68488,-148.895317,-135.980073,-39.414047,-1.720424,-13.723716,-13.088989,22.995767,47.887062,-14.209248,-206.61153,-295.747583,-254.276582,-85.898897,-32.901013,-9.759861,8.014263,43.272748,12.880505,-120.706658,-166.929656,-159.719853,-133.88323,-95.321999,-47.031756,-87.129717,-240.270158,-309.962908,-287.39477,-219.521646,-191.747819,-90.241528,-32.898442,9.398117,-3.143243,-51.056227,23.837416,117.765738,251.943828,256.452212,203.443883,174.321666,91.57445,-6.821024,-3.082082,132.397017,197.034902,182.894374,107.245099,-71.342772,-128.242726,-150.370515,-91.403465,-66.822283,-66.024858,-68.206645,-49.106069,-42.28446,-60.897725,-77.038111,-48.505996,59.814909,104.249161,136.459913,119.330766,20.619657,-31.918594,-56.007956,3.926421,31.13598,83.128792,113.943855,134.540356,115.509212,46.169919,-3.953392,10.504125,68.012158,70.490465,47.766773,44.851472,40.112859,23.711767,0.631939,58.83591,98.817303,167.396945,189.120211,179.29939,162.95635,163.133247,189.423701,191.920608,168.467022,154.224489,131.572876,113.165099,8.598351,-87.196693,-255.457357,-243.961168,-208.878246,-163.403519,-158.315304,-183.724275,-177.656902,-128.719988,-180.021728,-201.779367,-143.18565,-110.80198,-75.161563,-40.89814,-8.464019,-39.676296:-44.043536,4.097708,61.129997,153.782436,168.869145,110.500965,31.463673,-166.30775,-220.025589,-161.17775,5.734905,71.812349,108.487101,52.569611,-143.955963,-223.710795,-285.47747,-190.865383,-104.54825,52.75965,94.303903,39.573875,-35.374899,-159.440107,-182.178075,-145.592982,1.025074,87.036673,173.68982,133.693934,-48.855546,-123.545121,-134.745185,12.603614,84.544467,195.781762,248.148264,252.797454,181.18689,-8.095259,-114.393231,-124.519036,-83.364311,-44.440436,-23.407592,-63.636938,-138.211671,-140.303205,-155.009385,-170.078898,-134.941413,-44.364525,-34.442334,-104.271906,-173.767362,-334.354031,-384.982514,-339.584422,-193.580556,-125.169932,-54.276844,-73.006029,-180.143663,-232.632692,-268.020042,-193.400358,-149.782981,-101.496477,-84.170227,-75.507153,-98.428844,-171.460753,-163.653667,-106.636566,39.406824,105.284196,197.878669,202.229241,114.90702,40.783108,-64.647141,34.948222,133.513042,277.172039,288.746415,177.302066,80.166903,-105.61044,-178.082297,-156.359972,-88.690319,-73.513769,-103.711647,-153.005273,-269.646126,-313.738714,-361.297137,-315.349226,-256.306844,-124.766576,-71.898551,-27.638466,-35.846151,-50.266644,11.852932,72.373747,233.594546,311.542392,316.1675,198.111647,-138.455344,-237.040847,-174.133433,-27.842237,-4.968734,40.624419,68.42047,13.687832,-55.65329,-141.357387,-155.895395,-151.097466,-90.766429,-28.793957,72.457287,58.768235,-73.09949,-140.569665,-212.783216,-199.144981,-173.217373,-91.001707,-55.55991,-118.267044,-201.623903,-285.271923,-241.35335,-210.529735,-86.768462,10.667356,127.82948,95.955743,-59.462515,-129.858533,-230.051085,-187.266622,-136.973047,-139.97996,-188.801912,-272.227304,-277.777977,-268.583181,-282.967185,-250.053964,-98.316408,-25.906714,19.145301,-22.002005,-158.920206,-215.745263,-271.020416,-179.139028,-93.51389,-0.013757,-34.64679,-194.422682,-238.369496,-210.351885,-164.926591,-141.358796,-47.020655,22.720468,143.828383,156.979583,55.710379,-25.628516,-105.292944,21.845578,128.469955,315.401703,370.90154,360.926848,287.96266,100.611414,82.730936,143.395529,271.351088,330.629667,393.588503,342.55757,143.358443,75.24336,54.777156,106.628313,154.741843,324.473745,389.709021,314.226442,208.901975,32.4789,-44.39723,-55.646596,-42.739713,-12.806972,107.802261,183.560125,233.212369,163.067192,-12.920692,33.41316,113.166885,227.963437,217.52973,22.693451,-94.488148,-162.589575,-94.32942,-73.603461,-41.095545,-4.90538,64.582213,57.691276,-27.407036,-78.21561,-144.267578,-94.401749,-22.423949,140.988361,174.142282,76.477769,-9.959793,-110.480566,-78.55785,-29.052461,85.103613,131.819673,168.304394,138.626327,52.048188,47.950225,50.20485,-12.463244,-1.805413,150.808149,220.637037,174.381908,68.747806,-139.125158,-154.145728,-92.823624,33.725665,81.298462,164.757071,178.732683,103.595981,50.618032,48.921002,116.619753,129.897771,168.427339,204.496589,182.033901,86.695466,-179.542875,-262.265431,-172.261734,86.429214,146.180535,71.462351,3.426188,-25.184894,7.754713,65.038226,97.476593,131.943165,253.925123,277.924465,127.030299,23.085219,-68.076398,-49.671881,-13.982647,80.860405,112.882175,119.814453,98.680791,32.5315,4.506636,-5.159202,38.102601,54.424996,80.084689,110.066368,151.914697,119.815909,-48.313404,-163.681503,-130.103947,56.858359,138.371749,181.641736,158.501497,74.739106,5.939228,-121.015524,-86.419934,-40.524209,39.268968,74.0319,67.746503,1.279945,-207.8799,-343.313838,-348.156365,-273.997609,-203.901511,-44.630346,2.369027,-7.109232,-46.880905,-106.096799,5.761713,113.666536,307.211076,333.613849,221.584045,154.054486,41.854152,-95.734808,-113.055005,46.767578,182.139786,309.994161,230.926405,-65.073348,-166.15356,-212.204386,-195.330793,-170.989421,-63.729036,-8.275396,-8.867467,-72.039617,-216.072535,-211.360811,-128.601234,66.612554,121.226384,145.699124,134.815754,68.768589,10.235029,-74.088149,-12.208995,56.895536,217.784079,265.863133,190.379067,97.412631,-53.116567,-94.361917,-63.030689,89.663982,189.091503,307.012192,278.374232,86.48702,-15.546099,-90.084009,26.594083,117.123758,288.426078,322.71066,252.54383,208.257175,163.857522,128.217043,136.724927,192.21644,195.267909,108.922018,37.456303,-85.946095,-131.799695,-248.658505,-273.806266,-198.535928,-19.201852,12.087051,-55.926927,-107.648625,-166.777354,-201.674458,-212.696496,-181.268912,-141.178538,-92.920818,-97.485194,-130.095776,-133.343234:87.370283,10.056922,53.198152,113.90788,86.618936,13.491527,5.782036,-3.906692,-71.913176,-95.175368,-85.320022,-73.38452,-73.021673,-87.839951,-134.436302,-162.575875,-216.556899,-211.873998,-197.516512,-157.102433,-112.723319,-26.18752,-19.181111,-79.006995,-167.651647,-167.891743,-76.04545,-26.498826,20.84838,-8.1773,-186.29272,-276.821346,-304.612419,-155.116613,-81.214529,-8.49009,-0.246812,-32.995401,-62.979862,-95.069281,-80.94396,-61.126215,-42.144452,-65.125048,-131.266818,-139.455161,-80.43206,-30.866138,14.260865,-15.929331,-15.799654,3.263917,-4.698959,-74.702433,-118.651172,-154.091091,-163.90526,-203.582683,-286.324376,-257.173757,-99.694461,-72.386537,-189.932967,-263.157391,-281.581708,-156.268913,-100.250307,-71.043539,-76.340223,-67.648797,-58.967189,-69.310396,-86.235521,-81.32128,-66.078656,-61.130603,-64.543839,-64.987745,36.014274,124.967806,187.258345,152.399991,156.61003,185.419524,211.378197,283.168813,288.707271,142.215681,-63.473073,-106.71013,-126.855945,-159.572525,-272.611752,-305.322998,-263.667183,-238.599188,-306.984674,-331.953129,-268.477965,-132.484719,-99.072357,-94.116292,-106.347152,-118.938566,-66.24363,0.229717,135.343405,150.524086,81.042969,48.403542,63.753578,95.682353,129.2301,150.171835,172.120301,220.919744,226.822919,164.140335,137.199227,165.902584,126.263381,63.711317,-37.189615,-56.87232,-38.752635,-19.213405,-16.640163,-34.048088,-51.418475,-39.832094,-51.100224,-62.697912,-27.538028,15.590879,-33.056612,-168.594298,-145.781171,-74.840584,81.203646,143.680266,210.818474,179.438406,6.507122,-60.02893,-77.268681,-16.372085,5.150672,-21.428581,-50.144349,-107.553473,-129.524355,-111.405369,-78.103441,-92.579059,-146.508148,-146.19419,-52.552165,-2.275598,-8.229049,-47.437688,-79.60581,-0.428114,50.271125,78.392772,63.448776,69.833318,107.730464,194.293036,194.080032,193.735247,284.320982,335.395062,360.816326,345.866151,280.027131,240.013196,204.554635,250.901544,291.843193,373.626873,407.799157,429.168701,404.191968,334.357852,314.322945,328.986046,391.413674,399.811267,305.115489,247.308022,226.047622,238.812426,203.057376,150.944241,164.236207,262.076912,322.313813,379.876284,360.510909,302.686263,284.629183,258.429952,150.559835,120.171835,197.292113,255.34116,265.920602,211.011346,78.648549,106.987894,169.446946,208.819678,154.704996,-27.98394,-98.609591,-122.743972,-82.16719,-56.692618,-3.030524,10.10663,23.601841,32.634229,34.342991,29.297223,43.296497,76.338168,65.030097,-2.771622,-4.581839,43.664627,30.605078,-82.485134,-110.911783,-46.347653,134.568513,190.223516,193.166401,155.740213,73.565265,32.117938,-46.446176,10.823527,51.065515,40.943011,34.594072,40.093285,8.381322,-107.418541,-128.370622,-64.722774,107.546377,172.56577,240.062701,232.115648,179.396139,154.559853,81.447332,54.500176,87.311298,146.434181,135.127107,-13.585512,-134.74276,-296.705116,-256.71532,-189.467468,-61.451595,-36.749064,-41.565436,-38.484397,23.036773,62.553816,73.836691,85.508625,127.343753,140.910865,72.016627,-115.887215,-171.234462,-178.501845,-132.942336,-102.735536,-82.101377,-102.237794,-166.761012,-210.664144,-266.270955,-248.910167,-188.746049,-149.572787,-113.048904,-22.963395,-11.804039,-104.224883,-165.079869,-230.781807,-232.350558,-198.555865,-70.110398,-0.745549,93.809734,104.237554,50.033185,-12.756599,-174.158677,-239.993078,-227.847658,-145.384579,-83.519028,-25.199936,-57.979048,-183.064318,-235.456646,-219.772762,-161.382845,-121.641064,-13.615563,23.760589,25.139657,12.859253,8.597285,24.72668,45.785229,136.609412,199.939869,264.103517,223.490324,38.180919,-58.684944,-24.463438,104.238055,147.530023,140.155402,70.911827,-148.050877,-234.774129,-268.651293,-162.829652,-128.086898,-156.074804,-173.744794,-132.100904,-97.901935,-88.382398,-80.911005,-46.221266,45.924313,95.47561,193.455309,208.252005,149.03693,111.621241,51.580246,-26.432375,-69.097317,-70.425519,-15.71796,53.580711,24.346615,-69.037431,-83.533346,-69.525133,-36.817036,-16.125171,60.317635,96.778438,110.980102,103.853798,84.096542,88.864144,119.714755,228.220557,274.008469,284.980284,276.708844,290.807042,300.847201,320.07683,358.740025,341.671339,255.672407,203.827029,115.762545,87.444323,4.832152,-76.494184,-87.289235,-89.635266,-93.192341,-121.086715,-140.251281,-147.713883,-113.458649,-82.641007,-14.291117,11.913615,60.180335,96.894056,210.80143,259.506189:89.464109,-13.020849,-45.633033,-57.672192,-46.532993,-22.356976,-11.582937,-31.09126,-133.097972,-185.334557,-215.947514,-189.745089,-113.486907,-87.169399,-79.453653,-104.010688,-208.863144,-284.167292,-278.531778,-191.442403,-132.090353,-86.592519,-104.939909,-151.910525,-196.909421,-217.277021,-213.26477,-187.617996,-169.781009,-182.950851,-190.094181,-197.083068,-223.162548,-141.775379,-82.689513,10.678775,62.171548,121.049297,101.777125,23.834737,-7.638158,8.544565,21.345219,-15.656136,-131.875428,-165.657266,-99.884486,-36.733506,-31.427549,-154.051282,-171.509159,-32.445453,57.501409,105.786419,80.073339,-16.478718,-133.6753,-151.416928,-106.759303,-71.86592,-7.879213,-2.056466,-88.267747,-154.556466,-218.982878,-116.810724,-27.03658,99.323104,114.288656,43.114115,-31.751415,-124.55885,-12.402,73.64779,144.552005,130.842469,104.850739,97.994866,78.1401,94.107287,192.227214,225.704855,204.983404,211.490593,262.507242,334.792378,298.026214,109.318832,-27.400181,-52.566939,-120.486972,-169.16089,-245.84334,-265.223124,-262.543914,-262.324365,-282.24249,-228.883086,-183.32708,-75.634838,-7.103736,50.605151,24.104081,6.580985,142.938488,235.371551,328.520719,303.930964,158.01615,88.670104,115.385543,191.233611,224.194828,128.556259,133.97069,239.0866,279.310845,279.693392,268.390337,227.447765,103.670916,61.729658,80.393671,115.03454,200.102736,230.537942,216.658868,190.571441,139.697082,92.76096,62.514871,-4.784708,-3.626685,52.452966,54.682983,-9.474279,-18.851699,50.069604,241.391444,301.937726,333.574686,306.499919,188.888274,132.892738,54.02433,34.302102,45.950996,55.78906,56.312062,46.141068,21.426376,-55.221881,-90.104457,-69.846005,-9.230065,15.394525,77.53462,90.921688,6.157625,-54.294588,-101.617502,-75.795052,-46.245142,27.999905,54.296847,49.43921,32.587927,12.681831,-4.323538,2.939556,101.949055,177.487617,264.989197,257.864105,231.619767,241.257064,248.209995,214.647195,223.359231,332.556739,395.869856,407.21854,350.8654,229.776021,220.782157,254.47507,302.996287,299.945717,255.220286,226.669551,223.511649,240.877034,214.521921,165.454569,166.530996,211.668949,248.669907,294.605003,280.938466,206.701205,126.219087,84.073951,34.257782,54.879588,118.914752,98.333667,12.913471,14.932661,46.256349,-9.326486,-30.169613,3.639601,23.214401,-22.831388,-60.866008,-68.669463,-32.775652,-32.473193,-100.5795,-143.608947,-164.184521,-159.217126,-143.807011,-106.998921,-45.852064,-121.680353,-180.891492,-241.155792,-228.102242,-151.441282,-105.458198,-64.716685,-96.663515,-74.881671,35.036069,54.098771,-14.934732,-53.318315,-48.3227,-20.084222,21.084299,38.696655,43.840571,87.879619,124.797842,137.48441,111.645124,85.418323,101.241429,110.989138,147.382823,187.067885,272.746978,282.628418,257.936965,241.559832,170.521996,113.072305,108.309509,98.505574,91.783744,61.727911,22.047391,-96.818473,-167.629157,-136.524726,19.859498,89.315398,144.556473,139.065147,119.118574,114.464079,108.033251,115.941482,113.258366,85.871289,65.665821,1.283571,-31.732926,-86.574607,-173.443063,-214.679765,-209.270866,-162.117005,-104.905153,-121.326896,-138.816277,-118.526844,-74.249225,-36.909844,-13.519856,55.776974,91.828118,54.362103,-36.589639,-258.977561,-309.758308,-247.626897,-88.587073,-16.46599,59.865598,42.9361,6.186654,7.540268,-63.836557,-193.031403,-210.568263,-110.817474,-33.712519,21.565039,-3.920594,-108.868971,-201.716565,-170.04539,5.335091,61.973192,66.54684,64.099872,79.016991,60.615114,-10.417354,51.705161,137.499816,284.83866,307.462636,263.246563,233.862444,171.837118,51.177134,6.007863,15.923678,63.861087,156.521994,136.767499,-46.445883,-138.020117,-208.835414,-196.777945,-191.889346,-186.150576,-178.54065,-132.456934,-97.928052,-79.942831,-131.970636,-133.363254,-42.677491,41.615239,164.718042,153.974756,92.930428,94.009011,109.60845,60.771604,18.133322,10.212986,49.839366,70.635972,33.219676,-50.817539,-88.793034,-72.499421,14.544924,44.670712,45.189875,33.766497,34.231889,56.04028,106.875095,119.503646,125.516562,178.137852,211.078789,202.336415,169.161797,167.212291,242.704438,284.940366,352.401151,344.348225,262.700773,218.162971,109.098742,36.990935,-103.963713,-138.371278,-119.376949,-104.479992,-128.304523,-185.569714,-173.572604,-90.103251,-58.436009,-45.066962,-1.912649,12.004416,20.005066,14.947674,47.405348,112.989248:84.278429,16.25726,27.174252,118.627442,149.194776,76.449564,14.123764,-42.516738,-115.793538,-156.101006,-124.985216,-68.092775,-46.457833,-113.334155,-258.652336,-267.134615,-224.177409,-262.777566,-264.542122,-177.796713,-138.744403,-90.463498,-60.405316,-29.468064,-54.318365,-57.833949,-45.688606,-40.992832,-18.45977,-10.975037,-44.627373,-72.799024,-101.306308,-42.049325,-3.184205,27.492213,26.280736,-14.421468,-45.151564,-92.430289,-185.803809,-217.794591,-131.75256,-60.662158,-43.712125,-80.687984,-93.67467,-77.467687,-97.267547,-109.529568,-91.143133,-57.94697,-63.318499,-140.412094,-194.713552,-276.261109,-302.704151,-297.157863,-252.036456,-204.194369,-97.932939,-89.578128,-175.660691,-216.342636,-214.986393,-121.489278,-69.077687,5.574123,22.768171,-21.59899,-64.5553,-102.643481,-73.945679,-35.954895,48.428948,65.39431,59.10507,53.450875,57.662613,69.287256,102.115198,158.291772,203.005731,333.185285,380.28735,281.851297,161.794253,-1.438318,-64.209185,-88.543093,-129.722834,-158.71546,-237.780882,-272.160322,-324.962804,-364.240694,-424.429795,-299.248311,-200.479449,-107.608494,-94.492537,-9.50935,36.26713,2.974197,-69.104522,-42.042429,59.909878,85.611938,118.787151,131.965026,89.819505,49.753852,16.513144,33.259981,52.927023,113.059276,134.738747,106.693268,59.834027,-39.509619,-72.625058,-54.168107,-23.629052,-34.162337,-66.566542,-63.157297,-14.126749,8.583215,0.476187,-36.538428,-27.361497,-1.535109,-35.362581,-178.000221,-231.817039,-268.375096,-200.107402,-111.454561,25.931979,41.498459,66.397855,75.053475,36.666836,10.745196,-33.461742,-71.105109,-76.108614,-55.335167,-44.431173,-54.788648,-66.550038,-89.601477,-123.240569,-126.16423,-111.909285,-105.036358,-86.579461,-77.701291,-51.185488,-37.058078,-50.655255,-56.801026,-15.115409,89.309822,99.673392,39.492764,13.037932,7.685341,22.906135,55.707336,131.690423,133.549478,122.555792,136.570915,132.43644,101.079114,75.319705,158.993455,229.051786,393.17884,446.352445,426.067621,386.42327,362.313127,391.891146,390.128451,324.515439,299.840781,333.771538,339.737883,221.318108,142.168122,79.121972,130.984579,186.780668,320.482951,347.677426,245.819779,183.436451,217.145095,236.713463,153.022697,-9.442036,10.885177,207.127375,298.512307,355.364813,318.970972,156.073515,55.9416,94.981974,239.938555,248.563469,106.656592,39.818586,1.623737,4.162917,5.547007,-19.623711,-9.513744,114.688097,151.264279,66.267359,-2.499357,-74.857464,-22.435855,28.721802,90.541558,91.043367,47.914256,18.594756,-32.736569,-14.082304,67.393614,255.023376,272.061314,164.288907,96.638107,8.91989,-14.97321,-33.983791,42.22005,81.660205,75.69667,58.193947,56.172388,69.091438,7.496781,-153.492378,-158.234972,31.123897,162.946126,310.852187,287.152165,170.38314,127.247288,80.141738,90.52696,107.499413,160.187269,190.403649,143.381714,51.071893,-134.563275,-185.468687,-157.019165,-57.000627,-18.567595,-0.299368,-15.308805,-47.392212,-44.989055,-17.864702,30.447318,70.898143,134.692393,131.645595,0.418815,-98.956335,-180.46083,-144.143402,-133.283031,-87.484453,-36.002125,39.836132,10.993147,-147.724133,-202.869179,-170.421087,-69.671149,-54.142408,-39.03485,3.969996,35.4308,-21.85146,-147.127324,-172.856933,-157.086418,-36.685909,49.629056,150.773885,144.903925,37.075917,-52.784009,-225.341405,-229.046784,-176.100851,-107.995386,-102.802114,-85.534131,-82.832686,-188.876628,-354.999375,-375.431547,-293.480309,-224.403815,-75.226468,-36.602882,-37.629227,-25.156834,29.674407,91.667319,134.93677,202.389998,213.136631,185.11273,157.633761,139.388783,114.172324,83.428311,97.167943,152.336277,193.557111,108.831819,-162.051128,-242.500746,-265.450267,-228.781422,-202.395442,-156.063816,-131.137554,-92.181246,-91.836255,-85.800698,-75.48057,-69.41218,-2.978508,46.508576,105.002993,82.498838,-23.087096,-42.180159,5.849594,34.807809,48.095103,97.899033,114.398988,118.243514,111.291315,44.252315,-87.689256,-109.646863,3.938961,74.295922,75.841663,35.808019,12.135375,20.40385,15.37197,61.63308,121.712503,223.23355,226.091925,175.54395,174.648338,206.643665,208.775453,206.600971,136.419049,71.243547,34.036788,62.117887,25.397847,-63.805147,-226.38668,-222.170945,-177.712564,-73.331448,-40.923828,-56.933836,-79.740753,-125.861892,-238.426436,-259.448232,-144.870116,-78.028145,-40.382469,-40.414933,-3.149545,25.333497:backward
108.090429,44.535756,5.72908,-67.931982,-77.461934,7.53874,71.980212,147.879511,131.100767,110.412597,138.608897,193.621986,275.07635,257.531364,168.698483,151.208936,161.041148,120.222557,76.491034,26.001056,44.803641,66.136066,9.549363,-156.741809,-266.455229,-288.330302,-255.701662,-232.055863,-247.715973,-277.910787,-325.293687,-339.15266,-341.617213,-287.809049,-273.042439,-282.910177,-262.25512,-128.140702,-38.968259,88.677419,35.162684,-34.807682,-175.990618,-247.20741,-339.808519,-319.87867,-176.576105,-129.645781,-202.183856,-377.058591,-449.804845,-491.996526,-437.135777,-295.58165,-259.490948,-216.684333,-244.743437,-279.664247,-311.075376,-311.938465,-299.975041,-272.652799,-166.957206,-127.096077,-180.904374,-316.147082,-356.155459,-381.20834,-363.589818,-276.390178,-212.919065,-28.57934,75.064995,44.336776,-76.268536,-111.890654,-98.946879,-87.505121,-60.471543,-8.49807,54.390915,-84.637444,-182.386068,-295.244937,-279.289725,-135.25353,-61.989075,-28.996942,-138.525578,-197.386775,-243.18008,-248.864733,-270.230758,-266.539408,-164.194989,-85.371429,-61.570332,-164.596949,-185.230593,-205.855058,-207.956425,-114.74658,-42.251417,-2.664384,-128.181523,-197.70306,-277.012824,-290.118095,-288.450502,-288.803318,-259.727148,-210.264169,-146.79702,-216.216878,-271.442077,-328.127682,-304.047207,-204.76096,-162.311404,-141.204323,-194.78861,-215.054162,-281.003306,-343.302552,-379.903412,-316.879581,-150.720901,-95.754752,-69.76456,-141.472736,-192.081749,-245.612499,-223.638272,-115.554731,-67.731209,-53.55208,-91.03008,-102.365356,-153.680186,-200.06404,-260.264989,-240.43226,-108.308895,-46.674762,-64.748701,-199.529738,-239.609272,-250.61982,-247.75596,-301.469112,-345.342506,-330.600013,-280.997704,-317.037822,-403.638754,-400.205244,-325.343535,-284.846601,-179.240007,-99.814259,11.586108,-55.834581,-142.152569,-246.631442,-201.486282,-33.702255,18.428149,75.539904,76.610853,42.976563,-57.979165,-112.975496,-158.297105,-130.359334,-44.544532,-14.290924,-10.565393,-82.38553,-155.723499,-321.545974,-329.466267,-164.578088,-77.249022,-19.537946,-110.322882,-170.230451,-191.275602,-144.92654,-35.648704,-8.106549,19.837425,47.203377,100.711501,69.135681,24.599933,-17.762349,5.168815,36.699877,16.782656,-28.170053,-39.987014,-41.806412,-44.529402,-44.561115,-2.964832,26.698603,39.337217,20.606037,-76.647727,-185.849134,-225.251507,-284.744929,-290.386235,-290.341626,-302.531772,-247.267077,-84.976924,-61.584982,-171.882195,-219.323133,-199.794642,-176.370046,-160.419782,-154.937734,-165.005036,-143.575703,-127.48053,-207.329433,-258.675139,-244.033524,-211.600655,-140.409434,-103.243496,-154.87415,-321.134113,-364.456991,-286.26811,-189.007604,-69.687423,-82.943629,-102.065943,8.645452,52.337248,24.938088,-13.741865,-4.477362,72.419184,244.788559,217.528929,158.793505,59.52277,23.247853,38.469432,90.362065,167.925614,168.707538,120.383377,82.421498,58.746289,-18.332716,-32.49498,-0.635136,33.364325,151.852544,213.019105,199.333787,169.515951,181.973358,262.38604,288.115782,217.238268,149.921494,75.977377,32.107914,-24.575441,-186.646516,-249.411639,-265.534003,-215.641243,-50.719021,9.562158,-16.82064,-57.318089,-63.883031,-69.232275,-63.666576,-30.466627,2.262677,28.374103,-102.17128,-186.283525,-214.69371,-149.303102,-56.972701,-76.330032,-127.036283,-89.705932,-48.102695,-23.67429,-78.672432,-193.561853,-180.295554,-28.899673,60.380924,192.16709,268.285936,269.253967,175.67921,125.332755,57.479043,11.64981,-100.165787,-153.175742,-168.041102,-247.29289,-283.338759,-232.765228,-178.141557,-108.625239,-74.913931,-18.398224,-46.273684,-84.618475,-151.60447,-139.255501,-29.33558,10.625469,20.182766,50.443258,77.876163,37.416436,-12.618045,13.961769,86.992978,236.992619,298.176469,312.933548,92.53773,-59.705969,-238.895762,-218.896972,-68.056923,5.978702,126.232944,173.141827,176.969463,163.597703,154.957323,204.674258,232.191554,193.315216,174.749167,173.798208,86.115144,45.438288,64.958002,97.396249,124.186385,144.905444,252.441656,268.952859,197.956095,3.877665,-60.631094,-86.781133,-72.251049,11.908005,89.913923,226.026271,258.269,248.410668,244.28563,264.762648,260.976258,208.912691,112.081443,130.946809,159.312123,209.462725,225.032077,223.150025,219.213912,271.244231,324.569766,358.685855,300.76101,308.451164,343.672106,313.323178,210.589089,202.520161,289.139751,386.44219,418.498943,450.961059,463.750124,501.73773,507.070296,489.310916,495.64543:85.122459,29.287241,-2.592061,-40.407321,-7.399538,160.593778,237.486732,265.686924,254.413151,269.274483,238.01533,187.751203,129.539927,135.168826,187.303641,214.970287,144.354461,-136.735187,-268.720708,-287.885931,-179.409931,-32.328486,-72.898179,-232.977954,-347.502213,-388.814697,-425.060361,-422.707392,-395.448367,-381.219303,-353.205902,-342.529066,-358.561189,-395.531201,-420.8592,-411.430918,-337.810251,-128.880777,-46.180739,7.447335,-103.153266,-187.396001,-346.729206,-393.732867,-353.764921,-280.252739,-142.348222,-132.434945,-236.463037,-357.160536,-409.625695,-479.156124,-458.107117,-325.488828,-266.370285,-190.752005,-164.973841,-181.903913,-227.901065,-237.374001,-201.812289,-155.103552,-53.272874,-42.69783,-158.547059,-335.212172,-393.57301,-393.265785,-357.47885,-317.616806,-276.752319,-64.969922,43.521116,-0.98966,-127.395809,-158.740766,-160.145547,-153.183556,-94.412669,-35.460335,21.442805,-85.240555,-196.221773,-431.896251,-461.692433,-283.504833,-150.766835,15.468642,20.491754,8.995776,-66.777713,-129.167677,-152.661998,-112.876168,-44.551878,-44.805478,-155.664975,-286.277023,-313.24065,-348.266789,-346.677032,-268.428167,-232.799457,-248.924867,-301.267325,-323.344159,-422.328829,-481.832631,-452.098473,-360.419536,-202.46462,-170.064584,-170.051153,-207.324009,-228.826771,-257.344712,-243.284598,-120.42753,-36.126993,42.949548,-72.535649,-145.596198,-241.519367,-267.16819,-242.476866,-184.89721,-36.572286,10.411976,-0.568043,-75.293702,-122.918961,-211.660593,-215.842195,-115.262415,-50.247707,-48.267826,-183.075537,-229.736451,-297.964198,-344.19088,-398.154346,-372.54853,-243.346692,-176.314825,-166.688932,-368.197241,-450.008414,-434.527163,-400.238587,-388.985157,-358.991279,-230.487965,-234.377586,-270.860248,-316.918944,-349.786731,-392.823316,-354.084824,-185.249279,-114.939015,-106.822584,-230.650418,-297.929971,-325.998151,-265.253195,-123.135811,-87.033848,-80.939481,-175.101583,-224.107854,-271.431478,-286.180629,-296.976567,-283.447309,-203.82107,-155.450389,-147.898055,-181.8576,-200.124501,-317.03064,-353.814479,-286.074563,-242.242391,-219.050397,-224.65139,-242.468856,-317.074584,-348.844828,-351.297558,-313.528856,-144.803615,-53.568569,-22.478996,-167.725174,-239.151846,-246.353819,-180.263178,-30.466779,-4.808021,-114.274539,-226.440306,-207.521809,-133.314452,-133.910195,-174.027831,-180.123289,-164.780897,-159.22765,-170.528587,-215.45146,-263.140143,-329.372565,-318.100221,-277.697409,-257.43252,-198.036649,-228.313238,-266.838758,-305.314044,-313.496588,-292.038201,-258.657853,-184.790931,-145.849259,-54.371576,24.825822,14.490384,-105.151854,-137.1849,-63.814342,-17.758238,-25.470108,-138.617959,-220.425159,-357.744132,-372.052091,-254.222994,-149.352727,-5.582191,1.907799,-15.161578,68.269458,127.065714,173.687133,151.024775,106.944018,133.309128,220.667863,275.067117,292.323149,194.675287,106.431321,108.967579,206.074165,337.917433,313.545095,211.653617,172.236241,139.669027,90.169539,118.751317,254.773605,328.894547,403.431753,321.156678,264.540338,251.09434,296.000305,343.299708,319.521019,301.351148,313.877158,238.818286,85.573625,19.329076,-129.218309,-188.609203,-173.754457,-90.672451,80.706799,80.888716,58.483838,6.225793,-27.072251,-32.29924,-7.738091,62.510431,118.8155,165.940798,-9.754167,-121.229337,-216.393977,-180.688942,-47.371827,-5.512566,34.393313,72.85127,86.904233,96.413879,85.077853,25.696197,7.529205,109.833653,207.652115,308.363207,235.942975,184.409244,133.822758,142.04106,169.560852,145.21922,-15.36393,-183.685704,-222.35164,-196.807332,-161.00542,-127.351906,-118.509892,-17.853055,44.353504,36.669078,20.90279,57.921347,51.912213,-9.088489,-72.257038,-40.404831,61.016534,108.297104,118.356453,85.776064,44.662603,70.04108,148.474619,311.524938,359.211748,346.662731,221.285453,118.724002,-89.933276,-113.429361,44.991527,144.406088,214.85207,206.392055,231.362785,279.450737,263.362814,228.018276,241.328393,290.284427,311.596054,264.542418,109.429831,51.807572,24.171539,48.598995,136.772306,201.333959,341.519433,299.531824,179.717875,-94.665928,-170.70379,-136.09952,-58.446001,87.039793,111.514044,105.4864,169.343729,201.176976,222.043053,247.145896,308.530415,296.78706,216.347609,187.903542,178.768133,123.66038,93.50966,86.250071,123.259465,254.442369,301.586822,282.767514,259.969027,274.687281,313.072353,344.139526,443.298793,485.034662,474.941817,407.51258,400.83777,408.5064,407.712847,446.672521,477.601304,510.864176,511.913756:34.374646,-87.778211,-144.934389,-152.181945,-83.100854,138.60617,222.917009,214.357875,117.892753,116.619789,140.82399,121.243619,78.471396,80.619564,103.946092,106.480703,13.300549,-177.934569,-256.499534,-277.392784,-208.40755,-87.631173,-104.62943,-233.218679,-351.44948,-394.107404,-418.59628,-413.988314,-420.131795,-417.198583,-340.853533,-293.495153,-301.871062,-347.191439,-338.995457,-275.339761,-229.102274,-125.059509,-44.322017,112.767272,8.297222,-111.332399,-271.71958,-270.829773,-98.057738,12.635908,125.141444,112.471848,-37.406695,-225.5157,-297.869251,-380.761279,-353.67166,-171.134784,-89.553432,-83.303484,-207.043534,-248.71873,-237.824076,-199.973122,-116.707893,-90.104518,-30.021889,19.022006,27.687282,-165.977066,-261.327627,-303.396692,-272.315513,-218.168406,-188.822417,-81.838142,-15.810862,-35.090794,-155.021418,-202.230797,-161.492712,-102.506788,-38.066761,-43.532964,-77.153769,-71.031364,-74.094752,-144.625647,-198.126976,-244.528583,-188.220998,6.419718,50.640162,25.286885,-47.251256,-104.188343,-166.087108,-128.904577,-20.367783,-31.549729,-218.936734,-335.768822,-320.69995,-291.026351,-282.604962,-192.51757,-127.357909,-120.333303,-277.844549,-334.886194,-383.479572,-394.021777,-325.407562,-245.20528,-87.416908,-33.127821,0.008495,-77.934332,-148.005228,-245.945172,-217.683312,-11.864147,107.481416,205.432199,68.375684,-32.534785,-184.649415,-206.863988,-113.084826,-22.446403,122.192745,133.73498,29.391617,-78.777631,-116.95448,-126.365632,-67.704018,80.41227,116.396273,69.799011,-96.078492,-182.412366,-312.537501,-343.347921,-304.140567,-234.807581,-63.917693,-21.480054,-102.652723,-308.319043,-402.283811,-444.703565,-386.606188,-235.502927,-158.633434,-46.767321,-162.380767,-255.516347,-327.153841,-306.7253,-279.625365,-286.582816,-170.374068,-51.289773,78.975953,3.074847,-75.274891,-201.142747,-196.270004,-67.333742,-5.740384,25.965565,-68.982294,-153.511976,-292.785811,-308.069452,-226.441287,-159.160862,-19.459871,21.415371,-48.461775,-183.243945,-232.50387,-324.745614,-341.50598,-304.803136,-280.597943,-186.922125,-71.736164,-80.654397,-243.664255,-311.412267,-299.679432,-270.048668,-197.305403,-135.513039,-79.331799,-206.192281,-273.526002,-238.7319,-139.597932,41.140032,53.07776,-64.681258,-109.25147,-77.453164,-41.998564,-59.685929,-114.309263,-129.947244,-144.235248,-166.603625,-221.498181,-209.084602,-199.446257,-212.90378,-225.71186,-228.967537,-213.521404,-182.690518,-215.455697,-254.987317,-377.983046,-430.261779,-415.974953,-363.34678,-228.329513,-152.398082,-31.611161,-31.075606,-77.089728,-138.457609,-118.910667,-28.043623,5.53326,-14.577903,-139.972315,-228.354819,-371.811442,-380.912738,-267.829834,-193.591437,-112.933508,-96.68327,-47.111036,32.313786,71.503109,119.627761,124.926173,130.131879,141.210398,155.759438,194.983843,210.393961,116.654708,69.300398,128.541094,175.692596,185.488559,165.95846,132.274088,94.649005,72.048807,70.869438,87.136,91.6613,97.280385,145.48777,129.980073,123.000999,206.705976,249.257993,239.858435,224.253767,236.880731,230.590756,114.995408,-18.993122,-61.196091,-149.3152,-204.843909,-216.244676,-140.805321,-6.154307,-2.422609,0.669982,-8.656221,-37.863553,-73.738798,-50.697308,85.649962,155.872309,128.622882,-68.576388,-149.945184,-243.725797,-245.216686,-106.052753,-9.874662,88.249665,88.585902,87.704877,85.61145,75.394567,77.249352,109.553148,220.438468,258.719578,243.455476,220.727632,221.472013,153.042846,85.224385,2.713587,0.546409,-30.476026,-123.513502,-139.539279,-109.124745,-107.12421,-123.202168,-92.775276,64.212175,111.947596,30.045158,-13.504333,36.269602,111.493073,87.253517,-2.872074,4.732399,143.94564,229.101334,197.071575,30.270287,-16.428602,107.543441,208.404787,311.414307,337.553852,383.96915,239.123103,80.307977,-105.90464,-58.7631,136.424333,213.642174,323.773589,360.117497,344.73378,256.548823,214.450174,207.056404,203.760568,153.199467,146.738302,137.450892,23.451777,-37.525448,-13.896901,67.108057,188.218377,205.347399,186.260864,90.834185,39.730498,-73.342188,-122.084605,-95.707857,-34.579673,51.469647,46.515467,-1.689809,52.308778,105.776492,176.680203,197.957717,220.674604,211.747416,161.914941,92.775679,61.790474,30.10366,36.854647,87.08453,125.508824,217.32799,241.604066,245.984074,277.572783,293.285758,309.916366,323.419111,381.953913,407.968325,381.734126,303.806219,285.70476,275.40434,274.318018,326.569762,371.214168,398.646573,378.496134:73.548361,-33.507031,-86.856545,-149.520152,-129.487368,-31.153486,17.174976,115.181265,165.87062,151.284839,82.105219,69.629783,131.791873,174.707749,208.43536,192.053491,82.385543,-75.896222,-129.363976,-108.249682,-42.708324,17.172331,-34.80277,-199.948547,-315.311075,-334.267753,-308.289007,-295.85656,-286.432277,-268.946511,-210.979399,-193.252815,-237.655939,-333.324144,-352.702852,-266.758778,-167.133663,9.351898,58.124288,98.168802,38.35075,-22.694584,-179.412999,-239.988419,-179.769398,-72.426833,94.922273,101.883917,-24.981475,-185.756956,-261.875533,-388.283812,-393.398821,-305.16818,-261.615412,-220.176846,-250.088026,-298.087204,-394.959699,-397.335959,-294.100179,-226.737483,-110.663599,-77.21964,-129.941834,-232.89836,-256.194568,-297.408588,-306.212186,-252.7189,-203.686471,-89.910921,-4.625328,2.368895,-68.60917,-121.707114,-174.986412,-184.983418,-168.502548,-109.669705,19.642003,-15.706525,-90.684253,-254.315853,-289.190886,-204.390645,-109.095784,20.365845,-32.17052,-70.350929,-161.288168,-232.20856,-309.528069,-287.885817,-188.746477,-154.203913,-179.235024,-203.807313,-206.479177,-260.616596,-273.693171,-181.738152,-96.610116,1.118874,-116.447177,-191.920239,-284.266756,-329.715344,-383.642144,-355.144642,-221.980543,-153.643446,-98.430679,-161.283219,-211.939689,-266.725571,-232.969509,-85.022258,-21.094628,8.073616,-95.242005,-152.103535,-235.500154,-261.246547,-190.634284,-86.834763,130.426409,193.473106,187.29527,92.000178,40.771233,-52.584655,-65.491843,13.785791,83.93795,184.734999,112.661383,37.119733,-63.298817,-75.125882,-59.180856,-36.690749,31.805924,50.432381,6.968041,-107.268984,-172.372623,-255.643515,-250.728113,-199.054161,-187.618083,-191.957773,-213.701227,-234.564264,-308.440409,-342.620089,-317.76579,-268.041683,-138.42533,-57.378149,73.599318,41.677549,-24.498671,-93.775823,-54.125311,97.891685,162.201303,224.437017,125.329665,22.926331,-139.532708,-148.523484,-27.461769,35.203946,36.919991,10.906348,20.832382,32.291765,-23.257445,-220.602063,-259.698886,-129.814228,-57.726519,-68.071756,-167.7431,-196.353746,-228.022485,-235.487329,-159.204618,-81.523362,60.919904,113.540609,172.450754,91.33747,5.608056,-88.666316,-62.362765,40.847751,61.465897,17.690141,7.478426,55.948383,131.435945,110.361311,60.658675,76.767867,121.903864,107.178035,12.168739,-29.524486,-44.855634,-122.349475,-144.722155,-151.817963,-167.118224,-178.8668,-124.320167,-105.008705,-200.230041,-309.833411,-447.339787,-417.548209,-249.027402,-178.790544,-155.571588,-214.788601,-249.061599,-306.987617,-301.859426,-204.745502,-139.744464,-52.966523,-86.42097,-139.689437,-255.907112,-308.024147,-320.772996,-254.428853,-117.533159,-100.804969,-122.054428,-86.77876,-40.226096,-10.061865,-43.411199,-43.376208,34.627672,188.287388,142.360852,85.902852,-3.801278,-30.632313,-11.149879,27.327166,85.76096,94.884344,78.569233,22.91274,0.135435,9.654293,25.585563,28.038602,41.772859,131.324057,153.1923,143.151294,190.662493,217.619925,190.162221,160.920956,132.376298,120.086289,45.458511,-49.559017,-96.351671,-217.909354,-268.814568,-279.271195,-225.723726,-43.747812,49.160606,51.250287,39.500079,21.119932,-17.798438,-25.345095,-12.123574,8.698545,11.217218,-74.451977,-142.472148,-274.812982,-275.794418,-131.761156,-60.595955,-12.527004,-3.131581,0.183471,-68.965849,-140.841027,-189.189277,-134.970997,50.412769,147.282416,240.120897,138.637194,67.84845,-19.450709,-31.071514,-20.188668,-29.261336,-125.150141,-212.480267,-216.541513,-214.736438,-224.775152,-218.871368,-184.765189,-54.007758,8.509243,43.39194,-13.944473,-60.389586,-115.773155,-87.0231,44.853188,100.226269,159.947418,172.360715,147.53797,22.139054,-24.993031,30.624857,93.898703,179.337893,208.413456,215.262677,76.646142,-28.697108,-152.661315,-119.772743,40.574675,89.543359,108.505501,158.772957,186.556247,167.842001,152.125319,187.202602,183.675302,75.556494,43.455992,44.300089,-48.614783,-97.355323,-63.473273,-3.773158,69.897531,99.212949,209.73296,215.149891,151.680529,2.636589,-62.397402,-149.587975,-143.712979,-2.453591,87.46908,164.47637,150.981097,142.685887,150.619405,180.488229,227.703599,210.375682,162.199963,183.391535,178.210314,73.637136,20.108316,48.438967,108.771977,224.703843,276.317901,288.235699,182.943887,176.371157,269.9509,310.236618,322.589638,321.255075,364.354469,375.09871,345.843851,310.287778,340.986998,462.551767,483.657999,420.639121,393.976508:-27.329126,-192.693861,-242.697993,-239.358873,-186.897795,-21.872988,55.503535,117.006873,44.511717,3.969002,-47.069974,-64.243095,12.63405,118.819045,272.669301,240.480434,5.885132,-191.95162,-226.086937,-179.477783,-129.921705,-74.097926,-79.359532,-136.582831,-261.42454,-329.386197,-359.083474,-316.296761,-221.493589,-184.424373,-86.891215,-44.371953,-89.833245,-255.592559,-328.045442,-326.064017,-228.652273,-1.180973,70.647581,122.557507,41.49789,-45.917644,-224.914418,-233.75921,-18.204785,113.12578,250.259108,265.312332,171.957778,-66.181436,-176.683109,-276.269182,-265.88553,-187.739337,-133.949907,-96.978868,-252.069121,-344.112039,-429.456463,-426.070549,-368.709426,-308.313942,-110.349447,-17.727076,-10.289066,-189.870702,-264.866866,-289.406092,-265.489392,-232.787133,-195.901903,-55.727366,-41.827684,-94.41419,-191.290961,-217.769837,-246.629847,-252.160705,-187.24113,-128.561478,-99.17267,-119.082624,-112.161089,-138.912883,-169.895476,-171.544116,-121.803889,5.543991,-3.122948,-82.625751,-288.644223,-349.888221,-305.718911,-230.058233,-91.80232,-63.365017,-105.60066,-190.291951,-230.04719,-236.011351,-171.144261,35.727888,118.904941,119.346955,-12.254758,-65.163056,-171.075246,-213.841448,-199.227175,-159.417587,-43.281895,30.157255,76.174562,-103.856334,-222.174728,-283.29004,-183.22583,85.468794,152.214587,106.991209,-45.435447,-101.174828,-155.95674,-168.170302,-78.898867,27.245667,188.125437,201.746302,129.116808,7.464221,-38.097714,-47.076581,-12.457242,84.631163,138.619554,198.796533,83.764574,-9.858551,-146.424134,-176.562829,-154.035438,-93.037158,100.16074,178.710276,132.194095,-126.789973,-222.350907,-245.653719,-209.417557,-111.930921,-34.801292,62.634933,-147.38904,-287.483156,-360.929878,-293.309138,-157.939108,-137.505592,-76.390189,-2.006973,126.617051,109.75423,45.453637,-76.732773,-57.133081,132.763641,219.745702,254.678697,149.153511,67.573041,-102.642669,-132.679581,-18.748129,66.703451,140.192501,116.447424,29.513026,-5.006381,-38.4729,-197.292766,-255.173163,-181.076649,-93.092362,19.492054,72.779689,77.331885,-26.133319,-69.438103,-0.877526,59.470426,149.257894,187.019382,161.428171,-55.265651,-137.424232,-55.072256,60.9494,189.139672,171.07743,59.432018,39.510653,76.494553,103.332875,95.774251,113.281989,122.212558,140.840901,164.792864,161.31667,57.57897,18.732181,28.285596,44.588139,11.312321,-11.993493,-8.635481,-49.359216,-117.145569,-284.693675,-322.252467,-232.705728,-154.70037,-34.585283,-1.296765,-28.628138,-110.617079,-136.497476,-156.807151,-134.919535,-4.130834,85.581903,171.087151,29.055172,-56.187947,-155.897817,-186.863219,-200.940651,-168.702253,-34.535877,29.923411,57.370726,54.426533,73.245168,54.53823,12.680971,7.40789,73.32054,203.050668,175.07764,119.168847,33.571364,44.05266,128.637557,160.746767,185.410721,182.379905,122.273944,14.779177,-17.001729,-8.607435,-0.454714,-4.642321,27.290306,156.361581,135.328375,76.252481,56.225115,111.797765,232.042496,245.305462,179.857551,112.715367,-29.398239,-99.234128,-147.73524,-286.685226,-318.069739,-244.487768,-167.525093,-54.025178,-29.15609,-8.569663,0.988183,-25.020892,-47.24813,-34.910593,-5.965228,-3.781005,-77.492933,-220.131037,-272.761985,-276.61104,-229.230468,-141.637788,-133.245256,-96.225104,15.737372,20.837997,-135.363915,-218.726604,-218.738864,-147.448964,19.071032,77.797545,105.773874,6.482273,-68.0727,-142.200219,-132.300644,-111.151078,-114.65522,-140.968094,-170.25732,-178.825533,-260.13529,-334.501872,-385.470325,-314.212769,-55.156319,39.351317,3.533987,-182.879459,-253.667629,-253.028072,-182.765315,-16.094684,51.641057,138.946631,86.304409,19.018795,-85.189679,-82.455177,64.524773,162.342376,255.154886,235.955512,140.05644,59.100286,-1.452815,-104.211173,-77.35522,101.90306,194.884279,287.31372,252.63662,216.453489,113.046834,70.868216,79.217963,112.24361,160.494932,157.34374,62.018105,-108.643032,-181.655796,-196.615614,-129.244605,48.998198,127.006617,235.499274,196.647638,110.997729,-91.800706,-149.619153,-107.215246,-40.454586,70.15724,102.797576,136.860972,131.489575,114.281128,136.465094,190.92856,234.509886,199.918981,130.767393,79.560487,47.196256,4.682469,10.282574,47.137001,70.774825,200.063904,279.070179,272.016836,92.042394,36.465983,81.744866,149.608775,239.220386,250.580794,282.316365,280.399634,245.217037,215.688697,237.286451,276.176657,273.917959,269.869966,286.378652:4.223573,-166.287804,-280.124909,-390.569072,-362.476608,-256.049223,-221.640171,-151.048642,-81.177166,-52.998393,60.618673,136.388524,197.658105,167.325264,104.526734,110.196594,134.253609,93.895455,62.592146,81.395927,142.525222,189.056136,134.103733,-0.590189,-74.377498,-86.222958,-49.709842,-39.66846,-122.451299,-179.541086,-195.430882,-175.336674,-210.917656,-292.205213,-313.253113,-306.662246,-260.532902,-82.543785,13.242542,119.507814,64.714902,1.523678,-115.538637,-146.306619,-114.467005,-69.714525,5.572524,35.789052,39.86766,-134.107785,-248.985527,-370.820639,-364.275239,-312.910538,-291.569468,-249.41615,-278.368082,-327.26321,-394.938758,-373.126029,-254.194152,-198.908588,-101.824144,-72.948818,-145.708003,-245.368228,-235.878282,-176.403035,-158.744988,-122.193036,-87.95965,-4.501198,52.518229,52.19834,-31.94385,-101.605033,-202.160512,-195.615448,-48.13382,45.179012,87.158278,-40.715106,-83.991381,-59.830302,-23.878247,-9.653916,-24.173988,-12.259593,-58.102737,-152.323952,-368.663254,-435.730161,-419.462206,-334.343568,-128.378981,-61.909816,-24.124434,-7.546963,-2.118649,-38.65733,-36.112476,86.861184,150.51264,127.877503,13.789531,10.713362,28.31856,-25.57468,-160.048176,-163.165444,-100.013891,-78.973365,-41.977275,-41.535579,-72.497352,-125.700041,-112.218075,-26.110995,4.111546,-7.606456,-84.703094,-130.509231,-221.022795,-263.352795,-259.799935,-184.08644,41.986526,129.644768,151.099255,34.222893,-28.586329,-79.207203,-40.498977,61.527773,73.714804,71.367454,101.759911,112.372466,61.372589,15.582055,43.211359,123.420916,243.451588,252.109781,229.126146,139.079941,49.745465,-109.304828,-126.505834,-109.24626,-133.619182,-233.573792,-293.220552,-283.448465,-235.502612,-239.635126,-260.344775,-222.247832,-57.681105,7.683925,11.240117,-17.435085,-11.257965,-2.739226,14.245644,103.113462,148.653223,150.756419,33.960737,-13.896958,-11.91121,20.946128,75.44346,80.406684,81.123964,85.037637,63.053282,3.251253,-40.236793,-149.233557,-175.495461,-110.852028,-66.892254,-48.919283,-64.570507,-69.052436,-55.449415,-15.281524,123.14507,172.832875,202.676651,230.079779,278.234419,165.471106,97.330046,93.266405,142.108231,171.604043,131.167895,100.255426,176.832988,210.144147,263.089148,288.101605,350.95025,382.460697,393.39982,366.344824,274.246893,180.213316,117.782508,-15.36601,-35.84855,-11.122374,-10.077925,4.474822,65.876698,61.121118,-39.524313,-65.885393,-31.78722,-41.415893,-129.580576,-150.418769,-137.770173,-107.074093,-92.031816,-130.308359,-183.495274,-223.213609,-171.016403,5.167472,54.539775,-14.051673,-222.511476,-288.754363,-248.087395,-163.158899,-23.898401,-4.282407,-29.032643,-23.91618,-2.916349,-50.738199,-121.511589,-146.565193,-70.020448,93.155292,121.837764,88.994649,8.25245,-9.647141,-24.201628,-25.544893,23.058726,60.655896,90.925446,47.270073,15.235561,-51.291838,-89.477994,-129.260391,-94.40709,16.593753,-4.295686,-20.286332,43.501287,87.652699,148.524116,168.047158,166.287293,153.428806,114.569665,30.469134,-28.110069,-160.142273,-212.06341,-236.74408,-213.949397,-103.594142,58.023131,126.79818,128.855547,61.2819,-5.18081,32.050627,112.936298,102.168919,-40.184968,-176.894621,-180.363032,-112.622692,-91.524693,-116.204738,-136.54782,-136.423745,-123.898831,-123.299352,-150.938654,-181.164859,-181.640109,-121.614469,83.798839,189.785592,273.37352,186.257324,143.548599,48.026208,-15.762144,-106.423544,-132.493731,-206.60578,-278.328044,-288.476919,-329.804152,-358.489609,-247.385886,-124.667944,-21.305683,-59.665898,-151.952064,-220.509702,-271.746733,-319.751446,-273.909651,-89.907891,-1.119232,96.871284,116.758599,109.206258,75.131288,48.530994,-3.388578,8.423464,127.612153,174.372302,115.621633,-24.853819,-84.172689,-200.35086,-237.199375,-180.371436,-90.533562,110.216,197.732518,179.238756,76.926462,46.698661,93.732316,112.121536,37.020644,-20.539439,-104.80125,-108.232626,-72.288962,32.330037,84.725041,154.70334,162.453401,149.989028,132.980421,128.783201,91.79447,39.48152,-41.132704,-14.425035,140.001714,206.540747,232.76449,189.923278,169.393458,134.263013,117.878513,72.098934,55.102407,78.124678,141.335347,159.828438,116.198802,68.952948,39.379904,80.273146,224.896146,276.41387,226.209658,94.949923,85.868805,135.75207,122.122481,-0.599563,-30.512598,56.129055,101.68277,101.042421,195.229648,273.336316,387.371385,402.9163,364.799306,343.637427:23.401155,-177.752298,-267.159743,-377.472281,-390.457471,-300.844432,-205.88903,-43.642489,-45.622163,-62.147214,-54.211356,-45.735939,-2.360899,53.061504,202.105839,248.020429,181.90015,-18.738056,-97.482972,-128.165538,-96.600817,-24.200578,-5.221501,-19.59514,-138.975838,-199.370808,-189.641423,-146.468355,-101.414193,-78.851916,14.216044,33.455628,-74.468952,-277.727537,-362.777055,-390.840152,-311.165695,-61.418629,48.268026,163.330328,73.155716,-39.45073,-225.096278,-226.832726,-60.837115,29.161094,149.795832,207.476999,227.504913,-5.57013,-156.093138,-298.130482,-271.780779,-171.842198,-133.03638,-110.704137,-231.09036,-317.868201,-408.672923,-394.76606,-298.364989,-229.582591,-56.962666,10.763042,-24.683216,-201.495105,-267.524775,-284.944314,-247.675438,-165.734558,-132.008825,-52.583519,6.358606,-8.222235,-136.2265,-208.778523,-258.42448,-236.22736,-138.635954,-68.707674,15.269922,-43.198374,-95.175773,-159.171432,-147.676178,-74.117633,-33.524951,40.726964,-29.443662,-135.188558,-334.431221,-384.992604,-363.376924,-298.112517,-146.815646,-97.380681,-73.446267,-61.641718,-55.072393,-87.772358,-78.175242,91.695871,187.70858,178.735321,0.22409,-39.896503,-59.479118,-101.546605,-163.513746,-124.640728,32.496841,85.923655,60.932728,-62.79899,-122.251113,-184.721927,-164.806608,-40.259883,23.664567,51.761805,-81.150496,-147.589447,-186.883083,-177.716379,-81.674875,36.848794,263.023802,271.897124,156.956644,115.190774,78.894738,-37.044585,-30.400104,138.923209,231.997663,273.752902,138.284834,81.742337,7.047222,-26.946355,13.603422,109.694569,297.868882,323.207733,256.973083,68.551595,-80.685403,-265.470849,-214.894999,-20.405062,16.378437,-30.528571,-136.253683,-175.79762,-221.27569,-235.46478,-197.534073,-137.253093,1.401933,46.263442,51.394532,15.690124,4.174191,-5.056446,23.057584,146.264862,207.704053,243.819972,123.058961,48.047336,-66.019688,-84.869035,16.687815,112.925376,271.928441,294.808306,198.809423,57.161873,-1.36095,-114.979801,-141.126423,-73.627216,-0.387247,87.709032,3.039575,-45.94641,-66.219675,-57.325699,-6.542351,59.948099,269.11043,343.292611,274.301769,85.588832,31.076416,19.368266,52.45445,130.228058,161.325022,250.454412,316.654037,308.744282,225.584698,179.269462,181.663404,252.073727,418.482116,428.095617,280.956648,169.607145,139.914182,73.944119,59.254782,72.658331,83.933321,113.669831,121.870773,86.765482,-91.265045,-166.744734,-127.581695,-57.115333,37.335238,57.746178,8.867264,-123.894782,-160.262189,-144.856822,-109.924258,7.462414,95.977807,249.828662,166.904098,44.601586,-163.892442,-203.588071,-150.891796,-65.069387,99.950373,105.103156,10.445167,23.929821,40.122397,-55.180982,-119.192817,-106.863093,-26.571625,146.716566,191.284101,156.81575,17.518717,-32.410085,-4.234279,49.632634,140.164875,150.01891,85.732579,-2.767726,-21.118408,-49.195917,-72.562225,-48.494279,16.444033,93.50928,-1.423811,-21.026652,58.006627,84.917941,68.499545,70.077764,125.617069,139.606221,47.332434,-140.910695,-241.479738,-374.65501,-382.562484,-330.960333,-273.953147,-86.267528,55.669405,71.5607,28.627262,6.671148,16.422035,27.638709,29.818128,23.707352,-73.870685,-277.852236,-354.468477,-381.40372,-336.562871,-220.452936,-184.75161,-125.877504,-100.083127,-142.770905,-315.811607,-390.556732,-369.674663,-260.407478,20.20984,106.928298,98.015789,-13.822798,-82.326148,-216.341106,-246.738564,-248.974255,-247.701426,-245.738059,-254.184769,-287.415625,-437.397454,-499.025817,-417.681474,-286.52002,-47.875978,-1.749977,-66.73864,-260.623716,-353.37501,-389.450528,-310.97611,-64.258629,50.222583,187.658642,144.093074,65.899632,-90.157162,-121.670094,-50.902171,18.740313,121.155869,142.455874,113.544599,-12.617864,-88.479845,-197.386382,-196.293359,-93.310755,-32.727741,81.627018,164.41628,159.97239,64.846757,20.1797,28.288154,54.783403,64.307909,42.365791,-66.879048,-187.90972,-207.017394,-173.670851,-145.208466,-62.357065,2.754213,129.446845,130.896982,75.977199,-54.058067,-89.324454,-65.741935,-9.922518,151.735044,215.654821,220.551803,153.546171,117.165049,60.859688,82.61996,189.772711,211.847369,144.322542,62.930531,65.339186,96.105202,96.705146,121.132617,157.696477,240.690019,260.800529,184.554964,28.208543,-4.818136,29.54489,41.027153,36.664408,73.830241,213.290128,217.364309,155.448421,59.869162,81.487301,217.939509,247.66424,232.520756,257.300111:-148.590211,-233.990525,-299.588701,-386.264047,-374.246026,-317.273135,-302.39184,-260.230314,-167.93035,-114.24741,7.917969,59.169708,68.396548,29.275593,-45.765156,-47.081379,28.774384,156.413663,196.920332,213.688195,223.409777,280.168891,303.725821,292.627472,266.287001,262.088543,187.667221,104.639573,-30.903031,-43.376675,-21.395191,-26.649895,-122.646567,-285.256016,-334.228279,-327.051256,-287.826996,-198.066266,-151.28183,6.335592,158.749256,151.322982,18.188377,-21.45903,24.891811,42.939923,-46.862108,-95.636227,-85.201607,-14.145936,-0.14342,-70.277873,-114.387733,-116.508068,-104.065183,-131.519459,-172.741327,-165.269599,-110.859142,-80.056489,15.889946,75.325519,157.840341,184.122073,184.593381,106.149232,78.98746,97.743426,128.172463,142.204913,135.422237,206.42291,274.204495,259.604306,189.580867,145.55902,29.417471,-18.428434,37.295881,125.081646,199.467538,164.757813,175.497105,190.428287,165.191819,58.346927,-7.94232,-96.9425,-122.874439,-137.758649,-201.298011,-231.151083,-201.06343,-143.248177,-16.843223,38.025636,141.900805,269.035929,319.340384,339.921445,352.270308,463.441476,499.087854,409.998135,329.61949,349.253852,394.724342,386.084471,331.178723,288.764023,179.039531,139.221084,106.86073,89.848762,82.34138,70.864135,67.670012,61.590036,55.719321,8.242422,-77.881765,-97.34388,-113.611016,-151.465047,-224.884153,-191.925981,20.877828,133.123736,226.434952,182.66055,145.91595,81.812307,76.895363,96.202387,99.998923,126.90379,137.196842,109.5118,31.52235,19.781124,127.663597,229.397112,365.741189,376.061686,363.968471,358.153654,332.145855,186.364544,110.292575,9.437563,-69.067366,-261.443803,-273.538332,-213.740756,-99.232329,-88.249914,-149.621879,-161.20855,-41.38447,45.421749,108.330549,97.841841,121.954242,181.427878,193.454886,212.021882,234.855833,262.1025,214.121642,207.520572,238.330149,223.048906,146.229329,123.354545,108.986179,115.715596,114.014173,-9.087921,-93.980685,-190.015272,-184.341632,-93.628882,-41.960053,-3.183198,-27.931816,-29.428721,-27.096938,-34.025241,28.766808,115.523656,251.701336,265.475419,270.428552,263.963941,259.206003,290.838175,302.607758,240.573118,190.840245,189.158674,319.062329,375.198117,355.88073,288.59629,248.441322,321.562197,485.321512,498.830133,392.763364,282.689211,244.758857,128.849409,94.124446,156.709755,197.860237,208.679648,200.818318,206.995915,189.456361,138.754589,8.418172,-21.530493,0.960306,17.10218,-14.206282,-34.236208,-28.502088,-115.354147,-185.14198,-191.733219,-123.667665,-9.83904,-35.37182,-74.326693,-179.658859,-234.633239,-246.113646,-208.567757,-167.42015,-159.534281,-134.897639,-134.083284,-148.436473,-240.767829,-284.789373,-239.646562,-170.405274,-56.392373,-37.533074,-45.426439,-32.545483,-21.828374,-21.644479,-19.466763,0.123249,6.104712,1.516271,11.589154,10.767543,-44.785545,-77.147782,-107.276756,-102.581157,-45.046768,-1.716473,7.616112,35.539656,47.901383,112.252653,175.111827,258.024341,238.141938,95.168595,-30.010213,-49.919051,-69.802702,-99.686687,-171.131397,-180.241529,-91.686562,90.536863,158.211597,137.802405,63.553184,-51.730164,-51.265501,13.227263,22.259126,-69.913788,-166.549352,-176.110478,-185.488078,-182.292788,-119.545141,-96.004696,-97.369006,-65.452592,-46.636209,-54.183158,-66.889416,2.423514,82.943818,175.417974,166.562458,129.918152,109.816524,75.52766,-56.8022,-115.522628,-165.93746,-168.760043,-141.907353,-76.109164,-54.565045,-110.26235,-154.18613,-121.135197,-55.793711,28.100045,18.922604,-88.987141,-230.510682,-280.64963,-337.23116,-328.988143,-208.272565,-124.930978,-12.630319,-20.442135,-52.05536,-117.769593,-138.509728,-105.702727,-71.320415,-68.13112,-85.73606,-92.651437,-85.321619,-101.720593,-204.70032,-247.729129,-211.36905,-154.770693,-4.575275,150.476895,168.834258,32.62614,-64.273646,-156.470709,-162.376833,-153.385267,-139.966944,-138.768515,-153.088159,-144.153975,-97.432986,-69.325241,-40.097871,-27.57024,18.927874,23.981052,19.389927,25.200087,3.046726,-81.806879,-94.797619,-42.280169,4.955927,75.837231,40.663012,-0.480627,-95.674093,-140.197744,-204.698175,-225.407378,-197.903399,-89.0997,-64.365144,-125.825731,-172.202241,-193.932912,-171.276977,-107.585456,-89.885305,-143.759556,-230.730005,-247.672572,-297.503868,-339.966495,-403.046523,-416.754915,-392.367211,-276.68989,-213.618195,-107.745,-43.691489,138.252061,200.774053,136.749869,67.928812:74.607251,-54.350496,-103.842725,-162.54579,-162.527823,-114.143958,-98.569116,-109.254801,-110.899898,-77.068865,49.021602,90.33136,85.174335,66.974738,70.832406,99.624102,144.253916,164.82783,177.365116,208.708173,235.234511,257.265492,227.867275,134.473793,86.638554,87.171608,65.1911,21.217248,-72.722924,-111.620576,-204.338658,-232.39,-229.449748,-246.621715,-256.406505,-187.420493,-101.773907,73.97629,127.315982,181.497702,202.087958,198.615029,114.089461,29.926557,-79.908496,-64.143926,49.094233,88.229331,14.058256,-127.53691,-161.318438,-217.819243,-243.669897,-214.328447,-150.942993,-19.309096,-40.915658,-79.721846,-74.518517,-35.515068,39.454291,46.893699,2.918998,-6.161132,38.418499,36.517879,10.52833,-28.801764,-28.630488,11.571469,60.893721,226.514593,297.859361,268.039139,145.770501,77.758444,27.85573,34.140258,59.805693,114.341853,217.819065,138.106685,83.714523,13.69658,-11.33082,-46.273666,-59.173183,-90.679541,-159.493141,-210.356033,-284.859053,-273.226487,-156.409098,-96.317641,-32.168051,-22.342936,-22.699119,60.897732,119.784938,136.907625,130.461696,244.245922,322.805579,331.286944,255.545572,276.711898,371.296173,365.19142,230.445371,166.892446,138.36922,148.522691,83.565408,-59.61488,-84.041071,-33.816936,5.669325,30.291591,-5.610443,-104.8222,-130.165953,-130.655299,-193.827172,-247.178,-254.365479,-189.261646,-44.119489,-2.207295,10.4388,-41.695534,-78.175986,-97.354042,-47.297033,54.858486,56.928179,58.099702,97.579735,91.262653,7.624441,-41.887978,-70.889753,-38.944915,64.885012,109.228144,171.055548,198.931676,193.21654,119.650672,61.094337,-54.885596,-113.830125,-192.649809,-185.168843,-168.501519,-119.389813,-105.560365,-127.057329,-128.064367,-31.408609,46.184299,124.243817,68.563243,27.299106,7.678521,39.684374,96.991471,105.734656,127.669341,153.209913,163.930626,127.453246,60.569525,-43.019529,-37.233699,1.925238,-1.87034,-42.797285,-123.734513,-191.250436,-278.850049,-245.13266,-120.369221,-92.438394,-62.194191,-41.996933,-48.939094,-81.607395,-75.386528,52.96309,146.414139,271.974133,280.949561,240.600716,273.31037,313.662363,332.985127,299.190693,178.62978,131.915502,119.486722,109.492437,117.314649,201.537598,222.603247,199.553511,202.68788,244.990851,255.139878,210.41412,130.905432,86.010006,-50.281332,-101.857524,-104.869159,-88.933089,-51.831551,-6.994101,0.725069,8.596885,11.250853,-25.634847,-66.943505,-142.173305,-163.719077,-161.072867,-72.190711,-58.945733,-205.124803,-297.308606,-348.991107,-316.261776,-216.450918,-204.583135,-250.050623,-338.70896,-347.262595,-299.917381,-266.229172,-197.082992,-164.754051,-167.259024,-196.756192,-188.741646,-197.127148,-208.978338,-151.466649,-79.962292,45.326367,53.749495,12.699672,-131.322974,-194.94798,-204.001814,-166.740302,-92.352114,-54.910428,-9.614306,-39.927237,-69.664143,-126.097633,-150.59626,-201.630834,-184.949709,-43.716296,-46.562199,-87.068542,-41.787401,17.414284,88.502445,119.148,227.092241,255.716296,114.775445,-69.511399,-77.872002,-55.794719,-91.497078,-221.056786,-251.330923,-140.22872,17.56878,28.388692,-61.270914,-117.674701,-162.977891,-146.654128,-88.866546,-82.581818,-161.052729,-229.657809,-222.225458,-144.688688,-87.272447,-51.483822,-88.041214,-120.74409,-58.070915,-34.872253,-51.015019,-99.883617,-169.558133,-125.924814,44.700983,100.724509,116.152463,115.67165,120.463947,89.396816,65.108978,20.441746,-26.426638,-138.733658,-128.177975,-113.400729,-186.135049,-227.578087,-150.826552,-74.692054,-26.499524,-37.074785,-64.632189,-149.624061,-216.661111,-329.800939,-321.518691,-171.53284,-97.33665,-57.199033,-120.445608,-147.473097,-154.879629,-136.567423,-18.557915,44.982986,35.146319,-9.515767,-61.694906,-142.297896,-199.206072,-250.258113,-240.712443,-220.635527,-194.539893,-26.788198,151.892263,174.686249,108.775412,73.690562,50.904084,28.376398,-33.906416,-31.345421,-6.255802,-34.444495,-38.57254,19.534592,68.342591,99.287285,64.628231,13.021315,46.958377,49.144297,-33.124942,-101.558898,-199.031808,-210.848298,-162.610863,-104.415372,13.228035,68.864972,64.863106,-3.575106,-50.256674,-157.879099,-216.006252,-287.867159,-228.678716,-157.999284,-36.424633,-17.661727,-16.873884,9.669122,99.392421,128.189154,87.051969,-27.192662,-48.839166,-78.477469,-138.463813,-311.86767,-359.564366,-264.573868,-45.650253,34.599963,114.158214,146.348573,278.77051,343.622464,342.479888,303.102652:-97.777743,-234.586638,-304.652955,-411.581876,-424.156605,-356.003448,-310.049358,-262.038326,-206.832653,-162.179456,-99.241939,-73.457245,22.916635,67.651508,75.719352,61.392379,66.273106,73.503648,44.862579,-47.813979,-55.577938,10.013921,40.49409,73.363526,36.26475,0.779801,-0.044523,42.718029,142.197535,149.750099,28.428178,-58.635805,-190.156402,-268.601205,-294.730876,-309.399172,-286.382976,-198.290377,-141.295225,-13.438215,22.027423,14.135835,-14.691861,-49.442728,-49.385952,4.435153,96.96551,119.701194,164.448832,156.864159,89.189332,-150.393221,-250.957938,-290.780942,-256.16173,-215.951597,-260.664613,-277.740735,-281.118204,-267.766082,-175.910591,-112.252131,28.154684,93.166223,104.554291,0.587404,-24.212445,6.137464,23.748026,33.03666,39.811823,25.759674,-61.601774,-90.966411,-88.544674,-84.445519,-73.632147,-66.739277,-65.516181,-50.712435,26.208968,102.969738,86.35363,-48.335821,-58.651575,41.229989,53.874886,25.836769,-19.253717,-77.553793,-203.931151,-232.920207,-202.740783,-173.541426,-110.637747,-46.89229,104.933146,144.914416,125.044076,86.874323,108.144301,253.782546,333.413439,370.383161,257.867103,194.512294,108.091564,80.325699,49.336009,46.663831,28.105521,16.888251,21.210602,6.34434,-28.660244,-99.873227,-90.014479,11.699177,52.572624,37.134012,-37.366847,-81.789808,-188.547836,-219.549502,-150.598377,-77.58169,52.466967,106.311653,152.104981,93.126958,43.869263,-23.445474,3.51496,148.086094,195.540035,192.445225,162.611307,162.733063,153.78933,152.786714,234.385858,284.734589,288.95439,279.840669,316.181031,284.523766,219.412166,57.822284,-23.344594,-162.954031,-197.304839,-190.698355,-237.524969,-271.347229,-211.010555,-143.936176,-100.095486,-116.479253,-105.65297,-71.437953,-16.315302,15.751101,40.868456,92.850369,95.521825,58.039168,58.002976,117.738879,153.752301,167.674902,211.715421,215.10587,159.523776,140.282123,174.07998,191.762508,167.39725,105.75292,64.722742,-14.915803,-20.676489,29.993163,44.323667,33.671125,7.382309,-15.171128,-43.895699,-25.179264,70.341112,113.276808,200.867965,268.992205,318.791389,137.466304,59.42089,66.434433,96.425582,75.070458,67.585598,210.696869,369.205586,372.731781,325.801267,312.675857,285.233582,287.977988,366.538326,401.78446,368.30423,272.707094,237.385103,202.902022,200.909528,148.290114,92.462459,73.927762,183.48188,206.414839,139.493858,66.649636,-60.918122,-64.119413,37.103201,88.616891,113.379808,44.981002,-5.297286,-114.788297,-158.048163,-137.127794,-65.957336,99.913636,115.464255,52.004733,-82.104201,-129.477385,-207.305223,-216.869951,-136.718215,-78.85578,-4.378528,23.262743,1.960197,-143.058381,-214.061059,-215.475799,-155.511221,10.078049,128.522881,139.489583,106.120608,75.217559,1.626825,-7.650344,32.573086,33.064973,-30.961646,-51.680026,-42.073256,-70.337508,-98.931871,-120.762267,-110.239639,-49.354484,4.774368,25.307343,86.36846,110.604744,133.226885,138.454664,155.732815,168.634124,138.816178,51.728246,-0.085985,-145.562253,-201.491584,-193.446816,-153.393632,-54.406989,81.727569,145.324969,155.228761,86.892945,-25.785808,-9.900597,57.839294,27.726532,-182.688547,-284.724598,-228.34389,-132.162392,-162.540736,-235.486055,-216.986592,-85.281391,-4.572238,-38.647877,-140.430121,-158.135918,-165.194331,-153.503712,-21.709403,70.694043,106.810577,-58.298781,-136.212945,-222.432558,-235.378857,-227.716534,-216.1821,-155.610039,-62.951075,-59.469934,-170.77732,-231.069857,-239.895172,-189.078509,-33.184719,18.710424,-89.253509,-271.642339,-288.315506,-238.182305,-205.293904,-149.97339,-111.142723,30.104133,123.17375,118.257564,36.928936,-26.605578,-85.897219,-60.372538,-11.549987,-16.63709,-43.866521,-34.939531,-47.866965,-167.745348,-206.493226,-107.661967,-24.400738,83.793937,130.214566,143.33952,123.518852,86.268925,24.014347,-0.818234,-55.862309,-84.165765,-162.359774,-225.325137,-235.411102,-218.363114,-181.30534,-40.248757,30.399314,83.264044,55.912856,48.177899,39.79985,17.657043,-30.935511,-24.819697,68.424394,123.548857,122.937316,19.533321,-15.261583,-23.687447,-8.434936,-14.627049,-40.585592,-24.370672,100.596285,138.612888,96.321394,46.631372,32.551164,67.579819,92.531818,73.642553,21.403499,-7.37019,-5.130548,-66.888549,-131.048261,-170.10494,-137.907051,-57.655626,-27.592046,-22.386527,26.831378,56.942578,117.827301,154.048087,226.104352,257.718457:backward
-54.543861,102.750795,177.615242,324.001846,371.610893,354.381237,293.513915,133.115493,73.571294,84.480102,84.179927,85.028291,141.893732,176.102938,207.655287,221.433664,290.231262,335.008988,322.782246,301.356193,308.485119,324.904107,317.205039,192.981379,23.303877,24.121452,172.755868,249.941242,323.776951,310.732064,240.419034,223.03874,259.545985,289.872472,245.487485,118.043553,96.379109,75.010371,24.535303,-92.290566,-76.256349,-21.424943,110.027977,175.156095,240.420331,223.482485,136.91625,79.585487,-26.361128,-18.829813,19.409392,104.252366,145.126958,170.684691,139.173226,71.968432,218.525218,375.964516,584.492456,576.318908,433.139584,355.043706,304.893275,330.332407,336.81704,247.983896,215.766064,186.669998,154.237091,38.800735,-6.174881,-60.030636,-152.00295,-187.992151,-130.073513,-32.131666,144.170304,167.531336,158.579489,152.223506,102.270868,68.346603,87.236414,144.712968,143.558178,83.915551,59.986202,14.136732,-8.382381,35.055645,152.104169,190.312318,261.438727,295.085609,305.739752,257.163896,106.969118,82.215991,105.541878,132.541277,145.319158,180.576619,164.854079,69.207664,103.449596,164.29276,218.553224,222.240446,306.519815,387.942532,504.787806,492.105675,364.763715,293.076281,283.120628,249.782685,210.436533,75.471421,17.637322,0.17122,106.709912,175.89023,220.293943,193.945061,146.897373,139.852314,119.898184,92.562061,48.261086,133.306533,193.998098,231.99612,206.33219,99.107924,33.4003,-58.579269,-44.173468,4.665405,127.776595,165.417853,179.396578,182.546011,176.138718,131.35457,8.569253,-1.679756,9.954769,-23.956788,-61.538802,-101.931888,-79.599935,4.045903,56.164118,59.006616,21.149342,6.264925,22.366461,38.911152,48.265789,37.923252,25.155231,59.463768,101.202792,251.295255,301.307102,211.789978,119.755877,27.34564,62.067019,94.759494,158.799503,178.818383,141.521349,74.846234,-77.569659,-131.561223,-177.535153,-145.228251,-125.923344,-83.550517,-53.278394,-29.013223,-47.743717,-88.541749,-39.547478,8.32164,99.455537,148.737826,233.672532,238.848199,146.904394,69.201794,-54.355369,-34.193842,33.354319,166.957187,169.386351,39.032587,-27.064081,-44.68051,58.762195,132.850701,245.32841,262.417188,255.823085,236.324804,153.05936,113.343628,95.326705,127.042858,142.061535,143.901806,120.376413,54.331513,11.704534,-104.867208,-143.008015,-112.383888,-73.805702,-103.1681,-193.960002,-205.746219,-163.082058,-156.856469,-213.846603,-251.320268,-253.905289,-263.739377,-259.440104,-179.901375,-119.02435,-69.398785,-107.929665,-98.95431,-10.180499,22.819872,12.048073,-13.936717,-83.896769,-137.933081,-243.016535,-220.957044,-179.607241,-146.799348,-162.913381,-214.715753,-218.268092,-184.359657,-206.190852,-212.29078,-160.57361,-139.760441,-143.089617,-142.434371,-124.825442,-129.45023,-144.034507,-98.164305,-66.834449,-15.00706,-11.132306,-84.23469,-138.755341,-217.74981,-200.433726,-156.185881,-99.915595,-104.133236,-107.661402,-99.346731,-121.19753,-152.760129,-166.947989,-78.116019,-32.89053,31.183542,42.890044,-7.117227,-42.854795,-85.429176,-79.789974,-61.986245,-101.217829,-143.092332,-187.691803,-214.888725,-304.546779,-331.370198,-256.304576,-114.776355,-89.295912,-89.787321,-76.432823,-34.994738,-62.711241,-241.361974,-284.483444,-204.633568,-59.291295,-69.882799,-244.800785,-330.440378,-335.872732,-291.560109,-273.42068,-287.517027,-243.47614,-98.707032,-52.607418,-19.491425,0.43634,38.098557,11.209659,-22.876675,-93.998795,-102.967756,-54.27748,-33.588867,-49.397078,-75.565918,-92.431207,-9.449719,29.231028,41.456626,23.456554,-66.942592,-131.446521,-236.798889,-234.932418,-185.315191,-77.754292,-54.724274,-102.809533,-149.270486,-127.053941,-53.511641,69.908831,114.935428,126.638686,151.168701,156.357322,112.115372,75.636542,51.779165,133.171312,203.129429,283.153874,259.258011,195.16368,212.933292,290.774553,287.664989,185.632457,114.367873,109.208554,108.605992,94.891952,51.367836,53.624633,132.147374,161.415369,112.425669,-42.955179,-84.93086,-63.754518,-56.566038,-124.534435,-175.752495,-229.367335,-210.861199,-191.199855,-137.033557,-123.404985,-147.375046,-148.222674,-112.012968,-95.102835,-78.731243,-27.621764,-20.496704,-119.923709,-202.58264,-251.631476,-211.554368,-112.301263,3.426914,35.141212,-4.9746,-52.414423,-122.000549,-128.306867,-113.754692,-125.56395,-150.550224,-193.815102,-187.903435,-173.030204,-203.797682,-291.197055,-311.951277:-4.638503,132.505058,222.967251,380.257113,410.796434,380.329603,340.471352,233.023866,205.464688,234.961638,295.389394,337.666703,403.18947,389.747619,376.448072,412.249633,508.828808,536.619736,515.010502,460.317858,432.608915,326.934717,238.036781,73.444383,79.068906,126.841008,244.063396,320.415756,410.174839,371.972048,223.00472,177.394888,181.688498,203.655019,187.581491,140.732084,125.069871,70.431851,24.846501,-41.599014,22.218675,81.228835,188.644553,242.129199,279.687749,228.911887,43.303656,-30.201776,-64.51241,-11.58737,25.467309,74.028635,75.270719,74.984661,77.41909,58.71776,84.948364,155.97014,346.855879,395.116335,323.546146,252.191779,188.071665,195.376953,217.162367,259.706875,294.449348,327.138626,304.131594,189.7485,113.724837,-23.444244,-46.393744,-6.62479,139.021807,227.459264,304.601654,258.481398,107.365093,58.944687,68.487573,164.546751,193.180384,202.344762,197.36422,135.026437,61.687713,-99.527024,-115.551486,-82.073435,-10.411245,45.931363,185.864649,216.526853,143.878449,72.211572,-13.225975,41.515003,76.812417,101.479898,107.456432,103.770952,69.433805,-16.416617,45.752554,145.953668,334.709447,367.255606,341.567424,338.835829,348.537713,311.541898,209.603623,206.668555,203.355427,161.981449,143.465658,80.424368,39.029594,4.72199,91.257926,160.377843,239.211242,253.916568,259.299718,226.625087,123.232404,81.518868,39.74243,84.144279,127.711532,193.006983,177.80111,47.293747,-15.566699,-56.464687,-0.649204,51.790135,167.412805,215.022097,241.483641,211.379879,128.211328,96.959372,61.930089,87.585245,108.216788,78.138484,26.965271,-79.76762,-113.463014,-97.828099,8.612517,41.68952,-10.582229,-64.311799,-129.495342,-137.626152,-101.798938,-58.552001,32.163567,115.250984,159.367975,243.008186,261.475248,204.828255,149.567736,45.725637,-2.977764,28.999191,148.18565,165.796266,36.870539,-59.058725,-151.62956,-159.524345,-173.02971,-137.676461,-95.587371,-29.622826,-44.159871,-176.12865,-244.692431,-285.259268,-154.972193,-63.623884,62.941638,106.117964,139.462333,112.887845,-0.400446,-73.428049,-195.160172,-187.774127,-126.344824,24.750754,47.69372,-46.151834,-96.484908,-111.520255,-91.722713,-55.296514,101.390149,157.913467,104.353035,49.907397,3.383535,-7.464268,30.040705,148.086632,174.56892,110.535672,45.346955,-50.585471,-70.845852,-108.056486,-150.314779,-153.790969,-146.196451,-152.069287,-159.41589,-150.917854,-140.965525,-152.101386,-191.262659,-202.534653,-195.772689,-180.473157,-167.510011,-119.641532,-95.877344,-66.205977,20.204799,96.12171,210.727657,226.490585,182.350197,123.759461,4.225868,-21.049447,-18.890471,-23.079712,-13.28324,69.83184,78.607182,-92.392321,-200.993088,-277.178024,-211.899097,-173.69276,-90.972857,-53.628877,-96.559737,-170.717665,-216.558488,-161.714402,-59.180809,-26.404851,-2.05751,25.683153,-1.436427,-106.507809,-141.131823,-155.683979,-193.824142,-201.909318,-122.59412,-76.770409,-95.76061,-132.298435,-140.22518,-123.890687,-109.295011,-95.137551,-83.65849,-28.410527,2.268734,-39.656477,-112.348608,-236.092888,-208.998982,-161.604713,-133.903744,-157.134767,-209.25019,-236.76038,-318.994318,-354.429749,-327.371835,-195.131739,-148.081155,-124.425381,-127.169509,-126.74211,-133.125912,-187.56779,-189.634222,-126.739477,40.270845,61.846789,-62.910894,-140.503954,-188.032621,-169.938245,-125.662959,-71.053207,-44.694299,2.553462,33.753575,78.032296,68.488115,-21.370546,-93.663527,-89.303855,-19.582445,17.624962,15.475186,-19.215628,-98.684356,-129.990515,-123.131334,-7.93221,56.515963,125.408394,119.825481,89.426655,77.590084,-18.143791,-113.129105,-90.291177,10.095645,13.63301,-124.399149,-187.607909,-113.685466,-15.695967,127.49322,130.491041,107.72897,130.452103,157.384309,79.397167,-16.809798,-129.961628,-50.859707,32.256588,155.849168,166.192567,183.967493,227.139143,256.626229,203.999003,112.237915,139.852947,144.513426,93.686352,57.8852,-10.220903,-44.889479,-104.018211,-77.693111,-44.574723,-55.74292,-92.094022,-129.312525,-140.681984,-226.280042,-283.437101,-320.210979,-287.123989,-268.199016,-197.500688,-169.657826,-186.580744,-193.551899,-155.815085,-110.433488,-83.799172,-67.87172,-92.173068,-152.331923,-171.724369,-219.957121,-259.856498,-298.53699,-198.792919,-144.207846,-108.279655,-104.815224,-82.022444,-72.726835,-98.266867,-156.48418,-185.521997,-193.915599,-151.179394,-98.255229,-158.359566,-341.058687,-368.519241:-26.088377,142.350832,236.797507,363.877325,367.895222,277.778484,227.904846,191.134751,224.676101,245.480861,321.469358,392.928575,484.919228,462.038513,357.433251,332.952803,389.126378,492.212155,511.804178,455.384791,400.152679,295.462625,241.152325,99.253348,89.539058,167.20303,302.122182,326.510593,324.703407,299.347238,239.155114,231.96974,259.32305,253.587114,223.855823,177.697107,174.166032,156.2753,121.453372,31.443592,53.289291,111.757872,261.578338,319.057284,311.382491,246.13789,48.378897,-61.501067,-172.270342,-88.480382,-31.456317,46.653072,57.837471,7.25581,-38.954278,-78.418773,-3.605317,59.092216,218.753222,273.320385,197.128644,98.777177,3.992204,44.372755,182.630866,211.753904,201.928312,210.777106,206.947705,122.287348,51.702308,-99.320755,-131.240065,-64.296468,148.005624,239.96019,285.329017,243.073037,97.244856,19.130079,1.759505,174.622859,231.168693,199.580346,155.832655,65.989964,1.383203,-136.444012,-153.992259,-109.98262,38.799229,114.428359,163.732404,128.641143,2.619505,-65.614571,-134.721812,-86.276425,-50.2534,23.299237,60.691839,73.039054,27.422058,-93.770098,-34.972801,88.560917,314.698898,329.072447,221.403206,184.692462,181.039448,168.271396,118.645406,159.882038,196.993278,184.368854,135.336972,62.213215,56.049299,21.1351,11.508846,68.798222,184.177265,181.20191,88.966268,37.46241,-29.990646,-38.695835,-30.610989,18.059628,50.827974,49.220824,20.402376,-27.614413,-58.81469,-143.412649,-107.762865,-21.316431,169.855646,219.818284,212.864189,187.778196,122.012289,72.162062,-3.40755,-0.413053,0.188485,-20.83401,-33.151659,-28.200135,-22.785791,-82.988513,-128.462896,-98.322218,-35.929242,-40.371504,-89.622198,-103.502813,-73.417234,-46.454102,11.769087,127.658423,191.761082,253.285305,244.249454,152.85497,82.267642,-24.186495,13.031928,79.666179,184.835903,183.839878,75.344251,1.171322,-76.697058,-82.011967,-96.804406,-92.114005,-70.851344,-16.221342,2.406168,-36.94708,-123.037848,-351.335917,-296.681205,-152.316138,58.001473,72.623721,39.024095,25.016026,-60.348741,-145.837732,-257.980047,-164.587994,-85.710398,-10.819768,-37.470561,-147.851015,-186.766756,-196.140028,-139.299997,-77.19544,129.37339,235.189631,286.197886,233.429472,133.046535,107.666811,85.052058,96.831211,125.884274,177.019171,144.135034,7.802932,-35.361632,-70.340722,-119.487329,-134.896201,-127.500705,-129.322073,-163.515567,-173.96441,-162.662918,-168.966596,-208.067245,-190.532923,-174.630035,-148.560084,-118.832611,-50.208102,-35.119928,-29.848924,-19.00523,4.738512,134.556462,215.59987,262.593567,214.617345,40.842674,-46.318311,-85.379114,37.61431,82.910204,45.250339,-20.844955,-168.891132,-244.037807,-369.267792,-297.670963,-194.964031,-54.32472,-46.744111,-77.461083,-89.784412,-137.134913,-170.14928,-146.81896,-59.878156,-59.078937,-118.618541,-140.484675,-154.586737,-172.018229,-208.158579,-162.609764,-122.584292,-50.039815,-20.130355,30.594047,45.113997,-10.596505,-87.42826,-199.514869,-106.3389,-25.324476,35.026108,-5.777166,-113.977315,-139.952841,-142.60492,-96.278397,-65.517311,-27.634008,-37.151203,-138.091307,-225.413902,-429.126399,-499.014927,-453.102188,-221.743354,-131.637787,-121.161466,-165.831765,-210.335614,-205.790403,-214.869617,-183.759065,-125.925451,-1.52825,21.453965,-39.557784,-95.605091,-178.069594,-186.981827,-134.040877,-43.790122,4.162463,96.768932,116.987272,115.726052,112.664711,92.496409,121.519467,165.173262,204.898595,175.326298,78.462198,41.262105,-24.630538,-61.708463,-76.646115,26.717694,78.700095,108.857003,90.730828,33.69759,6.063722,-64.470342,-108.522337,-104.772591,-81.484914,-67.818129,-11.605486,31.223846,81.250696,73.600146,67.266252,94.466819,96.499014,156.338374,189.314053,59.939303,-60.941622,-168.399745,-60.078373,33.864877,179.163981,191.333395,150.571409,168.488876,242.212847,213.366748,69.462235,46.183567,66.765327,64.144143,34.981108,-25.181787,-38.087549,-31.059287,-14.154886,-21.77534,-47.15892,-43.82354,-65.362248,-106.536947,-199.5132,-239.955311,-255.84317,-231.08625,-233.080177,-233.131745,-246.092541,-281.252088,-250.503636,-125.965562,-79.019337,-60.654164,-0.384809,-0.79686,-108.77876,-184.852446,-266.679024,-270.483929,-259.059684,-178.293006,-109.804715,-10.463734,-19.803319,-136.221128,-180.913388,-190.591634,-158.942844,-119.518235,-9.251131,19.601742,-46.552362,-119.265427,-247.285452,-281.737915:64.787309,211.593886,251.951639,295.81829,301.698392,261.889043,227.126323,144.756213,112.802884,143.71634,227.76031,248.985185,241.894291,233.070032,243.238465,248.940758,255.340263,257.986899,259.447939,325.762681,374.792777,382.592635,338.421701,229.471708,140.758162,129.8969,205.886802,275.726604,375.783277,370.770808,308.290885,296.926746,307.254868,277.292105,251.740379,259.034391,280.017999,252.300815,198.987248,71.624905,10.78332,29.947606,156.405963,230.151173,291.903225,241.242289,12.71584,-93.627041,-151.940247,-67.41274,-28.468089,29.82601,40.067005,-3.319131,-31.029715,-21.630087,119.319082,223.36856,388.682768,422.011512,399.398646,361.479166,283.402142,239.60235,122.366236,95.334101,133.83782,179.138642,146.112632,31.596922,-8.449952,-86.592206,-170.582222,-171.085132,-85.289626,-13.775765,91.987658,84.730375,0.083488,-37.385817,-54.742843,35.354114,101.854873,181.477835,175.09169,83.74859,12.883936,-123.580717,-145.461654,-90.24136,89.632425,169.244443,231.546025,225.293236,191.44389,155.88076,73.859731,94.144175,118.821304,118.997728,107.808149,58.101363,8.219087,-96.581405,-60.816294,37.130321,206.417537,224.068538,237.070246,264.471291,300.233176,288.473573,236.085298,225.676292,233.527083,210.032705,172.748472,81.594669,61.856358,101.337697,113.589279,107.25685,156.945993,179.483723,121.391096,71.103283,24.623446,20.381757,18.804377,46.090543,63.428241,63.705323,43.619086,8.673678,-13.112591,-101.910591,-95.254825,-13.899225,146.335484,170.650187,164.194836,172.198911,176.930767,138.689402,48.979595,85.362405,117.981179,84.864225,36.417562,-0.129493,10.369749,0.663888,18.297131,65.511726,112.389298,75.818455,-9.655839,6.880384,149.932552,193.466989,117.115336,58.459223,113.415963,289.827287,324.529294,237.125645,169.848586,116.37567,177.361444,206.655321,173.476588,128.532255,61.433181,33.684231,-45.285226,-93.003506,-158.482244,-150.606965,-135.600456,-95.658476,-77.369293,-96.360087,-129.912768,-184.57819,-134.655168,-86.579414,-2.510638,51.745728,146.232932,145.821095,44.781132,-29.925626,-149.375727,-101.143797,-28.673232,36.766118,1.053196,-89.57396,-96.214795,-59.470106,-12.455645,41.217401,252.161808,361.191207,377.854804,278.517662,69.605012,24.983561,80.028262,182.695845,178.60522,84.608248,39.941394,-28.676938,-67.52533,-142.583042,-169.294424,-156.677231,-115.847432,-109.478347,-121.459267,-125.810392,-134.917758,-148.760171,-173.860822,-179.949828,-195.840979,-230.863269,-226.999769,-183.950655,-165.577574,-148.239145,-103.122785,-63.83822,19.157107,50.299664,57.406692,31.005402,-43.965029,-86.047782,-154.139983,-119.496507,-77.005931,-50.875571,-73.029601,-150.624465,-205.343499,-303.334759,-253.757328,-180.119635,-76.059198,-73.387164,-132.544928,-169.744699,-193.498069,-183.410705,-169.226381,-126.145567,-101.921727,-102.919302,-127.640783,-179.156986,-192.174523,-197.633908,-135.858968,-98.673838,-77.47099,-59.485695,35.957068,74.100184,84.094384,67.642089,-5.953552,-8.212931,53.418579,168.564202,168.904293,84.512009,58.42508,72.743104,67.07766,44.44045,-22.44581,-62.203761,-140.865579,-174.291992,-261.123094,-322.035625,-343.18018,-163.514922,-102.683131,-118.336993,-145.452375,-166.048143,-166.427085,-225.642394,-292.407178,-250.871263,-98.736726,-68.835041,-133.069343,-195.933894,-302.495164,-322.08393,-293.57461,-218.587835,-160.028289,-12.487908,32.975441,53.737779,72.184359,101.661268,65.480716,47.995262,-11.621835,-41.427911,-30.872307,-17.267142,-50.044642,-88.766218,-113.937053,-0.900848,52.742113,62.853739,39.239415,14.169123,10.74645,-80.904292,-199.453723,-187.606926,-81.617111,-57.838468,-99.551436,-115.884201,-67.976478,-35.487962,-15.641359,11.149394,46.120803,145.923609,180.268798,117.401885,39.33874,-51.104841,10.476034,66.16181,152.297181,188.824238,265.422392,286.972087,228.982596,134.2296,-12.929936,77.482395,119.266022,83.10404,47.225755,-19.119594,-53.804607,-83.731813,-60.917027,-66.02945,-133.401092,-161.05203,-154.7708,-147.675363,-216.122282,-284.214906,-355.408637,-350.738133,-350.837419,-299.482524,-261.037967,-260.062986,-268.542488,-194.160938,-129.606232,-132.156353,-127.443838,-119.245221,-164.815481,-215.945477,-268.070267,-249.013223,-165.502744,-94.437408,-78.526613,-37.010914,-10.796012,-41.503703,-92.252997,-137.425769,-120.656263,-137.529621,-165.366293,-129.64847,-75.448174,-129.540873,-307.840615,-348.885204:-53.615091,146.784521,200.341612,222.484664,200.299835,138.809867,135.038646,123.734035,67.118763,78.762849,195.210576,257.940249,308.157412,290.289321,198.128959,141.785584,91.422853,181.112204,243.993562,350.58429,389.15231,382.149192,346.980411,313.669962,291.233119,255.973693,225.169406,264.869172,354.323166,345.886561,249.161123,215.376213,255.605262,331.542027,332.737335,332.540651,342.516465,293.782317,228.31045,74.551178,48.997551,102.05071,227.111848,273.674583,295.560812,239.262597,13.660958,-85.089575,-131.034082,-68.833447,-41.000433,18.896091,41.437806,52.210244,42.555698,-22.360481,18.078153,126.922333,341.01962,375.46086,339.743082,304.652235,188.707128,111.966013,35.526554,110.934114,140.501919,89.138938,45.410622,24.044016,15.476745,-110.776138,-171.932896,-98.32439,112.707997,179.185166,187.073318,148.860822,28.953124,-33.325435,-36.249907,92.326462,161.304257,278.862152,292.738039,188.241353,90.491785,-94.334721,-78.182896,21.401244,210.966824,236.734758,205.473689,187.635462,123.68477,54.754205,-45.991192,70.043405,170.758892,288.282499,276.503955,135.030268,33.427041,-139.670801,-95.145833,15.214747,206.661144,241.303549,263.081256,279.499725,292.850212,273.143697,209.924763,186.880711,201.600148,214.557254,193.715831,154.503984,146.074952,97.974159,82.290187,128.771515,236.667557,249.566624,186.263249,133.10232,8.35349,-52.612443,-64.790803,84.993195,133.380154,60.388122,-6.324657,-51.783389,-73.298242,-195.088647,-174.079095,-95.16169,47.704824,92.852956,140.006041,135.702541,55.198776,-10.97629,-104.713976,-54.939143,20.741745,115.93311,78.979519,-41.828623,-59.366109,-42.123579,-8.986691,15.080691,65.999832,86.742191,100.238689,95.611442,47.111117,-7.1168,-79.949112,21.042866,110.323564,233.689526,233.335234,143.375193,93.054923,30.15339,72.156671,126.721366,164.845332,129.64088,61.047551,53.437066,-2.606813,-59.514357,-97.310216,-43.19617,-9.585099,73.59404,98.465881,64.286898,-10.000092,-229.679537,-259.886348,-173.236982,33.828821,95.054209,106.198424,78.60558,-22.837866,-87.817091,-156.836166,-109.087985,-80.815533,-69.878718,-82.272456,-100.019571,-104.177573,-143.425087,-131.293914,-58.52795,190.921831,314.960373,392.882992,333.584434,149.531527,82.632361,82.023315,165.416898,176.439967,155.20766,137.833853,35.705571,-42.307629,-113.789077,-36.890779,1.367415,-3.319407,-32.826424,-51.612977,-41.224014,-50.047633,-66.074002,-84.849628,-56.508341,-5.512714,77.930292,52.060495,-49.121677,-61.179664,-35.091947,-6.849774,30.613123,144.980833,173.224848,119.547834,77.309428,13.086968,-27.979829,-89.110824,-42.733166,-1.850591,31.07616,13.17542,-35.57495,-69.964213,-206.394954,-247.721837,-185.071578,-49.630561,-29.632908,-83.361453,-143.918968,-278.2846,-312.059452,-259.732749,-150.435181,-139.962783,-166.784712,-159.170134,-122.492733,-128.939967,-220.000009,-215.124454,-128.573323,50.698438,88.694355,96.217403,99.245397,87.135226,43.397701,-42.6404,44.521454,114.262021,160.278458,132.236452,74.926146,74.92003,60.866875,3.97837,-19.28472,-58.777316,-89.112781,-219.747763,-309.42528,-453.240421,-490.261618,-468.466381,-325.899659,-246.578462,-201.841083,-241.042355,-303.987235,-307.480962,-350.022886,-393.451507,-339.731834,-138.963042,-83.954437,-137.644826,-207.088119,-344.267211,-388.344713,-379.004758,-267.704667,-186.196457,-14.849642,31.070833,35.547029,27.743728,-9.544252,-43.497053,-26.651113,16.502833,12.830892,-33.198225,-63.861064,-154.347863,-215.036907,-263.973204,-149.931347,-83.641986,-6.394485,6.545598,-36.44415,-85.904247,-166.989523,-100.910186,-26.830137,53.181412,39.040391,-28.754401,-35.560094,9.393455,9.494637,-1.320014,89.948164,127.310652,153.260996,142.677062,15.904459,-74.578026,-156.943754,-57.596659,20.043858,153.437336,209.360539,298.395852,331.086181,308.307901,222.266793,66.514703,133.995684,196.538171,223.293505,169.126049,3.255321,-58.044371,-82.507299,-32.660618,-15.446938,8.785048,26.607313,5.059883,-43.731594,-154.312332,-211.624717,-311.62439,-315.33112,-272.104741,-161.752893,-139.436616,-135.359148,-107.060659,-56.780154,-71.896791,-53.500132,33.103183,60.840957,-1.14116,-75.524468,-171.536659,-179.428243,-162.452753,-98.534581,-41.349333,56.834058,46.269106,-82.915631,-142.672563,-179.453245,-116.44498,-77.778026,-53.293179,-46.68951,-46.446815,-70.943544,-123.577005,-148.963567:-46.632321,76.034405,120.814047,160.885857,156.5159,68.476492,9.352057,-64.43866,-79.79643,-49.396952,60.863559,97.906536,79.66681,49.377431,22.131485,27.501121,64.480118,122.660615,149.932131,189.299566,203.803216,249.280034,264.365516,149.883052,-60.003603,-69.94147,75.731896,138.903057,212.677013,242.541196,268.795959,262.260076,220.937416,193.772164,200.405833,222.690856,216.923713,160.365297,129.849801,72.034074,1.721748,2.777817,97.46561,141.376422,125.142681,59.690483,-102.893805,-142.482727,-78.449451,35.056537,63.356657,115.000418,136.576706,84.682857,40.821212,65.821722,240.951302,345.911664,454.960871,439.497357,367.51642,340.694867,278.368463,241.575536,198.840932,142.437485,77.103925,-26.189299,-20.682098,8.38781,-22.614256,-169.475729,-249.409228,-224.471986,-130.934889,-77.391874,57.219106,112.553938,170.814476,174.424179,104.04605,25.119096,23.623877,57.067873,49.697349,-34.957166,-74.445027,-86.990952,-14.892979,41.346788,134.312349,172.245704,278.946038,328.064053,283.947051,182.190984,26.439333,50.137411,47.914416,-15.264225,-23.041264,35.742675,49.005104,-35.461313,-85.18771,-38.189417,83.621628,121.531954,198.218261,249.275179,353.308059,379.284741,356.435849,329.259009,294.353488,181.835542,138.461178,83.075153,64.768116,54.46634,80.247198,86.264861,62.818628,61.480053,116.497263,144.881165,130.905165,95.096546,62.783901,130.035658,170.770997,205.833195,200.326847,146.233345,74.826262,-128.027914,-171.654519,-89.420768,100.681164,118.453317,45.288118,41.685896,113.205305,111.128668,8.499159,5.985323,51.734428,79.667076,41.657717,-42.268119,-54.342127,-27.462184,26.259931,57.145947,84.57074,84.737156,119.888011,139.241627,117.3825,98.572985,130.029629,219.487619,243.420265,259.210594,252.440248,185.765214,162.358458,181.737521,206.421126,230.349373,288.92713,304.086517,289.932641,247.809446,103.33524,35.665168,-41.384673,-68.394165,-63.376447,19.534131,71.176068,67.008593,18.886648,-46.136111,18.291853,61.604011,83.549756,112.211614,283.381522,345.68956,258.424195,151.703355,-12.703752,-20.314982,16.85859,76.256271,86.815746,76.768636,58.512942,44.167767,141.67511,224.203158,397.242691,461.097514,458.62702,380.425283,197.87127,150.308919,146.927366,260.093946,318.250712,282.735915,204.916731,50.86286,-1.083497,-30.953084,77.253236,150.017927,108.072247,-16.03535,-192.015092,-176.428187,-75.453568,-69.680761,-133.239685,-147.670652,-152.45774,-178.362711,-177.201445,-158.142127,-147.157467,-122.835815,-158.083297,-175.519754,-96.331795,-19.767818,38.845977,8.287711,-63.942529,-95.682448,-180.752328,-190.265388,-147.1914,-59.264084,-56.787949,-134.61365,-188.081955,-275.750105,-213.382136,-121.260457,-19.820924,-56.957507,-186.029526,-210.184152,-144.62037,-107.330198,-131.489923,-148.868201,-118.08429,-56.00023,-59.123431,-143.830977,-190.960555,-201.345234,-90.580515,-37.903742,25.81256,55.574887,50.054328,-1.52092,-69.411932,-47.644252,45.171957,158.531311,204.226567,216.899054,205.187023,207.644067,213.933323,206.007826,163.353188,134.514791,78.570991,52.731494,-45.154656,-140.581455,-320.349603,-329.610015,-190.706377,-49.934625,-30.398741,-50.906315,-35.623464,46.66644,19.023964,-228.074701,-313.474008,-240.505645,-125.288023,-133.861289,-200.450609,-239.783013,-353.786427,-404.31458,-407.002852,-315.101864,-257.44455,-133.814561,-67.774479,48.911279,79.148688,45.325016,-80.520712,-124.926012,-110.957377,-74.05081,-19.985974,-25.80465,-95.619677,-133.367852,-141.008561,-35.467269,1.689725,-34.612103,-68.262076,-85.212756,-98.498398,-242.422469,-347.680598,-283.143653,-69.321103,-31.262544,-94.883704,-125.819636,-158.738383,-185.430487,-208.887709,-96.941849,-6.972947,144.122625,164.774391,76.143316,12.31645,-35.127077,47.94068,116.427701,231.975623,265.958996,280.605928,263.642168,210.504281,183.699387,139.429471,124.900349,124.419577,113.168896,105.55131,94.740795,96.23498,133.356907,159.26501,128.652013,0.525427,-49.660508,-134.527554,-204.948659,-294.507919,-277.191996,-217.282945,-209.400579,-202.181239,-134.741234,-107.628705,-127.622082,-144.625199,-152.770991,-132.015773,-93.2182,14.157397,35.091969,-61.510184,-147.57399,-227.629324,-188.615912,-62.591315,-23.796531,-32.339005,-26.814267,-21.701439,-79.827856,-118.249787,-151.898155,-207.746191,-239.084458,-196.840904,-129.999187,-104.104609,-186.582801,-403.816747,-455.987502:-128.272077,54.720433,131.661648,186.581928,148.582734,0.372953,-44.54021,-38.04662,-23.0038,-27.721312,-11.312127,28.360681,98.571139,87.092096,-11.768894,-67.317916,-81.773484,83.172761,171.471135,247.157565,249.074969,259.875619,268.875936,217.305524,97.586206,88.219653,176.326024,215.704228,253.862588,265.634547,247.96072,221.009472,220.968995,320.99541,353.370957,341.488999,328.405126,295.665354,251.564695,119.390571,55.096927,68.509214,133.855206,176.254662,213.800712,158.85458,-41.345311,-104.067765,-77.337432,49.477901,107.828663,165.337042,151.0161,82.60328,62.212847,70.481673,197.359405,298.428877,462.214309,503.666221,491.524055,426.27296,246.422983,187.453788,138.035254,113.342578,102.246939,84.696646,77.26963,25.610694,-29.717333,-174.681564,-216.609236,-162.569597,-15.105651,59.405818,214.948749,248.871326,154.777154,57.103953,-37.533501,122.907816,223.646901,359.810958,379.72853,269.832351,171.135813,20.397709,14.896103,84.385331,265.906505,326.601288,374.801681,361.241574,244.264085,172.322279,168.89833,310.27922,331.064416,261.892391,215.538665,123.986572,71.555866,-36.239478,27.224869,134.171171,253.001179,244.457715,254.551541,288.587587,315.98581,288.046632,236.691139,274.50212,289.051388,270.85698,256.116319,193.637171,124.394815,-0.98508,65.524505,137.332335,207.910855,204.141274,187.699962,184.92924,172.832081,161.191289,133.381176,120.464783,136.392441,152.535734,116.967374,-6.451139,-67.270052,-191.937055,-208.487576,-119.759128,85.845634,116.391376,91.241512,104.465622,166.779408,147.212852,10.860311,6.340098,71.589272,150.053649,118.506234,13.048427,-2.883481,28.72361,74.533976,107.47917,175.078833,180.145512,116.694487,83.129673,47.356566,18.499462,-21.236283,110.708454,197.975565,253.897645,219.776816,102.531642,53.206397,24.328768,89.668033,152.519908,286.599458,318.044813,231.749499,119.522023,-104.519113,-157.962273,-133.911818,-72.165247,-62.221019,-16.741877,20.097371,-9.227197,-84.113187,-198.039961,-134.392117,-71.130615,-0.003253,13.815904,68.703793,99.257848,62.478187,-16.878558,-153.34569,-86.761051,-8.084585,73.608483,56.622736,6.508716,-4.486645,-30.175526,23.803648,119.354609,396.708297,513.528451,535.072309,442.734862,226.544481,156.849988,131.174637,210.75334,233.634026,169.957554,104.706829,6.600684,-14.161552,-57.110332,-53.461712,4.667002,102.674596,93.178691,6.523019,-40.345739,-112.591314,-127.613362,-64.546332,89.94412,136.068794,64.00119,-27.961071,-144.510397,-136.60601,-99.976476,-108.807147,-81.459198,46.537702,102.364757,119.247986,81.240786,-36.638009,-91.250564,-125.652807,-38.044473,20.881666,66.255996,37.432594,-86.063482,-161.301001,-261.720191,-180.034533,-105.094554,-36.242603,-44.507846,-113.956972,-177.100146,-313.633425,-341.832152,-258.144425,-83.56642,-20.928929,0.76273,-34.017944,-123.987959,-158.521702,-221.518262,-200.99798,-119.588311,92.237253,144.34116,74.77894,1.501871,-79.682809,-79.926455,-19.453328,127.216078,190.52388,204.84915,176.985262,149.978792,143.202946,81.731468,57.510822,70.118534,36.401113,-11.083329,-135.6667,-230.312485,-421.211221,-461.454683,-398.219103,-229.112259,-182.115077,-204.683529,-223.187128,-259.053952,-316.067418,-481.658656,-473.850806,-363.722344,-135.056159,-113.335565,-234.050969,-305.48608,-417.619522,-471.273197,-511.950209,-356.336481,-237.963845,-68.322156,-37.738147,-66.955616,-103.489906,-153.156878,-176.43539,-179.767032,-157.302591,-139.05133,-136.630712,-160.185297,-218.771941,-251.466302,-303.51981,-236.475949,-171.906151,-72.81029,-61.033115,-137.528956,-194.617476,-260.653233,-283.544933,-268.707942,-169.472619,-114.065232,-63.843867,-74.724285,-152.325154,-198.978441,-197.710906,-50.536525,12.785099,82.436561,94.892085,21.872558,-38.377285,-66.000254,25.517534,88.381553,217.382652,276.069306,348.145347,340.749673,246.213622,190.421466,155.890804,199.558914,216.715353,260.496115,272.354849,178.239496,99.194018,35.613148,103.648124,131.157723,110.803263,92.071917,86.008896,60.470472,-101.905938,-189.147846,-212.077629,-125.312036,-90.691416,-16.075712,6.991983,-20.781229,-41.55422,-43.02737,-32.46853,-14.123065,62.616045,106.073124,130.988799,88.190628,-61.331509,-110.95596,-108.844981,-47.882589,-9.829519,77.387275,102.515971,73.969125,40.603787,-23.581051,-68.802814,-73.77131,-22.589122,16.900369,-13.711793,-101.917855,-316.639538,-394.747176:-213.385132,-94.846648,-31.414622,4.471413,-24.771559,-151.783138,-215.54621,-289.599036,-295.349942,-265.002226,-214.837927,-214.76541,-175.395936,-132.121772,-102.569261,-115.042016,-82.852298,25.417038,62.215213,59.089727,45.449532,74.965412,85.748187,-24.331141,-145.967433,-132.534048,-80.413345,-85.667729,-90.819638,-67.187271,5.365791,10.278431,-55.068171,-39.604918,-15.920885,-58.916316,-99.325117,-85.361715,-42.120201,-9.211738,-48.627614,-59.505947,-49.598841,-41.145887,-53.302499,-66.291154,-39.027662,-23.692771,-74.424237,-93.795495,-66.911293,4.312699,31.005946,51.707389,60.801625,114.920253,247.681503,300.405503,262.015021,210.27928,152.087783,134.497426,101.212382,92.589937,48.265883,-65.73151,-109.168304,-129.207098,-127.208039,-128.567503,-130.62673,-196.607237,-374.388278,-435.671753,-391.822555,-311.683139,-135.082857,-67.018933,3.314371,-5.672512,-94.322519,-112.761546,-68.825135,37.190498,59.931837,6.93757,-53.220984,-139.706425,12.647072,159.559283,280.389781,231.864374,205.255888,266.78595,351.669813,335.159428,254.879911,175.163338,134.384655,81.026861,73.977442,43.26889,0.567652,-102.973372,-122.25187,-79.642549,30.260384,66.194447,131.48741,182.155937,307.987193,351.867342,370.993116,344.050127,311.492938,219.282436,161.531721,18.952625,-30.995423,-8.490324,116.036559,147.495671,127.159148,120.990994,125.113261,125.554539,188.421531,231.895714,239.245638,238.821568,254.710706,274.50365,271.735042,206.386523,144.684819,17.180268,-33.252754,-13.323875,60.408953,77.33927,32.165332,-1.479253,-24.025924,-45.043399,-148.418645,-187.31657,-190.804991,-217.364819,-216.755289,-166.901869,-128.744208,-74.425688,-117.222224,-145.503936,-124.799277,-82.347361,37.818814,96.782277,156.492404,163.45641,157.191076,125.210663,100.128518,56.634609,38.184444,-23.069302,-55.900173,-84.173994,-10.427368,77.435352,248.785185,283.90363,248.261358,214.313357,162.10824,118.930805,-14.668838,-71.492445,-60.701469,-5.819736,23.66602,7.603444,-19.345151,19.010736,102.654751,85.669411,-27.705574,-32.778909,119.399424,186.700069,142.250226,47.400902,-121.743689,-59.547347,33.994212,196.473912,238.630212,230.860593,200.199297,145.457508,189.971721,267.816517,441.422549,495.041199,444.153887,340.448116,183.716471,205.317005,368.767829,430.418932,390.8346,281.419714,267.287506,309.94296,322.893106,298.446752,296.200652,312.685841,291.453799,239.547223,149.069132,155.646724,226.938228,236.535828,180.098109,112.583411,86.853931,71.891994,78.994248,60.574209,47.146358,55.836032,9.636423,-36.399815,-57.001276,-17.198631,56.69727,45.460467,-25.470772,-47.976745,-94.62526,-131.335433,-115.131426,-69.003708,-75.542382,-102.512963,-78.819363,-12.046535,-19.011731,-28.962617,-56.651071,-64.07129,-26.647659,18.052786,100.679105,91.946938,-13.217741,-30.36874,4.871093,47.919867,29.681881,-59.338455,-99.607717,-97.261249,-13.683947,22.225152,63.484099,63.032557,16.930593,-6.650998,-16.541622,-21.40295,-30.439769,53.306548,102.530857,140.369122,152.698227,199.322063,210.776573,163.42786,67.361505,29.519524,-13.34967,-15.528618,-46.076816,-90.04253,-125.766305,-103.72501,-53.078461,-16.910911,-4.119737,6.66986,17.854522,45.659666,27.716781,-110.420318,-232.646108,-229.16383,-196.295127,-218.682646,-260.811618,-255.17102,-276.706528,-309.698771,-307.697245,-173.887539,-99.593665,-39.371128,-55.332113,-45.32558,9.949432,64.31042,-70.934568,-118.13317,-78.427232,-34.479661,30.65582,33.036043,-22.945366,-49.111064,-27.995107,24.757399,12.359963,-43.050863,-45.403344,-58.732274,-98.334509,-209.243801,-243.205231,-187.552037,-42.182,-19.829408,-47.741302,-52.505343,-66.326061,-115.810207,-235.603978,-135.797029,-23.862759,108.998161,117.096933,92.946645,69.789351,34.934741,74.268757,109.410851,165.018131,190.366198,225.547402,223.209811,212.181017,206.020146,142.940708,118.900389,154.397736,220.723777,207.610103,118.1517,85.661856,59.476825,50.054763,49.986258,2.488614,-43.679424,-138.738521,-191.316993,-242.195747,-203.782285,-94.769387,-117.110853,-120.492964,41.945441,132.564067,94.282013,5.106769,-81.732656,-32.564276,-1.157268,38.080173,55.249664,53.097854,-10.543444,-196.550246,-215.917626,-57.37643,49.166289,28.364876,-15.02019,-0.183141,42.454821,30.361932,-98.278164,-219.73942,-204.718963,-51.811616,25.398834,31.243237,-60.489801,-272.953556,-316.085554:-154.856286,-9.36377,67.112469,160.716139,167.621682,89.812749,3.75371,-164.319552,-159.189586,-99.745282,-40.77086,-66.8721,-137.863189,-152.394893,-129.877688,-113.625922,-88.945194,1.118195,40.672506,65.52462,90.392328,170.741966,175.453918,19.881417,-203.913097,-242.530883,-193.882723,-156.3521,-106.90401,-100.866971,-111.515994,-118.133761,-111.199958,-62.390262,-32.581601,39.312746,70.650826,38.295022,-17.773464,-112.195266,-165.184095,-183.90753,-179.409431,-129.057802,15.93574,51.168857,43.139377,16.494061,-74.534868,-80.974344,-29.828474,71.730387,71.59526,-11.588236,-39.356988,-11.596873,141.555878,253.237036,356.992841,297.886692,83.899621,17.980337,26.692728,34.717016,-63.762952,-147.837046,-143.273323,-157.955047,-190.485628,-197.567908,-168.752704,-189.775632,-340.327024,-385.529598,-324.484879,-247.172225,-78.776675,-9.739457,42.216805,16.219013,-100.333255,-171.841003,-169.103107,-143.112299,-128.343745,-79.983218,-59.336341,-35.835626,44.114413,92.15438,120.289245,132.956964,236.525047,286.995236,315.551107,302.8793,231.20126,122.636361,70.16777,40.893256,77.235462,136.470883,118.196591,40.441022,7.524404,28.093696,149.07688,221.617941,334.839356,373.560045,409.029797,394.521433,315.513872,278.978411,292.225915,316.435521,292.104085,173.252388,113.583221,12.816657,-48.474613,-28.589056,55.12723,82.73315,119.485199,134.042156,129.661361,98.14383,50.591823,137.404285,196.189461,269.193928,275.970217,206.205693,134.62096,-12.157008,-21.095908,31.346662,113.515304,95.867346,4.658537,-9.285291,18.856309,12.251332,-66.842005,-171.904834,-218.223306,-269.382264,-287.829538,-313.785962,-284.214774,-155.094678,-123.228918,-145.851713,-133.925558,-85.099746,15.974348,39.453867,54.132997,55.689649,7.178954,-51.630002,-23.371791,129.610489,168.25942,90.077702,35.067834,-3.190344,59.970645,137.744594,314.770861,357.225814,312.158285,254.40654,165.516996,148.278195,93.926019,16.063247,6.620383,80.165326,133.964351,153.010894,122.088439,71.018576,62.470811,53.761357,65.605388,112.151122,185.369588,167.477926,103.734602,74.494581,-32.121074,-75.050255,-13.47196,208.398857,281.045755,228.627649,160.913115,106.301682,174.855713,251.871031,393.327131,409.648863,325.544154,240.408163,112.139324,120.276727,207.752193,209.33022,183.294684,158.521935,168.721602,196.713052,196.751007,170.393873,129.251342,102.922845,18.107085,-40.057708,-113.573075,-98.513292,-23.211447,-18.962303,-92.912074,-145.689006,-151.123523,-132.27129,-117.868162,-123.235231,-132.933518,-135.977131,-109.335736,-84.842858,-84.461384,-97.94041,-65.60558,-43.249105,-77.216905,-126.186062,-201.913146,-165.434772,-141.073573,-160.183696,-171.333867,-139.238918,-130.490536,-198.862992,-248.780477,-223.365889,-154.967855,-121.687011,-21.091183,32.394752,86.309366,78.504819,26.371431,8.273603,18.686406,30.593339,10.500491,-47.908281,-55.183807,-33.100605,52.001612,107.823176,130.995797,98.400849,55.255875,57.79937,10.343873,-51.272445,-91.730181,71.973866,155.913509,218.783054,220.153769,183.425185,145.958311,97.429598,91.883259,74.129095,-32.292597,-87.015776,-103.534908,-80.702689,-29.021316,-2.473632,48.015001,58.145465,39.273001,42.675496,90.367588,176.365925,148.46627,-46.482814,-138.846119,-110.048404,-122.00787,-199.063057,-323.356665,-315.525024,-215.555676,-194.610126,-294.107183,-377.486053,-341.825759,-194.798701,-132.854161,-8.980598,70.931382,180.007921,102.968059,26.364381,-92.504927,-120.689096,-97.257342,-46.259407,45.022803,32.043883,-60.987708,-9.956169,47.129789,50.023261,-3.206554,-105.776308,-136.417099,-214.026598,-251.166366,-199.709773,-30.413553,17.567998,-26.236897,-82.303131,-143.708828,-142.262988,-109.396467,-25.823977,6.84417,53.537058,90.969822,129.172226,113.982784,88.322774,87.101145,96.554088,182.206718,244.963517,292.021242,261.540912,207.173378,214.906627,189.011176,75.773733,63.399153,147.526407,167.311513,65.007037,13.941055,88.10421,194.639616,168.481133,8.49627,-58.042025,-84.55892,-73.513771,-85.540675,-110.577235,-163.605664,-139.375259,-84.20303,33.306519,52.452343,-16.491432,-76.18346,-162.283478,-122.24824,-64.126794,31.834642,51.347825,0.513448,-67.075434,-154.300362,-142.897671,-94.542732,-70.42708,-62.711081,-16.122791,27.192386,39.142319,-20.381929,-168.191682,-243.22385,-246.911067,-183.338119,-130.231968,-69.852095,-85.643745,-189.658382,-258.170031:-74.788476,115.610911,187.776283,177.718123,100.454062,-108.945407,-175.776962,-157.528491,-103.951698,-111.358095,-127.380363,-91.866662,38.096469,73.827935,10.807284,-59.334896,-102.457353,58.354562,133.07772,146.789787,121.416661,124.901024,152.792644,136.523807,32.916451,21.503409,75.351996,92.910875,99.118878,108.919985,117.959594,104.98257,86.624233,147.325491,166.989837,94.340052,35.073305,27.264037,93.193314,163.603798,38.709212,-10.632741,-1.61882,33.980499,81.116063,63.550892,-12.535236,-38.113716,-48.648016,-7.059101,19.438328,79.786137,106.987193,92.368282,52.821964,41.377364,240.903542,344.016745,352.97946,284.383839,193.655731,201.954588,256.899912,261.641124,205.087091,83.583154,-3.972217,-108.378841,-86.015951,-47.435049,-97.474797,-285.226235,-343.731073,-301.253889,-181.06477,-103.171951,107.338342,181.336975,136.210539,43.622932,-56.098082,84.136653,152.207872,192.360114,199.545758,185.389667,155.979942,86.14233,72.276933,116.699566,229.473336,256.35656,273.13095,271.959964,238.713674,224.399274,240.149683,239.538829,196.999499,93.629584,72.397211,45.381211,8.591077,-73.469064,-37.999841,18.570713,66.598418,38.218323,28.21784,96.377275,261.487046,295.405596,290.095244,217.888542,152.488717,81.91764,89.090704,59.165254,29.657881,52.032018,122.250396,143.111817,165.622286,179.073417,180.689022,160.038416,170.598498,206.923513,213.623665,166.158335,148.660334,100.298607,73.079347,18.350279,-7.523154,-85.25177,-176.562558,-165.250074,-63.136034,-41.346701,-72.535782,-84.000447,-54.635612,-30.745676,-16.230632,-40.831519,-53.703832,-52.203029,-46.178319,-53.650489,-60.201639,-63.658442,-10.216792,44.197273,124.199,135.461706,158.772988,173.675954,182.107132,194.211606,247.889524,252.778512,242.174029,184.078063,114.516427,-45.506628,-96.00368,-120.260699,-36.644111,48.129163,201.61009,212.928561,101.096593,35.084488,-8.713407,1.66581,-0.706299,-32.494411,-37.884335,-8.764072,17.518528,27.366839,0.271702,-57.372442,-29.711911,-10.12255,15.024675,49.588346,129.121969,137.494859,94.222664,58.304566,2.733882,45.518636,75.759476,105.892181,128.878203,130.9646,74.876378,-24.69755,65.594823,152.478071,316.432434,379.458493,434.24244,413.537412,317.329907,281.39416,297.693714,321.537119,269.22531,140.997368,137.670787,207.721983,216.895287,147.692269,140.098123,179.473245,181.303588,119.768544,40.038532,69.730058,151.27621,146.67456,91.685075,116.456015,148.23776,162.11764,118.545893,-33.927138,-92.961555,-124.510406,-107.447254,-98.22536,-48.592925,-0.267176,44.69889,1.996907,-97.793727,-98.770626,-61.213552,-47.766137,-43.440999,-62.974661,-87.141343,-84.760804,-59.411388,-51.240131,-91.971077,-104.889774,-107.206908,-98.818231,-89.407488,-95.533748,-105.434809,-107.709342,-121.482524,-99.354938,-63.275019,12.249127,23.069674,-50.150498,-109.648266,-170.220471,-141.148367,-100.849333,34.475194,90.222756,60.737944,-3.896883,-82.854735,-68.71008,38.369047,133.178539,127.904064,50.215442,36.092758,96.727281,150.03063,221.675917,137.585299,71.946671,28.09941,14.421947,-138.291108,-264.413212,-402.665636,-366.700815,-228.196096,-124.806806,-87.845185,-62.10935,-59.124587,-82.283793,-122.925311,-224.442302,-256.596453,-215.197487,-119.795129,-129.137114,-243.056036,-289.681947,-313.569593,-326.855716,-357.837772,-244.528564,-155.099803,-45.045421,-31.975778,-36.570005,-42.111592,-90.248962,-131.11903,-121.165239,-88.008942,-67.292396,-25.16351,-48.488043,-188.643504,-244.420094,-214.434244,-71.746038,-51.27619,-124.953038,-144.10889,-110.832374,-116.748405,-208.822693,-242.592251,-220.212092,-181.94246,-180.989025,-179.777425,-170.401011,-160.381403,-166.322268,-167.950586,-94.641205,-45.284104,17.482273,25.995297,-26.196598,-64.397443,-64.369419,30.443618,89.788276,144.671785,134.559482,127.178667,150.765773,210.40448,210.841405,119.363543,24.757632,29.811891,135.146832,182.431085,181.864337,157.670919,92.940605,39.833913,38.900455,15.169702,-29.562752,-124.535504,-155.26035,-225.222804,-257.669105,-214.111649,-77.976924,-21.160584,64.780496,83.634621,31.841328,-29.066653,-119.255859,-41.269393,40.470627,150.514081,157.796183,108.688205,42.404175,-135.372108,-164.493454,-40.308292,68.235278,57.197874,-12.472773,-25.067476,16.898457,28.123148,-54.308091,-143.450894,-140.649555,-66.939892,-26.300173,-19.831144,-65.799212,-229.427738,-305.801901:backward
-78.205099,-160.43595,-139.949916,11.467623,84.224445,178.725929,205.501771,157.251649,9.112493,-21.614936,7.768346,24.908358,0.039436,-55.511529,-135.64107,-103.831533,6.613054,48.661157,51.691184,63.013053,83.021729,30.74867,-65.183415,-230.806298,-259.219792,-251.474476,-248.969926,-242.937274,-185.543493,-160.437302,-196.450217,-237.429972,-245.591008,-158.296938,-116.449868,5.790869,87.747063,156.622861,137.577699,77.124202,-12.568717,-46.569552,-77.788463,-85.293098,-48.846037,-3.071614,60.749087,41.753983,-16.450349,39.3083,77.164442,125.341444,139.786668,135.644131,116.979499,39.597379,-77.892288,-102.816763,-77.505683,-57.321569,-12.02521,27.947362,128.82621,128.622851,-23.060679,-83.793713,-57.766244,-54.927462,-76.773195,-100.76311,-109.58899,-204.67605,-368.073746,-411.541094,-349.857903,-244.855524,-15.443418,25.020015,-62.662509,-125.538774,-194.581558,-186.986737,-153.659278,-14.6333,76.208755,193.940552,194.053092,93.733791,-12.722896,-9.435003,63.096477,94.854387,169.358852,215.503964,271.750189,255.156207,110.042112,-12.619025,2.809028,141.238013,210.417559,306.851079,341.299759,319.255947,242.218984,252.859168,332.57211,372.751759,449.434454,464.964485,405.199424,338.014086,195.369832,129.523078,118.089293,127.265052,150.814416,171.070115,160.767205,128.820156,134.053303,190.717342,383.526442,469.246453,546.946789,526.562093,387.073722,308.327139,188.250157,150.818043,175.995039,272.767261,307.902857,252.758563,160.139176,-39.743236,-122.798985,-134.916107,-171.366537,-180.984095,-168.544932,-168.816969,-189.763973,-206.391054,-246.716299,-187.895004,-119.082981,-91.449786,-153.259136,-241.06789,-220.508425,-194.735955,-334.702846,-402.099519,-372.017696,-275.563581,-85.137143,-51.871361,-68.581459,-95.98213,-183.475328,-172.1231,-124.532411,-60.834286,-55.95482,-61.90829,-60.889522,-95.108599,-177.905025,-199.822585,-236.412269,-255.192365,-222.502864,-179.919232,-139.305317,-155.339674,-204.987814,-175.194376,-127.072768,-33.601436,-13.770595,-13.483088,-13.628785,-63.012704,-146.079014,-144.640639,-85.521542,-50.574662,8.368741,12.395404,-66.347798,-155.829983,-365.37798,-403.849001,-354.634705,-232.319338,-183.396606,-189.11768,-245.508699,-367.663591,-394.556601,-338.075096,-128.644867,-36.845764,69.97303,100.563975,68.729522,-23.855332,-281.519503,-362.455849,-321.150549,-265.844479,-278.459245,-328.311523,-353.928062,-386.494929,-359.252085,-310.860052,-191.553989,-144.34638,-92.864874,-98.298776,-145.454732,-168.997885,-195.845674,-139.057885,-97.863302,-8.818763,50.307028,138.654795,155.72893,144.057038,108.893405,140.860434,334.809224,444.049961,513.464184,452.648397,299.58677,252.45137,126.47136,-22.576721,-47.255121,-1.841742,44.320352,112.425967,99.451951,-27.692068,-127.830591,-112.957043,-15.544209,31.636703,111.56096,141.898918,177.671865,176.85172,102.297389,-7.566846,-21.721567,38.627578,57.669966,7.479194,-15.03408,-40.835244,-133.53623,-176.241154,-215.299046,-188.686856,12.725171,130.027724,201.891147,151.231255,15.22184,-19.476774,-0.667096,67.808346,87.976313,49.969612,20.823536,11.175189,38.919511,58.389727,124.185889,165.327732,201.294234,182.893601,150.792124,159.478018,192.182576,255.146103,292.778034,316.113001,307.933263,309.601971,307.58413,216.696746,84.232506,60.800937,88.041721,128.760829,219.868394,219.085993,108.206122,58.7296,62.742456,77.297698,66.971648,122.09444,188.334923,250.480626,224.510201,142.228136,172.042273,237.933445,297.788578,275.355545,268.09179,292.32668,308.315355,286.118035,206.651933,164.258478,171.939743,214.017101,226.800441,212.954404,210.428153,195.836114,108.393973,84.381188,100.362795,129.206271,229.588662,260.310832,211.31011,152.756976,48.609685,39.927176,66.052286,158.718837,205.36406,239.716805,250.685782,302.982756,365.272258,409.294964,470.849544,474.316744,481.379149,472.935853,377.794881,311.147525,173.2803,74.038818,66.659345,122.47842,174.321282,248.930478,242.885244,185.373665,111.988853,84.212391,62.498633,64.242949,111.649731,161.547022,278.181783,303.220125,214.560501,90.168582,88.081249,211.456063,296.752039,426.916847,455.51744,376.174009,151.588431,81.035455,153.846937,256.420965,390.273343,383.607645,252.680761,159.060989,23.944834,62.330352,130.429412,262.729785,291.327823,256.201335,236.827397,208.286346,16.9824,-90.676195,-80.470582,36.672525,261.313196,288.405138,217.891292,183.132619:-64.506088,-130.366905,-130.373802,-3.202633,89.784969,202.067289,192.464041,26.051499,-161.14734,-171.758509,-61.3684,-5.944026,26.733611,19.630034,42.572029,79.813415,124.688659,69.884234,51.260751,105.447876,122.156004,-8.326211,-120.32044,-262.576243,-262.441454,-257.227862,-247.322704,-221.399862,-195.683878,-219.567338,-268.252963,-278.831605,-297.272076,-252.32665,-198.022562,-54.682752,21.854974,85.491025,65.00029,0.202621,-40.443563,-51.600469,-84.539086,-88.144692,5.087292,73.671906,69.725275,-16.654639,-134.566834,-24.356493,55.811971,169.302488,195.239983,141.524142,60.488605,-127.146989,-220.390081,-205.760273,-98.833802,-34.880468,84.322877,124.801432,108.139154,37.198499,-160.64516,-202.895224,-146.739423,-38.49282,-26.510155,-71.607045,-116.122131,-223.92405,-315.54682,-358.45517,-390.604219,-316.815394,-81.631541,-45.697544,-170.521392,-246.524607,-280.295753,-135.071659,-36.255494,90.099323,85.499308,-42.765171,-109.62902,-163.086217,-168.314044,-152.986306,-70.411393,-23.606995,-2.350033,-19.176197,4.482688,25.928414,-34.794211,-137.532958,-138.733343,-39.034647,22.495393,99.51693,112.599168,73.761971,14.848525,33.617355,138.014495,184.497791,255.977715,288.765399,309.977267,273.580107,161.099995,127.891581,141.195031,206.090841,237.78057,229.36736,199.531587,134.163819,123.545206,177.734097,339.255465,396.566696,415.83312,396.001434,344.46774,302.252227,186.393377,150.394728,189.517541,304.992178,312.390077,202.296387,146.416668,75.992821,-32.5209,-97.85377,-163.303135,-137.619853,-61.697197,-52.140074,-48.105294,-56.986065,-153.436428,-219.926102,-205.613851,-184.083615,-199.309049,-217.649722,-208.331179,-213.004772,-273.691817,-315.358972,-355.857502,-334.059715,-257.188961,-233.53196,-237.963239,-266.773267,-331.791467,-282.369578,-217.361394,-140.384828,-154.887729,-196.638769,-183.692439,-138.293466,-166.976709,-198.705811,-277.921774,-312.664023,-303.021017,-264.913835,-230.104894,-263.658909,-367.371686,-325.510034,-253.042873,-175.616241,-178.621978,-125.667286,-75.307277,-98.659116,-156.597739,-114.229866,14.493768,59.804262,95.997376,76.537731,-25.766129,-100.996653,-267.72877,-346.787393,-337.091418,-210.196958,-133.503563,-98.071939,-128.206992,-223.485116,-309.155442,-295.461908,-110.226945,14.385692,134.102413,111.282271,-3.844985,-70.369249,-160.159523,-194.914175,-219.806102,-219.304547,-170.213699,-109.339178,-153.965666,-307.207151,-284.239327,-185.369358,-19.183729,-11.194771,-88.943852,-129.106508,-156.766364,-156.804981,-162.537735,-84.830051,-15.894535,76.387587,84.047423,82.562077,91.129342,75.717697,81.842145,146.735045,305.479191,335.344702,294.855837,263.109345,226.094546,198.891577,79.537878,-36.511877,-58.09729,-24.248588,5.557947,38.136741,42.630959,-8.423525,-25.678534,27.390066,125.608926,146.640946,199.9758,240.355753,293.176718,268.579679,136.238609,55.4244,54.831668,137.284313,190.757766,208.586204,174.423491,60.694511,-68.821957,-111.847677,-127.685596,-80.08061,150.474049,268.688109,332.63375,275.712946,96.471378,-5.274953,-5.123304,66.902954,106.335126,112.47436,100.447834,109.052155,62.704141,28.619425,61.2202,104.801279,114.449772,86.083351,75.487038,100.293247,155.860724,249.380787,295.622451,343.063665,343.510911,284.258658,227.594151,67.866136,-73.601313,-91.354034,-14.496167,50.393966,146.177136,148.766802,88.41494,45.835609,-1.280725,102.264083,183.200162,260.384249,241.215395,160.733188,135.196397,133.765801,195.628023,237.099744,294.55465,312.098043,318.500385,305.768364,278.692526,263.10856,206.413873,178.761046,177.886469,194.848442,226.470611,272.460444,263.873505,228.038032,195.880218,165.738396,117.465446,141.998748,255.803979,274.851149,194.715756,137.86479,57.96697,11.513006,-6.178031,49.55759,123.941685,245.292205,282.513787,340.857445,363.792614,390.96258,495.314151,524.523276,473.06154,403.575663,214.526801,126.326013,48.242074,113.29693,171.320716,278.431193,307.165106,312.26792,303.244418,236.796631,129.713864,113.269651,191.227402,243.73634,268.134224,261.474584,284.062119,278.421306,201.872952,186.619351,212.255257,304.691773,381.308952,530.424561,538.823323,372.777328,158.95161,117.689794,183.907405,240.603845,278.181902,255.570487,165.690678,102.271203,-18.432156,-14.079658,54.398108,204.617114,230.574027,224.738924,221.128439,124.623817,-62.545093,-77.903382,87.202857,191.91587,327.726469,356.326352,326.623149,256.972765:-37.032986,-17.103717,-0.259098,107.756812,175.364807,185.264634,120.191987,-71.195167,-215.70491,-215.098014,-56.587874,65.689694,206.747688,187.448135,108.583921,88.956221,67.046586,58.211785,70.552202,112.036804,83.644611,-88.577089,-156.789734,-210.601418,-249.760874,-264.243811,-252.957202,-221.171901,-190.491418,-209.100693,-251.781384,-272.828996,-294.275292,-251.14535,-231.569837,-169.323225,-98.757774,57.849622,90.809762,22.19738,-68.49767,-76.754247,-88.080257,-99.346482,-76.035402,-46.043989,-53.112067,-98.687835,-115.255044,4.474732,44.129137,55.086406,47.426573,-17.57131,-82.482549,-212.43612,-230.769683,-203.601114,-155.22103,-128.861059,-53.126417,-25.020804,-22.256223,-51.135041,-155.60682,-204.441234,-166.850651,-58.142109,-50.63729,-142.921613,-213.626147,-344.409611,-391.693274,-384.214787,-337.153607,-282.722335,-138.683082,-107.971884,-186.088,-250.628971,-300.064427,-169.949128,-50.974559,155.938382,185.463891,58.177257,-41.01348,-148.228947,-131.527075,-103.35939,-42.156043,-17.295411,-15.811852,-28.984505,-39.106395,-58.45089,-139.628302,-134.083207,-67.994585,112.069382,163.421062,147.585367,123.876474,107.566309,142.623314,159.595761,166.568434,177.325582,215.17705,234.284002,284.433362,299.254635,257.460965,168.709575,149.545566,203.567105,254.194159,299.881729,260.767342,110.002604,114.834657,179.042871,281.642294,312.44849,321.390222,296.651923,233.365588,189.804774,110.947307,159.02068,210.566584,311.847182,335.455544,259.454726,179.630879,45.373808,-1.91056,-16.235887,-13.328091,18.189089,52.868259,25.369737,-91.662209,-150.678081,-196.717998,-178.378628,-175.177734,-132.981643,-101.047506,-121.958965,-147.13006,-149.275239,-196.826605,-238.274747,-254.532347,-216.374002,-123.200828,-104.624547,-133.410203,-171.429797,-245.420717,-214.61902,-171.119381,-108.467432,-92.432335,-68.158994,-55.600756,-29.908457,5.009539,6.101034,-49.259955,-66.270221,-33.155304,-16.993133,-54.632818,-118.26469,-241.52644,-159.451179,-75.917541,13.992631,26.937363,45.856737,25.516745,-129.445679,-209.964544,-143.814835,100.59916,197.991844,226.543275,178.375318,73.180804,28.600834,-64.016878,-91.239813,-56.285321,67.15386,111.968544,117.108659,93.194028,-10.300544,-149.879977,-164.947956,-59.158763,36.417583,219.654955,245.289599,126.394816,29.650492,-112.248621,-131.161957,-118.301029,-94.72904,-76.887297,-43.151246,-73.099647,-228.377858,-276.472441,-222.357837,-57.062567,0.088164,0.181602,-35.352716,-96.627731,-124.546482,-183.741518,-166.194346,-107.647165,52.686676,95.553348,39.053468,-22.103406,-86.724562,-4.737505,90.45483,305.631526,374.233207,349.31518,275.933066,139.634915,96.139382,46.787334,50.497377,66.432366,112.867146,121.805042,71.869319,29.549938,-40.535365,-60.330347,-44.138391,66.09575,148.594665,244.441026,241.787492,256.974522,279.212661,217.288221,94.304183,96.684012,222.812433,267.689729,217.494068,159.187294,54.794638,10.034837,2.966631,4.985851,40.089231,138.854544,158.959477,129.327634,90.169782,-2.192441,-34.148167,-10.96459,94.251493,133.908391,101.169595,55.167769,8.84307,24.182261,13.473069,-39.180362,-29.223825,43.953351,61.228067,62.831542,56.277524,54.08223,121.053593,136.316633,140.695503,175.94885,245.891555,215.826631,22.784953,-73.590803,-41.014645,32.258925,50.42836,65.075643,48.727529,-7.737744,-34.89267,-60.063913,34.359105,111.561103,217.290428,212.876561,125.570673,93.513852,83.897221,127.521493,179.041212,287.541855,325.432422,376.472141,388.243518,383.229743,357.688792,272.691724,277.997694,313.183143,335.848575,310.683338,237.509282,221.978074,228.473821,151.290686,91.667251,120.182299,224.810402,376.919374,347.371727,174.326462,100.45975,46.836422,64.267802,55.856157,70.032198,121.540291,217.7329,241.125952,302.395915,415.821506,462.619413,450.076603,403.378856,319.345725,270.509086,135.973125,81.910011,44.923656,46.944544,48.83333,130.158659,197.139494,220.026196,167.803178,70.966764,48.172279,55.402591,83.930986,92.621892,106.347454,128.169296,164.533027,129.625586,19.260378,75.738644,129.686012,213.335549,261.262447,322.087498,308.566731,213.116801,104.569259,90.647748,186.80948,256.155014,298.555558,265.790624,154.690803,90.272414,14.662326,65.760266,95.42887,89.752776,72.748464,73.856639,87.28981,56.073325,-69.923789,-103.61989,-27.046583,54.006276,171.658708,176.325031,99.103199,45.958518:-235.130625,-215.006888,-135.884709,52.386018,124.496277,163.076352,119.579041,-61.710666,-175.67705,-146.26132,1.536793,78.112792,147.010068,114.929762,25.847178,13.162319,9.736157,-0.786879,5.761109,59.342002,68.037518,-57.18193,-149.065408,-243.137476,-242.229009,-222.087502,-160.51569,-136.996047,-121.706538,-119.27291,-150.854508,-196.420312,-245.654508,-196.128448,-174.480535,-120.084219,-61.015763,52.268544,52.12718,-72.229559,-134.072441,-94.233262,-37.9384,-51.362393,-34.967157,15.960393,103.55264,104.029616,48.069068,39.651057,62.063315,111.03233,120.184759,61.745612,4.629814,-96.129617,-150.169755,-156.201042,-147.358061,-123.452934,-42.284315,-17.852832,-5.030343,-17.838532,-124.307693,-199.326273,-178.63659,-111.02366,-104.924246,-143.194872,-173.083329,-281.043508,-426.920059,-457.916779,-364.434024,-245.386025,-21.780057,-2.445787,-133.484618,-203.65669,-246.993673,-181.845022,-112.077437,54.270132,100.908339,64.726359,22.453609,-25.782525,-44.833329,-37.872835,-3.248348,27.770957,127.514865,162.02614,149.304972,114.732989,23.456787,-0.103944,38.846549,186.142118,269.70877,378.803272,382.83525,315.377094,289.139716,310.209299,343.497376,359.183569,414.408288,409.086335,287.06706,215.548287,142.094157,108.373707,85.063086,97.613979,146.968509,245.000677,247.681233,136.612986,96.536778,178.815382,396.386038,451.4573,431.402921,383.453786,296.034365,275.034784,263.865565,264.192535,245.449299,207.086055,206.792381,165.699646,106.790423,-49.979874,-182.101326,-212.271777,-193.293633,-145.992687,-27.171214,-1.00485,-66.800312,-116.722028,-126.641435,-78.642903,-70.705989,-74.375748,-79.832383,-92.507914,-89.719749,-99.619104,-233.070795,-307.582723,-268.626651,-143.421115,108.918951,166.045862,153.902737,88.992742,-83.638557,-64.112347,0.449745,74.453842,83.106566,109.906955,130.584462,118.577797,60.142991,39.444801,-4.410307,-3.102062,87.156765,121.545406,55.477668,-15.963866,-97.268405,-52.650254,-20.213131,29.60529,67.202669,143.33299,137.437915,9.954754,-86.909522,-70.928315,56.36151,143.696874,242.37069,212.699174,83.046388,22.703518,-120.090601,-189.601017,-149.974779,-18.486368,11.175657,-28.988455,-60.23439,-129.137802,-199.458331,-159.873215,79.596601,198.244546,329.509374,350.176334,302.806753,235.818995,79.455963,3.290864,-9.588497,-46.722538,-70.200958,-98.73609,-111.182284,-178.404403,-251.036245,-237.384725,-119.41122,-61.823703,-24.555276,-36.75202,-83.882302,-118.790278,-167.474795,-105.92049,-54.753035,45.970645,89.905753,131.872497,130.60422,57.151177,-39.625686,-7.952246,197.577586,295.438717,350.807543,307.750907,190.439839,128.181648,-7.576808,10.380364,61.477324,114.774921,140.503105,215.668878,201.531141,-0.905984,-107.749256,-73.98039,-25.025193,-12.245828,73.770283,122.236982,160.92027,149.735714,58.061664,-74.589599,-110.005467,-26.261601,60.123303,118.101729,78.501567,-85.138155,-268.372368,-302.885223,-259.405911,-190.280169,-2.890722,57.091787,104.428708,108.484492,-17.803711,-185.178159,-164.308811,35.736754,106.263716,64.516201,5.723471,-58.471026,-46.278317,-22.054547,46.274469,90.922614,174.202554,190.014893,192.145943,200.461688,232.098406,259.676519,261.150611,277.705883,305.276152,321.626892,284.442601,132.482916,-8.993055,-24.686938,31.785584,77.65618,166.912943,180.573041,117.733965,58.856461,-36.292289,12.107442,75.281479,163.619749,164.590854,103.255119,91.552889,151.821606,208.271322,209.370955,175.867837,182.100546,287.649093,337.883346,334.548415,291.062281,179.863779,135.983294,153.356159,192.775326,192.021886,191.791592,201.1446,172.173862,102.162209,93.69046,188.161039,288.962493,409.149055,357.738388,181.005931,129.859392,72.25979,47.914051,59.624758,179.778818,282.13064,415.780134,418.010912,381.143461,396.965117,431.6695,498.174998,520.376007,529.068593,493.143741,371.19026,312.038863,203.618025,141.306818,131.356929,150.404752,171.320522,185.870523,172.717502,123.894528,75.062172,50.600559,9.369593,20.147881,120.581436,159.846612,153.588076,126.161601,63.419066,82.245949,130.022668,215.607322,233.802281,263.079933,304.955955,330.199692,152.338911,82.590214,127.891948,208.143506,305.208526,281.657432,174.261633,129.438048,27.794413,-56.170018,-49.362177,49.658392,100.932725,129.782204,112.199517,15.970935,-130.656792,-164.182359,-140.482041,-102.238058,20.568297,76.782835,89.063752,46.297702:-267.78311,-147.30229,-70.170224,51.214315,90.788537,108.120874,82.570909,-75.625937,-242.089238,-230.100979,-41.42386,66.780115,151.588914,103.562927,-39.15225,-68.794162,-33.691197,-31.726781,-35.899091,61.086359,92.976739,-69.182317,-209.659642,-363.551428,-270.549001,-215.051479,-185.049599,-155.385027,-68.247466,-70.139144,-167.195961,-224.558828,-292.601292,-297.467805,-279.217463,-158.856858,-68.439831,18.24314,-17.281384,-151.476251,-169.727626,-123.421421,-58.459078,-58.945336,-46.852793,-27.317756,-51.63233,-105.672499,-160.465473,-82.876447,-37.564471,43.845774,60.852808,-27.281264,-109.528361,-256.317154,-333.047696,-316.916813,-183.76235,-112.248371,-80.733359,-112.14574,-166.271089,-202.34122,-297.479805,-286.537977,-243.29027,-170.544027,-166.794175,-240.145372,-321.900479,-554.370788,-654.118468,-622.374979,-473.658777,-359.265309,-165.923917,-170.870897,-350.798951,-436.861775,-491.018175,-372.670534,-254.651062,-2.601132,59.637535,2.35837,-65.427827,-166.214316,-175.4767,-155.939432,-89.241001,-36.483299,45.840005,44.187641,-47.099472,-124.810388,-251.816304,-147.354042,-0.658959,308.22958,396.947347,375.218222,297.567127,130.609948,58.008825,73.73468,181.04162,258.563553,349.739139,317.26759,168.148757,96.920582,-8.910018,-2.334624,53.136537,200.267129,230.827183,115.144668,1.850793,-189.002714,-159.90887,-68.730193,116.595259,193.605892,281.983938,263.930399,161.41435,122.067906,106.895493,140.242612,163.648769,236.05714,257.337337,183.42564,96.444766,-136.953072,-288.229835,-275.788225,-162.332563,-96.812269,28.784172,62.739521,4.653275,-64.309572,-142.107348,-151.468668,-152.718776,-77.552759,-23.282412,-34.368263,-87.121537,-166.119798,-195.329817,-200.689134,-156.997418,-81.346835,102.903085,146.351382,114.791364,58.609616,-73.603192,-135.136613,-126.56622,5.288072,107.008279,223.818391,205.35642,78.146226,27.753607,56.536747,136.983044,174.501946,217.249676,198.368576,77.048795,-0.432191,-98.449734,-28.580009,41.717583,117.960505,110.723102,86.674937,78.934987,-29.433917,-159.27549,-129.257341,153.739081,328.068369,458.082324,379.300402,77.124179,-74.123319,-231.756294,-144.841455,-58.490586,69.054434,72.84558,0.088718,-28.163257,-103.951092,-209.87433,-175.136915,102.270845,230.927448,308.52545,306.319041,276.646219,206.633242,-9.013272,-73.093244,-23.240622,90.915496,91.950132,-2.459916,-61.810299,-179.812487,-205.535211,-155.028801,-15.088426,25.339365,7.593046,-18.217373,-49.288373,-78.143841,-154.113943,-133.277825,-83.833977,98.94278,203.952514,262.216861,208.545259,48.374853,-5.900049,59.70526,291.105503,387.210686,370.138901,249.800668,11.250084,-40.059454,-43.536311,-7.931469,10.87544,84.824615,135.9453,174.808575,135.598849,-51.435438,-189.731303,-182.413157,-86.508642,-25.903823,110.258559,164.963111,156.307904,86.495061,-44.372228,-10.859209,41.81584,161.390075,209.614712,208.622688,159.8824,-14.744012,-188.939944,-194.587698,-58.762249,33.87613,184.688222,217.773791,178.002395,109.962152,-39.306169,-55.564914,7.968495,222.280183,304.144275,282.502106,199.227841,26.029174,8.709052,49.007515,101.561971,126.801547,202.659269,220.243154,188.217494,145.9825,63.798827,103.438158,155.881675,266.964839,301.025875,248.053383,175.866022,18.419684,-124.56453,-154.963227,-35.664822,76.445646,136.532812,53.003729,-122.303252,-146.869042,-102.367195,-64.564051,-56.585579,28.067133,88.169722,69.957185,-4.077596,-100.626689,-41.472505,23.447363,148.443911,195.005303,260.548746,266.88189,187.937462,113.998279,25.114331,145.999795,233.418231,305.965689,290.525866,220.094915,169.18346,42.95801,-12.475482,21.129401,175.429897,253.834525,299.623706,257.514107,139.706903,87.527694,16.568755,48.503884,102.924283,274.581858,373.447727,447.298909,386.966456,231.75423,261.940287,325.709455,422.844787,450.880668,461.914079,429.533983,279.304394,170.964538,32.602125,127.596354,196.901257,265.737868,264.363106,216.135614,172.565952,-2.439338,-121.619683,-90.51587,21.307905,60.831518,99.189418,107.120998,98.983332,63.434226,-25.275363,-10.596189,60.111047,229.067972,264.559855,263.266677,265.712905,197.840632,17.335947,-6.912834,162.513704,279.894641,345.495302,284.06962,131.60692,67.624544,-22.346843,24.404816,83.011094,185.45485,209.721679,210.518852,187.681056,30.502659,-156.468187,-162.299016,-16.53723,75.182047,131.81531,69.394687,-63.191517,-75.462141:-100.680015,-83.981229,-28.82356,116.205222,169.227372,246.641899,285.132995,222.657174,-56.787342,-129.490169,-2.701691,110.465054,194.251859,156.569102,80.131832,73.262286,58.456325,60.439508,90.817751,125.039587,100.731116,2.215754,-50.51208,-132.248023,-145.583858,-125.596447,-90.337372,-80.103884,-56.381731,-45.424792,-48.085657,-86.675433,-206.669291,-233.913481,-200.91458,-32.264002,70.154528,113.000683,49.030869,-111.403407,-207.715199,-198.998323,-146.784338,-146.170069,-123.633752,-76.761229,53.58103,110.946997,131.416665,38.067561,4.169281,60.38868,125.226802,178.766328,146.393409,4.453767,-152.794447,-195.109004,-202.885929,-191.276625,-152.565181,-129.508894,-83.852986,-72.864706,-143.006324,-222.221255,-205.451054,-116.979141,-89.440419,-145.289411,-229.453676,-442.208093,-579.432007,-572.247445,-415.495187,-288.269061,-34.152457,24.942595,-60.893062,-157.562043,-302.168095,-282.187838,-203.558228,18.339172,99.691966,104.26465,64.226086,-13.171863,-116.02274,-143.94443,-103.746245,-68.388813,1.844776,47.068316,115.386897,105.465918,-31.441874,-158.850996,-137.899139,88.092354,238.639396,423.453712,420.587888,248.107083,57.263101,61.088763,229.762427,303.496235,342.888543,324.994012,260.37467,216.831416,85.770873,-8.087198,-2.682236,54.096784,72.689904,69.865752,44.761761,-61.435859,-82.915266,-11.283423,194.367179,278.830524,334.868507,303.508956,181.256018,114.257556,45.621373,99.118752,139.411977,185.488379,191.648092,124.394038,24.449948,-219.135279,-317.960423,-318.060683,-325.338164,-306.820083,-168.395335,-118.024263,-164.878746,-210.751509,-254.686193,-291.145876,-303.217718,-271.036663,-243.564138,-217.993754,-210.789172,-224.483072,-318.096384,-356.164187,-343.319175,-266.90504,5.061944,108.437738,82.47178,-9.858391,-145.909748,-100.911178,-61.267529,-72.188583,-95.144144,-51.688869,15.471339,78.948251,-52.399223,-106.068808,-81.910013,-12.233479,160.304235,199.926009,145.268014,78.991629,-54.812663,-1.19061,97.54864,217.787815,196.159452,72.673525,29.540072,2.010011,-80.528777,-138.126392,-161.180102,-112.80641,-12.476274,-3.59224,-84.828481,-178.306777,-408.718114,-433.729589,-352.636674,-214.529652,-208.005132,-264.489533,-283.866509,-293.505188,-295.267284,-258.030773,-67.77139,53.297401,224.895156,246.192463,192.632132,131.75577,-102.037777,-314.968139,-311.659137,-197.36016,-184.827038,-287.005821,-338.482666,-364.019386,-321.292773,-269.535104,-178.84145,-161.698828,-146.213719,-144.973886,-171.555528,-194.844627,-196.605909,-138.679704,-125.923282,-47.253483,45.891377,155.314651,131.56917,50.292503,26.231736,56.13057,222.091146,323.874641,440.739693,430.289011,311.297676,249.05176,193.853823,185.881134,168.971344,150.423732,183.00066,274.434327,253.279776,11.016571,-182.910284,-170.717377,-51.407494,2.799213,99.612019,133.179668,121.453964,84.899434,7.81728,-64.177262,-108.073519,-147.794123,-135.656977,-143.566318,-170.141964,-254.951035,-321.624535,-297.186967,-178.070542,-112.274867,24.527151,92.17753,197.610119,183.990643,-4.390553,-84.258665,-33.855165,99.372584,129.10601,70.545026,19.55428,-10.215448,0.460721,0.130379,56.093898,111.995411,173.918931,174.336725,238.12538,280.655172,211.053533,129.138552,181.421618,345.128545,374.258953,306.387389,248.992844,114.092115,-1.783569,-14.112742,42.982189,114.933848,285.505116,292.152651,97.203919,-7.30012,-53.867213,22.637517,63.309307,142.073281,170.848732,180.92072,177.615349,182.018274,160.731323,157.339532,154.215689,136.420784,100.939908,90.413726,87.419007,96.437214,103.516238,87.83034,74.181844,79.027024,108.239975,115.76449,83.979244,10.093557,-126.579257,-188.815223,-146.631199,-50.29634,118.975484,150.776605,140.14926,105.467811,12.426584,18.352202,50.316671,141.212463,206.618149,261.74375,224.974338,134.406579,159.6929,230.547333,406.479426,468.50198,496.053736,452.539956,288.346866,208.044417,116.944994,109.992223,118.513371,175.892284,230.513456,278.552644,224.695702,42.923276,-29.353412,-39.700748,-81.384947,-79.990811,26.927305,96.930854,160.763827,139.844821,40.282685,20.662394,58.795961,167.623399,216.858632,256.977872,245.504199,187.231867,102.120314,68.629552,101.966964,182.564875,335.119876,351.421734,293.563766,230.934361,63.489284,8.170907,36.923931,141.749243,212.756731,340.707112,338.127829,142.602408,-113.247362,-152.922404,28.514001,166.018068,245.222613,167.478967,14.344105,13.500548:-269.964734,-177.236434,-49.431374,195.021768,251.296024,240.480729,189.78912,-21.862362,-255.746966,-267.605925,-27.524702,143.427748,309.001678,259.900051,63.632498,-0.28397,-40.423827,-7.481283,35.361629,105.786719,108.55733,61.501646,1.355235,-202.023438,-299.309667,-262.897969,-115.468452,-33.783458,88.704422,98.176853,-23.305946,-133.306804,-319.096928,-333.518421,-273.846149,-71.74698,27.52322,83.244826,23.827715,-185.877907,-324.802106,-311.467691,-185.730741,-116.134792,7.814057,42.806092,35.183909,15.209466,2.549533,27.822249,60.244052,168.418628,196.90521,94.011167,4.817803,-97.512794,-146.582063,-159.388214,-98.748764,-35.4217,38.617687,10.702065,-147.123181,-248.219537,-391.618689,-346.644715,-285.976404,-198.212906,-188.239251,-245.008405,-307.221657,-480.980164,-621.645069,-622.450424,-458.68093,-317.277627,-87.458842,-69.100202,-196.503323,-291.766288,-446.618864,-410.296586,-291.479169,36.227965,148.781962,122.985926,25.796829,-166.46997,-290.088316,-324.450214,-307.042041,-236.769718,-44.358994,22.527813,35.532212,-29.735477,-248.057794,-281.467027,-174.384656,144.972444,285.517034,383.229141,334.692549,182.67083,79.633783,50.57236,98.916581,192.445293,376.320483,380.845958,183.541548,41.337906,-147.012585,-91.258653,-15.998529,138.996515,202.694226,191.685829,103.658736,-141.829571,-276.122799,-229.456157,54.269669,226.607375,426.88597,402.072538,193.951098,88.731417,-15.408374,15.939689,76.176093,251.199915,310.25392,244.383878,127.960877,-149.733736,-294.225113,-291.422813,-209.586586,-138.972702,20.614657,56.78644,-17.89191,-100.867097,-268.431151,-323.313893,-280.929736,-120.340422,-54.382974,-46.244881,-93.549466,-220.08242,-335.523917,-352.65746,-226.916965,-72.100288,258.89121,316.20044,134.613309,-27.636646,-255.834671,-196.244629,-88.901786,129.520599,191.2172,152.249773,73.652198,-74.456724,-116.595728,-100.052767,7.41514,94.081819,245.081151,277.804835,235.910803,138.315565,-139.658788,-172.636803,-78.827018,114.640804,169.281145,178.786725,128.134581,-75.927303,-228.623416,-214.91273,-50.205067,52.21518,218.833069,249.762618,100.851205,-74.15951,-407.04575,-418.878883,-320.549997,-127.019104,-78.661739,-28.720951,-10.116096,-91.108496,-272.641024,-271.078352,-9.942713,159.194225,360.212502,377.319545,283.651991,187.222351,-31.371403,-100.788548,-54.338445,71.170994,94.60198,9.40268,-77.242715,-220.395497,-257.724898,-232.812757,-90.581614,-12.48127,39.261068,17.715605,-71.637979,-140.200592,-266.166106,-204.638087,-98.905242,135.27469,213.517966,215.191945,150.206807,-30.909198,-136.784722,-96.042925,171.732083,339.151808,530.91408,507.599378,290.762187,149.654011,-63.465913,-30.547063,57.305895,246.253874,314.894399,327.940344,238.313602,-100.173851,-301.614706,-275.814771,-133.529762,-54.65546,106.323167,152.128651,102.25802,17.546985,-166.008069,-194.652013,-142.525606,2.367645,54.571111,36.297199,-24.438603,-214.447053,-400.720108,-406.094258,-210.606649,-60.296265,190.741941,243.958165,204.229027,133.293615,-39.601098,-67.595529,4.367816,211.875184,280.849094,266.253249,212.256339,70.141224,-66.993,-71.530538,87.884019,206.684325,361.500239,359.82912,251.265985,179.212646,85.09974,129.183269,177.7445,327.43078,415.106872,436.659537,346.509888,91.394476,-87.055069,-93.525795,36.829127,124.028231,226.759947,211.231367,34.356106,-98.410785,-289.358286,-223.714009,-114.876035,125.074138,201.883718,171.590734,84.283742,-93.520938,-119.976698,-78.736961,24.603605,96.002422,219.090464,196.742329,14.921575,-56.416108,-93.268096,-68.609123,-20.550282,139.343776,194.537943,191.882372,148.77834,-10.842498,-118.463807,-88.782493,72.788932,163.088845,290.130789,292.357331,176.246076,90.027621,-65.727771,-68.084252,5.080914,221.780296,314.774776,342.032638,283.448796,154.924339,131.516589,185.997798,381.930244,473.190907,480.744483,391.717354,250.49416,231.973068,188.204419,141.981205,149.65248,275.601511,366.220235,418.265956,334.798042,34.822103,-138.084711,-119.690012,-6.65202,44.266116,147.764445,190.612697,144.976068,37.72586,-169.448218,-118.670647,-16.557485,159.399141,200.456037,241.092746,252.361583,151.747915,-55.955435,-83.312352,102.744432,240.052348,363.666103,333.90673,206.177994,132.041279,-25.595569,-92.242841,-52.261459,148.579714,248.723337,269.956258,177.078649,-65.82878,-191.820063,-193.171577,-73.815714,28.559419,123.783008,76.878435,-34.742217,-52.414977:-25.716545,-90.675483,-85.918775,12.262624,90.386168,208.297068,220.552326,157.623715,40.945786,5.307675,41.402003,80.653209,92.05888,80.019536,97.902725,116.778116,104.81887,67.022195,80.530416,155.816993,184.115908,164.238529,122.5551,15.028862,-47.816554,-19.860415,87.72518,123.702719,153.677004,147.554589,72.061924,13.662178,-46.473255,18.574806,47.567892,61.565584,80.212094,105.84864,86.159789,-1.652259,-114.247926,-134.065582,-84.885842,-56.306619,-24.564567,9.78375,163.698869,235.517614,239.731389,192.818316,202.869337,252.445365,268.967301,239.280594,204.862178,145.435742,61.379464,27.435444,-4.395327,-17.445011,-22.631976,-11.877289,-12.906936,-49.791198,-172.35327,-216.878903,-216.403661,-240.46238,-228.432582,-118.108843,-77.46661,-155.574217,-305.227155,-287.305133,-64.972361,52.255154,175.213081,180.061931,122.19856,69.651755,-59.553654,-83.948501,-39.556239,74.732338,118.173045,153.693828,142.552978,96.338682,73.130981,53.830827,-45.077483,-89.375794,-74.007834,-33.232134,36.063302,33.034451,-74.105009,-167.245731,-158.39288,-28.355899,58.537513,150.782482,127.539623,-4.594001,-81.164321,-65.423552,36.462779,108.370041,237.345814,257.19244,191.843566,126.757747,-18.599855,-95.9367,-103.171933,-98.561323,-78.663931,-11.27251,-0.204142,-62.675187,-81.622712,-15.011649,190.699792,258.697389,231.598176,167.310182,108.254625,124.48888,125.127239,49.783033,31.684709,92.905889,151.495868,208.963943,172.665135,18.397236,-79.978017,-76.678416,-25.551554,-20.114412,-80.957538,-108.94145,-48.453309,-0.64773,-63.390933,-242.442328,-271.544625,-170.584062,-100.123501,-59.397143,-83.992383,-165.515263,-272.349811,-288.813628,-220.141631,-159.168185,23.767747,123.249814,157.319211,51.956149,-215.963275,-248.145455,-194.696218,-109.164321,-91.45073,-48.673528,-15.000426,-14.413259,-101.545667,-102.188778,12.381068,79.342209,162.413656,195.958918,245.479061,204.698418,-10.276598,-53.699761,36.101464,221.390095,255.245409,222.747777,188.898725,127.911847,71.793867,51.035973,16.540657,-4.754393,-70.073246,-113.860843,-186.016531,-226.974477,-379.110355,-463.395441,-425.572464,-290.431448,-248.524784,-267.899196,-307.35109,-343.530208,-317.040994,-298.1275,-250.048765,-210.155467,-104.006237,-74.50671,-61.728605,-66.248998,-193.968902,-401.302706,-424.804802,-290.8522,-227.055667,-289.240923,-368.79125,-406.007611,-313.827626,-265.929783,-190.6035,-160.947419,-103.319273,-85.471665,-115.241562,-156.653121,-244.359846,-320.853515,-334.064235,-255.999021,-184.398193,-79.814743,-48.171844,7.806409,25.732769,42.804354,162.730175,261.163828,424.078106,451.395128,437.381737,412.071364,321.865547,295.251018,326.254212,371.447336,373.626776,389.721336,382.49328,232.58302,18.07666,-20.854721,74.001388,168.727452,322.965194,337.289634,264.397011,215.886738,141.132299,56.657747,-14.071317,-98.223194,-71.361183,-14.245665,-28.595127,-59.765914,0.571821,43.547575,97.413969,129.857695,185.517792,170.282422,119.388513,110.687781,71.760179,27.005594,41.724455,144.456009,190.550125,174.3057,121.123941,2.56928,-55.215906,-46.929471,6.269429,41.832582,118.220649,137.997074,132.178316,116.15837,45.324006,16.590532,40.919423,56.784604,48.61556,94.797971,123.359595,43.584068,-71.753234,-48.177464,30.22042,43.41701,158.74133,233.764254,186.064828,67.986624,-137.534053,-108.553448,-24.887035,135.192409,172.956257,167.638128,151.78323,122.919224,75.022968,67.546362,111.58463,135.441441,131.815466,110.959336,81.301205,74.841771,70.139994,85.451563,74.820101,11.918373,-10.513214,-29.405961,-44.279498,-110.965795,-182.504224,-192.801088,-191.813929,-191.527193,-147.896029,-103.251597,-43.724888,-49.033109,-102.934699,-140.771029,-130.279862,-40.410725,6.026508,26.229528,9.647738,-55.58691,-111.147733,-79.839837,86.708768,154.803368,200.742096,192.269643,119.223101,69.040922,-15.209684,-60.001838,-66.224118,-47.284207,-28.724553,-10.012674,-25.104003,-107.939791,-235.48836,-286.299487,-319.444373,-306.104446,-221.769649,-161.222059,-59.595395,-51.922422,-120.711155,-116.894674,-93.152382,-85.225742,-62.686649,40.36636,74.145128,63.184998,-29.101039,-74.490246,-33.646951,50.512466,211.347696,250.178499,237.775399,207.615881,143.896422,62.515683,32.565776,91.684475,156.907778,185.650357,138.377855,4.636954,-159.464913,-231.412796,-232.062449,-157.561565,-27.277562,-29.647757,-94.978796,-110.31373:-28.840972,-54.165261,-53.794478,-8.057809,31.424579,116.37217,161.76098,213.437184,115.81283,59.210251,1.19189,-27.803724,-110.715461,-157.546557,-177.618453,-126.73412,0.20315,66.895673,77.214654,49.310004,37.490498,27.549745,-12.026868,-179.44718,-259.232036,-224.050448,-133.051414,-116.558717,-150.956041,-174.987125,-155.604814,-137.354182,-149.208137,-116.375408,-75.623672,16.954838,77.403914,156.583267,147.50276,77.687736,-16.501907,-45.004518,-63.056742,-69.591099,-46.775086,-17.480549,35.721131,57.995611,129.919934,234.988993,269.671411,292.25809,294.809392,262.840482,224.997541,116.996602,43.104489,59.375938,90.527656,53.981658,-64.69663,-95.924673,-55.291149,-21.240277,-45.220083,-118.419438,-141.184339,-183.060576,-197.768603,-191.270855,-177.350037,-211.35346,-318.8769,-328.758591,-214.767462,-133.705053,-10.370937,13.145119,-2.786476,-12.057123,-34.097866,-99.862541,-129.804318,-79.725588,8.709609,163.892877,178.621106,121.732207,70.988883,66.336492,79.707316,91.655538,125.946284,147.650828,180.909006,153.889109,10.497753,-17.801498,18.053866,55.83664,69.481318,143.670583,168.892988,96.053262,14.713107,49.243679,187.275667,245.201773,349.307578,380.553262,328.364443,258.977867,147.681819,136.917018,120.305949,16.239031,-27.620351,-39.39541,-18.066247,23.651302,33.517265,78.430608,274.342167,351.59528,353.087342,308.851471,236.66906,207.514681,120.041465,64.921747,80.257592,165.830784,211.406844,195.327499,115.250289,-38.431081,-82.641597,-98.828566,-169.227102,-201.104155,-211.942374,-222.068546,-289.649933,-307.095499,-257.205586,-199.913107,-199.235877,-233.040884,-253.48319,-254.055693,-230.256526,-221.037866,-314.705367,-350.487752,-323.24145,-247.310368,-8.378245,70.340012,24.598347,-57.366197,-198.729437,-188.778952,-141.035439,-79.137302,-80.043446,-106.359333,-100.258279,-64.944946,-73.672093,-82.91155,-132.409399,-150.148269,-78.445291,-26.405659,3.574906,-6.785623,-48.888007,-31.145979,3.371634,27.409638,44.641996,142.105936,162.395825,81.888319,12.919587,-3.725247,-42.170169,-45.107054,-7.727262,-12.575727,-138.151465,-236.9555,-414.624928,-415.41776,-369.273299,-299.828839,-268.137954,-261.387435,-307.177026,-400.655293,-413.087745,-372.657392,-223.470817,-161.89126,-123.787703,-116.06265,-37.329921,-8.361491,-168.34545,-443.391021,-489.538596,-405.771469,-351.454103,-367.9578,-415.787863,-445.854483,-366.201078,-294.435437,-116.723281,-36.620339,9.801117,-47.878978,-218.022586,-265.319028,-270.905934,-266.310401,-272.877606,-210.115433,-111.245848,99.863706,142.394838,104.758396,117.989818,184.308153,337.761494,400.247494,481.77883,483.975216,396.123251,317.882566,163.542041,138.568357,166.182843,187.795658,182.307741,224.966625,249.752576,148.905763,-23.115652,-22.391871,87.571563,118.577872,135.923683,155.45772,180.009754,137.687553,-19.962767,-77.947688,-80.373621,-97.023579,-90.509805,-11.182579,37.635166,19.116333,-93.771537,-83.135703,40.056053,83.147364,124.588882,162.466244,273.376836,300.689068,217.442395,87.125732,87.465977,232.436198,299.48803,224.633954,113.985319,-42.55738,-26.77132,47.478249,179.451632,176.99383,139.260805,152.001829,218.846772,237.866076,175.921777,111.024808,109.096124,74.006762,48.253422,100.436561,172.902954,209.751203,102.695556,97.754747,153.241756,174.596399,223.868376,240.441702,198.400548,138.208987,24.81691,26.882972,52.265423,117.616737,156.063238,220.616446,246.619766,217.219742,112.570755,126.807159,261.008823,299.794548,319.080348,318.845669,252.571987,213.72639,212.938108,223.880266,198.048772,145.246873,151.024333,173.051602,164.834233,106.219834,-29.915449,-94.855383,-131.834825,-95.616221,56.51439,127.587958,181.611341,174.014299,99.640735,-10.624322,-39.304996,-9.982589,18.729494,48.10956,65.395233,84.194111,81.310714,130.520161,256.060413,261.841603,200.326474,172.293782,96.438862,41.675749,-68.134281,-143.109379,-148.966234,-46.805233,36.722866,86.75816,35.029076,-110.794811,-208.300089,-213.864376,-185.800875,-184.509946,-172.819027,-124.756443,36.494943,77.409629,-1.742853,-86.166474,-92.405781,-77.215286,-49.285704,68.821848,147.507006,200.335205,1.336824,-89.391166,-58.476322,33.309109,221.685163,270.594163,230.355433,152.824559,-20.775158,-38.870395,8.207795,103.931265,131.416274,118.629543,94.563273,56.081809,-42.886508,-105.4617,-127.833606,-68.291596,87.573062,125.780335,126.081073,119.312872:-40.024378,-80.61809,-45.558698,138.501936,218.555683,234.908931,201.538458,77.024702,-85.406634,-111.23488,-2.392581,119.319291,298.906864,276.048495,150.904415,128.047834,127.733813,194.377315,244.824866,272.377644,247.297021,168.297506,127.182659,56.736019,-42.073927,-84.26627,-5.267825,108.553076,253.635,247.599689,166.680409,100.759675,-50.008097,-142.300665,-160.878754,-81.278797,1.52551,54.419677,10.768124,-80.111189,-126.41054,-131.464514,-125.331651,-113.59149,1.215404,83.054799,143.501121,118.694809,60.646907,70.250015,82.332488,112.027696,144.810435,170.906358,146.746945,93.937357,36.647028,5.76891,-1.519635,22.804851,50.437029,39.872402,0.937322,-19.348859,-68.051951,-123.413604,-140.886565,-131.078306,-115.811958,-122.62712,-158.047867,-258.643283,-313.082505,-304.332444,-183.557629,-72.523538,112.306362,109.580422,-68.423281,-159.902563,-241.721042,-232.183496,-176.639737,2.457886,61.403617,59.4469,32.5776,-43.653224,-145.756025,-164.834716,-127.849906,-104.27582,-68.396368,-30.53412,53.742021,28.673161,-191.306947,-287.839768,-201.03427,45.976324,123.940633,196.524486,201.86071,115.784825,-6.895524,-9.02482,140.332088,239.98805,319.486255,282.879074,173.134037,127.730154,-4.638082,-113.163786,-93.642572,41.955505,97.502311,118.961487,90.19218,-12.553812,-87.028668,-58.676642,94.967072,177.179124,269.568596,230.471699,85.525088,78.454732,109.621913,30.394432,10.761039,67.555968,104.619748,110.242438,76.532297,-52.828245,-209.577043,-244.033775,-162.573463,-81.052737,-10.86668,-50.830311,-116.867003,-90.005611,-60.022519,-178.369536,-208.081524,-133.830247,-100.398887,-130.596087,-148.789184,-190.734806,-353.697874,-420.695647,-391.206173,-300.802912,-17.001832,117.138388,130.82813,3.570378,-262.266843,-233.036108,-119.227791,55.305788,71.895547,27.756326,-1.505067,-9.782099,28.384873,19.121507,-23.049537,23.020247,214.10619,253.686244,179.588918,125.446476,31.280063,-37.766996,-13.844864,150.193769,219.286933,174.445719,81.110233,-54.386177,-66.765049,-66.288115,-66.687507,-64.099391,-58.022782,-52.41526,-84.202735,-151.045712,-345.442964,-378.95387,-316.156276,-212.890522,-214.210095,-282.63296,-295.305539,-240.507153,-239.073293,-237.603608,-113.277445,-14.874657,131.355119,146.725394,66.8425,-9.005206,-187.853606,-275.017877,-262.020067,-185.964593,-145.480943,-97.597932,-106.566701,-189.305697,-238.346722,-187.854572,-42.372861,-14.29386,3.019929,22.879419,30.771861,-13.465503,-163.240082,-215.928686,-173.597809,-1.65318,70.7909,58.482127,-0.269867,-60.622476,-15.566584,12.052427,128.082368,227.568223,355.960551,346.489908,267.054364,221.779512,127.011116,94.349629,106.333063,163.598584,208.898877,294.471622,297.818788,171.124467,-24.955214,-60.190249,-5.112966,49.471035,220.068609,290.983356,245.834224,147.320827,-52.203585,-159.806833,-180.494772,-109.395743,-38.847326,-29.711621,-94.901595,-197.808435,-237.815822,-232.456621,-113.216709,-27.66439,105.294528,150.962124,181.672475,144.187237,10.685542,-42.158146,-14.687404,112.489122,166.096794,152.742467,102.466046,9.67643,-25.467435,-20.686486,-4.915641,-1.83617,65.552635,130.926374,200.391825,168.184265,68.920702,101.718877,137.892647,159.72164,174.690136,237.677667,239.198936,107.374989,-82.842095,-114.311622,-31.573214,42.0375,204.415899,250.668214,176.243659,82.015009,-109.936889,-185.052863,-137.795573,74.764401,171.957089,218.151533,179.647806,88.316418,1.203424,-23.067929,-8.348201,17.875872,38.806286,11.222886,-41.247172,-57.325122,-100.456822,-45.833112,-4.46621,30.239867,43.192183,35.956411,11.093139,-37.568584,-141.659265,-198.33699,-160.373225,-61.528618,102.724046,114.574398,56.094004,5.656123,-127.942258,-166.20631,-115.143864,66.866461,150.893224,184.744659,144.154723,68.786238,46.576085,73.393049,212.648942,295.459163,399.295949,396.053113,301.269617,236.713209,127.591056,117.550609,127.037269,160.579636,195.878806,210.501069,151.266723,-52.572962,-161.42199,-135.86266,-35.281536,-8.269526,30.297649,75.423159,163.498749,116.796116,-130.855438,-143.364073,-89.245384,-81.906847,-58.621196,100.755815,139.249917,27.512808,-123.189271,-115.427426,58.653062,158.432152,301.227181,327.336024,253.745295,175.289919,56.079284,59.680153,65.77401,65.238543,107.995969,204.71682,173.376149,-45.690641,-254.231408,-292.368548,-221.76439,-129.460655,29.46749,35.438258,-26.671851,-52.742199:backward
237.942492,153.998488,119.751759,144.526616,185.022831,205.090824,176.505429,126.192412,97.650484,87.560768,118.281773,155.950898,208.101388,200.247151,168.718852,180.208061,203.371698,141.027034,136.166647,201.663392,203.284077,96.189011,44.385521,46.298831,33.126653,-7.97477,-12.344109,14.311887,6.357096,-19.770661,-64.037944,-91.630361,-167.694956,-200.719739,-197.1762,-163.073919,-127.538127,-69.079587,-57.646983,-18.724672,-7.370365,-26.055012,-56.106249,-62.621093,-43.416911,-20.387661,-25.568788,-57.394501,-102.578143,-97.02817,-79.216818,-36.094251,-18.978871,27.383692,52.573953,91.786976,156.83754,187.850317,190.870841,187.059603,306.587911,408.789382,470.953916,413.589394,268.751488,183.048738,171.612488,154.48195,115.040738,1.459399,-21.087365,38.87283,37.517587,-14.29353,-61.131235,-36.773936,-16.216937,-47.985171,-152.7027,-197.191288,-233.396122,-168.5941,-117.523796,-70.710295,-47.635164,46.457197,79.245305,136.974617,215.713429,213.699479,168.149438,170.244966,222.124388,253.432928,318.151623,354.038239,418.535772,440.355591,424.348687,379.777174,387.549311,459.65812,486.19371,460.606867,387.192362,379.864618,415.871659,412.614249,342.577029,312.317409,275.928951,244.681769,179.795796,216.317627,246.322389,218.775423,179.633354,143.725273,131.579583,42.627395,3.32615,45.770641,117.357055,88.276202,-30.168985,-61.244188,-46.946434,-31.578682,-40.26843,-103.65059,-124.447277,-77.422917,-32.904646,-19.851946,-51.926375,-57.174815,20.259404,43.778063,16.720296,-35.069618,-94.29676,-69.428946,-16.866798,-9.295142,51.168146,133.992853,134.923371,68.121901,59.997181,147.429029,190.949724,194.330263,125.103324,115.559105,191.93029,218.99705,182.429966,148.871986,57.416811,-0.619226,-64.85053,-9.333832,57.798505,194.889201,237.394862,245.435463,211.15487,127.968811,101.947864,103.640537,43.806762,-42.85733,-189.96437,-164.671855,47.95644,127.686044,88.976513,21.535714,35.504039,74.455319,82.293788,75.704109,64.868667,84.202649,177.087714,222.145063,235.965699,204.143558,200.278643,257.0952,333.793978,314.565302,203.518572,45.733144,8.686838,109.847439,209.48511,324.962864,310.774363,187.139648,42.856724,3.21607,-1.500205,17.665914,62.37763,63.837129,10.942532,-22.188647,-75.200563,-58.652852,-6.523102,133.590521,196.374879,294.073118,327.996279,334.955248,167.415,61.061373,23.752595,88.152034,172.056748,124.229801,-59.179846,-98.100979,-56.022112,-28.463605,-5.308358,126.899567,205.592444,226.488664,138.929332,-86.255795,-162.303263,-139.243099,-46.552524,-10.225599,19.602323,22.093977,18.722944,12.211332,-46.428437,-135.961496,-161.172878,-209.45513,-233.240882,-209.690581,-156.486022,-14.740744,21.329343,-24.590469,-88.13844,-71.834385,-2.533328,30.702758,88.157457,94.306018,10.521299,-37.731245,-0.073565,96.377874,136.920747,233.935621,278.560518,315.924749,267.26619,215.212252,102.563822,54.861462,-5.68824,-16.833925,10.870998,52.703173,91.588361,4.227762,-35.338399,-11.529921,38.420501,114.33232,111.114887,41.134556,-72.452404,-134.587811,-184.802803,-162.545092,-124.613544,-148.908448,-249.289218,-285.536775,-298.701177,-305.483776,-312.932863,-284.673262,-255.477696,-212.55657,-189.322661,-126.560924,-129.519799,-142.140985,-125.198219,-101.374502,2.225837,64.665857,95.480221,65.018909,12.908098,58.818006,106.201339,190.991501,228.080512,257.297,227.818677,132.621856,66.363199,49.533485,15.644565,-16.95186,-40.664904,-10.014426,49.390331,49.459616,-21.62916,-128.144842,-145.588211,-123.803362,-115.00455,-133.879796,-172.953344,-294.925479,-397.170611,-418.319502,-388.956504,-360.997657,-302.834438,-257.180535,-156.60066,-138.959014,-207.116047,-279.039281,-265.872108,-196.682327,-178.64788,-218.359699,-260.196802,-301.738864,-363.961945,-416.924568,-448.121163,-427.112071,-364.852759,-338.592133,-312.628266,-286.553254,-214.316866,-216.703559,-226.571918,-163.782784,-80.4899,70.872749,71.548148,-99.53353,-329.155003,-384.550369,-313.416695,-226.36683,-69.932928,-11.086765,86.288942,99.597536,-17.428199,-148.177962,-135.265942,-31.883907,-3.083781,-56.257414,-122.422088,-230.829018,-281.862792,-286.664795,-214.127613,-158.638012,-99.59002,-95.815295,-106.226719,-113.390783,-140.29444,-195.71789,-215.694843,-189.361316,-144.782142,-56.681077,-35.975809,-72.194427,-167.532994,-196.307067,-230.402207,-270.218311,-335.451862,-322.579043,-272.861915,-247.382125:204.622312,130.974818,107.336547,155.530563,204.695278,252.555936,240.891958,155.879976,-36.418742,-111.238186,-46.691918,45.145574,157.854444,180.27199,197.371643,179.422665,92.520836,81.130343,136.500764,282.32845,320.013791,260.519467,181.558667,43.515116,41.734023,75.981892,99.054925,62.888407,9.443264,39.781027,99.747466,59.479747,-112.612729,-154.575614,-108.777934,-32.586092,-39.245248,-113.791517,-151.864689,-179.565681,-188.433096,-176.157617,-114.802161,-117.723232,-167.250747,-145.351673,-33.317414,-12.324323,-90.636074,-115.855027,-37.839805,172.849005,214.905925,106.15733,15.974518,-36.475371,57.022862,80.419667,29.77323,-0.120274,101.408499,217.717049,340.524401,313.474846,191.781616,118.929046,105.682056,91.508017,86.531381,8.725642,-61.3983,-131.513487,-114.260739,-108.830816,-66.361621,-30.074249,12.076767,0.55223,-68.484302,-97.462603,-125.230522,-109.658927,-88.40251,-43.717733,-1.67699,108.933632,128.789002,95.71951,119.400193,156.829082,207.49635,215.409508,192.752941,154.442905,129.270058,190.947188,331.749342,290.397661,247.93558,248.208487,273.350548,290.638909,286.317097,299.515934,305.022115,291.671319,254.872819,238.387951,237.052621,247.710364,248.707657,231.175397,158.721994,114.261497,101.331791,17.905559,-11.995388,6.099944,-6.406844,-119.224678,-148.504553,-97.405226,-19.036418,-32.34876,-52.953055,-32.131084,-26.964646,-63.936181,-137.621753,-110.349651,-67.277711,-23.788641,-34.213834,-65.15507,-71.790778,-83.236887,-109.97499,-113.180691,-102.32136,-84.636392,-7.699609,11.281075,-35.049517,-44.986783,4.561065,4.099467,-4.441599,26.156721,52.032278,83.772941,81.423161,51.043967,40.579613,67.38448,161.330597,192.179991,219.494058,232.97046,204.63962,148.114682,32.871386,4.788001,40.154284,196.158715,260.749045,237.849472,164.582904,33.833625,32.522415,50.135388,5.234842,-30.378444,-25.703779,-13.486264,10.469483,43.374871,50.129612,-41.183987,-54.946019,-2.055561,38.897947,64.886942,39.693645,4.689239,47.278309,89.130734,155.670629,150.390161,114.282718,121.830866,107.884604,48.87897,-78.455101,-88.61492,-52.22743,68.702185,137.172875,207.33311,176.459259,42.342206,-33.454284,-38.989421,-14.97292,13.432744,66.584186,73.427747,47.105276,-0.38181,-167.715885,-177.922435,-98.765723,28.151575,57.332474,143.596431,210.90674,272.704994,132.591042,62.256638,20.270666,5.348794,-19.777336,-26.133577,-104.649966,-156.857779,-168.843974,-48.948847,34.293841,137.501295,132.744756,74.542763,34.935426,-86.90347,-168.860068,-136.842387,20.593789,66.386022,26.679427,-11.386677,-11.421617,16.151575,17.031337,-36.552331,-59.105556,-117.450697,-127.132198,-45.044811,16.703312,66.705022,-26.555609,-63.831541,-21.789941,22.916969,137.897402,207.904009,245.251391,186.127911,20.99276,26.366808,103.652895,238.785643,271.179743,292.925951,270.494179,199.587228,164.260894,145.773845,145.677425,179.259002,199.627963,149.717332,55.810058,54.496335,80.482619,95.449393,107.209784,133.986143,141.313826,133.644412,117.095499,38.142389,-125.818585,-195.505923,-189.450287,-123.526152,5.067614,13.258348,-92.631353,-145.619893,-178.834095,-243.66538,-275.365101,-222.389714,-164.3996,-102.953102,-95.064385,-107.738207,-109.073997,-54.279492,73.195338,100.947327,159.011352,204.295026,210.839988,170.663462,121.789153,137.68421,162.544725,232.728407,269.667656,293.038275,257.426368,140.907398,91.204434,112.621511,156.922294,142.200149,121.431604,155.847057,227.651636,206.596133,60.314456,-37.452133,-41.264605,7.085308,59.768884,115.961307,77.369382,-24.295292,-130.228774,-205.601213,-276.851669,-235.845034,-93.504356,-62.031593,-91.687564,-121.133295,-208.389937,-294.71831,-299.814766,-206.16355,-137.076138,-102.48838,-154.221428,-284.413674,-353.2387,-363.074539,-343.354841,-333.074188,-333.927574,-320.508039,-233.756881,-182.889036,-138.956478,-133.651467,-102.510761,-0.890366,40.364192,64.908852,47.522769,-34.222646,-157.64372,-192.623757,-174.347865,-149.627187,-70.067289,-0.752976,141.894804,158.990921,45.600112,-50.393164,-27.003178,72.169177,81.832903,-19.253565,-78.980715,-142.769805,-218.792787,-254.240951,-235.695848,-173.274503,-36.996748,-16.958396,-45.99433,-45.625631,-33.770419,-103.900374,-141.544231,-104.32832,-29.522398,87.054937,83.204768,-27.636626,-171.712542,-211.110211,-208.629906,-170.23551,-82.220205,-84.746028,-149.38305,-156.046325:70.707703,56.334145,82.169296,140.19033,148.044258,167.416456,192.295324,187.838046,14.991291,-66.702197,-59.527475,-3.183485,94.042047,126.673502,121.930458,71.928353,-29.29721,20.517116,81.813923,144.186094,137.073924,107.334556,93.852146,47.526463,-25.607739,-41.625327,-11.064424,9.732299,63.655316,89.873843,35.810333,-45.869384,-204.699335,-229.507269,-190.012901,-101.042532,-80.290864,-108.9749,-136.700819,-157.710587,-189.612158,-194.636106,-131.594557,-112.32815,-156.554446,-166.364462,-116.233709,-97.678333,-131.10905,-164.587886,-131.599545,8.656062,67.431246,76.713126,48.261546,0.725164,-45.00358,-60.079927,-27.812827,14.681025,97.356299,117.601192,139.216797,155.210764,138.831829,95.00264,89.469708,44.880316,12.848401,-16.914602,-29.801303,-104.884111,-196.356207,-186.817467,-64.099714,-0.052696,83.158735,74.283086,-79.042052,-168.939116,-260.206565,-240.753416,-182.899534,-28.021754,23.315404,41.812589,31.342557,38.364246,81.900259,90.343086,86.187032,90.324389,124.009091,139.174532,115.71708,87.557142,87.533259,172.971804,193.923981,150.895544,133.365686,159.452079,171.93534,175.295186,189.431577,201.431012,223.432938,219.490244,157.479026,111.726924,84.069513,101.961611,72.722896,-25.431685,-58.086858,-95.565273,-96.053351,-86.129824,-107.594923,-165.302248,-156.902228,-152.717421,-148.258506,-116.857638,-14.513038,10.346754,-43.328727,-106.515411,-219.171362,-171.304879,-115.841212,-56.855687,-39.032361,-32.815211,-51.16305,-87.854698,-127.367848,-128.409397,-59.98313,-24.580721,33.613783,60.077479,33.200279,-5.556309,-17.885798,13.698598,5.093542,-20.155375,-9.133687,12.546448,-4.258875,-71.750253,-88.551298,-51.927893,49.681338,92.11696,200.640105,241.065151,168.894813,70.450592,-117.348751,-96.062388,-6.917042,152.008793,198.525007,226.92858,205.121492,127.118428,18.34157,-17.266594,12.786559,44.120824,44.420951,13.8375,-35.201123,-34.549015,-27.698443,-6.517191,36.487492,143.282904,162.059378,102.895236,65.440018,42.405715,21.129091,16.379707,66.623846,101.939057,139.418188,147.100626,133.203345,93.162409,-27.515841,-74.921105,-54.146621,35.768572,86.144725,138.548666,132.956866,80.411213,24.783481,15.331998,10.784032,13.24423,56.121584,92.312332,137.080102,111.062253,-31.965539,-95.131957,-73.751251,-17.709766,10.700737,84.107027,120.359051,152.315771,79.609149,29.034831,-37.349291,-38.48971,58.110987,100.982729,0.545295,-99.270042,-196.559415,-82.165902,4.267365,87.957419,93.664492,93.242131,80.302892,2.939389,-42.33008,-8.893595,112.938302,149.493874,132.381984,111.682447,116.681496,121.781346,98.812295,112.592603,112.061616,45.860043,26.624869,90.290048,141.539223,144.515361,14.427035,-5.751537,105.639669,156.257118,193.636864,226.608698,291.904144,276.297634,181.049742,184.147401,199.962419,202.012435,238.794328,374.605682,394.549987,292.750017,212.050818,235.718976,330.665634,349.279905,299.090355,245.846592,139.948778,105.133748,83.838736,169.351355,238.310151,295.790304,273.643499,207.401692,177.234741,84.874296,-46.867233,-86.425318,-71.394571,-32.863306,59.287002,74.033982,-42.342447,-124.590539,-177.251297,-116.303673,-75.293772,2.256613,23.170161,21.370731,20.796932,12.08107,-16.19259,4.261029,111.029291,157.733205,163.330951,122.196563,46.567152,45.475628,76.093353,105.770133,145.519244,279.763062,329.465735,281.261849,212.883629,131.32497,104.846084,115.161883,186.988691,210.813413,223.559292,233.579251,244.812064,224.523799,115.056423,35.980185,53.160269,154.793328,194.537825,166.491291,113.105814,11.948983,-95.612768,-155.068414,-186.736601,-126.535264,54.882089,84.120068,-46.470318,-134.492931,-203.447005,-209.045307,-240.084063,-277.633317,-241.734064,-178.644253,-199.760505,-285.500584,-385.061381,-427.819141,-447.428259,-424.595069,-307.690814,-231.743161,-165.160854,-187.81782,-264.095227,-251.210494,-197.017884,-59.578007,1.542096,74.767697,66.672014,-60.444509,-219.611703,-251.558166,-173.494084,-94.447629,13.911836,26.091804,21.670058,34.971044,48.92944,-1.058411,0.211944,80.096157,119.817442,141.173098,122.333583,-6.417772,-177.448807,-186.265758,-93.026044,-73.822447,-87.298877,-67.651009,26.714324,56.848754,44.336591,30.753287,34.553482,67.029354,94.732846,112.284222,88.28466,-37.414484,-195.961988,-204.732771,-107.233004,-73.568994,-59.674281,-55.723498,-41.13345,-43.78916:94.836765,46.800101,41.349976,52.465246,41.287659,44.65523,70.375432,68.041946,-23.46912,-42.890243,65.846285,150.287816,226.767061,214.805672,160.596569,143.720063,119.407752,86.072309,83.755065,96.628782,87.844268,29.779415,4.181281,-7.062422,-59.067533,-111.303476,-154.543865,-123.432234,-39.428645,-26.200901,-71.980635,-124.626686,-270.924268,-318.417832,-259.116997,-131.701842,-140.759796,-216.656735,-199.708448,-74.272903,-13.258423,-5.356542,11.197867,0.862187,-58.160765,-75.357009,-82.71225,-95.100247,-126.61594,-107.188561,-79.004176,-25.789254,0.836005,58.153554,69.792599,56.69865,13.674221,-3.719145,56.86123,122.831924,235.317054,277.353524,306.750802,279.903261,195.919311,141.96018,143.290529,154.579162,134.623505,66.278459,32.28706,-8.341444,-41.27933,-53.242316,8.906533,59.896131,85.090092,42.919827,-117.849206,-192.550882,-221.495969,-151.307132,-144.58259,-153.377994,-103.342814,72.247227,113.740695,77.079444,65.651164,86.060985,115.783022,108.887497,78.453771,81.238567,136.278309,179.64117,262.920085,299.256801,301.636727,268.087206,249.358411,303.458888,371.640485,472.971259,408.180797,334.628256,283.64819,309.03101,296.896145,240.977708,155.704671,160.791367,186.421754,187.808547,200.90651,189.699126,143.267856,11.594541,-38.843546,-36.970623,25.176474,32.05022,14.684831,9.226142,10.060864,9.34003,-0.467365,-15.935338,-90.963376,-105.57543,-62.505723,17.45991,32.62894,26.929511,10.518323,-10.065663,3.733961,7.905254,15.532647,23.850789,25.14112,8.343503,-11.727342,20.892441,111.248242,120.240474,119.893989,140.433407,147.355661,134.851506,110.091511,68.982851,107.24415,144.43587,184.012954,174.297307,176.325193,200.899839,179.952748,122.631256,29.497887,6.940091,22.328094,112.066787,160.537922,168.800284,110.772898,-31.635524,-23.664916,32.497837,107.222863,73.924858,-45.794422,-61.198282,-14.588341,4.750217,-20.423754,-64.331335,-50.570016,15.158508,40.726053,65.761702,65.772816,62.380771,69.674807,82.084234,116.487862,113.89335,115.970915,157.941251,220.657128,187.483363,33.430127,-62.765567,-48.719336,64.259399,137.306861,233.907699,217.544316,97.160715,5.419414,-30.489212,-88.955419,-92.467967,-47.771479,-22.788158,4.49434,7.884333,-34.489748,-110.770666,-112.948568,-10.185976,68.78877,203.171864,250.894285,303.297297,212.44205,130.912711,35.487557,37.307008,73.283045,56.531944,-82.165619,-140.265413,-142.980812,-80.847158,-25.568434,92.944861,127.305633,145.370809,119.396419,-13.331067,-109.758621,-93.017884,9.795955,43.616108,50.600032,48.943998,67.971036,77.410456,40.090066,-5.065556,-2.333927,13.024444,29.262593,89.012156,115.582239,117.309086,12.786289,-33.23359,33.380539,114.604401,183.018182,164.255542,149.948563,162.163035,127.172114,82.931274,111.700397,206.83001,232.707696,270.07551,300.265366,291.465667,149.619013,105.855487,128.35505,138.747384,129.697908,142.353807,157.692245,132.903248,63.982104,48.312219,69.381398,146.252832,184.932589,224.065903,207.35086,87.572889,-80.793628,-145.230887,-169.95042,-137.199073,-80.389876,-94.945608,-207.076551,-266.07353,-310.527417,-285.865065,-282.016391,-267.512058,-220.490223,-74.76075,-32.910757,-48.062488,-103.486246,-111.868237,-78.339547,-60.782482,-29.687733,-4.574809,20.529448,6.903278,-23.545769,18.869203,70.355517,178.813932,211.911917,204.142974,179.397261,169.674457,188.107274,191.087892,172.454709,157.230703,194.117234,242.444982,293.38729,271.080494,149.941159,41.130952,34.591252,91.302914,117.239521,70.730895,2.098768,-101.589915,-178.348427,-236.183163,-267.77135,-212.88261,-65.526567,-16.649776,-2.971957,-45.182811,-170.844769,-220.153518,-239.311678,-274.396868,-252.241957,-192.215427,-206.58967,-321.563051,-459.221614,-502.9875,-519.312016,-499.443,-405.087037,-344.475852,-283.656028,-274.325569,-212.348281,-162.564101,-160.705665,-145.140627,-102.953619,47.416401,91.750331,-5.260374,-192.673991,-233.487403,-188.276045,-137.4613,-19.768837,41.528261,130.669815,145.718441,75.297142,-20.305681,4.532138,103.000005,111.920863,66.404522,23.168463,-121.215781,-216.353136,-191.502096,-109.877798,-111.066562,-132.159908,-98.356487,15.64332,32.89466,-38.662416,-61.838741,-45.959001,-37.20357,-15.746716,78.401882,101.605741,47.929511,-68.229891,-104.142907,-108.609337,-107.003471,-124.25816,-126.965836,-93.455947,-62.017975:-53.431048,-107.910432,-84.477768,-5.854414,20.697852,34.155765,35.150269,3.553701,-56.399898,-40.09233,71.934724,116.073266,143.987401,132.695654,49.142172,-6.207831,-66.479764,-39.776908,-17.601382,-20.920915,-32.874695,-43.486883,-66.854568,-133.480676,-170.261289,-172.96427,-155.400831,-146.947336,-110.012635,-76.291341,-70.990957,-142.770248,-387.528351,-476.97361,-408.231418,-242.101208,-205.190429,-165.973699,-145.057034,-125.356387,-137.398635,-133.501235,-80.796996,-53.932277,-64.465985,-95.265987,-144.742452,-172.695125,-277.024842,-273.66713,-202.224511,-76.761058,-35.743658,56.139692,80.194497,9.478711,-134.126062,-152.593729,-5.179054,104.12716,226.32766,217.273333,132.031076,94.788512,5.411331,-68.212704,-46.295249,93.16511,156.011469,136.808117,60.91146,-51.839835,-27.556187,-8.375085,18.517862,50.704342,131.73915,119.254789,-59.076899,-156.693828,-230.05937,-200.241035,-176.85668,-89.710561,-32.247575,-3.748969,-36.835166,-74.232462,-41.528532,-6.660593,66.460659,80.674217,95.726885,105.187121,125.411684,142.099345,163.413052,203.849915,236.43758,257.511545,253.438543,282.979403,309.366617,313.380557,221.097272,175.412572,200.716994,258.963068,281.580042,220.437583,117.469945,115.624151,121.132897,81.503067,58.947775,43.203862,50.291866,25.99705,-14.793271,-102.869955,-155.524192,-137.890124,-9.823814,57.21441,96.344693,68.155511,36.731521,45.807202,-6.088403,-64.467635,-37.857958,39.322821,68.738873,128.803022,133.816036,48.686053,-28.658176,-16.341467,55.892554,75.47625,72.627988,56.475227,-2.364596,-19.160749,-10.255568,-3.514216,3.441493,-7.560791,-20.122162,-16.225372,-14.533933,-21.959813,-31.293215,-21.48888,73.700207,135.215173,225.67876,244.716756,189.956471,116.681487,-28.050172,2.616647,79.072435,180.901643,170.438528,53.235598,-21.569257,-99.888765,-45.405555,-2.69909,62.352198,79.339588,85.35483,74.222829,27.172222,-0.543956,-80.688499,-129.048061,-90.903623,23.280334,56.152098,85.483621,73.83342,-3.777217,-34.701945,14.739917,153.568269,159.100048,90.041614,107.175844,217.66155,210.385289,-9.50031,-166.603994,-103.73295,150.568469,224.329494,208.852907,168.097743,91.033047,19.216539,-6.285788,2.428719,35.120733,82.933522,78.909746,64.015841,62.790077,0.446924,-78.31994,-61.255139,51.955187,108.062395,208.864603,251.775707,222.279475,76.765432,46.134653,70.251481,94.30563,152.129078,155.893104,53.073922,-25.434763,-113.961478,-23.75347,64.309877,206.964394,247.056652,262.996484,225.578021,84.623889,-22.457806,-14.507351,124.806449,202.660244,242.207425,201.779151,113.268337,83.815106,9.211972,5.938441,51.556906,140.788298,179.981812,240.974754,236.634041,162.398792,74.483972,69.258021,140.378974,173.843074,216.046346,234.430401,246.345003,244.271085,248.085441,234.999312,218.380714,223.395904,263.650937,364.17216,375.58327,267.783941,136.564672,146.521598,258.837529,292.009218,292.779302,263.74433,143.375758,92.598006,61.196802,71.524088,113.215159,236.559819,257.423272,184.309231,140.78393,74.80147,-62.356665,-124.370068,-127.758441,-87.057106,-22.440068,-33.330249,-146.443001,-223.609057,-313.647249,-220.298923,-153.588238,-64.343339,-27.985958,23.169999,41.555383,27.819166,-83.415414,-99.924524,-0.979405,46.793265,43.020867,30.445359,61.571818,66.910754,-24.183388,-77.173003,-34.127819,147.175125,224.251238,224.198493,182.944449,135.520396,78.511189,62.26144,149.23915,231.460839,311.948976,291.816033,246.898749,228.886643,121.207408,21.00361,27.394017,126.481642,184.557506,210.77701,164.316997,27.924264,-86.764382,-122.888205,-113.954403,-64.464827,79.012522,135.162232,110.049031,17.220176,-217.375286,-293.273954,-255.771861,-135.373485,-103.387764,-175.762414,-240.942774,-343.158417,-468.005447,-499.134067,-436.617274,-383.829975,-282.622727,-242.071913,-265.32306,-324.956434,-388.805037,-276.425657,-197.765332,-97.8185,-53.702666,57.594372,81.944547,-7.354729,-190.846167,-237.948032,-169.780187,-87.297149,55.487437,90.257938,124.715302,143.336407,123.756142,15.064455,-13.548853,46.81945,101.023253,106.77613,42.272761,-129.818687,-232.695591,-226.107108,-151.776257,-119.119054,-37.324899,22.283594,76.598808,34.568268,-78.900539,-11.169179,66.160774,154.685122,159.467946,132.32161,100.977408,13.62489,-108.121547,-169.451632,-178.609553,-118.402872,20.200844,45.557703,-9.440299,-61.11645:116.463644,8.962529,-16.38599,11.589106,44.475774,79.088077,66.619702,20.943821,26.050657,56.457418,140.186529,170.671686,195.469952,187.52933,102.785744,50.637919,15.198454,52.049614,78.500275,79.135016,48.009706,-21.300522,-68.683393,-183.276038,-222.077637,-206.273792,-153.470055,-140.512576,-128.433221,-120.965417,-155.853373,-198.123756,-293.132201,-361.402468,-332.405386,-187.262467,-154.27666,-158.977383,-123.583846,2.296568,24.079937,9.292076,8.483496,11.023783,-1.011883,-11.017577,-93.87896,-156.337307,-178.420822,-78.168693,-41.848048,-33.100015,-29.359626,41.625701,74.354538,70.308041,132.625822,188.807579,218.143837,200.885489,217.734614,258.028044,302.611746,294.54182,230.542843,160.13182,169.588616,223.185477,205.44931,63.97915,-12.594375,-44.112333,53.108146,88.788222,75.423226,34.187805,-19.897465,-25.311166,-67.186144,-97.806571,-181.522408,-290.470244,-297.539411,-206.295543,-148.49366,-63.452172,-35.790675,30.68816,94.821684,90.522075,66.691776,84.343865,158.488462,195.277912,237.093793,250.023981,292.37435,318.843381,323.752976,333.685683,340.816881,378.427542,405.941483,410.17842,321.532346,302.224739,361.388418,377.354171,290.40796,234.909682,198.762107,200.422018,193.389431,245.339493,304.882897,354.679702,336.114159,304.835801,281.004452,165.313197,40.591468,16.345487,59.759685,83.199901,40.763695,-0.412493,-18.945838,1.209347,-14.910043,-59.648839,-27.902572,75.71508,93.047498,54.077796,37.711878,84.432563,128.120096,96.833588,22.986638,26.627968,60.504066,37.908145,-69.969349,-84.441566,3.779396,70.052157,78.224984,75.038477,76.609981,104.41971,115.656175,125.009801,143.354027,161.540128,201.449239,196.805049,141.64895,118.605895,53.290626,11.039209,6.859,85.456127,140.175103,247.912131,264.066307,182.142212,90.309656,-50.6064,22.030605,96.140924,165.919021,126.126544,-9.070963,-28.289022,19.301281,33.517781,9.591621,-23.571088,-29.056383,-0.084916,45.632157,144.274531,153.816201,133.992799,210.251211,258.552386,267.102563,232.647506,194.13413,227.979701,329.545026,339.032971,212.735672,4.338268,-40.181123,47.201234,143.856693,289.462314,298.842676,246.408633,134.259591,64.164703,44.595299,121.114455,252.333791,214.208441,6.508297,-59.696921,-53.468482,11.830518,57.6737,184.989131,252.116769,330.175041,333.07969,326.331753,257.317905,178.668469,87.358237,112.490573,170.002113,139.186092,15.227272,-5.318131,25.076443,23.438378,39.050311,134.823974,186.25132,231.46722,214.967648,119.220432,12.476334,8.578692,70.60237,74.362415,39.166303,44.882772,89.427735,81.466089,-22.801506,-73.973632,-54.299364,-38.205629,-61.321109,-95.524294,-82.288564,-33.863033,-27.644717,-38.544279,-33.886176,-22.182306,-5.371664,7.673765,37.134963,47.835701,20.088351,-1.732766,44.47516,158.854817,192.190687,264.206425,301.115144,313.064072,214.939755,160.484074,109.909339,79.177196,-22.768438,-32.149302,63.653294,92.379506,30.54742,20.867121,75.836434,183.988509,193.82025,146.441927,121.782486,81.075295,-26.894544,-100.48055,-189.948858,-199.560387,-220.139351,-242.092244,-298.709076,-324.928245,-330.943701,-304.521125,-283.016214,-197.779583,-152.846899,-128.869811,-136.878289,-75.441726,21.232306,21.253052,-27.499673,-55.184316,-100.523178,-99.220215,-76.906728,-92.908098,-153.621773,-56.259003,45.098163,194.466984,235.563517,238.188409,177.681576,37.962847,57.237189,110.360543,122.45913,63.603529,0.308634,40.699797,138.352973,148.759335,104.394585,12.832737,-30.43616,-87.74757,-92.386616,-98.761977,-133.788374,-220.478816,-304.097909,-353.254195,-339.311082,-265.328517,-81.077195,-15.202797,-11.177237,-55.291556,-154.051918,-203.105128,-199.049747,-191.162317,-186.495307,-132.967143,-123.15749,-204.702468,-325.931594,-363.143764,-382.716869,-380.281817,-325.146476,-281.535392,-273.640589,-288.672115,-227.43982,-151.430278,-145.204596,-121.13599,-72.21909,60.54717,74.442963,-78.221494,-266.553754,-291.559138,-175.969228,-87.145466,54.340106,120.019554,200.320169,167.437067,-4.298385,-49.456855,-10.50212,35.414463,23.415634,-99.294926,-215.622245,-368.173457,-247.579176,-158.733274,-60.911733,-52.991291,-77.28912,-87.196942,-88.971866,-88.68581,-102.644557,-134.399884,-135.412076,-82.745075,-34.320787,71.122979,91.072988,-0.969487,-132.167209,-155.938492,-165.814611,-182.682767,-203.407252,-179.51321,-133.018789,-156.291815:4.470136,-97.820362,-112.160944,-98.557592,-80.088214,-16.49108,15.83211,3.737114,-68.12031,-59.63667,64.071854,120.116122,174.051424,183.112588,75.661444,-25.341625,-124.08883,-75.613435,-54.272672,-43.978212,-37.573567,-51.717366,-93.898463,-192.603949,-236.775353,-227.676223,-160.029731,-131.095849,-123.749051,-142.012994,-208.948702,-256.192373,-360.808819,-407.121492,-376.616936,-250.950339,-206.886407,-156.638376,-118.860812,-78.46806,-121.168252,-112.202841,-36.00971,-34.201903,-100.878902,-120.21372,-155.13669,-193.656537,-274.355316,-222.167065,-138.513262,-18.077139,-3.191162,9.070218,14.201905,-0.39909,-55.393124,-72.981371,-20.160423,31.574155,121.913882,156.615455,180.023099,156.823816,81.489113,78.380026,111.794257,175.860043,197.815783,187.951239,125.977601,-46.887133,-90.052613,-54.882944,71.881066,135.461599,169.138171,130.953031,-8.222743,-91.676825,-234.230733,-231.815367,-179.26057,-57.83874,1.438695,82.498341,89.194181,38.184285,-28.359707,-23.922715,52.552446,97.496277,213.399814,272.747174,291.758638,257.987917,221.352347,255.440014,282.795683,338.782403,359.395998,347.988537,316.958884,286.882396,280.078384,263.615374,299.111364,346.627632,349.898952,288.69048,162.369719,141.711536,161.597358,175.624707,190.646514,273.517541,314.777393,302.73335,251.782125,138.531387,66.289892,44.911144,53.34528,79.337942,113.813557,113.847047,96.46027,80.646606,40.363969,28.488441,45.212968,158.065696,231.875791,237.496594,156.459186,15.974746,17.18118,33.557287,47.822041,54.144783,63.031159,41.740172,-42.481679,-63.667312,-43.445497,1.468568,46.186101,136.955552,142.220723,67.627522,15.958762,-21.504224,26.72727,56.753027,121.016341,139.929768,157.826204,173.122582,136.64754,80.658164,38.15664,93.703313,112.172911,141.520889,153.319142,75.026044,-13.566103,-121.805218,-75.356374,-28.244286,65.187162,87.032211,78.611904,66.692894,32.471451,4.117584,-75.257315,-119.896318,-98.129248,17.156424,63.127192,65.495444,42.471733,20.973823,15.054111,17.030525,92.839489,136.502445,170.837741,180.568664,186.048886,171.402253,95.191604,11.561241,26.966138,176.543212,260.898024,331.187904,300.705298,186.111449,42.56755,-28.709262,-46.373082,20.42208,172.156603,186.313404,70.510884,5.365053,-50.764573,-71.402331,-65.254686,57.00927,169.996148,325.120861,314.886336,198.210186,92.492749,62.230544,50.233214,63.339145,84.609655,54.758901,-68.539357,-108.8852,-107.070556,-22.938159,42.037331,177.787815,232.861845,276.787906,253.736417,129.850112,18.915071,29.933373,143.318271,181.37003,201.281537,200.910644,144.737373,86.165936,-31.392114,-0.625825,80.232553,200.141329,201.644611,157.472122,136.318611,83.10225,1.133823,-15.330041,57.781626,112.63101,179.341287,195.691649,185.303046,149.606062,62.572579,48.663252,73.3096,152.764475,198.930297,252.471172,244.619307,200.782028,149.822747,130.371552,111.406474,106.549472,131.498983,150.899467,135.288405,107.427486,31.350061,-31.181824,-4.441733,158.863617,225.568709,195.959007,122.414063,-15.727695,-160.234262,-227.323449,-217.091282,-139.747842,-40.764395,-81.46698,-260.92097,-336.912702,-385.320469,-304.653769,-261.458615,-181.330236,-114.255356,-12.368834,-23.287404,-79.748439,-66.69,-41.622769,3.034801,7.205447,26.204667,48.942121,15.419817,-48.518429,-164.602803,-121.203206,-22.951135,196.900167,256.659548,216.546264,153.563879,104.971693,154.081201,176.934173,209.167562,211.912877,222.3176,249.181377,295.29169,291.100339,232.656047,160.373778,142.013261,136.994085,135.050251,76.843659,18.408653,-96.5631,-211.72902,-230.621701,-87.620829,18.734283,133.093752,131.686121,58.015006,-3.703328,-157.365385,-211.363666,-170.545909,-83.17588,-90.644208,-211.322182,-286.5916,-372.303841,-407.553025,-403.302844,-318.064468,-280.713608,-273.652063,-278.869906,-291.591551,-307.278195,-320.473071,-256.483128,-205.398575,-138.171486,-113.058644,-18.63523,10.454927,-97.864292,-287.80453,-293.401859,-91.621906,40.977751,208.106989,218.794427,156.859271,108.029327,-24.881542,-46.990584,24.012549,172.788082,183.199741,25.918499,-104.329874,-313.232394,-383.372898,-358.808037,-211.550567,-135.109555,-76.777625,-91.544021,-143.033245,-158.564553,-165.460852,-134.564011,-91.165529,36.153796,90.064308,115.729159,93.451605,-0.691609,-125.466318,-152.106708,-112.022825,-82.756892,-55.988151,-55.251624,-71.501336,-96.079261:119.002486,-47.589258,-92.913233,-48.997908,-5.132458,1.982903,-14.655829,-15.926867,-14.540136,-11.37238,15.32342,25.147727,21.739389,13.406973,-23.458774,-42.555988,-49.890401,-27.71581,-12.897112,-50.513853,-117.169579,-229.392977,-236.160531,-215.220899,-251.76416,-262.161168,-195.904536,-154.762468,-140.018513,-170.304516,-267.529971,-278.826297,-213.990937,-218.458791,-231.775238,-220.63963,-223.284311,-216.039848,-162.868133,38.431138,164.582282,155.730531,104.151834,88.036679,61.187016,53.759855,33.96313,23.075762,0.973472,-70.05692,-92.270596,-74.627317,-65.179745,-99.082232,-123.952443,-52.988854,106.862791,139.698272,140.004823,137.542214,169.396814,218.078866,285.859796,259.629653,160.791041,136.002178,152.375499,176.526522,163.882325,102.684472,60.818787,18.428779,79.214025,97.952282,73.45748,50.588668,-3.150377,-38.844474,-107.809468,-119.039003,-120.950709,-209.269813,-265.856901,-328.093171,-323.923318,-231.919888,-173.914733,-92.108608,-46.07019,-48.68879,-77.164871,-67.672089,16.15633,50.819594,15.69453,-17.552412,28.17329,145.391077,189.2788,254.779386,257.589389,209.546776,211.232783,298.17258,338.694973,340.513214,347.459647,327.812919,255.290389,215.136694,78.895708,24.099158,114.951558,342.228185,403.949718,354.885069,287.493293,226.407305,241.727011,261.848004,194.467351,170.310804,191.853184,165.759422,-4.948692,-56.761646,-23.652861,12.280683,66.453117,69.261229,44.014185,-21.67445,-23.2355,56.710844,97.051429,135.071341,114.900992,74.564786,30.19099,45.218996,16.787594,-49.616933,-172.970039,-192.214532,-159.283048,-77.126617,-20.18759,8.051349,-50.671132,-123.155442,-67.174528,106.185237,116.074047,67.896341,22.154471,27.347153,25.274596,29.179868,46.992478,54.48485,94.785757,150.081028,177.547974,208.065298,217.953143,264.704107,274.2582,228.129671,166.025622,158.089218,150.526836,106.043095,-17.519337,-32.346642,19.619466,30.315694,-9.080922,-59.101443,-73.32115,-55.844023,-18.140284,63.002376,78.326797,121.974176,239.970091,274.56882,222.438683,170.031266,146.357666,166.088869,129.218306,69.837647,-31.481027,-71.5675,-64.250571,34.206224,120.700172,273.968917,296.715218,242.600524,147.194873,122.694199,202.40145,277.40391,318.508191,259.964287,91.126817,48.473351,77.66559,168.189262,257.348646,487.963739,566.792429,599.919849,571.961694,502.394225,402.097667,317.737779,212.167944,231.706503,331.791305,349.591181,246.175037,176.279286,169.004915,248.510356,272.629122,290.785328,282.958625,238.61022,210.756656,137.372499,62.823597,69.215625,173.348209,209.85359,184.457058,161.075002,161.464005,182.25037,201.630528,142.357459,112.681215,80.743839,64.297886,20.53436,7.277148,38.588305,82.115171,64.785453,-7.699192,-31.740306,-19.396709,16.851571,69.853522,54.320483,-31.741644,-71.052831,-41.926322,112.658677,196.633801,267.598362,259.703758,222.118611,123.05541,48.324922,-73.383428,-107.868965,-122.868317,-113.044912,-137.246115,-170.083281,-156.272127,-39.116016,21.96627,84.089431,74.49344,64.701433,87.895645,128.88728,69.941471,33.246752,53.42877,77.192939,46.509035,4.564128,-52.875682,-58.268164,-99.447729,-161.526354,-136.372704,-32.35722,-1.788788,14.305132,26.762568,100.447717,141.696105,139.468878,166.2551,180.807376,111.357813,40.516474,-44.785374,-43.356234,-10.349806,21.936775,44.096945,84.896941,94.146467,95.808359,80.443707,43.919682,73.245724,113.710018,143.835211,84.249229,-80.458617,-112.499264,-81.618097,-43.224648,-1.005574,-76.57162,-98.480894,-88.512478,-104.516709,-153.113885,-151.98212,-112.227762,-145.171053,-192.801786,-213.167767,-169.258698,-46.2481,-4.425724,-34.776318,-89.031813,-167.875082,-183.660313,-190.084039,-198.277791,-165.441327,-63.080908,-54.345335,-119.148268,-179.430621,-191.039557,-210.357589,-252.826835,-324.366054,-293.574201,-178.113157,-149.440192,-142.688422,-125.509395,-127.031949,-180.215622,-185.446313,-110.614689,-91.27343,-166.014181,-270.309755,-279.180003,-171.14451,-72.078278,133.834169,189.780609,135.894649,59.306406,-51.528573,-44.958593,-14.733158,-2.619997,-45.485018,-199.297506,-290.043054,-381.037688,-261.276415,-176.708308,-70.378304,-61.519738,-71.855486,-53.477411,-39.691771,-85.138977,-202.439973,-215.127006,-199.644213,-189.175048,-166.041653,-74.092459,-49.149723,-74.052887,-145.357242,-169.831485,-145.145291,-120.954496,-104.287118,-90.169955,-49.051915,-65.799616:169.126152,55.45158,10.622858,60.519024,121.539963,139.852784,79.107685,-48.128973,-73.79341,-49.418781,49.773703,73.913461,26.828928,-2.095332,-2.914287,20.185,61.727071,27.096405,-17.11453,-109.317655,-141.021528,-162.225704,-149.394032,-96.71543,-93.722985,-105.24726,-71.206805,-49.234644,-68.701092,-94.74347,-140.76682,-142.675175,-129.082405,-171.78236,-192.827879,-219.593106,-215.88851,-99.542957,-2.096059,143.958879,132.886386,95.515648,77.570684,100.654229,124.399114,102.077153,12.351474,-26.059479,-60.750459,-65.837382,-73.631143,-103.345204,-97.178487,-35.863316,-17.548552,8.623495,87.159182,122.598326,124.784411,99.606684,144.716824,220.563082,293.093247,269.639641,179.055091,122.521573,133.843205,110.124128,45.554475,-44.500618,-35.987863,-9.143416,-48.311381,-66.622137,-61.301416,-62.614817,-144.545444,-206.486917,-253.195047,-236.533887,-269.181523,-368.976407,-376.659195,-307.271825,-254.442404,-152.357419,-118.15004,-70.816837,-18.285162,-7.88315,0.508078,36.594419,157.04009,196.474991,220.5889,236.311125,295.404117,336.611699,344.27007,345.00546,341.864151,372.440721,409.472918,408.873007,290.282023,274.992966,328.510318,321.026576,231.487059,194.939091,150.260178,137.868178,151.282545,256.00408,330.720104,355.637543,276.769828,144.587266,160.740453,205.017778,103.332437,71.798335,133.637065,134.738508,-20.789755,-71.771702,-23.168632,2.233723,1.541975,19.238913,37.645826,78.885527,99.03064,112.176621,103.385528,94.67855,101.679867,99.032718,69.531276,36.859863,-44.813653,-67.09211,-58.670986,-49.942369,-40.136524,-6.266604,22.609878,41.871392,35.36158,52.13672,70.867008,122.847313,194.815494,204.139178,155.977061,116.573258,37.711696,10.149715,-48.424367,-85.606038,-91.151692,30.402456,104.024989,237.518313,308.769436,383.539858,325.891301,119.317979,51.413335,55.41077,31.213314,-9.205545,-99.516511,-101.46443,30.533903,106.633873,118.206537,49.357382,64.194298,148.700529,161.057217,108.044574,80.812533,112.396063,257.134589,329.395544,369.709541,328.458444,248.731939,251.607077,252.587492,212.356904,91.915895,-13.947133,-30.205901,85.966969,198.973892,365.624749,372.417883,300.881985,198.424503,147.514334,148.096967,205.578524,302.624782,296.01137,201.871986,147.552495,60.116828,63.168701,123.604174,301.325589,369.158283,428.560853,441.607932,450.193904,336.551399,231.632106,132.777829,174.54882,284.098228,289.341186,202.632163,158.74877,129.403772,126.410306,142.027146,221.278193,253.955743,224.354841,175.976165,115.390371,87.051809,78.091248,99.756389,112.776467,126.582236,139.233026,161.968573,151.134076,53.814876,-38.323131,-47.483264,-80.577541,-118.522996,-150.393712,-120.270597,0.411909,51.165254,23.448466,-57.24022,-87.251832,-112.303851,-98.065058,-47.727431,-40.563067,-93.891789,-101.011008,-24.957946,173.531386,237.022678,283.603377,273.584948,226.680522,115.236383,30.005991,-87.509876,-116.167626,-134.504694,-107.93429,-38.622588,-32.979802,-73.812823,-81.419139,-34.806536,93.077859,119.475075,106.231072,116.773298,197.190939,142.23945,53.201936,-74.946014,-115.277109,-208.517309,-227.65984,-191.300894,-158.461074,-107.384487,-172.391304,-206.704744,-148.952946,-86.37717,7.256645,34.607968,70.272897,51.485062,17.0195,-20.824421,-4.560607,71.454668,110.259039,132.104904,114.633707,80.564354,123.263092,175.558418,253.386049,250.794921,201.88019,177.470913,125.853592,48.533509,5.885147,-23.242579,-16.336123,-34.711255,-50.660598,-64.446288,-82.157479,-183.101053,-286.085937,-288.807777,-218.677031,-171.1862,-146.584384,-200.281952,-334.271182,-408.968419,-448.181866,-461.156607,-404.568344,-208.997837,-115.272037,-71.625813,-121.715243,-216.872455,-237.23589,-236.411394,-222.952228,-220.55052,-239.24206,-239.606787,-232.433537,-325.187954,-379.153457,-409.111343,-400.158324,-343.06497,-306.286698,-288.322304,-282.785462,-212.187831,-174.25552,-184.855449,-184.955958,-152.586061,-64.750116,-50.262504,-132.995601,-293.644772,-338.3585,-298.017884,-232.924615,-62.756713,20.625753,100.850982,84.743011,-3.223388,-58.183251,-46.712284,19.933304,37.532836,-35.561817,-118.463011,-217.802633,-173.884696,-156.191788,-129.152118,-108.666131,-94.001856,-101.914683,-125.780759,-139.541267,-205.536622,-337.550987,-362.60395,-230.113072,-133.490285,-68.81198,-90.591944,-151.821108,-247.160176,-277.318323,-241.001213,-222.768318,-246.777723,-259.562794,-264.76908,-266.369722:62.54955,-39.839982,-80.52782,-99.883389,-84.83691,-51.631798,-42.865346,-13.203478,43.579545,60.344553,42.10035,14.272004,-8.179491,8.141832,14.728496,-13.700528,-56.080479,-30.422691,-1.889756,12.0228,-21.167056,-77.425011,-83.820509,-92.160914,-108.453451,-112.230726,-113.974169,-122.468321,-171.914351,-209.150083,-244.259226,-229.35966,-223.276028,-282.994002,-276.48388,-183.900845,-153.099767,-115.657024,-72.380028,51.975934,98.539181,82.927188,56.693066,38.620256,-42.596168,-79.668028,-143.24179,-176.968547,-183.551524,-117.627867,-103.19923,-103.572047,-86.525133,-24.947422,-13.774711,-9.697589,51.436116,76.148994,64.985017,39.135754,35.791015,73.795364,136.498875,140.892832,85.655406,2.226126,28.342581,214.999221,273.506502,146.647544,22.996101,-47.980204,101.973975,137.409632,139.587461,168.901168,174.938748,83.04303,-144.585855,-178.4515,-135.699325,-154.874046,-170.111091,-140.398297,-107.738716,-82.485874,-99.443419,-129.901598,-135.06417,-129.925457,-22.809381,86.589209,268.791382,286.8308,208.922212,160.52555,114.258346,132.913198,178.168708,300.115299,326.819108,278.912024,230.99276,179.033954,221.783182,261.247167,310.363411,285.996589,177.104952,143.82125,135.081334,139.504861,163.284303,255.88854,330.553095,394.564544,354.787882,227.359828,167.63768,115.241922,134.822092,113.771529,31.926768,-0.839131,-68.106255,-94.436686,-54.276519,-4.23794,-2.708499,-122.842661,-121.155894,38.822911,104.044586,73.345909,13.739133,-15.540485,75.635682,98.876078,73.834534,46.476931,-9.043681,-43.326023,-115.339598,-126.269333,-87.217361,-14.265882,40.668242,137.586647,138.4953,34.213136,-22.994582,-11.405229,108.337326,145.873551,167.769219,168.72443,192.792024,215.897015,154.843808,63.351538,8.867053,144.133188,178.13182,142.124091,109.147759,69.972852,63.703389,71.761586,88.984649,102.274557,111.340517,74.584586,-33.169914,-48.95692,1.897321,34.605891,26.469672,-75.709434,-84.606123,15.788034,51.283248,30.194608,41.513342,134.439189,98.977003,47.62004,44.138765,68.392988,63.433086,63.962397,93.105826,85.12385,13.584025,-43.024971,-15.683126,189.644689,309.030247,381.73583,320.417177,172.522058,103.068111,84.485852,104.309532,135.480724,154.054314,117.104709,-16.73485,-68.189948,-88.843127,4.798128,94.36739,242.463529,288.222601,353.888081,335.997893,196.533804,108.889934,108.236948,143.664304,147.377743,126.143843,123.179852,96.856504,73.080406,100.751376,190.543685,213.915261,228.532098,251.736867,323.601921,294.30469,86.971924,1.483448,51.08436,201.240591,225.003765,149.455401,116.457169,113.05785,95.080599,4.08529,-10.678988,25.121399,104.30049,117.090625,52.747477,10.27419,34.998925,70.001641,35.667316,37.000774,87.312384,115.180089,76.867078,0.343577,0.063768,49.188983,102.743143,141.626503,208.69524,232.700918,295.059477,301.049751,187.165526,23.185225,-20.403191,3.126487,40.133002,46.488761,11.33281,-64.85506,-86.559764,-72.67666,57.192465,139.003118,178.679402,141.050365,93.422371,90.34796,92.083844,76.480947,48.042562,-15.328673,-46.049826,-117.202838,-139.50526,-166.216506,-199.223863,-259.00447,-201.075543,-134.375105,-36.805631,-33.759793,-59.860004,-62.809921,-46.838022,-30.938641,-8.954544,64.755526,67.499489,-11.33348,-37.894197,-18.085878,-14.308553,-68.872274,12.839883,121.422945,213.441507,173.328497,83.116728,56.735753,20.332995,-11.895843,-21.824266,18.471255,52.844036,67.032862,56.315406,72.03412,106.638384,144.525044,54.643893,4.586747,-21.670863,2.053783,73.229455,75.72685,-40.240857,-169.722519,-174.984065,-69.832668,2.194607,91.124096,86.846268,3.483479,-56.259918,-183.673283,-245.626744,-238.362425,-209.467528,-191.123717,-88.653005,-34.99709,-51.912327,-194.196033,-245.791445,-279.511486,-289.893297,-246.477657,-173.107616,-79.998414,-106.643775,-192.07902,-178.275172,-147.4507,-64.109058,-17.131597,16.738496,-23.393908,-159.906283,-252.269603,-256.235084,-117.613472,-3.841149,151.783319,179.466541,168.647292,136.267123,22.690394,-101.588535,-125.372015,-88.202053,-73.360061,-164.724906,-269.189238,-447.190538,-412.992991,-339.903574,-199.173486,-153.691424,-97.042014,-75.83047,-66.152526,-73.919277,-79.197843,-114.110767,-131.739677,-134.948922,-119.225757,-42.330207,-2.173337,24.283853,-58.157219,-120.394153,-135.053307,-77.454434,25.445735,27.241157,-70.595687,-136.131906:backward
145.16159,-80.526891,-146.643179,-137.115401,-117.444709,-143.698319,-164.898361,-159.623666,-218.877625,-274.878515,-310.514279,-297.882972,-282.574018,-278.0134,-192.918764,-100.310763,29.28544,-29.618142,-83.460459,-156.397385,-168.47554,-176.785638,-185.324077,-179.026975,-139.512271,-125.149032,-153.16884,-196.34742,-213.980516,-163.809367,-47.631646,-2.797864,69.085902,64.837889,20.433635,-60.638131,-54.688291,8.096322,27.459129,66.852619,104.575684,88.886233,12.00295,-10.782477,50.083816,116.523031,194.3148,181.98182,85.397317,29.398954,40.838172,72.172675,89.833649,139.031683,142.646446,78.983794,49.587769,77.0291,108.291983,84.136241,18.249589,-4.943871,-38.857921,-58.610732,-135.885679,-251.481011,-307.157098,-356.76219,-334.942154,-267.638976,-247.912177,-197.957314,-116.003511,-92.62209,-143.236195,-200.290186,-245.524674,-216.33041,-115.277939,-57.656041,10.549876,-13.214629,-42.967929,-118.242503,-131.51345,-96.265297,-74.997681,-60.427605,-73.938129,-49.431825,63.510011,89.857052,21.693442,-25.755137,-38.454043,-19.815024,-4.997006,-4.584789,-21.913306,-113.126848,-145.576712,-134.147696,-110.023673,-52.188306,-17.575858,-8.229561,18.886621,25.861212,0.088488,-31.998154,-93.311464,-106.449313,-117.905213,-108.988293,-92.779476,-38.60934,8.762366,88.874753,92.280019,80.57448,134.244604,172.565135,178.930403,133.849714,69.400635,77.487574,104.239735,110.51626,81.481731,-11.714327,-54.317423,-63.989254,-27.389597,76.026212,129.947363,211.905706,173.230056,114.117652,10.665078,-16.385784,-30.392406,-28.410474,-6.194875,14.463573,43.991391,61.612645,75.007121,107.106434,121.159607,147.69329,162.943249,179.023416,184.508235,189.190546,165.845157,146.086553,146.331606,140.581695,70.579055,43.062943,49.234893,62.14621,39.988097,-48.444768,-66.262663,-13.726865,16.64341,-20.973065,-100.292197,-93.03654,-88.407812,-123.905869,-179.022961,-184.865521,-187.784547,-184.506063,-181.813859,-182.830113,-170.449811,-123.979538,-98.079493,-76.141473,-91.92158,-141.639735,-160.339908,-162.738425,-228.48366,-284.844497,-305.625393,-244.924736,-37.034654,55.85547,71.156287,-35.404178,-46.471866,10.191538,61.753755,208.667286,272.880024,298.180967,263.89442,257.538731,202.007221,150.147922,111.481118,123.586984,114.02175,99.807365,71.111274,40.174385,60.939484,164.021078,203.518377,193.132633,145.543572,4.273435,-93.206033,-105.098888,-84.879918,-49.543558,41.0568,66.38199,119.524467,167.846533,236.76025,217.055446,195.913972,177.460296,188.178827,211.701307,197.284528,140.177109,129.616063,120.217098,26.654149,-24.911902,-32.926478,-10.319352,24.307258,36.437471,20.169918,21.900397,57.563613,153.37154,197.653785,224.088476,198.740588,125.224957,47.782917,12.252212,-53.821186,-85.437899,-78.265067,-23.293268,123.031456,161.756267,108.081216,78.787128,103.618074,72.52903,25.585957,14.386531,36.136469,36.929724,-10.188765,-23.502405,-12.89731,-5.837384,-16.816859,-28.124939,3.263666,58.248605,115.414218,-9.430551,-85.848135,-139.380629,-101.2177,46.721013,122.150606,171.052282,73.964565,33.938628,7.495485,5.340887,23.933065,41.2232,56.848214,40.391295,-45.876466,-123.746603,-141.288633,-125.901597,-78.484808,71.307015,141.377621,202.776335,148.336517,102.558172,28.6998,25.374635,82.260946,86.791958,22.303771,5.292503,-3.013328,-58.880452,-87.261415,-124.027468,-146.043142,-170.291414,-148.794467,-83.119425,-50.618255,-28.263751,20.179169,22.495293,-24.499367,-58.023472,-68.705158,-31.272531,26.59024,10.264995,13.8732,63.659967,102.006784,186.477973,208.815573,145.351348,17.988195,-11.133894,-20.85024,-45.729752,-126.160208,-140.318944,-89.559257,-64.292923,-107.315249,-169.910655,-161.441127,-93.217685,-55.089073,-38.395548,-78.266935,-162.766625,-159.124968,-161.701938,-181.768712,-161.452288,-110.565179,-121.992473,-128.446894,-86.809801,-36.677834,-118.281336,-178.43907,-265.763925,-272.504594,-251.302959,-252.125152,-302.43887,-382.298219,-394.917021,-333.658486,-273.669711,-108.103837,-24.758913,40.971267,17.578927,-73.400954,-120.788906,-119.741566,-100.409562,-72.943396,3.204392,29.400826,44.564063,66.805833,105.663667,187.377013,209.116145,244.756309,257.811556,219.557074,174.70595,104.99108,116.901135,134.040546,140.900063,140.110671,148.78242,151.309257,147.143004,165.17003,179.934942,158.353737,133.521746,141.524546,158.893132,155.090843,143.078302:195.26987,-4.001408,-68.36597,-88.973867,-75.641793,-54.913585,-49.284917,-53.730864,-140.228664,-192.12901,-243.526682,-259.024039,-264.033937,-220.111121,-66.768703,-28.965971,-102.552478,-206.32628,-241.440131,-256.847718,-225.36508,-157.34906,-155.309146,-219.849896,-258.599125,-261.689722,-345.600822,-392.51096,-327.052884,-247.154041,-179.181409,-172.723866,-79.810045,-9.043957,-56.759796,-189.232846,-185.94968,-86.769454,-59.663571,-54.884662,-44.129305,-54.043855,-107.67974,-117.259114,-41.552005,4.394178,-1.860571,-31.969909,-25.81201,52.441867,61.5469,28.858323,31.803363,106.018738,128.556259,42.107163,-45.9973,-27.269024,40.186175,48.385177,24.213802,9.581143,13.561481,2.591952,-147.468294,-307.020343,-347.674981,-418.928796,-429.53016,-318.489938,-232.41779,-170.844829,-216.904006,-218.467273,-229.134033,-264.282453,-264.889499,-190.961769,-39.760461,-23.19629,-83.25726,-156.013949,-194.794537,-264.455148,-274.74127,-255.126537,-228.698068,-216.920322,-291.40736,-264.06379,-91.132488,-47.042399,-111.954208,-158.549325,-169.166976,-162.962421,-175.985116,-182.748882,-219.306126,-295.655545,-262.445613,-128.655594,-113.556297,-178.487811,-157.966441,-106.067954,-68.160586,-98.839529,-120.018505,-84.673228,5.361862,31.395521,19.564846,-1.296506,5.111378,37.346732,71.122976,192.589421,251.404106,245.793452,168.828188,172.692218,177.697163,135.688752,61.230198,74.755623,147.669576,156.422532,48.546511,-109.421865,-129.236045,-62.3872,-27.405049,-6.297963,8.179588,75.947858,80.950964,36.280178,-65.58513,-73.779201,-40.448835,-49.922914,-76.11199,-61.710284,-30.739292,-48.125834,-67.906458,-35.422404,32.134291,110.097495,91.614281,43.073226,40.57105,64.783208,124.864414,140.867347,159.515762,153.627165,97.023352,69.753786,37.911865,37.0812,51.665318,48.142532,8.772243,-62.086445,-46.908309,30.768519,43.761608,12.864672,-86.156661,-105.290402,-74.595268,-75.632542,-114.401571,-116.452395,-74.536773,-62.483494,-79.925844,-72.216063,-54.247005,-53.566345,-44.366793,23.848455,34.666932,-21.607383,-200.283538,-243.676818,-147.720192,-62.407907,36.290782,37.596497,-32.754265,-63.511009,-23.342868,101.674353,165.35004,248.92331,254.782532,215.253912,181.590942,177.002107,116.132607,73.833666,65.552358,81.90806,74.870519,43.233749,-37.702248,-19.723048,16.61742,61.000207,75.742108,85.898718,63.450341,-9.986558,-55.759023,-68.877644,-107.651276,-104.36939,5.662416,87.581182,212.860785,232.917125,216.037193,175.82897,164.931186,185.033562,209.551614,267.549914,281.348548,234.451223,149.863891,107.719311,-36.408914,-109.34032,-52.188945,70.354697,234.721052,221.538292,146.699935,188.809954,227.571931,257.429271,265.717157,310.822729,321.337001,216.021019,13.071202,-42.872755,-59.843677,-57.905389,-8.441845,61.170368,211.812111,221.678946,94.092695,23.605084,45.896312,95.479532,105.149906,127.077543,138.651238,165.674881,192.937411,185.006671,148.951229,150.788499,183.879913,179.625694,118.907076,96.299815,69.473524,-38.065378,-102.393278,-133.368636,-95.92539,41.962434,119.113754,172.022729,71.280863,10.070313,-64.816687,-62.008729,14.625553,37.037463,-5.349181,-40.345139,-147.208307,-282.268958,-282.360646,-161.420532,-102.142272,34.774462,128.221646,204.457937,84.958829,24.734752,-7.98294,25.533875,126.214293,143.337469,80.578296,35.10894,-19.363738,-59.9291,-66.821803,-18.830218,-3.346498,-40.911541,-46.223443,-3.305608,-9.277957,-24.556466,-47.667511,-55.654854,-56.942969,-55.029066,-25.142107,6.352754,33.016922,12.385809,3.287595,-0.116304,9.523714,60.244636,101.950604,156.009881,85.172232,34.297781,-39.678785,-78.014588,-140.232201,-136.356934,-88.793281,-89.559944,-127.412583,-102.595009,-82.489088,-32.212796,10.906416,57.591337,50.38519,54.547619,47.245986,-6.90102,-152.105206,-182.797633,-144.823792,-112.553748,-42.453095,-1.041903,26.511584,-65.664115,-130.042746,-180.866109,-157.923873,-86.704565,-57.321596,-81.414566,-240.863852,-303.037489,-310.467132,-261.782385,-131.113012,-96.748056,-64.949617,-41.225864,-46.253953,-140.943908,-184.24993,-149.473507,-83.08335,0.335188,14.668195,47.292038,70.678326,54.899086,-2.763798,17.164883,135.89099,158.495826,122.775947,107.805993,73.207429,25.903355,32.913079,101.019292,121.442736,107.737616,100.5968,68.689212,28.76234,61.476792,145.649706,125.358273,29.419742,26.414228,129.003192,177.526415:176.062726,-46.809969,-136.612037,-147.069419,-78.687143,43.396879,63.132103,27.705885,-87.082694,-132.899943,-158.310393,-151.191134,-117.816668,-91.761641,14.385125,63.045981,-11.936696,-175.701341,-200.528154,-144.969005,-103.692372,-91.537115,-125.300873,-220.937373,-288.663675,-308.469167,-361.972686,-364.135845,-253.866993,-188.184159,-139.846096,-139.607338,-113.704028,-67.904387,-70.57695,-111.919846,-116.909952,-54.444353,-6.890006,19.419015,-40.913182,-64.494754,-90.254981,-98.927545,-81.081258,-49.488378,-0.654592,-12.678786,-98.390036,-142.792214,-116.731954,-20.987619,18.349775,109.946645,158.860206,141.130235,-25.106723,-97.387881,-167.516388,-158.371509,-62.164256,-36.765863,-59.741913,-61.567005,-114.714423,-310.397194,-401.062146,-434.057109,-365.556213,-153.825686,-78.117763,-114.272259,-263.22499,-270.497678,-193.196348,-184.647859,-194.545739,-180.814413,-190.954995,-227.05346,-273.819038,-262.64803,-268.715495,-292.157638,-290.546266,-283.642005,-286.744135,-277.33013,-269.949007,-277.89922,-278.21733,-260.11608,-233.414394,-227.113232,-187.741591,-164.606607,-179.186949,-283.244137,-344.088463,-372.412352,-323.987251,-212.473599,-191.104414,-207.899904,-211.062937,-198.330786,-151.6275,-113.467642,-48.568138,-43.215811,-45.139869,-36.156027,-44.275023,-89.950811,-97.162145,-21.452731,57.016406,191.923363,220.5899,188.152921,59.058486,15.392082,19.569389,40.780297,91.184391,118.709276,157.983299,157.51117,70.532998,-72.664235,-111.098279,-92.241653,-66.676359,-86.799601,-107.449659,-72.355567,-85.665291,-143.775563,-233.109705,-211.80699,-121.602283,-121.959285,-157.652183,-153.19254,-152.836199,-129.066315,-99.62664,-52.390829,-17.441657,61.382094,76.401584,41.809089,-16.354793,-7.457407,96.527528,155.645682,200.673386,182.97201,156.954918,163.492683,145.490541,83.563449,65.693294,71.72312,75.69994,84.397294,107.570878,132.506678,17.147472,-78.938356,-187.92041,-159.932989,-62.696938,-58.28838,-73.871355,-43.786247,14.922085,-104.63257,-178.729883,-135.907426,-44.77016,68.506146,75.397753,58.069053,35.763767,9.790925,-68.948731,-84.645012,-29.2762,31.135978,169.87336,202.608251,150.192598,100.071736,113.871212,170.789962,210.109021,307.013509,336.742254,312.732844,260.546636,241.846439,167.426482,121.821692,97.407851,114.486839,125.05344,96.797662,8.992875,-7.027334,0.23916,23.23307,53.948748,114.669559,120.004246,88.979904,54.077158,28.72417,-26.005187,-30.932841,13.83678,54.642896,120.594917,128.605134,139.061941,168.426587,174.586821,196.413747,237.047552,353.644216,375.74029,245.723886,44.915406,-3.090317,-24.055117,-4.917825,94.822439,151.801683,213.531917,205.664637,180.744334,235.388744,263.229193,287.250561,302.372421,306.887472,280.606491,205.083732,100.577275,27.706847,-83.582704,-81.235006,7.231471,66.108077,204.121203,245.335883,170.212436,76.118297,98.676453,192.886569,217.825951,214.466725,209.629463,221.467083,221.128631,203.169212,150.986893,145.520778,199.092476,224.753374,236.404999,238.911913,192.191488,34.587799,-31.024117,-38.771491,11.10619,111.929274,127.089074,104.052793,67.313223,49.351825,25.827064,12.674533,-24.325103,-42.266416,-75.07082,-91.031505,-138.296026,-177.506413,-179.451595,-157.066041,-123.401107,34.160914,128.950252,180.14819,54.430162,-16.1785,-95.509696,-71.856935,71.00239,125.65575,127.722243,86.344954,-35.096308,-103.138632,-95.80353,-17.799587,24.638807,24.627219,-4.799051,-18.935696,-20.931608,-49.389783,-113.524057,-121.105044,-118.610704,-109.483035,-15.725586,28.781609,7.425192,-2.007378,37.453304,92.816841,75.062948,29.4214,35.188539,42.674618,0.198945,-12.211337,-21.257463,-13.337381,43.076978,74.694237,91.987061,55.333566,-48.415673,-16.910572,22.049629,30.364115,21.590495,46.505057,66.86914,80.476876,55.124921,8.565104,-139.62723,-183.709753,-135.838165,-68.976629,47.196115,62.141835,10.501149,-69.885866,-114.718394,-176.758205,-170.458976,-95.088169,-52.903077,-40.074018,-137.076657,-190.924475,-225.094033,-179.843272,-40.467194,-7.47541,-1.262453,13.837342,24.987559,-103.054428,-164.971962,-144.524534,-93.248721,24.29702,103.339134,181.777486,45.649096,-28.564597,-74.876914,-59.786359,12.140182,67.637058,173.147256,189.320615,126.263476,34.398157,20.724406,103.037544,160.242846,195.849028,184.646435,134.894612,91.748033,95.993917,122.418227,120.545886,94.085083,95.765104,136.012652,135.572611:205.704674,-25.19901,-113.273243,-144.261865,-123.121686,-99.300967,-90.671065,-70.59969,-125.240965,-173.89303,-215.508479,-195.476627,-137.139295,-118.98625,-65.402802,-27.516418,-35.487494,-110.522013,-117.40714,-107.483925,-109.593393,-117.792936,-125.886353,-157.627292,-219.36924,-261.765222,-332.373824,-342.464568,-290.85084,-240.219653,-136.350798,-90.394184,-15.60161,15.447198,10.466347,11.344673,30.633309,45.005503,32.377144,39.424469,64.101732,42.354896,-37.430498,-47.325435,56.488859,122.879947,165.757297,153.805484,105.518541,70.910434,74.161351,85.875298,92.339401,122.672809,118.580573,30.318936,-69.839668,-93.974359,-89.270402,-61.957563,-16.328077,-40.432757,-137.421047,-161.490538,-195.390777,-249.402157,-261.04037,-247.143091,-233.169529,-221.942651,-218.825716,-194.691757,-125.173422,-85.803854,-95.417325,-145.505385,-201.752379,-166.182408,-37.400262,-12.008897,-102.687916,-210.729372,-222.264609,-230.426221,-240.139124,-211.24294,-170.986036,-143.903998,-227.121244,-235.489377,-101.793324,-24.972391,1.802466,-25.908759,-75.075026,-95.168954,-122.169804,-152.688753,-190.041417,-261.685573,-247.479678,-153.024331,-137.424989,-187.616509,-189.214042,-157.854847,-111.916425,-108.156815,-96.9301,-84.463086,-62.825927,-61.832412,-93.995947,-111.836828,-106.973035,-82.152413,-54.296494,2.778814,13.835811,-0.746774,7.770402,43.324814,92.605271,62.160347,-16.347825,0.23267,130.222179,186.226532,141.241434,-8.793583,-34.891893,-6.63678,0.358374,-28.720497,-24.53012,7.533375,-96.900366,-167.494692,-201.546785,-172.578334,-143.47243,-156.772816,-138.385427,-98.126087,-28.380084,4.093423,-2.531579,-29.040987,-15.051134,53.068518,87.761849,156.992434,183.676959,184.056057,214.678223,243.451171,279.848815,257.774242,141.581054,99.811573,115.713509,158.976347,135.722232,30.246791,2.161011,8.587864,7.803093,-27.81437,-60.56298,-69.016598,-97.14964,-99.76121,-42.665003,-28.097884,-90.355433,-120.145741,-91.755181,-24.363456,-12.968815,-16.934923,-15.95235,-22.013114,-25.393885,24.852305,47.508481,-7.904699,-157.655443,-169.086955,-48.860983,10.856611,66.978735,84.73627,93.146533,74.89293,73.857843,129.658543,196.850389,364.737242,426.912012,413.277139,286.892544,249.038684,201.623271,175.750166,184.332884,200.573625,160.209718,110.868445,22.522595,20.251885,46.523482,113.435098,134.633969,98.690296,59.520616,25.923116,12.578512,-20.091654,-65.096048,-24.492597,101.594535,119.266183,103.343561,111.621783,139.212426,138.25931,133.740826,117.445009,115.91703,159.278035,184.039932,151.10913,58.164596,24.812611,-56.629422,-97.98194,-61.86252,13.086658,129.53352,147.069246,154.415855,137.256374,129.051276,166.435982,207.18832,264.009325,253.007771,149.015731,9.974284,-51.971902,-114.722605,-85.536027,20.300841,36.809802,45.911666,75.784692,123.410791,139.563324,144.490353,95.994926,77.074232,146.442505,193.465781,164.799237,28.191579,-12.664121,-17.670122,14.124257,117.102735,152.971277,198.768139,225.810236,217.053929,74.809896,-8.299782,-69.09773,-13.136937,164.189046,216.489566,212.965507,152.546703,129.074968,53.901128,2.200044,-31.6082,-14.941494,30.494492,56.090418,44.209661,-72.561928,-112.901117,-88.839566,-49.33346,22.544566,64.426544,137.552503,110.645907,88.786798,88.367564,97.718044,103.21901,85.413135,19.201892,-7.722478,-55.57366,-113.765843,-123.839881,-75.572399,-40.943884,-22.03532,-23.901428,-24.040261,-67.730082,-83.909152,-86.113213,-87.869412,-117.924459,-142.77115,-113.002585,-54.969879,-29.127538,-84.282341,-64.995191,26.120623,53.941776,56.070262,41.77602,-27.452336,-116.858919,-131.440968,-83.52228,-56.639302,-57.98635,-62.349883,-20.510067,-3.761063,-37.392098,-41.557272,-26.363931,-35.861541,-44.102629,-29.3237,-31.950945,-83.063151,-135.423516,-165.75107,-252.378683,-270.681217,-164.394748,-78.237148,-5.665547,-35.859348,-135.057019,-175.473833,-191.85841,-241.028382,-244.888837,-195.696262,-178.75444,-224.249698,-290.671654,-293.81511,-255.917889,-236.112627,-210.308382,-191.205997,-125.529994,-96.398613,-82.766801,-83.060617,-72.449712,-46.287957,-34.490588,33.838203,95.211467,166.14474,128.884647,96.105065,52.783134,68.42574,158.528436,195.619665,214.051933,212.280122,200.868846,178.430894,177.88147,198.341116,212.901075,221.127834,217.571202,228.97439,235.336588,216.981306,124.791523,79.439838,71.219054,90.908832,132.643351,148.925545:144.161712,1.671689,-62.31018,-82.573288,-49.091677,-12.157421,-1.987419,54.687274,19.548399,-49.679992,-181.365229,-210.125082,-167.530613,-99.059267,68.227746,107.336745,12.578091,-122.763265,-143.916944,-134.294935,-123.131261,-95.888815,-69.869082,-33.560398,-134.413264,-227.267599,-356.499061,-345.802855,-212.164394,-126.995065,38.225177,102.678906,143.062613,77.927627,35.403853,7.801528,29.310477,78.115367,91.50311,118.935679,119.587771,58.991264,-141.907979,-172.068489,-7.129246,91.818978,148.467294,112.042899,-22.968209,-90.931941,-48.465848,108.306361,144.823391,118.748353,110.852381,70.268478,-98.157671,-156.545739,-132.594605,-98.6331,-64.611384,-42.38077,15.689339,12.676236,-60.837584,-171.765684,-250.221463,-325.237486,-272.716965,-87.108936,-20.768059,-4.496166,-40.03347,-42.551428,-72.872224,-100.629496,-101.629028,-72.577186,-10.745254,-13.240151,-122.011022,-264.971177,-316.040431,-333.62673,-293.081824,-221.5866,-225.09148,-268.42299,-244.609707,-194.944731,-125.794567,-127.021183,-139.696159,-120.255217,-45.511086,-44.399956,-153.292927,-252.428252,-266.288203,-222.493836,-180.095159,-112.784049,-97.896092,-140.756582,-190.144032,-155.148958,-83.492133,-85.559742,-45.753143,3.179924,49.307559,37.222621,-7.064499,-67.366419,-101.990721,-126.986538,-99.242762,3.852675,29.654916,-33.616628,-115.439816,-113.42325,-48.795011,-22.607623,-11.748734,-3.210662,84.99335,143.424309,140.735375,-8.262265,-52.552362,-33.311686,-28.951973,-78.793657,-77.58562,-23.523195,-105.95808,-187.177943,-301.193856,-312.548383,-269.75675,-234.418693,-135.133477,-94.23822,-95.518339,-95.852034,-70.883094,8.6284,66.773803,178.727669,195.783957,131.984293,100.847864,137.218895,192.433197,184.819009,125.563086,98.8732,151.444577,209.313296,216.451112,95.972828,55.492023,54.726921,57.901056,13.854946,-5.100126,0.540284,-28.138572,-64.842853,-122.937614,-119.934129,-40.631429,-0.414905,31.564588,39.704955,21.137042,-68.008519,-99.190631,-57.44761,-11.38386,48.380039,84.158739,170.153855,133.235438,80.718098,-4.271861,-13.416447,70.260752,134.104433,221.181945,230.114668,185.142577,127.944679,107.45154,148.466063,235.349512,405.113575,424.584962,364.367771,266.683768,234.200082,213.549554,204.697065,154.117834,137.911364,183.547564,202.357851,130.424822,10.88788,-18.520041,41.282938,108.114478,186.874302,188.464619,126.869641,-0.371374,-48.779547,-48.814661,-5.376599,90.620218,114.292552,134.321197,133.217368,101.529744,74.67484,61.344002,103.972119,172.883536,256.474097,229.658234,89.19885,23.910741,38.392987,21.087122,3.286622,67.602299,114.596402,110.535262,80.85307,111.542151,226.001099,235.60755,172.459314,171.159184,254.704953,274.96922,176.967282,7.713578,-51.953801,-95.279022,-87.867027,-28.142584,34.613535,209.557236,262.521414,217.308776,112.205498,74.020201,57.80452,97.944019,224.541763,262.805365,241.412671,198.478147,198.224276,155.90219,133.116661,202.314997,254.900142,298.840137,304.677225,276.202841,167.158605,90.81388,-21.533849,-4.368822,180.554121,273.779783,298.309517,166.694414,88.960856,-27.438535,-53.054805,-59.896152,-47.645005,12.056148,33.630812,-11.911358,-117.385168,-151.289779,-130.358168,-76.099856,72.135115,123.63348,85.044247,-19.030123,-26.794376,4.709408,20.054678,58.064657,67.661967,44.060535,22.417589,-54.446047,-164.443902,-175.262904,-67.917311,0.918988,84.616765,95.087034,44.910915,-35.368709,-68.248243,-142.787598,-165.262806,-115.241303,-63.241128,-30.633707,-70.264665,-142.807159,-86.670305,-41.701939,0.047939,-12.42702,-31.483512,1.837083,77.012847,34.550989,-0.041581,-14.74838,-5.011896,-1.231392,14.049285,123.520218,157.843698,70.4884,-92.42624,-134.541352,-38.359565,53.805037,114.946712,90.644359,41.964458,-23.929432,-79.241874,-202.636046,-224.167645,-132.378038,-64.433082,48.66141,81.362515,12.803188,-155.002479,-211.657888,-236.195704,-204.531287,-80.59514,-26.812927,-36.096844,-167.530728,-215.178589,-207.919839,-166.004134,-73.201128,-43.941953,-6.007104,10.131936,30.274751,-3.95554,-37.527816,-44.351083,-8.705109,99.448597,165.289121,233.193091,103.517518,15.103694,-52.594519,-28.203832,60.640527,108.426421,215.616822,248.461969,197.530659,73.101579,37.453394,68.755671,129.521339,275.785253,329.218942,337.410609,210.704651,133.946812,71.856984,99.223886,182.466282,214.649793,286.017568,295.85889:10.992594,-124.214961,-119.81078,-25.841566,1.026475,-34.879367,-68.723482,-100.479105,-130.406872,-158.462649,-233.713893,-254.02395,-184.928608,-119.567416,-8.246947,31.313091,21.625965,-87.477454,-117.314934,-110.959491,-97.110499,-92.031732,-115.680745,-154.684582,-123.767931,-120.093403,-183.835409,-207.021439,-118.614421,-36.317671,35.626327,25.803115,50.567282,93.509036,71.919736,-11.927837,-37.729306,-30.300335,-6.368136,62.157512,110.996073,106.212012,47.867065,27.858009,76.258616,132.612894,251.608019,285.240491,220.142469,121.060451,131.232646,184.935644,178.914144,116.65762,83.92295,33.090124,40.738061,61.346924,41.271811,4.693721,-12.565597,-16.609422,-114.686282,-169.593535,-209.73243,-241.075946,-280.846938,-349.061131,-340.769975,-232.101793,-155.532025,-57.932719,-90.504298,-114.50014,-133.894552,-149.00514,-138.376234,-88.104159,34.453322,70.56981,64.615955,36.71392,9.933372,-81.072595,-83.759694,15.516123,54.740973,67.711259,13.325067,4.099265,127.321031,182.347946,90.500311,22.612826,60.545681,115.446515,98.375517,21.395023,19.348972,35.387283,37.890653,20.338722,7.68733,11.798154,4.117272,-2.105499,7.746371,6.731336,-5.375341,-21.477726,-140.021175,-217.332406,-286.565668,-275.37086,-261.916455,-186.956681,-124.627544,-37.341037,-47.956111,-137.563235,-133.67454,-63.32221,76.311036,91.002974,43.063583,19.127582,63.39713,132.135609,195.133539,52.43183,-22.594531,-26.829537,31.941281,127.982911,139.452414,162.272937,132.690489,59.561442,-58.75354,-47.692587,19.357454,9.342147,-78.231776,-94.988708,-5.73012,125.534544,154.502905,158.842153,151.554495,129.16204,137.849893,215.761395,254.570936,251.451838,221.370423,182.710083,127.686598,129.577704,128.966547,125.974537,135.436999,139.457663,127.327365,80.867135,63.28072,40.098577,35.700075,7.693982,-83.099055,-112.183608,-110.411131,-94.701625,-53.138884,-40.205588,-22.62198,-4.620268,-19.344295,-73.905683,-46.957401,74.304793,100.303307,11.934402,-59.610877,-96.61496,-53.485061,-53.843757,-105.30608,-145.22551,-162.752877,-130.404481,-59.731042,-34.27744,24.02529,57.851303,49.379081,64.977989,119.429484,259.779956,306.630543,301.41367,203.789727,185.87592,215.976163,215.39143,165.136855,132.683486,111.408584,122.20052,89.198664,55.904983,100.138112,226.071534,252.899831,218.279793,174.047836,47.480056,-97.374949,-133.015476,-63.941937,13.569868,151.585822,194.427213,213.267106,191.417774,141.826865,128.745023,115.933438,59.460211,38.405785,58.895213,84.749372,86.548344,26.974388,-10.746464,-100.643017,-108.48011,9.285472,70.519807,41.988329,-17.749225,-68.645572,-41.246421,-29.799301,-3.796535,16.028353,71.321818,96.94272,73.533097,-7.675966,-21.678346,-71.131534,-129.807961,-142.375951,-56.00214,120.941192,143.489767,94.529611,41.750692,11.576314,-70.728929,-81.100558,20.99034,75.805806,41.082082,-88.266235,-110.569994,-83.942556,-76.046759,-45.63898,1.207678,147.67046,216.436676,227.459797,62.121088,-38.269167,-121.409988,-70.64567,96.064701,147.618884,148.858725,98.095947,104.793048,175.632806,194.190075,140.412317,91.843997,85.815148,125.496217,96.502073,-70.609219,-114.49333,-54.559278,18.688246,115.775514,123.844173,139.475256,155.442641,152.084551,132.235644,112.938748,68.526953,41.100405,-27.883407,-54.551334,-102.794256,-122.145149,-101.088673,-46.908965,-26.957465,17.343138,43.255904,27.499017,-72.063016,-79.853003,-62.449487,-98.912439,-186.51478,-186.932383,-137.712371,-116.633805,-102.812873,-98.515115,-65.278385,67.814521,124.145422,122.246516,70.804945,-38.43281,-57.777275,-38.984531,-23.770289,-38.949766,-60.530685,-49.423353,10.792174,42.361051,35.040478,-23.753963,-26.002586,13.292556,3.598838,-115.587723,-173.61265,-206.936517,-239.355129,-266.763922,-276.662442,-255.104105,-168.18456,-117.474419,-30.136615,5.24433,-18.930467,-153.607684,-193.188841,-178.388843,-153.670123,-115.75461,-111.791621,-167.505022,-278.372847,-319.02812,-318.103154,-279.571461,-178.063493,-115.899116,43.382655,110.140809,89.269732,-27.96751,-32.833372,7.714045,26.414749,98.083049,129.679334,90.957258,60.316989,113.802435,248.199488,270.937878,242.192724,232.860447,290.964326,324.768333,241.928229,42.111559,-8.814523,80.919983,190.081657,301.707416,267.735622,161.068981,106.921075,94.533059,84.848478,94.449844,165.818203,207.64099,255.609286,257.659677:103.808776,-109.770179,-143.571236,-34.620148,32.649154,76.340948,70.60623,59.610172,-7.569501,-62.862538,-166.354609,-189.66152,-139.811692,-89.056015,0.087989,44.303422,70.45128,-78.358543,-141.810248,-101.429693,-48.083958,-31.56188,-41.869998,-14.228245,-65.86096,-138.912059,-258.660771,-279.10267,-215.391606,-126.428497,56.120892,97.707901,110.275091,90.251543,78.265797,101.528207,131.850368,156.388415,143.066603,122.91022,110.076809,72.387159,-29.613731,-27.071524,127.590267,210.133735,245.828824,204.279269,93.607121,51.794333,52.404226,63.076591,88.557555,179.894559,206.283274,145.757505,-10.789778,-87.169194,-178.895092,-167.120071,-11.095201,67.229505,31.741034,-62.036619,-198.612535,-241.598724,-272.881262,-301.816864,-256.792215,-102.602475,-41.178157,12.946174,-34.238184,-73.622289,-121.130716,-127.473443,-79.981066,-28.713592,63.904877,84.838089,44.833139,-84.055072,-153.277028,-235.930656,-225.652836,-123.395635,-71.863857,-57.449436,-141.025085,-160.767167,-86.312148,-36.81255,-14.166425,-16.228741,39.886312,78.832382,39.256286,-121.365922,-166.21126,-123.896868,-72.848993,-10.363415,4.065747,-8.508401,-85.976876,-109.413129,-122.037049,-117.532093,-78.535895,-62.089029,-89.048027,-129.607527,-206.447751,-227.207543,-225.74226,-198.136034,-156.740285,-69.960108,-61.090776,-99.61681,-86.343387,-41.846043,-0.485535,-31.043259,-74.037237,-47.656653,63.952823,115.015924,138.617224,68.840777,30.822726,-13.28175,-12.612395,19.580843,32.95603,37.902497,-31.923842,-94.780508,-194.234289,-202.385123,-167.997962,-167.110544,-173.667369,-142.581118,-63.907304,-8.584266,24.502248,101.458599,146.615425,234.894588,268.093633,280.551712,248.111737,244.69335,241.741178,228.580037,177.028182,140.021467,72.726297,54.869237,79.089953,126.769848,101.820941,14.170451,10.457386,37.573254,11.747768,-114.759453,-180.520447,-161.652775,-116.091274,-110.617332,-83.589648,-63.717065,-34.563774,-24.082857,-48.148648,-82.80039,-72.008883,2.643563,47.213876,79.709171,72.28075,65.101382,-4.446806,-78.166847,-170.393514,-134.552892,48.963932,120.225991,149.038587,140.155578,134.17368,95.837507,69.228181,113.866492,200.317195,400.016267,467.137304,465.857907,295.113955,225.007537,238.678312,283.248617,285.468806,240.649002,214.63417,235.105174,187.994274,95.660085,82.550428,117.652895,155.679474,195.745449,187.991372,153.34494,47.364934,-13.224449,-13.172572,45.738522,157.484475,182.377741,191.53909,183.128675,158.64297,136.180368,111.637482,66.435018,65.527432,85.47451,91.140681,69.872335,37.537236,31.535446,-4.255515,-19.787647,14.064327,38.032191,39.336241,32.336587,43.186229,40.505699,22.386754,38.424781,88.267592,152.713521,133.246425,58.613432,7.454818,-17.279593,-60.945027,-72.986334,-28.177097,45.450696,206.447484,226.384287,118.704014,12.789162,-9.875291,-37.556435,-24.144773,85.108578,142.722666,133.863297,36.692897,45.346824,110.610354,105.445005,86.216407,126.900845,253.017334,262.642683,122.349166,-51.51043,-106.930976,-103.351688,-14.656827,218.522352,278.905058,249.051532,154.851362,115.790944,70.621899,76.39425,105.795612,107.799049,110.412744,105.777627,-6.005695,-173.82773,-203.288519,-106.889093,-13.323424,108.675619,100.668642,28.926825,42.686461,75.691973,96.375567,82.236511,84.390911,100.826948,75.801809,22.595734,-108.274753,-191.277922,-175.78591,-57.799159,-14.324217,15.974315,35.488254,41.844674,-74.409116,-130.733478,-163.449196,-173.130954,-199.808632,-174.798,-60.419799,-27.65382,-51.33011,-83.771807,-73.046647,-20.429507,1.938355,39.961093,61.946217,47.474576,-73.659165,-122.716204,-98.97058,-39.074179,74.188369,111.134484,149.963121,139.810593,56.345793,-10.379883,-26.984954,-52.936803,-50.297315,-26.85946,-33.261886,-86.936904,-144.485185,-176.933244,-264.064803,-276.877503,-155.523446,-59.642601,83.438643,100.497234,3.392365,-139.421684,-190.874368,-207.11798,-158.459993,-28.839235,7.94784,9.772483,-71.47286,-130.911394,-193.406219,-182.927237,-124.142646,-88.785743,13.131325,71.931808,113.609406,21.096551,-26.905346,-6.569815,52.434454,183.660785,240.592262,276.025004,183.65681,128.997442,80.078933,107.962452,235.327737,281.786054,327.08988,339.84323,249.868558,42.556306,-9.146092,101.886762,211.162221,332.288865,336.498405,297.138846,196.84325,141.073721,84.804376,82.322752,118.617061,167.11128,275.382626,278.963493:-12.868241,-109.774564,-136.068566,-103.890552,-79.419543,-89.151413,-108.973304,-114.992655,-117.568615,-112.853188,-113.952302,-161.565849,-257.297134,-232.451383,-81.165005,-9.825011,40.266192,-68.042944,-120.748916,-108.956287,-76.011099,-78.93819,-101.460174,-64.444804,-6.078765,-30.194969,-92.411949,-61.348899,100.848824,166.242565,206.886451,197.365926,158.572023,120.821148,104.977463,83.76583,76.615532,52.445057,55.059769,124.856494,126.475243,73.218529,-54.01593,-99.548445,-96.980307,-49.08918,54.727489,97.115291,165.539243,176.405769,150.252797,74.744581,51.807874,33.220836,24.43231,53.070733,153.295229,167.237562,85.726965,43.621932,30.474832,32.250241,12.80265,-2.599311,-52.950486,-85.642595,-99.975202,-187.290489,-229.522521,-221.946354,-186.630459,-114.476836,-50.674241,-13.171649,35.304606,23.098789,-6.235489,17.779152,138.509647,198.835261,200.52376,101.262814,80.557411,82.287056,89.678879,135.923497,169.028974,221.260848,208.436119,187.995695,215.027049,247.452625,239.67701,207.036538,179.059193,193.625853,226.6215,252.204737,250.661694,172.822153,137.743834,172.457422,211.787597,229.934924,148.900232,89.429638,21.687899,25.172414,54.720659,48.224609,-64.115333,-144.016646,-235.500784,-242.503509,-241.328207,-223.273734,-202.807893,-175.925508,-180.369006,-173.555929,-94.271133,-39.437442,48.323442,64.753024,53.156436,45.068842,51.192454,67.590378,113.849867,141.927204,131.817314,87.087193,98.754031,232.059087,314.468111,387.038393,312.084365,264.915469,266.647107,292.383605,263.872037,210.795532,110.202811,80.715913,60.066417,72.103075,73.060092,50.177717,41.072983,66.912879,106.282449,199.973126,199.654093,146.786373,7.628729,-58.922332,-125.086004,-96.885344,2.593275,17.763932,-22.014025,0.519155,42.593682,89.37521,88.911748,70.460373,53.146634,-4.971963,-72.890739,-92.973232,-103.102907,-98.11923,-62.449214,-44.329349,-22.468379,-18.709167,-58.336926,-59.21182,-20.776218,12.508153,3.866225,-13.155647,-34.986558,-57.492642,-2.008277,8.187893,-105.376351,-203.034333,-291.562771,-263.294078,-187.289267,-165.791844,-90.835091,14.091561,30.34784,23.611996,57.188241,177.684515,205.767438,179.205012,136.723454,118.667322,79.143976,66.13767,53.991909,45.357654,58.7962,97.523744,127.852048,110.126887,162.358114,282.340909,282.966565,212.929592,178.111779,131.735803,105.150691,99.831271,142.210545,174.83035,191.748055,182.187014,185.394587,209.598066,267.772781,278.006501,249.527232,113.43853,40.418129,-34.325464,-26.97817,28.801593,-9.73775,-42.977619,-62.431972,-65.272971,-66.544964,-54.793316,-26.774851,-31.643212,-87.973298,-136.858554,-136.21749,-109.588117,-105.152865,-103.680102,-81.536871,-23.467529,-28.460513,-25.967536,-31.95698,-66.233566,-107.258866,-90.136138,-31.927619,-7.521304,6.095295,-23.506119,-34.543508,-56.64979,-72.632814,-67.546754,-42.244562,-17.530739,-100.258238,-152.850073,-210.04427,-231.847261,-271.124417,-259.71612,-132.526408,-38.579503,39.310506,-141.52752,-243.912177,-275.667269,-197.665616,-27.49172,-6.158638,-23.990578,15.181728,60.883855,185.452568,234.972845,245.628173,214.851301,156.597282,136.832948,89.497746,11.61469,-28.725444,-19.362089,21.665943,19.813665,-15.403395,7.11959,122.978231,161.426792,189.623078,188.494099,151.35652,109.308626,-1.687117,-37.353198,-44.448863,-23.448805,-21.778736,-63.830517,-82.128045,-54.83091,-25.362708,-22.864942,-77.379927,-83.918505,-101.667087,-140.634329,-222.06387,-236.900693,-215.155715,-187.920605,-127.206388,-92.992452,-74.28852,27.034473,92.544507,123.842844,73.580674,-45.816946,-51.968488,-19.423101,18.3423,1.329046,-52.841553,-60.630497,-38.458608,-21.85832,6.813895,48.577186,66.498851,71.043303,63.49858,12.687241,-27.835561,-75.305715,-119.698964,-156.059357,-179.836673,-153.179611,-49.734311,-4.523264,-0.630415,-27.977586,-63.832602,-38.279054,-31.889465,-83.60712,-114.941233,-147.000466,-149.277537,-128.74715,-132.788169,-147.229598,-145.859026,-111.186872,-13.890616,11.593937,28.299459,36.205096,17.329798,42.167005,78.57029,51.207149,0.903551,-50.386489,-39.114325,45.699804,92.97408,94.406666,179.465926,254.586224,327.557205,305.310865,210.60588,165.669089,71.943248,-29.582141,-50.868543,-8.104714,54.42813,185.047808,201.925885,143.622314,83.02055,67.488371,44.514929,46.19289,102.835412,132.765142,157.032691,175.553397:-46.182923,-115.203493,-110.518987,-102.713411,-125.821809,-211.791111,-237.526508,-191.518081,-178.602323,-203.234439,-214.830622,-205.382732,-210.573281,-221.626055,-170.767492,-93.627635,25.471968,-20.202468,-54.059752,-66.467004,-56.088362,-61.87576,-92.315391,-97.945108,54.177575,108.395496,34.706696,-41.98348,-46.322521,33.699075,145.688094,138.082217,113.933122,131.511108,111.200929,1.699687,-45.266216,-47.902647,-4.293232,130.815355,175.680363,130.434273,-16.523697,-64.608547,-38.552553,0.555676,22.471923,23.143692,93.606174,176.144104,158.649424,30.402092,-4.238703,66.728189,117.538931,133.211341,123.081901,138.783186,142.30383,130.376274,112.346959,71.308856,-88.653991,-157.355785,-198.396063,-153.683144,-146.89028,-202.534937,-223.889244,-221.639517,-225.191329,-223.500683,-129.389646,-57.229222,-8.232569,-66.171554,-194.429881,-181.141615,24.050283,146.613096,240.833774,185.410069,162.899642,159.838202,177.826794,204.069742,200.634436,190.725337,149.383696,128.245822,175.953722,217.967138,206.805638,170.38491,160.91595,183.552936,147.519306,7.981563,-39.757531,-62.433004,-40.230067,53.463162,98.052395,107.124599,46.635509,33.459641,42.471484,50.151912,54.245258,38.924853,-59.721481,-128.166812,-195.286051,-146.015244,-135.895443,-178.491275,-177.870635,-97.723508,-70.677764,-102.018624,-96.693596,-39.228821,64.048377,65.435619,24.973879,21.838495,71.888241,113.337556,154.797545,88.556692,40.809937,24.758108,83.494381,272.2853,352.35885,420.960462,396.482845,375.623821,350.267272,328.043392,249.624288,214.708187,157.579237,129.273904,100.404796,139.848752,171.857359,181.768804,134.366343,32.943189,46.456065,182.656452,237.945813,197.878338,47.773385,-20.640756,-57.312594,-51.410302,-76.383711,-63.789758,36.86896,56.803997,29.58175,-1.458629,14.141795,73.180944,79.890445,-10.208024,-151.871724,-201.731664,-245.950963,-238.392898,-190.625067,-178.247678,-169.951475,-152.554088,-129.389774,-116.637508,-92.051024,-18.86514,33.29282,85.737611,29.813064,-139.449743,-156.716127,-141.946303,-207.273198,-265.986493,-280.674561,-232.615685,-102.527955,-39.290123,19.942556,10.556581,19.075765,66.919981,92.604817,116.653852,117.556021,126.858486,169.78092,203.330106,204.419764,161.243532,83.178291,69.00003,60.899037,57.929266,45.834828,59.530092,85.662593,132.565632,160.35061,216.638874,202.918889,77.821278,-8.724502,2.293606,66.570135,90.702858,138.246295,156.298604,161.235028,174.797002,214.889121,205.157439,186.023039,128.365003,96.229445,76.090162,105.356706,151.214587,70.232776,40.779129,89.389263,132.108575,161.874331,136.296171,49.935796,16.579766,-49.135962,-88.404947,-63.849178,59.854052,118.513999,155.902779,151.957404,142.612642,97.846691,73.813964,-1.735445,-68.40836,-139.573949,-114.617349,-45.245823,-31.345341,-20.891725,51.84128,93.285092,13.318976,-80.848453,-133.332939,-90.402052,-46.053387,-76.141253,-68.875426,-62.119028,-102.958437,-186.298385,-175.074483,-49.799396,37.097303,134.84386,-11.240145,-117.265341,-171.699533,-99.828237,92.610005,163.29426,239.957134,156.659892,101.434929,99.740041,117.27644,116.209548,101.304884,50.290226,24.056917,-15.119567,-56.799638,-78.496326,-91.722951,-78.702149,-32.784327,13.04398,156.629469,189.391975,142.857012,73.178918,83.196792,114.720978,98.687738,48.778674,43.612494,3.133829,-46.661185,-35.382943,-39.945672,-73.291344,-94.918643,-64.204477,-28.466705,-67.20287,-36.835561,65.25087,44.872489,-92.969705,-128.67253,-83.219537,-25.618628,60.618724,-5.690835,-53.950309,-0.274762,80.670129,132.444695,99.934369,54.894588,13.838688,-11.068053,-24.056715,-16.16552,-4.658545,-11.753445,-30.12114,-24.751012,20.771171,55.44792,37.420951,-4.150445,11.025552,48.60909,33.560038,-50.399863,-169.282671,-221.548846,-243.873423,-207.487858,-106.438864,-83.447509,-104.567023,-118.269951,-130.860937,-172.325447,-224.188373,-307.98777,-287.744906,-202.991795,-192.238746,-235.712305,-315.91724,-340.428666,-300.811792,-231.809889,-34.082399,51.916006,117.442023,97.322537,4.013351,-65.672246,-74.139135,-71.859831,-66.967042,-14.223816,21.275326,38.194746,26.580428,61.83447,186.254459,220.355242,212.409541,209.186198,231.438717,217.761905,108.600206,43.064301,49.705876,135.382,189.866721,207.785203,194.247236,234.723929,235.427629,188.105529,96.112011,92.064172,179.368276,224.169818,247.856618,239.512851:28.572525,-114.018628,-135.452573,16.072061,93.383557,11.383285,-89.311309,-90.27536,19.545673,10.155126,-47.628636,-59.041092,-50.907902,-37.987972,-0.880713,19.547179,2.746986,-77.685309,-92.294507,-44.707771,-2.232081,24.577218,1.672381,-1.521154,26.438099,9.04268,-50.035585,-67.43885,-52.783779,-26.354704,38.412866,73.790484,129.617756,172.074538,179.436695,114.688342,66.082361,12.782466,6.614297,28.995127,48.798902,34.749424,23.888427,45.252151,128.551178,189.981592,270.473522,248.278871,156.371487,148.723625,177.683744,190.433737,149.007772,84.853419,100.433929,163.043127,134.737485,79.731537,-9.912972,-6.825033,52.601234,55.360169,-23.250575,-58.917395,-79.996934,-97.66097,-116.329795,-140.170978,-124.196345,-106.781229,-134.615087,-185.627292,-85.353,15.484446,116.851106,63.825388,-26.389351,29.789644,219.016956,249.328285,105.472336,-61.738923,-88.476072,-65.622054,-33.357167,-3.692003,-6.650022,46.933971,79.240205,59.046004,108.462853,183.206317,222.321178,155.064221,20.762578,15.657649,85.035327,167.569914,172.791475,70.407942,29.190569,79.395623,123.785807,121.7167,62.379491,43.245439,12.565947,10.1789,62.321901,79.09677,-43.823276,-152.198152,-286.453797,-253.710069,-212.403476,-187.463969,-175.876392,-115.670589,-125.180632,-242.00471,-223.241984,-108.953112,139.863846,168.8346,59.373945,6.878147,0.599161,32.790471,72.419227,48.253904,40.776866,55.551997,67.381843,60.594802,58.344001,108.308126,92.306585,32.207283,-50.095866,-45.698815,-37.935235,-64.272564,-125.048452,-118.362814,7.682727,110.92914,99.519039,78.635161,96.236577,98.762479,90.850069,144.891281,200.477801,187.187795,113.764068,71.465094,-13.358472,-58.339738,-119.743967,-102.213766,26.387086,115.808434,115.385941,64.142788,39.891024,16.358325,3.779357,-56.72495,-135.81777,-160.664736,-193.878549,-203.88225,-149.18667,-89.359467,-4.208843,12.294415,12.781793,-0.437403,7.991643,11.220437,-7.398674,-54.082775,-79.592769,-109.039012,-94.366315,-93.833178,-104.049284,-103.228891,-107.145542,-124.926516,-175.22097,-184.954642,-112.383061,69.370559,121.73412,87.709663,89.934056,266.131435,355.255314,340.447638,246.703345,242.873815,201.808885,133.354674,61.191071,100.018089,215.562032,239.963041,218.765165,173.177519,165.874609,208.668623,243.045382,241.4554,201.583609,140.71565,118.165254,109.392247,84.838153,61.841607,67.829076,121.346636,209.481765,191.122548,98.391297,70.343245,59.801028,-9.772913,-55.956906,-132.023896,-139.547303,-107.859431,-104.492414,-103.621501,-119.4956,-132.530522,-103.277082,-95.302332,-172.158205,-187.806132,-90.927655,-52.937202,-85.637532,-136.67262,-107.215026,-49.016257,-84.552035,-171.204906,-107.717074,-44.908807,-32.6023,-88.999707,-82.141276,10.478452,138.459943,126.865644,78.706708,46.012006,7.381478,-73.226644,-84.53241,-41.634549,-11.877772,-3.844595,-52.684172,-76.986958,-108.92165,-103.408092,-39.782294,-14.152961,-23.4576,-28.227858,-15.165253,-54.102733,-107.81219,-216.190497,-190.036147,19.752917,96.825567,100.97609,94.177839,122.396169,159.350096,148.892693,143.196955,175.462912,235.501285,219.725414,89.12199,-33.022532,-32.821162,28.224185,43.793343,26.665562,19.45224,63.708237,108.841593,106.966812,101.730619,111.021015,133.885173,119.850954,23.483734,-24.237673,-87.977658,-135.978484,-119.096673,-43.099176,-33.483925,-43.426598,-28.311787,16.722068,-20.166406,-61.895665,-103.823479,-108.419957,-151.504301,-185.270087,-192.405172,-150.89215,-77.768307,-91.890405,-76.932872,31.172744,76.027035,101.770331,105.071397,79.9091,-20.996099,-65.283185,-89.590938,-67.527609,12.194656,36.866543,27.076806,8.340801,-18.84972,-16.366819,-31.868718,-80.943762,-78.901313,-80.222907,-118.977651,-229.500816,-269.12237,-245.717289,-179.036637,-154.021352,-97.188472,-71.22322,-34.172349,-18.624266,-35.326965,-76.347449,-90.252441,-94.928558,-69.34752,-7.761208,10.166567,14.62037,-79.625398,-130.424362,-142.292396,-110.054245,-46.129206,-40.67509,-31.11344,-3.360547,40.389571,67.145863,81.568736,60.125858,41.657403,40.462177,47.317953,59.06768,76.828789,105.627936,193.838579,243.691516,349.998525,367.700802,269.731857,201.510047,130.20241,36.340358,-22.172013,-8.197572,67.7313,221.03679,245.725479,217.746523,213.164641,208.603136,156.705139,117.50117,109.303617,155.599708,222.415993,206.523172:backward
217.489361,148.701613,130.016451,147.863691,136.812903,12.571829,-71.455978,-179.244571,-145.425098,-75.879021,-20.697281,-93.079994,-268.721893,-286.83905,-200.559541,-155.24032,-159.63464,-206.258018,-206.837856,-209.55029,-251.007266,-382.274555,-394.992115,-230.271085,-25.151503,18.591631,27.178711,30.198456,81.569657,122.166161,209.714362,242.286464,212.217286,134.053662,119.063775,109.895297,86.391315,-23.568681,-90.52919,-145.035999,-44.250874,-17.633648,-81.063719,-100.626605,-64.451336,-58.994382,-94.057667,-103.146557,-8.763426,157.323657,163.280652,70.156993,63.726174,134.163938,121.699392,12.076812,127.221744,249.450187,346.107286,300.570533,159.935631,87.419932,-35.571155,-42.27797,90.137459,207.009746,186.319522,64.307319,16.140989,-2.626486,36.524623,161.491827,270.419226,320.467003,334.447675,267.718906,91.375576,41.906997,3.442611,-30.853004,-148.866233,-203.619387,-213.563133,-281.093013,-310.668405,-258.834967,-181.998524,-12.943497,32.004343,1.974925,-33.506768,-23.929681,-70.378717,-113.762226,-91.192247,-66.632661,-81.794822,1.487909,95.317192,258.519726,283.030201,229.14899,225.939463,406.982444,688.336829,777.370257,770.952778,701.519585,501.314218,371.954433,139.315973,86.965375,96.378956,119.570723,129.44298,147.35484,128.399097,16.005961,-24.973187,-4.88612,11.824653,3.328421,18.018956,39.956399,15.95951,-56.556236,-172.016543,-135.022387,44.996318,82.704691,24.348515,-70.235168,-54.292815,31.330856,78.187203,211.63211,357.860016,391.261939,332.471694,266.366144,107.154774,9.475984,-153.572299,-176.54375,-86.557781,17.980515,3.369994,-78.805493,-96.225914,-87.353657,-55.701518,31.826295,36.943933,26.266429,22.629288,31.33048,52.851353,39.067453,-21.135597,-20.48333,41.901231,-11.211769,-55.60447,-19.012102,18.246822,-19.691047,-78.56936,-170.937262,-161.212218,-114.250364,-1.714561,18.687502,-47.522274,-96.078989,-126.482621,-98.492591,9.379624,98.100772,116.314104,86.382598,51.506505,-3.066104,-10.306472,20.580935,65.009476,92.205432,158.040647,162.83551,78.895418,15.242378,-66.156053,-85.772065,-84.955067,-37.597902,-66.36046,-162.365875,-156.0454,-95.593143,-94.124641,-132.371919,-108.291061,-76.636163,-62.364884,-80.723515,-130.985088,-157.929338,-189.316301,-180.677635,-74.318966,59.392443,42.01997,-159.838549,-278.571987,-418.686633,-408.225257,-257.931225,-54.952215,29.788112,54.50126,-14.94098,-197.936844,-255.934329,-232.386247,-188.222881,-181.828835,-205.804887,-211.388518,-248.108373,-253.671046,-220.285671,-205.023518,-173.766753,-88.090914,-21.120123,35.232865,-26.628285,-246.612639,-335.376227,-351.601744,-257.705666,-11.494944,55.251977,15.33682,-138.736811,-212.730811,-230.78357,-150.533787,84.612856,207.383612,204.247284,93.88419,20.265319,-62.381135,-79.054385,-137.979497,-174.786457,-196.371094,-197.88678,-247.232866,-354.012392,-338.08959,-255.936348,-255.952567,-277.324581,-175.337094,-87.748966,-2.196403,-37.339802,-191.964226,-258.81513,-268.119132,-208.530102,-28.515099,94.228847,109.829244,76.844965,17.084365,-120.698976,-135.909225,-68.811714,11.464832,35.615817,-19.686297,-76.286378,-97.349874,-71.458884,-86.063462,-136.690062,-200.63397,-144.863805,-118.879838,-127.726613,-155.316087,-214.092247,-212.549836,-131.375423,-36.837493,4.308101,27.449247,-3.42469,-50.779454,-36.459813,-7.39964,-46.245048,-212.041881,-239.968259,-189.727448,-101.484478,-85.528089,-102.755828,-110.946524,-73.934648,-41.002161,-47.072123,-100.30119,-127.09369,-162.541651,-185.359039,-180.297228,-131.700379,-21.995812,47.814557,91.638428,167.57852,138.179261,-62.089365,-126.403497,-69.112515,49.676857,92.696135,57.961002,-27.223462,-231.936144,-319.890107,-376.709864,-323.373213,-177.982969,-146.898264,-169.982636,-191.071129,-169.773638,-168.096475,-184.884028,-122.336782,-4.207132,19.428071,7.027071,6.141273,4.357147,-15.950155,19.086332,78.828443,163.002761,235.738186,257.600069,183.661535,105.282309,-39.118793,-58.072053,38.545187,143.04671,169.85409,184.429135,164.187474,91.203681,65.020079,119.31141,213.730525,382.02361,342.785247,307.000149,320.726554,318.167912,205.603782,157.944656,206.481082,321.139265,345.039777,219.159442,73.315806,-147.225943,-149.968457,-18.022768,40.772922,85.765463,132.247064,165.42882,178.612022,132.150179,21.318448,29.104445,133.292163,138.710949,104.999865,14.504789,-51.860099,-191.613044,-225.681631,-160.466316,-74.928263:156.017573,218.720326,211.630021,167.408462,149.078717,102.030462,34.737328,-98.224243,-29.049938,73.909108,175.351013,70.281549,-308.101483,-397.837543,-233.807263,-109.839477,-83.637799,-204.248903,-217.325695,-216.450165,-250.544383,-275.152305,-216.747336,-74.434654,8.111797,44.435095,128.014633,168.684567,215.657535,223.881018,264.158769,291.841093,262.29501,215.01102,227.647183,226.289009,188.589974,110.463026,92.198192,72.091333,54.50955,17.298541,-100.076813,-110.152328,-34.796101,-32.94727,-98.605151,-112.269324,-69.425559,35.42773,80.696785,125.444425,128.168595,82.312227,21.094274,-80.589404,32.797111,125.341627,184.80579,146.748143,49.97996,15.886605,-16.560375,-3.675192,94.806413,174.246712,155.339324,66.525832,61.052035,132.539233,172.303725,222.090978,234.441758,240.350927,211.863983,140.7107,-55.7196,-99.836508,-49.837477,-20.187856,-58.891528,-187.890992,-239.986769,-268.120093,-257.234813,-215.364938,-187.77932,-130.11303,-99.27161,-106.428393,-101.194587,-68.00799,-77.833853,-113.514152,-51.010836,13.289078,82.136182,153.062693,193.424289,254.828787,246.7931,153.301727,140.043003,258.589965,458.504419,536.148314,557.875127,516.025764,411.408106,339.120382,160.956411,120.868094,210.570675,254.525877,223.248603,207.047472,211.779178,143.583688,97.707333,69.386513,78.367602,66.067707,39.199422,37.959862,-10.135345,-56.7011,-98.065306,-81.845683,3.893858,25.257765,-28.644317,-107.67557,-76.856984,4.624841,-4.709786,-31.571882,117.878058,212.128316,232.73075,170.139512,-9.503938,-114.67833,-240.601414,-225.043549,-104.523812,-28.113111,-30.48703,-75.685039,-101.192548,-116.970608,-96.38798,-41.007634,33.64217,68.186093,35.603806,-2.776895,-68.376018,-99.540147,-78.743133,-40.046543,-5.15773,11.038489,27.690278,38.104436,18.180814,-19.221329,-18.72655,16.948309,59.416984,55.693912,26.437055,3.724098,-76.707497,-106.2107,-94.536781,-42.433453,137.335759,219.601826,206.372914,149.106461,101.090284,-2.83215,-8.684321,132.377732,280.098087,297.196353,264.181666,209.841695,69.09836,23.485832,-38.845261,-60.136401,-2.647054,67.568525,6.451504,-174.878431,-203.753906,-150.231164,-116.354997,-87.01163,-65.060063,-59.663948,-64.696147,-66.051382,-135.287511,-219.53185,-302.094732,-241.44446,-32.580471,55.283359,16.602467,-166.919879,-260.393876,-350.085651,-350.257795,-297.779852,-167.973767,-90.731227,-6.610549,-15.139243,-121.305122,-197.632815,-266.253144,-261.864343,-259.728532,-178.404627,-133.51282,-139.187067,-162.97059,-191.387204,-193.937369,-158.429882,4.414972,115.592986,152.814755,33.093222,-237.379451,-287.139762,-224.870487,-139.512456,59.226527,120.680342,65.921429,-86.428502,-111.680895,-36.204144,31.599989,116.105167,117.401079,125.310986,80.684739,-8.36149,-202.53388,-238.761064,-213.220104,-191.853931,-124.827838,-102.356648,-171.467514,-319.852636,-300.870104,-173.589459,-149.128161,-177.471969,-125.995532,-60.152255,-40.446108,-111.14714,-255.385625,-270.395848,-194.539115,-140.331096,-18.826741,85.698639,88.099086,18.129009,-28.333658,-93.963,-105.684885,-99.148211,-17.221464,1.006918,-151.545937,-254.751639,-291.756513,-238.082195,-127.133138,-95.439546,-41.783549,-50.464986,-115.291428,-228.309521,-234.700625,-250.027509,-270.991783,-201.25745,-15.933983,27.860894,-37.655692,-89.339133,-106.044199,-80.009584,-60.357157,-99.113966,-195.261915,-181.639806,-175.2792,-232.606763,-263.450235,-251.987127,-230.859797,-201.631216,-119.420181,-92.494445,-169.696508,-233.254723,-295.355634,-288.197289,-174.310762,-79.041678,93.82975,142.754169,116.90499,60.429755,48.679251,51.202019,66.100371,58.186831,44.530348,86.936715,134.881811,63.190213,-233.736071,-362.64934,-373.735508,-267.590583,-71.63491,-117.120883,-180.945138,-179.310208,-135.727508,-144.278349,-170.163992,-105.225943,3.130577,19.378109,31.789879,46.684204,9.643817,-54.738046,-76.909922,6.481037,163.310948,130.21375,69.033059,-73.368906,-153.839153,-254.810464,-199.082857,61.867718,172.515181,168.919227,102.783836,29.904142,-75.722072,-62.764267,74.379735,177.934724,332.149211,298.351855,261.276635,245.66492,229.908176,105.501325,63.146865,154.725891,273.802269,252.525684,43.119916,-85.095659,-241.040128,-244.868693,-119.092639,-39.597147,70.324939,163.51968,194.481164,188.087155,147.73655,41.24524,18.342286,81.144799,175.677315,196.035385,142.459529,43.80144,-207.651527,-246.89983,-113.796857,-38.381598:251.821206,255.875962,213.326262,94.210818,60.334154,64.887806,52.764138,-21.240857,-50.600119,-13.496912,38.713524,-23.820169,-246.824374,-294.20851,-182.618732,-110.500208,-120.160912,-187.902508,-180.752518,-163.652693,-179.993278,-163.841111,-103.77165,-34.678334,-57.014882,2.433736,185.000943,207.262741,149.143234,152.638468,296.034867,370.290749,357.384711,281.943895,272.888983,228.82363,174.11187,61.520478,41.974084,62.833948,103.793682,108.591567,57.740225,35.522506,-25.063224,-90.902621,-177.061044,-162.43771,-84.293316,44.456557,123.590448,180.309951,124.945708,-65.01491,-134.431636,-88.898779,51.137637,48.630402,-31.441063,-34.139038,33.147786,47.268278,1.6682,-22.588704,0.653049,76.560984,80.92049,26.904758,13.906093,18.29364,31.883745,121.031865,124.939169,81.841679,52.584855,40.441928,-41.983228,-54.606889,-6.669617,-5.040583,-79.958389,-153.898466,-183.335755,-274.126585,-326.428839,-335.349681,-299.820771,-280.885507,-235.864577,-171.522849,-100.447256,-133.105467,-245.834129,-230.52166,-59.010041,5.316465,90.236486,174.969694,189.999836,211.53273,215.511989,163.38539,146.660065,216.899394,360.478835,413.045546,411.231092,355.912805,175.683463,75.494808,-35.192332,3.806011,194.580209,203.576212,134.147291,114.244278,143.500615,64.084546,11.348349,41.078281,105.802694,103.668624,12.514756,-57.025494,-144.64006,-134.876702,-55.880498,-22.966831,27.435921,57.739901,48.111347,2.349808,-18.676677,-45.817135,-41.728969,14.086393,137.915645,203.106553,216.25059,157.250982,-18.235107,-92.732559,-114.738774,-95.903912,-101.115156,-67.616818,-36.912299,-62.935585,-119.387174,-178.433128,-156.789996,-73.625439,25.557703,36.280421,-79.568947,-123.982671,-80.074884,-63.425138,-123.3743,-141.441061,-19.765232,128.066923,110.520812,-56.826779,-117.530655,-90.06411,-65.396404,-53.832599,85.787503,148.178427,78.335007,-8.395205,-119.168583,-128.661686,-59.460928,2.861882,101.716439,114.781098,109.181626,104.318454,97.030102,91.539532,108.172713,190.551919,289.248247,324.99247,346.053967,286.987756,75.242589,13.351161,19.122882,33.183107,11.832135,-95.779296,-159.201368,-167.771563,-115.029743,-31.942076,-51.745663,-165.612059,-196.824041,-169.824438,-75.681759,-62.108116,-166.691783,-218.530384,-168.161035,-87.861627,67.59164,50.114711,-44.558351,-182.207205,-190.139375,-231.57039,-271.137446,-225.310409,-53.524521,-16.08483,-66.711996,-100.731508,-136.231797,-183.447306,-317.391929,-328.557711,-235.065041,-183.450286,-177.064738,-146.092904,-135.229039,-129.620797,-115.369334,-41.15979,108.621545,180.151034,135.564513,-6.433895,-281.96956,-314.492584,-231.181683,-151.584475,59.599273,103.54734,22.781304,-95.786692,-86.132944,-45.572422,-21.572295,53.202045,50.202993,29.552097,9.288264,-18.553271,-166.442447,-239.785238,-238.636399,-181.711174,-76.139772,-52.095066,-113.94832,-278.813792,-282.222887,-159.376874,-122.688756,-166.894586,-169.194059,-115.822634,-23.764846,-34.802902,-146.580034,-188.539359,-191.658302,-169.661486,-46.518219,77.788839,44.342417,-124.923365,-168.751587,-174.280247,-168.997176,-63.177504,147.812687,137.36955,-202.426943,-346.901576,-306.561224,-206.308574,-108.659325,-124.42864,-140.706194,-110.6693,-111.156221,-140.982333,-163.866514,-168.994025,-165.23775,-184.654803,-59.132523,28.122177,64.297169,49.080158,88.699051,113.126774,51.830549,-15.032046,-73.060484,-57.9553,-92.540272,-163.510006,-149.497728,-101.007775,-113.316609,-167.231116,-140.690092,-126.361636,-160.459745,-195.641236,-286.834808,-312.532481,-196.843962,-57.75584,175.463712,152.729229,97.632394,46.132764,34.900972,2.051738,-11.418301,-31.050215,59.632154,119.855284,69.356068,-39.48251,-290.359335,-374.046362,-366.053299,-290.078226,-111.68365,-46.064963,-69.299224,-106.180715,-96.608594,-109.513468,-131.837268,-69.24454,109.605397,173.075156,218.303792,211.904912,88.05906,-11.132228,-66.816396,-7.520283,116.985732,113.201187,67.98287,-37.540104,-111.468213,-270.613777,-255.073288,52.050905,293.847962,279.615213,101.795214,1.031874,-96.936141,-61.741447,109.821768,198.024191,307.566698,303.329577,284.340575,226.14324,166.892956,45.961653,48.148138,133.534616,73.461919,1.916823,-38.959672,-28.265224,-121.350586,-182.64438,-132.893215,-36.143764,144.596312,134.975075,71.958302,28.316151,61.624106,89.299418,73.14177,102.759848,199.06675,207.987573,90.491217,0.47524,-110.491086,-97.905606,22.350786,83.923628:199.328692,266.788912,266.78774,223.217348,201.046853,118.732237,45.733065,-90.961028,-89.815809,-30.493771,63.64508,29.04707,-172.798883,-238.258453,-152.558168,-69.8222,-19.708361,-4.200905,31.888632,80.154014,65.965059,-11.641696,-35.409287,-16.639183,38.747145,71.824509,136.867311,153.162765,145.0274,144.287952,219.87007,277.276448,319.286045,311.419799,303.534737,238.620225,179.674235,41.762537,-16.965997,-53.911071,39.405591,64.585481,-3.425867,-39.927626,-87.551642,-124.134648,-135.859243,-85.711607,5.86175,-13.093656,-36.883989,-22.954093,2.660513,-38.482904,-103.465302,-152.116234,1.286165,82.394414,90.42842,44.209687,-28.928194,-60.886412,-103.596679,-91.341588,-42.129628,-15.324241,3.30553,-8.4405,-64.250241,-167.848361,-145.699491,55.77165,259.072867,315.334623,335.307679,291.343615,119.846325,28.183804,-116.10593,-162.364335,-199.463104,-201.912973,-220.214477,-307.912196,-357.34017,-388.124541,-354.69576,-233.272389,-125.598105,-106.983769,-153.782761,-200.911062,-299.445848,-311.132759,-224.707756,-178.283503,-108.728132,27.637169,88.078669,134.402079,147.50948,181.465406,215.170444,357.250616,550.665404,629.460452,625.463062,541.23105,345.390862,270.21283,175.699063,145.779134,117.888275,90.963046,53.26754,33.474077,49.632442,-26.469681,-93.068499,-125.477268,-70.030997,-49.268151,-39.633811,-58.191543,-154.771511,-214.010184,-253.330927,-210.315815,-65.050106,38.812283,70.252754,139.465183,176.886245,236.246698,265.382982,347.694785,458.036916,505.820642,476.360391,384.702744,137.74284,23.624154,-94.91229,-93.854441,-44.513528,2.177673,8.343463,-28.776781,-57.332497,-66.475654,-30.214067,49.609476,74.601404,77.676579,12.300956,-41.819593,-76.503082,-64.664543,-33.52231,-8.404048,28.977723,-10.660168,-22.545889,11.612983,17.448354,-23.870978,-42.515559,-74.022632,-110.939313,-114.2596,-102.676282,-88.622305,-89.905944,-118.388174,-123.878275,-75.074234,56.791256,126.263381,120.756493,25.550064,-39.016653,-68.526557,-8.701889,170.573546,258.413885,262.498222,218.613964,167.243354,76.749229,54.346245,12.374052,-1.007179,5.806516,-58.378899,-128.063714,-199.815119,-182.873264,-156.869912,-165.940825,-173.671087,-172.44123,-177.748819,-171.464317,-162.929369,-191.564352,-222.709715,-196.263398,-136.738644,-44.394624,-39.834958,-70.117232,-158.455992,-198.048739,-283.402019,-325.047429,-304.602931,-112.802808,-18.803631,30.251871,-11.423214,-150.095785,-221.885281,-280.83203,-270.702387,-280.41325,-266.094426,-233.686502,-242.530523,-284.200227,-271.393161,-178.693463,21.339923,76.120965,81.388155,49.784901,-23.455036,-241.055797,-312.766814,-271.247803,-178.196871,11.12748,57.488752,15.086914,-125.96608,-190.67977,-204.418065,-123.357277,78.149926,127.593825,121.593444,92.611998,32.785353,-186.018753,-275.250566,-306.175999,-274.000803,-158.4361,-21.768411,-33.146806,-219.57545,-288.216115,-253.814208,-208.650601,-188.739779,-162.10865,-116.060167,-55.504353,-79.672884,-215.497263,-275.911812,-252.390343,-169.649308,-24.784264,-69.041697,-129.927794,-162.034595,-127.88861,-107.962729,-137.995609,-145.940043,-60.202736,-52.348427,-182.920071,-258.235636,-269.187431,-218.979252,-151.617189,-157.799414,-146.51986,-104.03786,-126.203775,-184.358538,-177.429429,-118.72276,-106.083067,-126.382765,-53.30917,19.89093,89.266026,72.219435,26.229484,18.04911,22.754403,20.397789,0.64424,-2.724106,-16.481813,-61.230247,-74.430481,-98.48533,-100.369011,-44.610975,15.512823,4.968797,-106.777756,-169.538149,-215.334907,-193.042867,-105.754385,-46.276922,55.860698,65.041688,84.249635,145.248575,124.09702,19.55525,-10.183785,-50.275461,-57.294692,-9.2273,56.792022,-5.003361,-268.73064,-378.673112,-404.71414,-337.550088,-205.679221,-201.500012,-210.225463,-167.471595,-162.125522,-258.811572,-276.553463,-70.978567,194.084733,227.164909,137.348901,94.815144,60.68834,43.809861,86.964649,160.497935,253.519273,208.287598,173.760301,119.58504,64.516517,-107.769409,-123.519154,80.505227,281.913497,304.680737,246.983443,196.819111,106.974675,90.988201,177.693332,275.955598,421.428865,412.419974,401.913595,378.434327,334.067628,206.771301,181.825661,241.24323,240.506766,183.612935,60.659623,11.785552,-108.500625,-158.406062,-100.842019,-9.647097,130.296938,185.843057,195.93444,166.317019,128.743393,55.965496,49.952767,120.382825,190.931275,181.279362,39.486478,-70.928271,-251.493237,-272.377102,-133.509887,-26.018941:248.404375,231.018454,185.473085,67.809629,43.53443,71.015979,62.231458,-47.099995,-30.949301,40.58233,73.384825,-6.272004,-222.666682,-278.140935,-209.495268,-128.372518,10.266999,77.700854,56.951015,-68.470125,-110.071762,-77.375315,-42.917518,-27.007833,39.260368,116.36737,215.200686,193.456758,58.071947,19.596189,133.387519,224.34757,287.074548,270.245724,245.570185,124.941164,43.341853,-57.021152,-56.896522,-29.002243,47.829594,89.463824,57.944655,0.208253,-109.429602,-150.911495,-166.517867,-121.570822,32.206221,117.034901,100.00967,-22.473307,-95.769429,-161.257332,-140.129769,-27.8498,85.267105,85.24614,0.333265,-39.2914,-136.145835,-183.422677,-157.562681,-108.928433,-50.707471,-7.313368,-2.143965,-57.23383,-99.543293,-156.82515,-131.848712,39.519036,162.223084,178.380967,182.333708,154.154039,16.192975,-46.424181,-98.960056,-112.130587,-104.06989,-21.556551,-10.01751,-183.705753,-334.965581,-472.782755,-421.597171,-276.843027,-146.476316,-77.549661,-90.639949,-201.081642,-407.451486,-395.17826,-201.158935,-127.911499,-77.624535,19.668427,98.515497,153.485075,95.114443,17.443492,75.864901,291.84094,486.324552,537.570653,481.093843,398.121255,196.982665,105.683506,52.143163,87.77566,180.528301,170.540881,114.546784,51.466019,48.752337,-21.638953,-58.173472,-34.524464,-24.723906,-50.914362,-109.404819,-142.604209,-245.933923,-279.086395,-173.763599,-70.212235,61.347328,149.471111,221.315804,347.742804,348.753395,270.044332,269.293223,393.905036,491.298386,489.117135,408.366403,322.504707,68.676437,-34.38834,-62.667786,-23.335101,52.973818,86.248427,64.068761,-56.333,-107.457977,-85.175472,-40.930016,9.859597,85.426079,113.385583,17.860048,-55.722681,-97.373535,-87.052587,-35.777604,18.264371,122.110552,112.776259,74.839317,2.374667,-25.640614,-56.836991,-58.215198,-21.701178,124.527717,186.778577,122.17704,37.284874,-77.07119,-113.461651,-131.796578,-70.201798,144.764274,220.906531,186.428411,83.625299,39.7933,-4.086217,12.616318,157.83271,364.444494,415.020829,332.060996,232.493803,75.154899,50.694805,82.17479,118.491883,192.759209,144.732994,67.690899,-48.78074,-62.075772,-36.601086,-31.288875,-80.466073,-108.244871,-92.572817,-49.184675,-57.434464,-173.047025,-222.532432,-120.350013,5.482487,183.580744,133.392341,55.726321,-65.763152,-100.509665,-159.251292,-164.141986,-53.146058,112.106518,147.516296,99.578668,42.861715,-81.865867,-143.616095,-210.337164,-184.146718,-61.065888,-12.649393,-27.754584,-107.236739,-167.823418,-220.049673,-164.151529,30.48343,217.94349,289.628416,252.750564,123.386318,-163.175119,-227.828011,-186.696316,-120.401022,54.679453,117.366778,60.020692,-58.071231,-72.074125,-43.994862,-15.332587,37.209899,75.879259,102.350814,131.449456,92.129914,-142.278205,-271.144988,-317.974223,-242.879911,-56.583013,61.909144,37.647065,-145.147823,-221.646733,-216.092924,-135.162036,34.608597,76.553442,67.660763,48.942052,37.600933,-39.194684,-103.28033,-164.337625,-127.692042,14.976576,52.63446,-7.338243,-137.758143,-154.429742,-167.426473,-188.921184,-149.001982,6.954835,11.997445,-158.791861,-212.321084,-162.832816,-126.761612,-103.790551,-94.632174,-17.696106,-8.38026,-88.347505,-285.458277,-323.691764,-239.830491,-194.220086,-185.267248,-77.808275,-6.433165,4.369718,-19.08334,4.913327,13.146956,-53.364571,-80.05752,-55.877012,-53.226399,-78.779589,-153.279824,-203.126764,-275.362383,-259.598572,-142.771258,-74.049361,-103.112845,-243.160956,-299.97544,-360.653375,-370.109301,-288.639078,-190.914239,37.62546,147.157078,123.694954,-3.731262,-56.938604,-77.093007,-58.798482,-44.271474,-41.900734,-34.604966,-64.970519,-125.689035,-288.229997,-333.90225,-298.165466,-235.672261,-102.273462,-115.658965,-161.595558,-151.096312,-125.251639,-202.280268,-243.596568,-92.431075,190.79233,252.544955,201.341549,143.798444,4.324973,-62.696197,-37.363692,59.704723,213.881226,173.046449,127.145558,67.237089,7.97424,-184.311956,-205.036105,46.037605,299.846628,310.019931,175.236888,92.81303,-17.347519,-31.881355,75.144044,188.241325,391.605575,432.1211,372.251462,154.418807,59.370401,-20.401964,-2.518501,116.843694,174.567946,127.899678,2.68245,-30.863889,-138.652331,-207.83545,-183.869311,-88.786999,78.081568,133.072141,133.577666,85.406808,48.104225,20.056342,45.836925,134.563503,206.23059,203.859101,70.600247,-29.984285,-201.086943,-245.504325,-176.559033,-65.92835:228.186125,209.451625,222.555297,206.722199,138.990369,-109.501678,-205.301045,-148.064068,4.549769,24.204981,-25.088427,-91.393548,-252.158547,-286.944734,-190.350759,-98.034228,13.215785,-6.569697,-37.490445,-121.581483,-173.481951,-226.315913,-183.603219,-8.925683,126.385025,165.127234,142.094734,80.34808,-10.929761,9.035435,167.052882,238.723122,239.306194,230.554431,254.094655,198.014674,121.060261,6.404411,-22.285332,-63.923069,-49.572248,-15.185786,-2.659921,-53.784826,-176.101209,-196.885555,-122.307514,-50.559669,54.620672,28.272957,-25.160011,-72.418241,-25.171878,124.061982,162.063203,119.817489,107.987009,159.664571,262.262689,287.640066,276.621002,223.349369,73.686445,16.80494,-2.628865,70.097064,72.434897,-32.015976,-90.15314,-88.188966,-18.080468,156.718848,258.430439,273.525291,233.08282,196.978958,141.929663,103.112195,-29.699016,-90.838247,-140.67165,-160.513756,-207.203611,-325.501511,-334.130477,-239.874811,-167.525497,-6.168213,83.771246,74.393357,20.279474,-8.884275,-148.308941,-226.05475,-204.567722,-132.074519,-41.162828,13.115079,60.29571,141.157414,152.706436,180.045341,237.348111,441.950294,686.346149,783.825577,766.197014,632.868648,304.258734,185.924921,88.468744,85.572192,66.325689,-13.115628,-49.857596,-43.992516,-9.879841,9.344653,-13.683636,-29.130963,23.60018,21.754713,-18.734856,-17.653957,-50.882994,-106.921897,-141.933486,-92.395181,21.137296,120.876775,161.968558,207.232286,238.413191,336.468428,373.732736,407.574184,476.887762,500.835507,384.583173,265.636254,50.421494,-30.552218,-89.47291,-44.810377,84.344989,97.664661,72.733089,61.144807,65.849057,5.788149,-24.673623,48.6799,150.076469,135.502922,48.340846,31.279329,42.234954,44.687022,37.263145,33.93903,54.320758,77.946121,79.5624,46.719754,3.820114,-73.061918,-91.872951,-145.811661,-214.144181,-210.16946,-145.902277,-120.428051,-137.497107,-164.655599,-147.143352,-91.393547,42.898078,104.171836,101.471108,70.662107,45.599851,-9.669349,-20.172254,18.766426,152.398679,231.420421,267.449019,221.397445,125.835129,106.924225,120.077769,124.822115,111.071473,92.660055,75.020933,30.28867,-3.336795,-97.678193,-131.171902,-134.732514,-71.971155,-40.350797,-25.248138,-40.400092,-130.258402,-174.2721,-82.958389,26.492611,174.00759,230.058828,228.02177,88.94382,-27.960095,-172.366652,-160.247654,-43.640703,70.913397,114.831848,131.559885,85.878283,-54.011002,-97.780001,-50.577859,24.507083,133.225688,68.753117,-16.163624,-133.372736,-124.031286,-62.879655,-38.124739,49.398586,182.36497,216.53839,125.159609,22.94643,-143.026396,-167.78493,-105.609644,-42.21405,89.367018,155.423522,145.729834,57.505064,-16.42804,-130.826547,-107.464533,78.548564,198.85711,193.266312,120.213646,72.509638,-33.192185,-85.101342,-150.507294,-143.617817,-68.637516,-18.040746,-57.192701,-221.342641,-280.973166,-311.784151,-296.739473,-260.729413,-198.101015,-134.624696,-37.659489,-36.497851,-88.7224,-114.455147,-102.879144,-66.222036,2.046227,2.821725,-37.343625,-135.254727,-161.871601,-173.178545,-152.833772,-43.237423,55.597208,57.591026,0.069462,-11.827596,25.675942,33.573484,-10.400565,-43.692181,-72.389138,-28.180082,-29.326013,-100.203022,-133.320738,-168.272293,-175.153591,-164.158598,-87.310311,-26.640005,36.453341,23.328937,21.1116,42.791368,37.726072,9.200977,-47.312836,-77.110371,-78.317135,-45.208368,-30.360801,-71.190101,-87.378431,-21.405496,-24.692966,-91.780399,-222.642569,-241.026795,-248.620787,-278.009055,-285.490247,-218.283663,-44.741222,8.761421,-2.85577,-41.939092,-82.371258,-178.78575,-186.436597,-128.303034,-87.589608,-59.458837,-44.146704,-116.2305,-350.558646,-430.750717,-405.903904,-333.411403,-259.87468,-251.881411,-210.695828,-117.182152,-128.608205,-258.751377,-283.975356,-110.308286,95.374952,95.177989,-50.427784,-100.648185,-49.944528,7.748054,115.820807,161.197135,214.435584,274.360496,286.904738,181.950889,79.080413,-75.518152,-53.243391,177.018124,304.182431,273.953702,175.991579,141.345048,94.041601,85.964089,149.352618,229.86129,367.60981,367.149029,359.702667,378.279299,359.87415,202.370031,138.779718,201.924321,304.768859,284.468734,109.682114,4.766872,-96.128547,-93.885996,-52.62021,-4.55622,123.756946,196.969387,201.979007,127.40296,56.716527,-39.468368,-26.627439,39.812006,-14.631405,-55.106518,-64.542083,-78.684457,-231.538209,-307.613909,-233.091509,-104.720438:229.866335,248.455862,251.776634,162.096958,65.85866,-107.048895,-130.744042,-78.647639,18.814223,62.588602,49.41003,-11.366508,-142.655626,-178.621091,-158.705394,-96.963826,90.407737,178.761775,135.315731,-24.685312,-80.690083,-122.069536,-108.615951,-7.373099,149.069177,225.033605,249.580741,173.245897,-3.668381,-13.548021,157.603278,257.07067,357.660816,402.016158,366.773985,130.154236,3.6328,-58.647726,-2.253213,68.238469,48.515467,58.239211,49.181039,-8.735762,-172.13796,-208.461725,-108.364912,-36.531574,27.535635,61.714437,47.95749,-40.863725,-58.713407,-17.768542,4.314657,47.978238,95.962052,90.210159,12.364554,-31.633932,-97.44497,-114.046445,-79.48222,-48.508843,-23.364216,15.030192,29.45178,-33.923735,-90.839819,-99.203774,-23.946721,165.318843,256.992516,280.895946,317.702125,313.549405,207.868652,127.560189,43.825942,52.820624,93.276692,44.850916,-27.438945,-184.422909,-236.067147,-257.517443,-231.850412,-138.403428,-37.947454,-3.234502,-31.401767,-125.695782,-364.143319,-385.59507,-182.966377,-82.512622,-21.861108,31.9364,74.565999,97.052277,71.389682,57.610579,114.66602,368.221675,678.669513,768.560152,686.770973,548.337804,260.406597,158.658697,119.620806,176.816356,271.516113,142.888899,35.617799,-14.809285,21.280991,-19.306633,-63.838483,-16.4856,68.589575,71.288891,41.402526,6.685826,-150.248863,-232.306688,-196.424529,-85.580964,133.84761,279.332223,311.420354,309.286168,317.852796,388.745286,432.331566,531.993344,635.866557,623.902527,432.081698,318.55682,148.438662,80.645063,28.728144,64.705071,170.828572,223.916692,219.441833,128.705975,72.247708,40.431661,65.770646,138.611546,241.397205,268.663025,142.528978,43.517344,-17.220575,7.107387,47.237492,63.547775,122.436927,152.387531,137.672643,51.405155,-10.946872,-81.773737,-66.78889,13.725217,50.232444,31.134561,-57.35516,-108.619869,-199.60401,-217.249991,-131.346845,-46.334915,128.060477,218.177288,176.878424,-12.703213,-69.593243,-28.775794,34.056851,178.62821,277.518423,284.841179,223.498039,184.559504,149.212477,148.514275,181.097362,211.691873,233.967474,160.532994,97.347865,-36.886358,-87.255395,-158.610608,-187.714842,-174.338064,-35.998912,21.523061,13.481005,-41.397062,-174.611167,-211.239564,-101.363706,18.474606,153.849706,109.477089,62.04545,-51.495942,-104.893333,-161.47437,-148.938246,-42.917799,58.307556,72.395783,45.539369,6.678187,-119.28063,-172.788916,-162.717185,-105.53166,9.655828,35.498517,4.080012,-113.491218,-155.916467,-123.104375,-52.806053,121.478698,279.592196,309.571238,174.828323,53.392944,-135.665932,-185.75115,-162.026184,-74.038919,154.015973,193.499647,109.085857,-58.816888,-73.169304,-28.537352,2.339661,123.703671,250.361023,259.741375,174.117504,91.872339,-139.720466,-228.220955,-207.70264,-133.525186,10.250698,73.486437,28.709673,-127.240658,-161.946379,-158.412726,-148.948168,-110.525484,-49.458887,-14.491892,9.191807,-39.188861,-218.04114,-261.239912,-142.244912,-51.314369,3.851449,-83.038981,-139.413648,-221.080033,-244.509679,-257.288195,-229.942376,-134.434443,-88.287483,-99.078378,-203.510633,-253.730053,-237.699291,-196.822599,-155.245863,-142.41133,-39.526347,-9.441804,-94.277347,-259.530676,-274.378875,-234.625614,-211.061552,-152.801444,-70.448523,-50.332636,-68.113943,-83.761421,-127.180566,-152.540454,-129.127063,-73.560403,24.512072,38.878544,8.501291,-130.501876,-204.796139,-240.135697,-193.491075,-95.475594,-101.290269,-134.392694,-243.767908,-307.413112,-384.558174,-380.96918,-292.73209,-212.920404,-44.694764,1.867789,-33.340301,-149.377048,-197.317341,-188.68991,-128.508883,-22.686887,21.297266,41.399154,-51.105069,-194.222815,-455.988071,-466.423795,-297.628875,-216.722922,-125.215212,-113.987712,-136.985777,-185.223313,-220.245357,-290.384739,-262.164016,-53.649654,124.753933,145.485086,92.460265,56.504163,-7.211346,-15.296914,104.035723,203.202684,322.028311,302.00013,269.458991,176.559579,93.451164,-100.182628,-122.444982,74.733364,330.653131,386.429251,313.728438,201.343748,0.61425,-10.477033,126.756945,216.753708,347.624694,386.974517,382.547688,328.036032,265.929497,111.281514,76.49362,151.036648,173.392734,105.084832,-49.608476,-102.331803,-214.102197,-242.57121,-126.411371,-21.06145,98.482705,93.438569,87.765239,36.963195,-32.873771,-154.7561,-137.032552,39.020631,170.370672,156.777087,-18.921078,-139.027625,-316.540151,-331.469241,-203.70694,-96.702131:238.649446,235.876241,246.10431,207.017638,121.808564,-135.865522,-220.999863,-187.767127,-81.628871,-59.540801,-96.230307,-155.31316,-223.888766,-186.762555,-80.473692,-73.397064,-120.126961,-130.455921,-144.384754,-262.865408,-348.13052,-439.27295,-391.563873,-187.252135,-63.464215,-35.935328,-43.688497,-87.835293,-182.610833,-184.670702,-95.313549,-49.05324,14.571553,67.955627,78.534739,67.256489,39.609513,-90.123011,-164.337716,-225.95533,-186.182627,-159.57907,-160.993234,-201.877711,-269.035569,-240.569509,-108.346136,-79.330826,-99.959461,-39.966725,12.607391,109.110791,169.080052,302.358164,340.712105,314.940514,251.395018,251.793901,348.581844,414.96924,431.410672,383.966796,351.210329,372.487227,336.515686,214.234457,168.073438,100.004295,85.509842,110.05849,141.769842,253.741013,356.921477,377.899129,362.201285,323.147728,166.824917,47.708471,-175.009457,-227.477959,-223.480192,-203.335043,-212.274055,-214.169793,-183.516333,-108.395983,-70.852936,50.911123,167.05365,198.462113,145.932226,52.092953,-93.947692,-81.777341,15.324791,23.787168,-20.980261,56.76033,117.805432,145.199171,124.404444,121.106511,157.064745,282.544308,442.20088,494.591561,414.383059,300.077349,56.157337,-60.205438,-216.992577,-219.53749,-156.143681,-168.130029,-192.727918,-182.285191,-141.897638,-81.545905,-68.070031,-14.176381,24.388734,24.892268,66.509348,109.697568,118.504904,70.593492,-21.091301,-31.53414,42.78281,187.966007,231.67682,239.408375,238.024954,279.202969,318.291746,392.553919,393.459266,345.433324,199.863398,125.470357,-39.549345,-122.528906,-236.093753,-253.645416,-188.159328,-47.330211,-7.465662,2.005645,10.112035,0.936689,-21.939571,11.41807,114.634062,124.894335,92.009933,113.543404,249.173206,293.364772,227.135586,155.116464,73.752917,130.481985,187.719753,252.382549,231.340125,110.849277,40.112491,-64.207396,-97.371052,-103.18668,-139.684148,-154.421108,-111.802247,-70.671909,-19.807087,-13.297418,-9.295988,51.766586,97.043678,100.664439,37.951836,-91.825487,-77.87392,129.956731,351.193936,395.455413,349.356694,314.555737,307.142553,311.966839,311.725594,316.743392,343.117857,325.341497,267.563318,91.734417,22.431256,-24.025176,-18.119608,-19.916964,-46.744694,-44.942449,-48.770672,-80.643028,-178.418875,-207.691317,-134.052828,-40.332378,139.54234,228.553504,223.56847,144.733003,105.188594,17.96258,-29.356039,-35.243787,57.748868,96.286118,114.507808,95.300006,42.718381,29.891302,71.362863,103.752509,79.602799,-0.766254,-31.493039,-81.177668,-94.025082,-78.759193,-45.611705,77.823462,178.835239,176.717277,84.329351,27.408957,-50.437959,-61.057942,-36.171383,-23.491038,0.770353,50.348545,54.825569,-11.164564,-61.964765,-96.253073,-54.502205,67.192126,91.735592,85.892965,108.144983,99.309225,-23.074309,-125.28301,-308.66168,-338.249104,-268.619565,-163.403452,-167.774875,-258.439127,-276.309684,-268.449769,-279.589482,-311.425546,-263.791682,-205.854786,-137.745961,-150.260442,-201.440532,-221.425939,-207.601054,-176.561818,-144.344698,-161.985087,-172.966747,-168.052814,-155.770808,-152.862163,-148.357829,-78.704162,-12.571323,25.224896,148.521804,193.175987,177.730364,139.099043,115.557957,138.947661,145.696728,37.258686,-21.452037,-77.160178,-85.485636,-91.845906,-75.420566,1.000289,78.428453,118.748225,189.219414,185.818367,113.269754,90.053028,85.37093,65.455221,-14.483141,-33.391735,-23.290103,8.960428,41.375439,130.570272,155.683376,81.016613,-88.6477,-138.872167,-164.713272,-174.760305,-212.135229,-223.563559,-196.712286,-163.509511,-117.475796,-87.764162,-59.442304,-65.759303,-134.842681,-301.66574,-310.866993,-154.840123,-74.458371,-99.665685,-160.05888,-177.717746,-234.28516,-275.300521,-276.847325,-231.774712,-175.358849,-143.351116,-117.669784,-114.072162,-130.434982,-145.643757,-142.99358,-83.729541,1.142328,7.557853,-5.480424,17.938148,97.004628,111.850672,125.020877,155.12771,263.459546,399.850824,407.20154,254.712741,180.914945,138.850023,134.732909,112.411731,131.930637,157.512777,131.377726,78.892127,-4.42419,-7.305218,96.507296,169.990605,220.666204,175.324893,166.73682,187.792042,183.59527,75.221198,11.612554,18.564203,120.711807,148.318424,129.110856,74.459867,-97.22798,-164.008597,-161.165456,-93.338271,68.601225,54.672589,-13.688626,-81.671561,-62.444827,-25.496016,-24.166047,-47.99199,-99.758387,-98.640538,-61.830574,-76.645875,-180.667037,-221.652131,-174.414934,-97.970974:290.088733,316.544442,295.609142,172.721128,71.606542,-125.922578,-177.394519,-187.821073,-169.447204,-145.283901,-135.837449,-191.336985,-293.350969,-271.313996,-105.520231,-36.686286,-63.383659,-181.605067,-222.307632,-288.340099,-335.252168,-425.902696,-408.5509,-214.736757,-51.202568,-30.165593,-34.116598,-28.1288,29.526461,79.539752,183.074593,202.315813,149.255724,102.231827,93.150135,69.227139,35.548175,-94.24237,-151.696319,-169.703105,-109.027766,-95.095663,-150.352632,-185.061825,-179.364806,-133.05118,-2.316707,27.970063,-3.905576,-29.293092,-28.278564,43.686826,127.775958,302.012692,333.687789,269.45892,221.576738,257.993777,408.318464,456.468259,368.494112,256.743571,149.895978,200.193085,333.435269,347.59193,308.159035,199.78755,175.702241,215.3037,253.168517,288.016181,270.285047,284.305933,358.52651,357.449302,198.576107,76.330217,-93.688532,-119.534734,-143.747343,-148.088237,-132.259099,-107.67728,-97.47275,-62.046008,-31.426864,100.95797,227.90692,230.070045,159.049486,138.774819,119.452107,85.450601,-6.340673,-41.190728,-77.595843,-48.196893,1.063554,135.274016,189.558999,225.043437,223.550474,292.376174,514.342247,603.380161,532.210371,408.931768,164.069852,46.167966,-139.732611,-150.233481,-64.584792,-94.16923,-131.77474,-133.729263,-117.661031,-101.072232,-83.126513,-12.412919,28.418584,28.739404,71.447087,111.26259,107.553057,63.296799,-22.103364,-56.114092,-66.006979,34.128168,58.398658,55.001305,91.940933,196.836032,204.190825,184.51453,271.979097,316.144318,292.459592,247.205184,108.353867,3.492764,-156.494483,-158.074615,-44.115994,57.790675,47.674448,-44.172217,-73.987036,-59.34164,-20.40491,52.634803,80.747418,115.838275,198.338283,222.227505,249.619152,243.372345,173.5119,131.752451,67.729903,40.37974,56.042142,102.882768,98.719996,46.804951,13.976874,-108.923372,-258.676306,-265.289024,-140.890486,-85.001025,-106.193964,-143.515641,-144.424038,-110.988441,-13.314253,78.475195,109.315003,126.575805,103.167838,-3.495416,-51.92309,-24.750466,97.763813,124.482877,103.863532,89.330672,58.664709,30.229636,-25.200367,-52.783388,-89.932193,-22.771333,8.711112,-7.144637,-27.225239,-68.601123,-89.907554,-96.161999,-58.846112,-45.480598,-53.339759,-77.15957,-151.736189,-173.872994,-142.336619,-101.34849,11.515328,148.966901,176.188901,71.971767,-13.141468,-135.812568,-180.630503,-190.520532,32.21512,164.798289,188.661731,75.544593,-110.03566,-99.415099,15.733503,34.76703,-7.007184,-70.031146,-110.840594,-143.872284,-149.223046,-219.897231,-239.475575,-148.892571,-63.670487,-52.585172,-65.566933,-113.351644,-274.164588,-325.581449,-252.843486,-162.219578,-46.532827,-10.794677,-1.544929,-53.021238,-109.148381,-193.463894,-176.329885,5.126777,172.182321,184.711616,97.75468,41.234915,-33.380503,-70.894124,-186.373807,-245.617831,-312.92908,-262.867258,-233.12437,-282.010608,-344.486347,-473.755251,-515.762222,-476.670256,-282.6757,-205.576821,-205.529906,-234.064971,-250.714832,-255.130616,-235.625214,-187.480036,-63.894223,-20.839233,-28.957702,-34.96665,-40.436388,-79.727684,-92.865515,-64.459795,59.852761,118.047278,99.032269,68.510717,118.192063,151.03021,146.605147,139.150094,113.543,51.981948,19.466025,-43.513545,-62.266866,-75.481749,-81.309984,-65.374866,80.257593,185.651363,237.208517,152.790497,-20.907869,-34.545824,13.658915,0.849702,-108.13224,-141.020089,-119.79155,-27.371487,41.596508,150.52201,143.650153,-8.870946,-139.838193,-158.075594,-184.417364,-207.6675,-236.849856,-233.682588,-181.127964,-151.356859,-159.109896,-164.060002,-121.350575,-31.995795,-54.981705,-210.466416,-237.194644,-146.933715,-79.361405,-58.430609,-67.416925,-113.581952,-240.422435,-304.098083,-322.657237,-258.038625,-164.633122,-197.51349,-194.558523,-95.812579,-40.384546,-66.705917,-133.87471,-145.759797,-26.023951,-10.614189,-26.714367,-18.944251,-1.214887,9.21873,122.65621,189.467915,203.221183,267.363536,344.826032,354.895461,264.851218,97.115996,76.520257,88.994698,109.283173,128.327595,103.282508,49.540795,-30.52201,-18.231939,121.005409,216.982294,323.258419,253.613849,209.327247,220.792579,246.254997,182.07059,120.564729,124.234873,226.947024,243.056097,127.743145,16.570464,-131.923676,-139.15404,-82.894261,-40.99314,45.511396,102.335633,115.263772,102.619581,68.502651,-9.69897,-18.058745,-10.149389,-122.283004,-171.50956,-119.757429,-77.424084,-129.866121,-196.877126,-222.917697,-167.058778:236.174553,230.847077,191.949856,120.124437,84.792292,-76.087012,-166.01368,-203.858401,-44.121457,46.238227,62.486511,-14.296657,-137.386527,-145.785234,-109.248606,-73.561061,-7.478749,19.926978,6.841703,-134.035433,-223.031354,-274.880632,-231.577899,-68.649605,142.670253,231.831648,233.301002,141.66915,-40.135185,-55.66109,54.821496,104.42533,123.52226,179.310742,218.409199,226.37429,201.937713,128.368571,92.305827,46.436448,-34.253562,-85.09174,-165.20062,-201.252784,-247.611213,-226.068153,-129.011364,-110.541796,-133.515797,-90.463962,-36.616261,68.433384,107.572687,125.527439,103.805043,22.334631,-33.040808,6.665519,135.347162,144.61365,53.112754,12.670501,37.847173,77.315447,89.75091,44.389513,22.935498,-4.65694,-6.794403,-38.112218,-42.218141,91.742797,255.376829,277.174668,220.090005,173.627644,113.704243,89.793865,19.199993,-12.656229,-47.440958,-102.020972,-147.261027,-193.440175,-171.306247,-93.132234,-58.016848,19.290373,63.955867,69.049174,84.253347,71.700139,-44.216008,-113.913561,-149.072883,-106.19127,12.925198,94.295942,96.880453,38.465677,33.492992,130.173219,219.606811,436.746463,577.891849,611.776456,576.733718,486.493139,248.520638,142.010192,12.119007,17.099789,122.491671,107.81053,31.567982,-59.31576,-32.597279,17.634977,-1.124627,-44.68477,-37.940096,-13.071157,55.720339,60.392466,-5.605058,-42.803516,-79.616422,-82.673918,-28.324355,133.873795,210.312267,282.590864,300.850669,369.208638,400.653445,427.909108,454.711303,442.314516,324.235309,228.137269,34.008011,-18.754221,-11.468101,14.577115,55.144331,74.731033,76.841687,101.233081,123.507614,101.753997,62.559982,91.623619,236.436564,269.997675,247.750552,239.331795,249.795863,232.341768,150.154867,120.102748,128.743206,187.862526,182.494855,86.170704,37.546145,-34.726378,-81.937493,-159.259287,-118.558107,-83.004675,-60.271598,-62.147186,-65.686115,-94.876567,-197.331262,-202.521496,-76.700048,72.763988,109.894756,56.147058,-14.457408,-101.634321,-78.885784,72.834259,249.052471,306.515046,274.166828,216.702669,189.887343,234.874534,335.411588,343.768867,273.636169,227.775027,220.368576,104.409184,0.154815,-156.024574,-182.588328,-167.096059,-137.408458,-127.185445,-109.649022,-123.350662,-217.746916,-247.655866,-116.853029,14.31838,165.451729,103.631893,50.789348,-3.459959,-11.551426,-74.458587,-120.596825,-117.608553,-18.032907,22.168438,23.960337,-42.44775,-173.52452,-153.981223,-5.609914,46.173376,49.341266,-1.377136,-42.592818,-116.06921,-104.03303,-34.225151,-14.592212,26.713172,98.616433,126.977533,91.099183,33.831246,-37.981721,-45.812327,-63.415043,-55.355193,2.306778,-17.303625,-55.410533,-86.519567,-80.755527,-84.55144,-70.609099,36.012487,138.476997,166.072053,155.515589,107.28117,-50.160673,-129.818403,-200.687306,-180.717244,-94.245382,-20.152519,-50.616982,-230.876104,-270.196685,-185.699088,-150.411327,-186.108041,-172.550052,-113.424614,-44.086632,-61.965623,-141.846638,-189.565305,-223.959236,-193.361542,-148.844215,-179.354438,-174.638088,-131.517467,-135.170053,-172.058849,-167.806339,-96.314993,-34.913008,-33.823864,-42.140137,-27.34316,41.210713,66.4166,49.807466,24.650066,-19.922693,-77.064481,-113.279581,-124.736863,-106.019685,-103.157915,-97.68271,-62.361541,-126.787833,-175.746737,-208.969109,-200.80217,-143.203192,-91.269469,-0.775962,18.528267,53.214233,79.028837,56.010963,2.956121,-5.82297,-44.348894,-54.95707,1.908966,-25.610213,-112.701874,-282.850217,-310.230223,-282.576154,-267.457823,-230.980702,-178.431256,-13.83671,64.492276,31.182334,-78.396258,-104.459181,-116.231402,-96.688782,12.986096,32.22334,-4.234767,-90.023787,-154.74377,-301.176538,-326.122939,-245.011635,-188.364852,-123.80356,-115.51668,-127.058972,-119.097443,-94.977524,-110.968703,-159.846954,-168.338761,4.129428,83.697324,112.808153,80.387,23.018466,10.129988,94.112052,210.628115,404.892555,388.877803,321.800364,135.998823,57.228097,-8.125252,-1.066987,41.141076,108.871609,169.66692,237.505537,205.523358,134.93529,135.298971,151.506941,166.423321,242.213632,308.46737,305.685668,238.420776,201.095062,138.611464,131.092497,183.550944,162.028204,109.835706,19.33458,-10.956086,-75.064478,-98.557361,-53.293407,15.898097,175.14956,235.496998,201.810005,38.527265,-36.487099,-29.429322,32.770728,119.913029,103.705731,65.739378,-45.44063,-101.973817,-189.142367,-211.528252,-189.542982,-148.659695:backward
